@@ -5,14 +5,15 @@
 # This should let a user bootstrap into a talking Emacs.
 # Not intended for daily use.
 
-#  Prerequisites: espeak, libespeak libespeak-dev 
+#  Prerequisites: espeak, libespeak libespeak-dev
+# libespeak-ng-libespeak-dev libespeak-ng-dev espeak-ng-espeak
 # Downloads,  builds and runs specified version.
-
+latest=56.0
 v=$1
 
 if [ ! -n "$1" ]
 then
-  v=46.0
+  v=$latest
 fi  
 
 u="https://github.com/tvraman/emacspeak/releases/download/${v}/emacspeak-${v}.tar.bz2"
@@ -27,9 +28,9 @@ fi
 # Build it:
 cd "emacspeak-${v}"
 make config && make
-(cd servers/linux-espeak &&  make )
+(cd servers/native-espeak &&  make )
 #Run out of this directory.
 # Default to using  espeak unless DTK_PROGRAM is set.
 #
-:${DTK_PROGRAM} ? "Using ${DTK_PROGRAM}" : export DTK_PROGRAM="espeak"
+export DTK_PROGRAM="espeak"
 emacs -q -l ./lisp/emacspeak-setup.el -l $HOME/.emacs
