@@ -1,33 +1,42 @@
 ;;; amixer.el --- Control AMixer from Emacs  -*- lexical-binding: t; -*-
-;;;$Id$
-;;;Emacs front-end to AMixer
+;;
+;; Emacs front-end to AMixer
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2017, T. V. Raman<raman@cs.cornell.edu>
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman<tv.raman.tv@gmail.com>
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
 ;;{{{ introduction
 
 ;;; Commentary:
-;;; Provide an emacs front-end to amixer.
-;;;amixer is part of ALSA.
+;; Provide an emacs front-end to amixer,
+;; the sound mixer in ALSA that is used to configure the audio device.
+;; 
+;; The main entry point is command @code{emacspeak-audio-setup} bound
+;; to @kbd{C-e)}. When called for the first time, this command
+;; builds up a database of available controls on the default audio
+;; device. These control names are then available for completion in
+;; the minibuffer. Pick a desired control, e.g., "master playback
+;; volume", and this displays a prompt with the current value. Enter
+;; the new value and press <RETURN>. To reset all controls to their
+;; default values, Press @kbd{C-j}.
 
 ;;; Code:
 
@@ -35,13 +44,17 @@
 ;;{{{ required packages
 
 (require 'cl-lib)
+(require 'emacspeak-preamble)
 (cl-declaim  (optimize  (safety 0) (speed 3)))
+
 ;;}}}
-;;{{{ Customizations:
-;;; forward decl:
+;;{{{ Decls:
+
+;; forward decl:
 (defvar emacspeak-speak-messages)
+
 ;;}}}
-;;{{{ Definitions
+;;{{{ Custom:
 
 (defcustom amixer-device "default"
   "ALSA Control Device."
@@ -60,9 +73,6 @@
 (cl-defstruct amixer-control
   numid iface name setting)
 
-(declare-function amixer-control-name  "amixer.el" (amixer))
-(declare-function amixer-control-numid  "amixer.el" (amixer))
-(declare-function amixer-control-iface  "amixer.el" (amixer))
 (cl-defstruct amixer-control-setting
   type access values
   min max step
@@ -73,7 +83,7 @@
 
 (defun amixer-populate-settings (control)
   "Populate control with its settings information."
-  (cl-declare (special amixer-card amixer-device))
+  (cl-declare (special  amixer-device))
   (let ((fields nil)
         (emacspeak-speak-messages nil)
         (slots nil)
@@ -141,7 +151,7 @@
                 (line-beginning-position)
                 (line-end-position))
                ","))
-;;; only need 3 fields:
+        ;; only need 3 fields:
         (setq fields
               (list
                (nth 0 fields)
@@ -191,13 +201,15 @@
         (forward-line 1))
       (nreverse values))))
 
-;;;###autoload
 (defvar amixer-alsactl-config-file
-  nil
+  (cond
+   ((file-exists-p (expand-file-name "asound.state"
+                                     user-emacs-directory))
+    (expand-file-name "asound.state" user-emacs-directory))
+   ((file-exists-p "/var/lib/alsa/asound.state")
+    "/var/lib/alsa/asound.state"))
   "Personal sound card settings. Copied from /var/lib/alsa/asound.state
-to your ~/.emacs.d to avoid needing to run alsactl as root on first
-use."
-  )
+to  ~/.emacs.d ")
 
 (defun amixer-alsactl-setup ()
   "Set up alsactl sound state."
@@ -206,13 +218,15 @@ use."
    amixer-alsactl-config-file
    (let ((sys-alsa "/var/lib/alsa/asound.state")
          (f (expand-file-name "asound.state" user-emacs-directory)))
-     (unless (file-exists-p sys-alsa) (error "Alsa not setup correctly."))
+     (unless (file-exists-p sys-alsa)
+       (error "Alsa not setup correctly.")
+       (message "Perhaps run \"sudo alsactl store the first time.\""))
      (unless  (file-exists-p f) (copy-file sys-alsa user-emacs-directory))
      f)))
 
 ;;;###autoload
 (defun amixer-restore (&optional conf-file)
-  "Restore alsa settings."
+  "Reset Alsa."
   (cl-declare (special alsactl-program))
   (if conf-file
       (start-process
@@ -228,7 +242,7 @@ use."
 
 ;;;###autoload
 (defun amixer (&optional refresh)
-  "Interactively manipulate ALSA settings.
+  "ALSA settings.
 Interactive prefix arg refreshes cache."
   (interactive "P")
   (cl-declare (special amixer-db amixer-alsactl-config-file amixer-program))
@@ -247,8 +261,7 @@ Interactive prefix arg refreshes cache."
         (choices nil))
     (cond
      ((null control)
-      (amixer-restore  amixer-alsactl-config-file)
-      (amixer-reset-equalizer))
+      (amixer-restore  amixer-alsactl-config-file))
      (t
       (when (string=
              "ENUMERATED"
@@ -278,34 +291,9 @@ Interactive prefix arg refreshes cache."
        (amixer-control-name control)
        update)))))
 
-;;;###autoload
-(defun amixer-equalize()
-  "Set equalizer. Only affects device `equal'."
-  (interactive)
-  (cl-declare (special amixer-device))
-  (let ((amixer-device "equal")
-        (emacspeak-speak-messages nil))
-    (amixer 'refresh)
-;;; mark db dirty.
-    (setq amixer-db nil)))
-
-(defun amixer-reset-equalizer ()
-  "Reset equalizer to default values -- 66% for all 10 bands."
-  (interactive)
-  (cl-declare (special amixer-program))
-  (cl-loop
-   for  i from 1 to 10 do
-   (start-process
-    "AMixer" nil amixer-program
-    "-Dequal"
-    "cset"
-    (format "numid=%s" i)
-    "66,66"))
-  (message "Reset equalizer"))
-
 ;;;###autoload
 (defun amixer-store()
-  "Persist current amixer settings."
+  "Persist  amixer."
   (interactive)
   (cl-declare (special  amixer-alsactl-config-file alsactl-program))
   (unless amixer-alsactl-config-file (amixer-alsactl-setup))
@@ -315,14 +303,15 @@ Interactive prefix arg refreshes cache."
      "-f"amixer-alsactl-config-file
      "store")
     (emacspeak-auditory-icon 'task-done)
-    (message "Persisted amixer state.")))
+    (message "Persisted amixer state to %s."
+             amixer-alsactl-config-file)))
+
 ;;}}}
 (provide 'amixer)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
