@@ -1,40 +1,40 @@
 ;;; cd-tool.el --- Play  CDs from Emacs  -*- lexical-binding: t; -*-
-;;;$Id$
-;;;Emacs front-end to CDTool
+;;
+;; Emacs front-end to CDTool
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2017, T. V. Raman<raman@cs.cornell.edu>
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman<tv.raman.tv@gmail.com>
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
 ;;{{{ introduction
 
 ;;; Commentary:
-;;; Provide an emacs front-end to cdtool.
-;;; cdtool can be obtained as an rpm
-;;; check using rpmfind
-;;; or from its home site at
-;;;   sunsite.unc.edu /pub/Linux/apps/sound/cdrom/cli
-;;; This module also provides the ability to play or save
-;;; clips from a CD if you have cdda2wav installed.
-;;; cdda2wav is a cd to wav converter.
-;;;
+;; Provide an emacs front-end to cdtool.
+;; cdtool can be obtained as an rpm
+;; check using rpmfind
+;; or from its home site at
+;;   sunsite.unc.edu /pub/Linux/apps/sound/cdrom/cli
+;; This module also provides the ability to play or save
+;; clips from a CD if you have cdda2wav installed.
+;; cdda2wav is a cd to wav converter.
+;; 
 ;;; Code:
 ;;}}}
 ;;{{{ required packages
@@ -48,7 +48,7 @@
 ;;; Code:
 
 (defcustom cd-tool-start-command "cdstart"
-  "*Name of cdstart command; most likely either \"cdstart\" or \"cdplay\"."
+  "Name of cdstart command; most likely either \"cdstart\" or \"cdplay\"."
   :options '("cdstart" "cdplay")
   :group 'cd-tool
   :type 'string)
@@ -59,10 +59,6 @@
 ;;;###autoload
 (defun cd-tool ()
   "Front-end to CDTool.
-Bind this function to a convenient key-
-Emacspeak users automatically have
-this bound to <DEL> in the emacspeak keymap.
-
 Key     Action
 ---     ------
 
@@ -83,26 +79,26 @@ cap C   Save clip to disk
     (while (null command)
       (setq command
             (cl-case (read-char "CD Action? ")
-                  (?+ (concat cd-tool-start-command " +"))
-                  (?> (concat cd-tool-start-command " +"))
-                  (?. (concat cd-tool-start-command " +"))
-                  (?- (concat cd-tool-start-command " -"))
-                  (?< (concat cd-tool-start-command " -"))
-                  (?, (concat cd-tool-start-command " -"))
-                  (?t (format (concat cd-tool-start-command " %s")
-                              (read-from-minibuffer "Enter track number: ")))
-                  (?p cd-tool-start-command)
-                  (?s "cdstop")
-                  (?= "cdshuffle")
-                  (?\ "cdpause")
-                  (?r cd-tool-start-command)
-                  (?i "cdir ")
-                  (?e "cdeject")
-                  (?c (cd-tool-get-clip-command))
-                  (?C (cd-tool-get-clip-command 'save))
-                  (otherwise (message cd-tool-message)
-                             (sit-for 5)
-                             nil))))
+              (?+ (concat cd-tool-start-command " +"))
+              (?> (concat cd-tool-start-command " +"))
+              (?. (concat cd-tool-start-command " +"))
+              (?- (concat cd-tool-start-command " -"))
+              (?< (concat cd-tool-start-command " -"))
+              (?, (concat cd-tool-start-command " -"))
+              (?t (format (concat cd-tool-start-command " %s")
+                          (read-from-minibuffer "Enter track number: ")))
+              (?p cd-tool-start-command)
+              (?s "cdstop")
+              (?= "cdshuffle")
+              (?\ "cdpause")
+              (?r cd-tool-start-command)
+              (?i "cdir ")
+              (?e "cdeject")
+              (?c (cd-tool-get-clip-command))
+              (?C (cd-tool-get-clip-command 'save))
+              (otherwise (message cd-tool-message)
+                         (sit-for 5)
+                         nil))))
     (shell-command
      (format "%s &"
              command))))
@@ -125,7 +121,7 @@ cap C   Save clip to disk
 (defun cd-tool-get-clip-command (&optional save)
   "Query for and return an appropriate CD clip command"
   (cl-declare (special cd-tool-clipper cd-tool-clip-track-history
-                    cd-tool-clip-skip-history cd-tool-clip-duration-history))
+                       cd-tool-clip-skip-history cd-tool-clip-duration-history))
   (let ((filename (when save
                     (read-file-name
                      "File name to save clip to: ")))
@@ -160,9 +156,8 @@ cap C   Save clip to disk
 (provide 'cd-tool)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
