@@ -1,47 +1,47 @@
 ;;; dom-addons.el --- dom.el addons  -*- lexical-binding: t; -*-
-;;; $Id: emacspeak-<skeleton>.el 4797 2007-07-16 23:31:22Z tv.raman.tv $
-;;; $Author: tv.raman.tv $
-;;; Description:  Speech-enable <SKELETON> An Emacs Interface to <skeleton>
-;;; Keywords: Emacspeak,  Audio Desktop <skeleton>
+;; $Id: dom-addons.el 4797 2007-07-16 23:31:22Z tv.raman.tv $
+;; $Author: tv.raman.tv $
+;; Description:  Emacspeak dom addons
+;; Keywords: Emacspeak,  Audio Desktop DOM Addons
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
-;;;  $Revision: 4532 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2007, 2011, T. V. Raman
-;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITN<SKELETON> FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2007, 2011, T. V. Raman
+;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITN<SKELETON> FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  introduction
 
 ;;; Commentary:
-;;; Useful additional functions for dom.el
+;; Useful additional functions for dom.el
 ;;; Code:
 
 ;;}}}
@@ -50,7 +50,7 @@
 (require 'cl-lib)
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'dom)
-
+(require 'g-utils)
 ;;}}}
 ;;{{{ Additional helpers:
 (defun dom-alternate-links (dom)
@@ -81,7 +81,7 @@ Added element goes inside the HTML head if any."
     dom))
 
 ;;}}}
-;;{{{  Filterring Inspired by dom.el:
+;;{{{  Filtering Inspired by dom.el:
 
 (defun dom-by-tag-list (dom tag-list)
   "Return elements in DOM that is of type appearing in tag-list.
@@ -146,13 +146,34 @@ ATTRIBUTE would typically be `class', `id' or the like."
   "Return elements in DOM that have a itemprop name that matches regexp MATCH."
   (dom-elements-by-matchlist dom 'itemprop match-list))
 
+;;}}}
+;;{{{DOM From URL:
+(defun dom-from-url (url)
+  "Return DOM for HTML content at URL."
+  (cl-declare (special g-curl-program g-curl-common-options))
+  (g-using-scratch
+   (shell-command
+    (format "%s %s '%s'"
+            g-curl-program g-curl-common-options url)
+    (current-buffer))
+   (goto-char (point-min))
+   (xml-remove-comments (point-min) (point-max))
+   (libxml-parse-html-region (point-min) (point-max))))
+
+;;}}}
+;;{{{dom-node-as-text
+(defsubst dom-node-as-text (node)
+  "Return all the text bits in the current node and some specific
+children, e.g. `a', concatenated."
+  (with-temp-buffer (shr-insert-document node)
+                    (buffer-substring-no-properties (point-min) (point-max))))
+
 ;;}}}
 (provide 'dom-addons)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
