@@ -1,51 +1,51 @@
 ;;; emacspeak-2048.el --- Speech-enable 2048 Game -*- lexical-binding: t; -*-
-;;; $Id: emacspeak-2048.el 4797 2007-07-16 23:31:22Z tv.raman.tv $
-;;; $Author: tv.raman.tv $
-;;; Description:  Speech-enable 2048 An Emacs Interface to 2048
-;;; Keywords: Emacspeak,  Audio Desktop 2048
+;; $Id: emacspeak-2048.el 4797 2007-07-16 23:31:22Z tv.raman.tv $
+;; $Author: tv.raman.tv $
+;; Description:  Speech-enable 2048 An Emacs Interface to 2048
+;; Keywords: Emacspeak,  Audio Desktop 2048
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
-;;;  $Revision: 4532 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman
-;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITN2048 FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITN2048 FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  introduction
 ;;; Commentary:
-;;; Speech-enable 2048 Game
+;; Speech-enable 2048 Game
 
 ;;; Code:
 
 ;;; Commentary:
-;;; 2048 ==
+;; 2048 ==
 
 ;;}}}
 ;;{{{  Required modules
@@ -68,7 +68,7 @@
   "Push current game state on stack."
   (interactive)
   (cl-declare (special emacspeak-2048-game-stack
-                    *2048-board* *2048-score* *2048-rows* *2048-columns*))
+                       *2048-board* *2048-score* *2048-rows* *2048-columns*))
   (push
    (make-emacspeak-2048-game-state
     :board (copy-sequence *2048-board*)
@@ -83,7 +83,7 @@
   "Reset state from stack."
   (interactive)
   (cl-declare (special emacspeak-2048-game-stack
-                    *2048-board* *2048-score* *2048-rows* *2048-columns*))
+                       *2048-board* *2048-score* *2048-rows* *2048-columns*))
   (cond
    ((null emacspeak-2048-game-stack) (error "No saved  states."))
    (t
@@ -120,7 +120,7 @@
 
 (defvar emacspeak-2048-game-file
   (expand-file-name "2048-game-stack"
-                    emacspeak-resource-directory)
+                    emacspeak-user-directory)
   "File where we export/import game state.")
 
 (defun emacspeak-2048-export (&optional prompt)
@@ -259,10 +259,10 @@ Optional interactive prefix arg prompts for a filename."
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
-     "Provide spoken feedback"
+     "Speak"
      (when (ems-interactive-p)
        (cond
-        ((some #'identity *2048-combines-this-move*)
+        ((cl-some #'identity *2048-combines-this-move*)
          (emacspeak-auditory-icon 'item))
         (t (emacspeak-auditory-icon 'close-object)))
        (emacspeak-2048-speak-board)
@@ -281,6 +281,7 @@ Optional interactive prefix arg prompts for a filename."
 
 ;;}}}
 ;;{{{ Setup
+(declare-function emacspeak-pronounce-define-local-pronunciation "emacspeak-pronounce" (word pron))
 
 (defun emacspeak-2048-setup ()
   "Emacspeak setup for 2048."
@@ -301,7 +302,7 @@ Optional interactive prefix arg prompts for a filename."
   (define-key 2048-mode-map "/" 'emacspeak-2048-speak-transposed-board)
   (define-key 2048-mode-map  "="'emacspeak-2048-score)
   (define-key 2048-mode-map  "r"'emacspeak-2048-randomize-game)
-  (define-key 2048-mode-map  (kbd "C-SPC") 'emacspeak-2048-score)
+  (define-key 2048-mode-map  (ems-kbd "C-SPC") 'emacspeak-2048-score)
   (define-key 2048-mode-map "g" '2048-game)
   (dtk-set-rate
    (+ dtk-speech-rate-base
@@ -312,24 +313,6 @@ Optional interactive prefix arg prompts for a filename."
   (emacspeak-2048-speak-board))
 (cl-declaim (special-display-p 2048-mode-hook))
 (add-hook '2048-mode-hook 'emacspeak-2048-setup)
-;;}}}
-;;{{{ Counting moves:
-
-(defvar emacspeak-2048-move-count 0
-  "Number of moves in this game.")
-(cl-loop
- for f in
- '(2048-up 2048-down 2048-left 2048-right)
- do
- (eval
-  `(defadvice ,f (after  count-moves pre act comp)
-     "Count this move."
-     (cl-incf emacspeak-2048-move-count))))
-(defadvice 2048-game (before count-moves pre act comp)
-  "Reset move count and board size."
-  (setq emacspeak-2048-move-count 0)
-  (emacspeak-2048-board-reset))
-
 ;;}}}
 ;;{{{ Randomize game
 
@@ -350,9 +333,8 @@ Optional interactive prefix arg prompts for a filename."
 (provide 'emacspeak-2048)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
