@@ -1,40 +1,40 @@
 ;;; emacspeak-amark.el --- BookMarks For Audio Content  -*- lexical-binding: t; -*-
-;;; $Id: acss-structure.el 5798 2008-08-22 17:35:01Z tv.raman.tv $
-;;; $Author: tv.raman.tv $
-;;; Description: Bookmarks for audio content like mp3
-;;; Keywords:emacspeak, audio interface to emacs MP3
+;; $Id: emacspeak-amarks.el 5798 2008-08-22 17:35:01Z tv.raman.tv $
+;; $Author: tv.raman.tv $
+;; Description: Bookmarks for audio content like mp3
+;; Keywords:emacspeak, audio interface to emacs MP3
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
-;;;  $Revision: 4532 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2017, T. V. Raman 
-;;; Copyright (c) 1996 by T. V. Raman
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman 
+;; Copyright (c) 1996 by T. V. Raman
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
 
@@ -42,12 +42,12 @@
 
 ;;; Commentary:
 
-;;; Structure emacspeak-amark holds a bookmark into an mp3 file
-;;; path: fully qualified pathname  to file being marked
-;;; name: Bookmark tag
-;;; Position: time offset from start 
+;; Structure emacspeak-amark holds a bookmark into an mp3 file
+;; path: fully qualified pathname  to file being marked
+;; name: Bookmark tag
+;; Position: time offset from start 
 
-;;;; This library will be used from emacspeak-m-player,
+;; ; This library will be used from emacspeak-m-player,
 ;;emacspeak-mplayer and friends to set and jump to bookmarks.
 ;;; Code:
 ;;}}}
@@ -67,11 +67,8 @@
 ;;}}}
 ;;{{{ AMark List:
 
-(defvar emacspeak-amark-list nil
-  "List of AMarks. 
-Automatically becomes buffer-local when set.")
-
-(make-variable-buffer-local 'emacspeak-amark-list)
+(defvar-local emacspeak-amark-list nil
+  "List of buffer-local AMarks. ")
 
 ;;}}}
 ;;{{{ AMark Functions:
@@ -105,9 +102,9 @@ given name, it is updated with path and position."
 
 (defvar emacspeak-amark-file ".amarks.el"
   "Name of file used to save AMarks.")
-
+;;;###autoload
 (defun emacspeak-amark-save ()
-  "Save buffer-local AMarks in current directory."
+  "Save buffer-local AMarks in  currently playing directory."
   (interactive)
   (cl-declare (special  emacspeak-amark-file))
   (let ((l  emacspeak-amark-list)
@@ -118,23 +115,21 @@ given name, it is updated with path and position."
       (erase-buffer)
       (prin1  l (current-buffer)) 
       (save-buffer)
+      (message "Saved AMarks in %s" (buffer-file-name))
       (kill-buffer buff)
-      (message "Saved AMarks in %s" emacspeak-amark-file)
       (emacspeak-auditory-icon 'save-object))))
-
-(defun emacspeak-amark-load ()
-  "Locate AMarks file from current directory, and load it."
-  (interactive)
+;;;###autoload
+(defun emacspeak-amark-load (&optional dir)
+  "Locate AMarks file from `dir' current  directory is default, and load it."
   (cl-declare (special emacspeak-amark-list
-                    emacspeak-amark-file))
+                       emacspeak-amark-file))
+  (or dir (setq dir default-directory))
   (let ((buff nil)
         (l nil)
         (where
-         (locate-dominating-file default-directory emacspeak-amark-file)))
+         (locate-dominating-file dir emacspeak-amark-file)))
     (cond
-     ((null where)
-      (when (called-interactively-p 'interactive)
-        (message "No AMarks found.")))
+     ((null where))
      (t (setq buff
               (find-file-noselect (expand-file-name emacspeak-amark-file where)))
         (save-current-buffer
@@ -142,18 +137,14 @@ given name, it is updated with path and position."
           (goto-char (point-min))
           (setq l (read buff))
           (kill-buffer buff))
-        (setq emacspeak-amark-list l)
-        (when (called-interactively-p 'interactive)
-          (emacspeak-auditory-icon 'open-object)
-          (message "Loaded AMarks from %s" where))))))
+        (setq emacspeak-amark-list l)))))
 
 ;;}}}
 (provide  'emacspeak-amark)
 ;;{{{  emacs local variables
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
