@@ -1,48 +1,48 @@
 ;;; emacspeak-analog.el --- Speech-enable analog -- a log viewer  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $
-;;; Description:  Emacspeak front-end for ANALOG log analyzer
-;;; Keywords: Emacspeak, analog
+;;
+;; $Author: tv.raman.tv $
+;; Description:  Emacspeak front-end for ANALOG log analyzer
+;; Keywords: Emacspeak, analog
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-09-01 15:12:15 -0700 (Sat, 01 Sep 2007) $ |
-;;;  $Revision: 4150 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4150 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2017, T. V. Raman
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 
 ;;{{{  Introduction:
 ;;; Commentary:
 
-;;; Speech-enables package analog --convenient log analyzer 
+;; Speech-enables package analog --convenient log analyzer 
 
 ;;}}}
 ;;{{{ required modules
@@ -60,19 +60,19 @@
 
 ;;{{{ advice interactive commands
 (defadvice analog (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-analog-update-edit-keys)
     (emacspeak-speak-mode-line)))
 
 (defadvice analog-quit (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 (defadvice analog-bury-buffer (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-mode-line)))
@@ -87,7 +87,7 @@
          do
          (eval
           `(defadvice ,command (after emacspeak pre act comp)
-             "Provide auditory feedback."
+             "speak."
              (when (ems-interactive-p)
                (emacspeak-speak-line)
                (emacspeak-auditory-icon 'select-object)))))
@@ -101,10 +101,10 @@
 ;;}}}
 ;;{{{ field navigation
 
-;;; You can add a fields property that holds a list of field start
-;;; positions 
-;;; in analog-entries-list
-;;; emacspeak will use this to navigate using the arrow keys.
+;; You can add a fields property that holds a list of field start
+;; positions 
+;; in analog-entries-list
+;; emacspeak will use this to navigate using the arrow keys.
 
 (defun emacspeak-analog-get-field-spec ()
   "Returns field specification if one defined for current entry.
@@ -129,7 +129,7 @@ Speak field or char moved to."
      (fields (emacspeak-analog-next-field fields)
              (emacspeak-analog-speak-field fields)
              (emacspeak-auditory-icon 'large-movement))
-     (t (call-interactively 'emacspeak-forward-char)))))
+     (t (call-interactively 'forward-char)))))
 
 (defun emacspeak-analog-backward-field-or-char ()
   "Move back to next field if field specification is available.
@@ -141,7 +141,7 @@ Speak field or char moved to."
      (fields (emacspeak-analog-previous-field fields)
              (emacspeak-analog-speak-field fields)
              (emacspeak-auditory-icon 'large-movement))
-     (t (call-interactively 'emacspeak-backward-char)))))
+     (t (call-interactively 'backward-char)))))
 
 (defun emacspeak-analog-speak-field (fields)
   "Speak field containing point."
@@ -214,7 +214,7 @@ Speak field or char moved to."
   (let ((fields (emacspeak-analog-get-field-spec)))
     (cond (fields
            (emacspeak-auditory-icon 'select-object)
-           (next-line -1)
+           (forward-line -1)
            (emacspeak-analog-speak-field fields))
           (t (call-interactively 'previous-line)))))
 
@@ -224,7 +224,7 @@ Speak field or char moved to."
   (let ((fields (emacspeak-analog-get-field-spec)))
     (cond (fields
            (emacspeak-auditory-icon 'select-object)
-           (next-line 1)
+           (forward-line 1)
            (emacspeak-analog-speak-field fields))
           (t (call-interactively 'next-line)))))
 
@@ -233,33 +233,17 @@ Speak field or char moved to."
 (when (boundp 'analog-mode-map)
   (cl-declaim (special analog-mode-map))
   (define-key analog-mode-map '[left]
-    'emacspeak-analog-backward-field-or-char)
+              'emacspeak-analog-backward-field-or-char)
   (define-key analog-mode-map '[right] 'emacspeak-analog-forward-field-or-char)
   (define-key analog-mode-map '[up] 'emacspeak-analog-previous-line)
-  (define-key analog-mode-map '[down] 'emacspeak-analog-next-line)
-  )
-
-(defun emacspeak-analog-update-edit-keys ()
-  "We define keys that invoke editing commands to invoke
-emacspeak-speak-and-skip-extent-upto-char "
-  (cl-declare (special analog-mode-map))
-  (mapcar 
-   #'(lambda (cmd)
-       (cl-loop for k in
-                (where-is-internal cmd)
-                do
-                (define-key analog-mode-map k
-                  'emacspeak-speak-and-skip-extent-upto-this-char)))
-   (list 'emacspeak-self-insert-command
-         'completion-separator-self-insert-command)))
+  (define-key analog-mode-map '[down] 'emacspeak-analog-next-line))
 
 ;;}}}
 (provide 'emacspeak-analog)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
