@@ -1,42 +1,42 @@
 ;;; emacspeak-arc.el --- Speech enable archive-mode -- a  Emacs interface to zip and friends  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $ 
-;;; Description: Auditory interface to archive mode
-;;; Keywords: Emacspeak, Speak, Spoken Output, archive
+;;
+;; $Author: tv.raman.tv $ 
+;; Description: Auditory interface to archive mode
+;; Keywords: Emacspeak, Speak, Spoken Output, archive
 ;;{{{  LCD Archive entry: 
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
-;;; A speech interface to Emacs |
-;;; $Date: 2008-06-21 10:50:41 -0700 (Sat, 21 Jun 2008) $ |
-;;;  $Revision: 4532 $ | 
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com 
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ | 
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2017, T. V. Raman
-;;; All Rights Reserved. 
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (c) 1995 -- 2022, T. V. Raman
+;; All Rights Reserved. 
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  Required modules
 (cl-declaim  (optimize  (safety 0) (speed 3)))
@@ -45,8 +45,8 @@
 ;;}}}
 ;;{{{  Introduction 
 ;;; Commentary:
-;;;Auditory interface to archive mode
-;;; This lets Emacs manipulate package files such as .zip and .jar files.
+;; Auditory interface to archive mode
+;; This lets Emacs manipulate package files such as .zip and .jar files.
 ;;; Code:
 ;;}}}
 ;;{{{ Helpers
@@ -67,52 +67,52 @@
 ;;{{{ Advice
 
 (defadvice archive-mark (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'mark-object)
     (emacspeak-archive-speak-line)))
 
 (defadvice archive-next-line (after emacspeak pre act comp)
-  "Provide spoken feedback"
+  "Speak"
   (when (ems-interactive-p)
     (emacspeak-archive-speak-line)))
 
 (defadvice archive-previous-line (after emacspeak pre act comp)
-  "Provide spoken feedback"
+  "Speak"
   (when (ems-interactive-p)
     (emacspeak-archive-speak-line)))
 
 (defadvice archive-flag-deleted (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'delete-object)
     (emacspeak-archive-speak-line)))
 
 (defadvice archive-unflag (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'yank-object)
     (emacspeak-archive-speak-line)))
 (defadvice archive-unflag-backwards (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'yank-object)
     (emacspeak-archive-speak-line)))
 
 (defadvice archive-extract (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice archive-extract-other-window (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice archive-view (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
@@ -132,7 +132,7 @@ first initializing it if necessary."
           (fields nil))
       (save-excursion
         (goto-char (point-min))
-        (setq line (ems-this-line)))
+        (setq line (ems--this-line)))
       (setq fields (split-string line))
       (cl-loop for f in fields 
                and i from 0
@@ -162,7 +162,7 @@ first initializing it if necessary."
      (t
       (message "File: %s"
                (nth  (emacspeak-arc-get-field-index "File")
-                     (split-string (ems-this-line))))))))
+                     (split-string (ems--this-line))))))))
 
 (defun emacspeak-arc-speak-file-size ()
   "Speak the size of the file on current line"
@@ -176,7 +176,7 @@ first initializing it if necessary."
      (t
       (message "Size: %s"
                (nth  (emacspeak-arc-get-field-index "Length")
-                     (split-string (ems-this-line))))))))
+                     (split-string (ems--this-line))))))))
 
 (defun emacspeak-arc-speak-file-modification-time ()
   "Speak modification time of the file on current line"
@@ -188,7 +188,7 @@ first initializing it if necessary."
      ((null entry)
       (message "No file on this line"))
      (t
-      (let* ((fields (split-string (ems-this-line)))
+      (let* ((fields (split-string (ems--this-line)))
              (date (nth  (emacspeak-arc-get-field-index "Date")
                          fields))
              (time (nth  (emacspeak-arc-get-field-index "Time")
@@ -208,7 +208,7 @@ first initializing it if necessary."
       (message "No file on this line"))
      (t
       (setq mode
-            (archive-int-to-mode
+            (file-modes-number-to-symbolic
              (aref entry 3)))
       (message  "Permissions  %s "
                 mode)))))
@@ -219,18 +219,17 @@ first initializing it if necessary."
   (define-key archive-mode-map "c" 'emacspeak-arc-speak-file-modification-time)
   (define-key archive-mode-map "z" 'emacspeak-arc-speak-file-size)
   (define-key archive-mode-map "/"
-    'emacspeak-arc-speak-file-permissions)
+              'emacspeak-arc-speak-file-permissions)
   )
 
 (cl-eval-when (load)
-           (emacspeak-arc-setup-keys))
+  (emacspeak-arc-setup-keys))
 ;;}}}
 (provide 'emacspeak-arc)
 ;;{{{ end of file 
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end: 
+;; local variables:
+;; folded-file: t
+;; end: 
 
 ;;}}}
