@@ -1,55 +1,83 @@
 ;;; emacspeak-bookshare.el --- Speech-enabled  BOOKSHARE client  -*- lexical-binding: t; -*-
-;;; $Id: emacspeak-bookshare.el 4797 2007-07-16 23:31:22Z tv.raman.tv $
-;;; $Author: tv.raman.tv $
-;;; Description:  Speech-enable BOOKSHARE An Emacs Interface to bookshare
-;;; Keywords: Emacspeak,  Audio Desktop bookshare
+;; $Id: emacspeak-bookshare.el 4797 2007-07-16 23:31:22Z tv.raman.tv $
+;; $Author: tv.raman.tv $
+;; Description:  Speech-enable BOOKSHARE An Emacs Interface to bookshare
+;; Keywords: Emacspeak,  Audio Desktop bookshare
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
-;;;  $Revision: 4532 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2017, T. V. Raman
-;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNBOOKSHARE FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNBOOKSHARE FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  introduction
 
 ;;; Commentary:
-;;; BOOKSHARE == http://www.bookshare.org
-;;; provides book access to print-disabled users.
-;;; It provides a simple Web  API http://developer.bookshare.org
-;;; This module implements an Emacspeak Bookshare client.
-;;; For now, users will need to get their own API key
-;;; This version needs Emacs with libxml2 support
-;;; You need Emacs 24.1 or higher.
-
+;; BOOKSHARE == http://www.bookshare.org
+;; provides book access to print-disabled users.
+;; It provides a simple Web  API http://developer.bookshare.org
+;; This module implements an Emacspeak Bookshare client.
+;; @subsection  requirements
+;; @itemize
+;; @item You need to get your own API key
+;; @item You need Emacs built with libxml2 support
+;; @end itemize
+;; 
+;; @subsection Usage
+;; The main entry point is command @code{emacspeak-bookshare} bound to @kbd{C-e C-b}.
+;; This creates a special @emph{Bookshare Interaction} buffer that is
+;; placed in @emph{emacspeak-bookshare-mode}.
+;; Se the help for that mode on detailed usage instructions and key-bindings.
+;; 
+;; @subsection Sample Interaction
+;; 
+;; Assuming you have correctly setup your API key:
+;; @itemize
+;; @item Customize group @code{emacspeak-bookshare} by pressing @kbd{C-h G}.
+;; @item  Press @kbd{C-e C-b} to open or switch to the Bookshare buffer.
+;; @item Perform a search @kbd{a} or @kbd{t} for author or title search.
+;; @item You will be prompted for your Bookshare password if this is
+;; the first time.
+;; @item The password will be saved to your configured
+;; @code{auth-source} --- usually @code{~/.authinfo.gpg}.
+;; You can also use @code{password-store[.]}
+;; @item The results of the search appear in the Bookshare buffer.
+;; Audio formatting and auditory icons convey if  a result is already available locally.
+;; @item If not available locally, press @kbd{D} to download the content.
+;; @item Press @kbd{U} to unpack the downloaded content.
+;; @item Press @kbd{e} to  display the entire book.
+;; @item Press @kbd{c} to display the table of contents.
+;; @item Now, use all of EWW  @xref{emacspeak-eww} extensions  and profit!
+;; @end itemize
 ;;; Code:
 ;;}}}
 ;;{{{  Required modules
@@ -57,15 +85,15 @@
 (require 'cl-lib)
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
-(require 'dired)
-(require 'eww   "eww" 'noerror)
-(require 'browse-url)
-(require 'emacspeak-we)
-(require 'emacspeak-webutils)
-(require 'emacspeak-xslt)
-(require 'dom) ; Cloned from Emacs 25
+(eval-when-compile (require 'derived)
+                   (require 'g-utils))
+(require 'dom)
 (require 'xml)
-(require 'derived)
+(declare-function auth-source-search "auth-source" (&rest rest))
+(declare-function dired-get-filename "dired" (&optional localp
+                                                        no-error-if-not-filep))
+(declare-function emacspeak-xslt-get "emacspeak-xslt" (arg1))
+(declare-function emacspeak-xslt-params-from-xpath "emacspeak-bookshare" t)
 ;;}}}
 ;;{{{ Customizations
 
@@ -78,19 +106,16 @@
 See http://developer.bookshare.org/docs for details on how to get
   an API key. "
   :type
-  '(choice :tag "Key: "
+  '(choice :tag "Key"
            (const :tag "Unspecified" nil)
-           (string :tag "API Key: "))
+           (string :tag "API Key"))
   :group 'emacspeak-bookshare)
 
-(defcustom emacspeak-bookshare-user-id nil
-  "Bookshare user Id."
-  :type '(choice :tag "Bookshare User id"
-                 (const :tag "None" nil)
-                 (string :tag "Email"))
-  :group 'emacspeak-bookshare)
+(defvar emacspeak-bookshare-user-id nil
+  "Bookshare user Id.")
 
-(defcustom emacspeak-bookshare-directory (expand-file-name "~/books/book-share")
+(defcustom emacspeak-bookshare-directory
+  (eval-when-compile (expand-file-name "~/books/book-share"))
   "Customize this to the root of where books are organized."
   :type 'directory
   :group 'emacspeak-bookshare)
@@ -98,38 +123,16 @@ See http://developer.bookshare.org/docs for details on how to get
 (defvar emacspeak-bookshare-downloads-directory
   (expand-file-name "downloads/" emacspeak-bookshare-directory)
   "Directory where archives are saved on download.")
-;;;###autoload
-(defcustom emacspeak-bookshare-browser-function
-  'browse-url-w3
+
+(defvar emacspeak-bookshare-browser-function
+  'eww-browse-url
   "Function to display Bookshare Book content in a WWW browser.
 This is used by the various Bookshare view commands to display
-  content from Daisy books."
-  :type '(choice
-          (function-item :tag "Emacs W3" :value  browse-url-w3)
-          (function-item :tag "Emacs EWW" :value  eww-browse-url)
-          (function-item :tag "Mozilla" :value  browse-url-mozilla)
-          (function-item :tag "Firefox" :value browse-url-firefox)
-          (function-item :tag "Chromium" :value browse-url-chromium)
-          (function-item :tag "Text browser in an Emacs window"
-                         :value browse-url-text-emacs)
-          (function-item :tag "Default Mac OS X browser"
-                         :value browse-url-default-macosx-browser)
-          (function :tag "Your own function"))
-  :version "37"
-  :group 'emacspeak-bookshare)
+  content from Bookshare books.")
 
 ;;}}}
 ;;{{{ Variables:
 
-(defvar emacspeak-bookshare-curl-program (executable-find "curl")
-  "Curl executable.")
-
-(defvar emacspeak-bookshare-curl-common-options
-  " --insecure --location "
-  "Common Curl options for Bookshare. Includes --insecure as per
-Bookshare docs."
-  )
-
 (defvar emacspeak-bookshare-api-base
   "https://api.bookshare.org"
   "Base end-point for Bookshare API  access.")
@@ -150,36 +153,56 @@ Bookshare docs."
 
 (defvar emacspeak-bookshare-md5-cached-token nil
   "Cache MD5 token for future use.")
-(defvar emacspeak-bookshare-password-cache nil
-  "Cache user password for this session.")
 
 (defun emacspeak-bookshare-user-password ()
   "User password.
-Memoize token, and return token encoded using md5, and packaged
-with X-password HTTP header for use with Curl."
-  (cl-declare (special emacspeak-bookshare-md5-cached-token
-                    emacspeak-bookshare-password-cache))
-  (setq emacspeak-bookshare-password-cache
-        (or  emacspeak-bookshare-password-cache
-             (read-passwd
-              (format "Bookshare password for %s: "
-                      emacspeak-bookshare-user-id))))
-  (setq emacspeak-bookshare-md5-cached-token
-        (md5 emacspeak-bookshare-password-cache))
+Get user and secret from auth-sources, and memoize the user and
+the MD5-encoded secret."
+  (cl-declare (special emacspeak-bookshare-user-id
+                       emacspeak-bookshare-md5-cached-token))
+  (unless emacspeak-bookshare-md5-cached-token
+    (let ((auth-info (emacspeak-bookshare-get-auth-info)))
+      (setq emacspeak-bookshare-user-id (car auth-info))
+      (setq emacspeak-bookshare-md5-cached-token (md5 (cdr auth-info)))))
   (format "-H 'X-password: %s'" emacspeak-bookshare-md5-cached-token))
 
+(defun emacspeak-bookshare-get-auth-info()
+  "Get the email and password for BookShare if it already exists
+in `auth-sources'. If not present, ask for email and password,
+and create an entry in the `auth-sources'.
+
+Returns a cons cell where the car is email, and the cdr is password."
+  (let* ((auth-source-creation-prompts
+          '((user . "Your BookShare.org e-mail: ")
+            (secret . "Your BookShare.org password: ")))
+         (found
+          (nth 0
+               (auth-source-search
+                :max 1
+                :host "api.bookshare.org"
+                :port 'https
+                :create t
+                :require '(:user :secret)))))
+    (when found
+      (let ((user (plist-get found :user))
+            (secret (plist-get found :secret))
+            (save-function (plist-get found :save-function)))
+        (while (functionp secret) (setq secret (funcall secret)))
+        (when (functionp save-function) (funcall save-function))
+        (cons user secret)))))
+
 (defun emacspeak-bookshare-rest-endpoint (operation operand &optional noauth)
   "Return  URL  end point for specified operation.
 Optional argument `noauth' says no user auth needed."
   (cl-assert emacspeak-bookshare-api-key nil "API key not set.")
-  (format "%s/%s/%s/%s?api_key=%s"
-          emacspeak-bookshare-api-base
-          operation
-          operand
-          (if noauth
-              ""
-            (format "for/%s" emacspeak-bookshare-user-id))
-          emacspeak-bookshare-api-key))
+  (unless (or  noauth  emacspeak-bookshare-user-id)
+    ;;  initialize user-id
+    (emacspeak-bookshare-user-password))
+  (url-encode-url
+   (format "%s/%s/%s/%s?api_key=%s"
+           emacspeak-bookshare-api-base operation operand
+           (if noauth "" (format "for/%s" emacspeak-bookshare-user-id))
+           emacspeak-bookshare-api-key)))
 
 (defun emacspeak-bookshare-page-rest-endpoint ()
   "Generate REST endpoint for the next page of results."
@@ -224,24 +247,10 @@ Argument id specifies content. Argument fmt = 0 for Braille, 1
           (format "for/%s" emacspeak-bookshare-user-id)
           emacspeak-bookshare-api-key))
 
-(defvar emacspeak-bookshare-scratch-buffer " *Bookshare Scratch* "
-  "Scratch buffer for Bookshare operations.")
-
-(defmacro emacspeak-bookshare-using-scratch(&rest body)
-  "Evaluate forms in a  ready to use temporary buffer."
-  `(let ((buffer (get-buffer-create emacspeak-bookshare-scratch-buffer))
-         (default-process-coding-system (cons 'utf-8 'utf-8))
-         (buffer-undo-list t))
-     (save-current-buffer
-       (set-buffer buffer)
-       (kill-all-local-variables)
-       (erase-buffer)
-       (progn ,@body))))
-
 (defun emacspeak-bookshare-get-result (command)
   "Run command and return its output."
   (cl-declare (special shell-file-name shell-command-switch))
-  (emacspeak-bookshare-using-scratch
+  (g-using-scratch
    (call-process shell-file-name nil t
                  nil shell-command-switch
                  command)
@@ -250,6 +259,10 @@ Argument id specifies content. Argument fmt = 0 for Braille, 1
 
 (defvar emacspeak-bookshare-last-action-uri nil
   "Cache last API call URI.")
+(defvar emacspeak-bookshare-curl-common-options
+  " --insecure --location "
+  "Common Curl options for Bookshare. Includes --insecure as per
+Bookshare docs.")
 
 (defun emacspeak-bookshare-api-call (operation operand &optional no-auth)
   "Make a Bookshare API  call and get the result.
@@ -260,7 +273,7 @@ Optional argument 'no-auth says we dont need a user auth."
   (emacspeak-bookshare-get-result
    (format
     "%s %s %s  %s 2>/dev/null"
-    emacspeak-bookshare-curl-program
+    emacspeak-curl-program
     emacspeak-bookshare-curl-common-options
     (if no-auth "" (emacspeak-bookshare-user-password))
     emacspeak-bookshare-last-action-uri)))
@@ -273,7 +286,7 @@ Optional argument 'no-auth says we dont need a user auth."
         (emacspeak-bookshare-page-rest-endpoint))
   (emacspeak-bookshare-get-result
    (format "%s %s %s  %s 2>/dev/null"
-           emacspeak-bookshare-curl-program
+           emacspeak-curl-program
            emacspeak-bookshare-curl-common-options
            (emacspeak-bookshare-user-password)
            emacspeak-bookshare-last-action-uri)))
@@ -283,7 +296,7 @@ Optional argument 'no-auth says we dont need a user auth."
   (cl-declare (special emacspeak-bookshare-downloads-directory))
   (expand-file-name
    (replace-regexp-in-string
-    "[ _&\'\":()\;]+" "-"
+    "[ _&'\":();]+" "-"
     (format "%s-%s%s.zip"
             author title
             (if  fmt
@@ -295,7 +308,7 @@ Optional argument 'no-auth says we dont need a user auth."
   (cl-declare (special emacspeak-bookshare-directory))
   (expand-file-name
    (replace-regexp-in-string
-    "[ _&\'\":()\;]+" "-"
+    "[ _&'\":();]+" "-"
     (format "%s/%s" author title))
    emacspeak-bookshare-directory))
 
@@ -311,7 +324,7 @@ Optional argument 'no-auth says we dont need a user auth."
 (defvar emacspeak-bookshare-categories nil
   "Cached list of categories.")
 
-;;;temporary definition
+;; temporary definition
 
 (defun emacspeak-bookshare-categories ()
   "Return memoized list of categories."
@@ -326,9 +339,9 @@ Optional argument 'no-auth says we dont need a user auth."
             'result)))
       (cl-loop
        for r in result collect
-       (emacspeak-url-encode (dom-text (dom-by-tag r  'name))))))))
+       (url-encode-url (dom-text (dom-by-tag r  'name))))))))
 
-;;;  Following actions return book metadata:
+;;  Following actions return book metadata:
 
 (defun emacspeak-bookshare-isbn-search (query)
   "Perform a Bookshare isbn search."
@@ -340,7 +353,7 @@ Optional argument 'no-auth says we dont need a user auth."
   (interactive "sId: ")
   (emacspeak-bookshare-api-call "book/id" query))
 
-;;; preference  getter/setter:
+;; preference  getter/setter:
 
 (defun emacspeak-bookshare-list-preferences ()
   "Return preference list."
@@ -356,14 +369,14 @@ Optional argument 'no-auth says we dont need a user auth."
    (format "preference/%s/set/%s"
            preference-id value)))
 
-;;; Following Actions return book-list structures within a bookshare envelope.
+;; Following Actions return book-list structures within a bookshare envelope.
 
 (defun emacspeak-bookshare-author-search (query &optional category)
   "Perform a Bookshare author search.
 Interactive prefix arg filters search by category."
   (interactive
    (list
-    (emacspeak-url-encode
+    (url-hexify-string
      (read-from-minibuffer "author: "))
     current-prefix-arg))
   (cond
@@ -384,7 +397,7 @@ Interactive prefix arg filters search by category."
 Interactive prefix arg filters search by category."
   (interactive
    (list
-    (emacspeak-url-encode
+    (url-hexify-string
      (read-from-minibuffer "Title: "))
     current-prefix-arg))
   (cond
@@ -454,7 +467,7 @@ Optional interactive prefix arg prompts for a category to use as a filter."
 ;;}}}
 ;;{{{ Periodical Actions:
 
-;;; Returns periodical list
+;; Returns periodical list
 
 (defun emacspeak-bookshare-periodical-list ()
   "Return list of periodicals."
@@ -471,7 +484,7 @@ Optional interactive prefix arg prompts for a category to use as a filter."
   (shell-command
    (format
     "%s %s %s  '%s' -o \"%s\""
-    emacspeak-bookshare-curl-program
+    emacspeak-curl-program
     emacspeak-bookshare-curl-common-options
     (emacspeak-bookshare-user-password)
     url
@@ -523,7 +536,7 @@ Optional interactive prefix arg prompts for a category to use as a filter."
       (error "No handler defined for action %s" action)))
 
 (define-derived-mode emacspeak-bookshare-mode special-mode
-  "Bookshare Library Of Accessible Books And Periodicals"
+  "Bookshare Library"
   "A Bookshare front-end for the Emacspeak desktop.
 
 The Emacspeak Bookshare front-end is launched by command
@@ -535,9 +548,9 @@ the end of this description. Use Emacs online help facility to
 look up help on these commands.
 
 emacspeak-bookshare-mode provides the necessary functionality to
-Search and download Bookshare material,
-Manage a local library of downloaded Bookshare content,
-And commands to easily read newer Daisy books from Bookshare.
+Search and download Bookshare material, Manage a local library of
+downloaded Bookshare content, And commands to easily read newer
+Daisy books from Bookshare.
 
 Here is a list of all emacspeak Bookshare commands  with their key-bindings:
 a Author Search
@@ -562,7 +575,6 @@ b Browse
 (cl-loop
  for a in
  '(
-   ("SPC" emacspeak-bookshare-action)
    ("+" emacspeak-bookshare-get-more-results)
    ("/" emacspeak-bookshare-title/author-search)
    ("I" emacspeak-bookshare-id-search)
@@ -580,8 +592,8 @@ b Browse
  do
  (progn
    (emacspeak-bookshare-action-set (cl-first a) (cl-second a))
-   (define-key emacspeak-bookshare-mode-map (kbd (cl-first a))
-     'emacspeak-bookshare-action)))
+   (define-key emacspeak-bookshare-mode-map (ems-kbd (cl-first a))
+               'emacspeak-bookshare-action)))
 
 ;;}}}
 ;;{{{ Bookshare XML  handlers:
@@ -602,7 +614,7 @@ b Browse
     (if (fboundp handler) handler 'emacspeak-bookshare-recurse)))
 
 (defvar emacspeak-bookshare-response-elements
-  '(bookshare version metadata messages string
+  '(bookshare debugInfo  version metadata messages string status-code
               book user string downloads-remaining
               id name value editable
               periodical list page num-pages limit result)
@@ -634,7 +646,7 @@ b Browse
     (cond
      ((and handler (fboundp handler))
       (funcall handler element))
-     (t ; Cant get here:
+     (t ; Can't get here:
       (insert (format "Handler for %s not implemented yet.\n" tag))))))
 
 (defun emacspeak-bookshare-bookshare-handler (response)
@@ -643,7 +655,8 @@ b Browse
     (error "Does not look like a Bookshare response."))
   (mapc #'emacspeak-bookshare-apply-handler (dom-children response)))
 
-(defalias 'emacspeak-bookshare-version-handler 'ignore)
+(cl--defalias 'emacspeak-bookshare-version-handler 'ignore)
+(cl--defalias 'emacspeak-bookshare-debugInfo-handler 'ignore)
 
 (defun emacspeak-bookshare-recurse (tree)
   "Recurse down tree."
@@ -667,6 +680,24 @@ b Browse
                                 'face 'font-lock-string-face))
     (insert "\n")))
 
+(defun emacspeak-bookshare-status-code-handler (status-code)
+  "Handlestatus-code element."
+  (cl-declare (special emacspeak-bookshare-last-action-uri))
+  (let ((start (point)))
+    (message "Status-Code: %s" (dom-text    status-code))
+    (insert "Status Code: ")
+    (mapc #'insert (dom-text    status-code))
+    (insert "\t")
+    (insert
+     (mapconcat
+      #'identity
+      (emacspeak-bookshare-destruct-rest-url emacspeak-bookshare-last-action-uri)
+      " "))
+    (add-text-properties  start (point)
+                          (list 'uri emacspeak-bookshare-last-action-uri
+                                'face 'font-lock-string-face))
+    (insert "\n")))
+
 (defun emacspeak-bookshare-page-handler (page)
   "Handle page element."
   (insert (format "Page: %s\t" (dom-text page))))
@@ -817,13 +848,15 @@ b Browse
   (cl-declare (special emacspeak-bookshare-mode-map))
   (cl-loop for k in
            '(
-             ("e" emacspeak-epub)
+             ("e" emacspeak-bookshare-eww)
              ("q" bury-buffer)
              ("f" emacspeak-bookshare-flush-lines)
              ("v" emacspeak-bookshare-view)
              ("c" emacspeak-bookshare-toc-at-point)
              ("\C-m" emacspeak-bookshare-toc-at-point)
              ("M-n" emacspeak-bookshare-next-result)
+             ("n" emacspeak-bookshare-next-result)
+             ("p" emacspeak-bookshare-previous-result)
              ("M-p" emacspeak-bookshare-previous-result)
              ("["  backward-page)
              ("]" forward-page)
@@ -889,9 +922,9 @@ b Browse
   (interactive)
   (let ((action (read-char "p Popular, l Latest")))
     (cl-case action
-          (?p (call-interactively 'emacspeak-bookshare-action))
-          (?l (call-interactively 'emacspeak-bookshare-action))
-          (otherwise (error "Unrecognized browse action.")))))
+      (?p (call-interactively 'emacspeak-bookshare-action))
+      (?l (call-interactively 'emacspeak-bookshare-action))
+      (otherwise (error "Unrecognized browse action.")))))
 
 (defun emacspeak-bookshare-expand-at-point ()
   "Expand entry at point by retrieving metadata.
@@ -1037,7 +1070,6 @@ Target location is generated from author and title."
 (defun emacspeak-bookshare-unpack-at-point ()
   "Unpack downloaded content if necessary."
   (interactive)
-  (cl-declare (special emacspeak-bookshare-password-cache))
   (emacspeak-bookshare-assert)
   (let ((inhibit-read-only t)
         (target (emacspeak-bookshare-get-target))
@@ -1050,9 +1082,7 @@ Target location is generated from author and title."
     (shell-command
      (format "cd \"%s\"; unzip -P %s %s"
              directory
-             (or emacspeak-bookshare-password-cache
-                 (read-passwd
-                  (format "Password for %s" emacspeak-bookshare-user-id)))
+             (cdr (emacspeak-bookshare-get-auth-info))
              target))
     (add-text-properties
      (line-beginning-position) (line-end-position)
@@ -1060,20 +1090,14 @@ Target location is generated from author and title."
                 'auditory-icon 'item))
     (message "Unpacked content.")))
 
-;;;###autoload
-(defcustom emacspeak-bookshare-xslt
+(defvar emacspeak-bookshare-xslt
   "daisyTransform.xsl"
-  "Name of bookshare  XSL transform."
-  :type
-  '(choice :tag "Key: "
-           (const :tag "Daisy transform from Bookshare"  "daisyTransform.xsl")
-           (const :tag "Default HTML View" "default.xsl"))
-  :group 'emacspeak-bookshare)
+  "Name of bookshare  XSL transform.")
 
 (defun emacspeak-bookshare-xslt (directory)
   "Return suitable XSL  transform."
   (cl-declare (special emacspeak-bookshare-xslt
-                    emacspeak-xslt-directory))
+                       emacspeak-xslt-directory))
   (let ((xsl (expand-file-name emacspeak-bookshare-xslt directory)))
     (cond
      ((file-exists-p xsl) xsl)
@@ -1086,9 +1110,10 @@ Target location is generated from author and title."
 (defun emacspeak-bookshare-toc-xslt ()
   "Return suitable XSL  transform for TOC."
   (cl-declare (special emacspeak-bookshare-toc-xslt
-                    emacspeak-xslt-directory))
+                       emacspeak-xslt-directory))
 
   (expand-file-name emacspeak-bookshare-toc-xslt emacspeak-xslt-directory))
+(declare-function emacspeak-xslt-view-file "emacspeak-xslt" (style file))
 
 (defun emacspeak-bookshare-view-at-point ()
   "View book at point.
@@ -1103,10 +1128,8 @@ Make sure it's downloaded and unpacked first."
       (error "First unpack this content."))
     (emacspeak-xslt-view-file
      xsl
-     (first
-      (directory-files directory
-                       'full
-                       ".xml")))))
+     (cl-first
+      (directory-files directory 'full "\\.xml\\'")))))
 
 (defun emacspeak-bookshare-url-executor (url)
   "Custom URL executor for use in Bookshare TOC."
@@ -1133,7 +1156,7 @@ Make sure it's downloaded and unpacked first."
       (unless (file-exists-p directory)
         (error "First unpack this content."))
       (add-hook
-       'emacspeak-web-post-process-hook
+       'emacspeak-eww-post-process-hook
        #'(lambda ()
            (cl-declare (special emacspeak-we-url-executor))
            (setq emacspeak-we-url-executor 'emacspeak-bookshare-url-executor)
@@ -1142,8 +1165,8 @@ Make sure it's downloaded and unpacked first."
       (emacspeak-xslt-view-file
        xsl
        (shell-quote-argument
-        (first
-         (directory-files directory 'full ".xml"))))))))
+        (cl-first
+         (directory-files directory 'full "\\.xml\\'"))))))))
 
 (defun emacspeak-bookshare-extract-xml (url)
   "Extract content referred to by link under point, and return an XML buffer."
@@ -1166,12 +1189,12 @@ Make sure it's downloaded and unpacked first."
   "Extract content referred to by link under point, and render via the browser."
   (interactive "sURL: ")
   (cl-declare (special emacspeak-bookshare-browser-function
-                    emacspeak-xslt-directory))
+                       emacspeak-xslt-directory))
   (let ((result (emacspeak-bookshare-extract-xml url))
         (browse-url-browser-function emacspeak-bookshare-browser-function))
     (save-current-buffer
       (set-buffer result)
-      (emacspeak-webutils-autospeak)
+      (emacspeak-eww-autospeak)
       (browse-url-of-buffer))))
 
 (defun emacspeak-bookshare-view-page-range (url)
@@ -1190,7 +1213,7 @@ Make sure it's downloaded and unpacked first."
          (browse-url-browser-function emacspeak-bookshare-browser-function))
     (save-current-buffer
       (set-buffer result)
-      (emacspeak-webutils-autospeak)
+      (emacspeak-eww-autospeak)
       (browse-url-of-buffer))
     (kill-buffer result)))
 
@@ -1209,8 +1232,8 @@ Make sure it's downloaded and unpacked first."
   (let* ((xsl (emacspeak-bookshare-xslt directory)))
     (emacspeak-xslt-view-file
      xsl
-     (first
-      (directory-files directory 'full ".xml")))))
+     (cl-first
+      (directory-files directory 'full "\\.xml\\'")))))
 
 (defun emacspeak-bookshare-toc (directory)
   "View TOC for book in specified directory."
@@ -1226,22 +1249,18 @@ Make sure it's downloaded and unpacked first."
   (cl-declare (special emacspeak-bookshare-directory))
   (let* ((xsl (emacspeak-bookshare-toc-xslt)))
     (add-hook
-     'emacspeak-web-post-process-hook
+     'emacspeak-eww-post-process-hook
      #'(lambda ()
          (cl-declare (special emacspeak-we-url-executor))
          (setq emacspeak-we-url-executor 'emacspeak-bookshare-url-executor)))
     (emacspeak-xslt-view-file
      xsl
-     (cl-first (directory-files directory 'full ".xml")))))
-;;;###autoload
-(defcustom emacspeak-bookshare-html-to-text-command
+     (cl-first (directory-files directory 'full "\\.xml\\'")))))
+
+(defvar emacspeak-bookshare-html-to-text-command
   "lynx -dump -stdin"
-  "Command to convert html to text on stdin."
+  "Command to convert html to text on stdin.")
 
-  :type '(choice
-          (const :tag "lynx"  "lynx -dump -stdin")
-          (const "html2text" "html2text"))
-  :group 'emacspeak-bookshare)
 (defun emacspeak-bookshare-fulltext (directory)
   "Display fulltext contents of  book in specified directory.
 Useful for fulltext search in a book."
@@ -1257,7 +1276,7 @@ Useful for fulltext search in a book."
                                emacspeak-bookshare-directory)))))
   (cl-declare (special emacspeak-xslt-program))
   (cl-declare (special emacspeak-bookshare-html-to-text-command
-                    emacspeak-bookshare-directory))
+                       emacspeak-bookshare-directory))
   (let ((xsl (emacspeak-bookshare-xslt directory))
         (buffer (get-buffer-create "Full Text"))
         (command nil)
@@ -1268,7 +1287,7 @@ Useful for fulltext search in a book."
              "%s  --nonet --novalid %s %s | %s"
              emacspeak-xslt-program xsl
              (shell-quote-argument
-              (cl-first (directory-files directory 'full ".xml")))
+              (cl-first (directory-files directory 'full "\\.xml\\'")))
              emacspeak-bookshare-html-to-text-command))
       (erase-buffer)
       (setq buffer-undo-list t)
@@ -1281,9 +1300,8 @@ Useful for fulltext search in a book."
 (defvar-local emacspeak-bookshare-this-book nil
   "Record current book in buffer where it is rendered.")
 
-;;;###autoload
 (defun emacspeak-bookshare-eww (directory)
-  "Render complete book using EWW"
+  "Render  book using EWW"
   (interactive
    (list
     (or (emacspeak-bookshare-get-directory)
@@ -1295,10 +1313,10 @@ Useful for fulltext search in a book."
                                  (dired-get-filename))
                                emacspeak-bookshare-directory)))))
   (cl-declare (special emacspeak-xslt-program emacspeak-bookshare-directory
-                    emacspeak-bookshare-this-book))
+                       emacspeak-speak-directory-settings emacspeak-bookshare-this-book))
   (unless (fboundp 'eww)
     (error "Your Emacs doesn't have EWW."))
-  (let ((gc-cons-threshold 8000000)
+  (let ((gc-cons-threshold (max 8000000 gc-cons-threshold))
         (xsl (emacspeak-bookshare-xslt directory))
         (buffer (get-buffer-create "Full Text"))
         (command nil)
@@ -1309,29 +1327,20 @@ Useful for fulltext search in a book."
              "%s  --nonet --novalid %s %s "
              emacspeak-xslt-program xsl
              (shell-quote-argument
-              (cl-first (directory-files directory 'full ".xml")))))
+              (cl-first (directory-files directory 'full "\\.xml\\'")))))
       (erase-buffer)
       (setq buffer-undo-list t)
       (shell-command command (current-buffer) nil)
       (add-hook
-       'emacspeak-web-post-process-hook
+       'emacspeak-eww-post-process-hook
        #'(lambda nil
            (setq emacspeak-bookshare-this-book directory)
+           (emacspeak-speak-load-directory-settings directory)
            (emacspeak-auditory-icon 'open-object)
            (emacspeak-speak-mode-line)))
       (browse-url-of-buffer)
       (kill-buffer buffer))))
 
-(defun emacspeak-bookshare-sign-out ()
-  "Sign out, clearing password."
-  (interactive)
-  (cl-declare (special emacspeak-bookshare-md5-cached-token
-                    emacspeak-bookshare-password-cache))
-  (setq emacspeak-bookshare-password-cache nil
-        emacspeak-bookshare-md5-cached-token nil)
-  (emacspeak-auditory-icon 'close-object)
-  (message "Signed out from Bookshare."))
-
 ;;}}}
 ;;{{{ Navigation in  Bookshare Interaction
 
@@ -1364,9 +1373,8 @@ Useful for fulltext search in a book."
 (provide 'emacspeak-bookshare)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
