@@ -1,46 +1,46 @@
 ;;; emacspeak-buff-menu.el --- Speech enable Buffer Menu Mode -- used to manage buffers  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $ 
-;;; Description: Auditory interface to buff-menu
-;;; Keywords: Emacspeak, Speak, Spoken Output, buff-menu
+;;
+;; $Author: tv.raman.tv $ 
+;; Description: Auditory interface to buff-menu
+;; Keywords: Emacspeak, Speak, Spoken Output, buff-menu
 ;;{{{  LCD Archive entry: 
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
-;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
-;;;  $Revision: 4532 $ | 
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com 
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ | 
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2017, T. V. Raman
-;;; All Rights Reserved. 
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (c) 1995 -- 2022, T. V. Raman
+;; All Rights Reserved. 
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  Introduction 
 ;;; Commentary:
-;;; Speech-enable buffer-menus.
+;; Speech-enable buffer-menus.
 ;;; Code:
 ;;}}}
 ;;{{{  Required modules
@@ -105,7 +105,7 @@
         (when this-buffer-modified-p (emacspeak-auditory-icon 'modified-object))
         (when this-buffer-read-only (emacspeak-auditory-icon 'unmodified-object))
         (dtk-speak
-         (format  "%s a %s  document  %s with size  %s"
+         (format  "%s a %s  buffer  %s with size  %s"
                   name this-buffer-mode-name
                   (if (or file this-buffer-directory)
                       (format "visiting %s"
@@ -118,16 +118,16 @@
 (defun emacspeak-list-buffers-next-line (count)
   "Speech enabled buffer menu navigation"
   (interactive "p")
-  (next-line count)
+  (forward-line count)
   (emacspeak-list-buffers-speak-buffer-line))
 
 (defun emacspeak-list-buffers-previous-line (count)
   "Speech enabled buffer menu navigation"
   (interactive "p")
-  (previous-line count)
+  (forward-line  (* -1 count))
   (emacspeak-list-buffers-speak-buffer-line))
 
-(defadvice list-buffers (after emacspeak pre act)
+(defadvice list-buffers (after emacspeak pre act comp)
   "Select the window displaying buffer-menu,
 and set up additional Emacspeak bindings."
   (cl-declare (special Buffer-menu-mode-map))
@@ -137,118 +137,118 @@ and set up additional Emacspeak bindings."
     (forward-line 2)
     (define-key Buffer-menu-mode-map "," 'emacspeak-list-buffers-speak-buffer-name)
     (define-key Buffer-menu-mode-map "."
-      'emacspeak-list-buffers-speak-buffer-line)
+                'emacspeak-list-buffers-speak-buffer-line)
     (define-key Buffer-menu-mode-map "n" 'emacspeak-list-buffers-next-line)
     (define-key Buffer-menu-mode-map "p" 'emacspeak-list-buffers-previous-line)
     (emacspeak-list-buffers-speak-buffer-line)
     (emacspeak-auditory-icon 'open-object)))
 
-(defadvice buffer-menu (after emacspeak pre act)
-  "Provide auditory feedback"
+(defadvice buffer-menu (after emacspeak pre act comp)
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'task-done)
     (message "Displayed list of buffers in other window")))
 
 ;;{{{  buffer manipulation commands 
-(defadvice Buffer-menu-bury (after emacspeak pre act)
-  "Provide auditory feedback"
+(defadvice Buffer-menu-bury (after emacspeak pre act comp)
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-list-buffers-speak-buffer-line)))
 
-(defadvice Buffer-menu-delete-backwards (after emacspeak pre act)
-  "Provide auditory feedback"
+(defadvice Buffer-menu-delete-backwards (after emacspeak pre act comp)
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'delete-object)
     (emacspeak-list-buffers-speak-buffer-line)))
 
-(defadvice Buffer-menu-delete (after emacspeak pre act)
+(defadvice Buffer-menu-delete (after emacspeak pre act comp)
   "Provide spoken and auditory feedback."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'delete-object)
     (emacspeak-list-buffers-speak-buffer-line)))
 
-(defadvice Buffer-menu-mark (after emacspeak pre act)
+(defadvice Buffer-menu-mark (after emacspeak pre act comp)
   "Provide spoken and auditory feedback."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'mark-object)
     (emacspeak-list-buffers-speak-buffer-line)))
 
-(defadvice Buffer-menu-quit (after emacspeak pre act)
+(defadvice Buffer-menu-quit (after emacspeak pre act comp)
   "Speak the modeline of the newly visible buffer."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
-(defadvice Buffer-menu-save (after emacspeak pre act)
-  "Provide auditory feedback"
+(defadvice Buffer-menu-save (after emacspeak pre act comp)
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'save-object)
     (emacspeak-list-buffers-speak-buffer-line)))
 
-(defadvice Buffer-menu-select (after emacspeak pre act)
-  "Provide auditory feedback"
+(defadvice Buffer-menu-select (after emacspeak pre act comp)
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-mode-line)))
 
-(defadvice Buffer-menu-unmark (after emacspeak pre act)
-  "Provide auditory feedback"
+(defadvice Buffer-menu-unmark (after emacspeak pre act comp)
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'deselect-object)
     (emacspeak-list-buffers-speak-buffer-line)))
 
-(defadvice Buffer-menu-backup-unmark (after emacspeak pre act)
-  "Provide auditory feedback"
+(defadvice Buffer-menu-backup-unmark (after emacspeak pre act comp)
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'deselect-object)
     (emacspeak-list-buffers-speak-buffer-line)))
 
-(defadvice Buffer-menu-execute (after emacspeak pre act)
-  "Provide auditory feedback"
+(defadvice Buffer-menu-execute (after emacspeak pre act comp)
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'task-done)))
 
-(defadvice Buffer-menu-toggle-read-only (after emacspeak pre act)
-  "Provide auditory feedback"
+(defadvice Buffer-menu-toggle-read-only (after emacspeak pre act comp)
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-list-buffers-speak-buffer-line)))
 
-(defadvice Buffer-menu-not-modified (after emacspeak pre act)
-  "Provide auditory feedback "
+(defadvice Buffer-menu-not-modified (after emacspeak pre act comp)
+  "speak "
   (when (ems-interactive-p)
     (emacspeak-list-buffers-speak-buffer-line)
     (if (ad-get-arg 0)
         (emacspeak-auditory-icon 'modified-object)
       (emacspeak-auditory-icon 'unmodified-object))))
 
-(defadvice Buffer-menu-visit-tags-table (before emacspeak pre act)
-  "Provide auditory feedback"
+(defadvice Buffer-menu-visit-tags-table (before emacspeak pre act comp)
+  "speak"
   (when (ems-interactive-p)
     (message "Visiting tags table on current line")))
 
 ;;}}}
 ;;{{{  display buffers 
 
-(defadvice Buffer-menu-1-window (after emacspeak pre act)
+(defadvice Buffer-menu-1-window (after emacspeak pre act comp)
   "Announce the newly selected buffer."
   (when (ems-interactive-p)
     (emacspeak-speak-mode-line)
     (emacspeak-auditory-icon 'select-object)))
 
-(defadvice Buffer-menu-2-window (after emacspeak pre act)
+(defadvice Buffer-menu-2-window (after emacspeak pre act comp)
   "Announce the newly selected buffer."
   (when (ems-interactive-p)
     (emacspeak-speak-mode-line)
     (emacspeak-auditory-icon 'select-object)))
 
-(defadvice Buffer-menu-this-window (after emacspeak pre act)
+(defadvice Buffer-menu-this-window (after emacspeak pre act comp)
   "Announce the newly selected buffer."
   (when (ems-interactive-p)
     (emacspeak-speak-mode-line)
     (emacspeak-auditory-icon 'select-object)))
-(defadvice Buffer-menu-other-window (after emacspeak pre act)
-  "Provide auditory feedback"
+(defadvice Buffer-menu-other-window (after emacspeak pre act comp)
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
@@ -259,9 +259,8 @@ and set up additional Emacspeak bindings."
 (provide 'emacspeak-buff-menu)
 ;;{{{ end of file 
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end: 
+;; local variables:
+;; folded-file: t
+;; end: 
 
 ;;}}}
