@@ -1,62 +1,63 @@
 ;;; emacspeak-c.el --- Speech enable CC-mode and friends -- supports C, C++, Java  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $
-;;; DescriptionEmacspeak extensions for C and C++ mode
-;;; Keywords:emacspeak, audio interface to emacs C, C++
+;;
+;; $Author: tv.raman.tv $
+;; DescriptionEmacspeak extensions for C and C++ mode
+;; Keywords:emacspeak, audio interface to emacs C, C++
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
-;;;  $Revision: 4637 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4637 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman
-;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
 ;;{{{ Introduction:
 
 ;;; Commentary:
 
-;;; Make some of C and C++ mode more emacspeak friendly
-;;; Works with both boring c-mode
-;;; and the excellent cc-mode
+;; Make  C and C++ mode more emacspeak friendly
+;; Works with both boring c-mode
+;; and the excellent cc-mode
+
+;;; Code:
 
 ;;}}}
 ;;{{{  Required modules
 
-;;; Code:
-
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
-(require 'cc-mode)
+(declare-function c-beginning-of-statement "cc-cmds" (&optional count lim sentence-flag))
+(declare-function c-end-of-statement "cc-cmds" (&optional count lim sentence-flag))
 
 ;;}}}
 ;;{{{ advice electric deletion
 
-(defadvice c-electric-delete-forward (around emacspeak pre act)
+(defadvice c-electric-delete-forward (around emacspeak pre act comp)
   "Speak character you're deleting."
   (cond
    ((ems-interactive-p)
@@ -70,7 +71,7 @@
  '(c-hungry-delete-forward c-hungry-delete-backwards c-electric-backspace)
  do
  (eval
-  `(defadvice ,f (around emacspeak pre act)
+  `(defadvice ,f (around emacspeak pre act comp)
      "Speak character you're deleting."
      (cond
       ((ems-interactive-p)
@@ -84,14 +85,14 @@
 ;;{{{  advice things to speak
 ;;{{{  Electric chars speak
 
-(defadvice c-electric-semi&comma (after emacspeak pre act)
+(defadvice c-electric-semi&comma (after emacspeak pre act comp)
   "Speak the line when a statement is completed."
   (when (ems-interactive-p)
     (cond
      ((= last-input-event ?,) (dtk-speak " comma "))
      (t (emacspeak-speak-line)))))
 
-(defadvice c-electric-delete (before emacspeak pre act)
+(defadvice c-electric-delete (before emacspeak pre act comp)
   "Speak char before deleting it."
   (when (ems-interactive-p)
     (emacspeak-speak-this-char(preceding-char))
@@ -100,41 +101,41 @@
 ;;}}}
 ;;{{{  Moving across logical chunks
 
-;;; CPP directives:
+;; CPP directives:
 
-(defadvice c-up-conditional (after emacspeak pre act)
+(defadvice c-up-conditional (after emacspeak pre act comp)
   "Speak the line moved to."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line)))
 
-(defadvice c-forward-conditional (after emacspeak pre act)
+(defadvice c-forward-conditional (after emacspeak pre act comp)
   "Speak the line moved to."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line)))
 
-(defadvice c-backward-conditional (after emacspeak pre act)
+(defadvice c-backward-conditional (after emacspeak pre act comp)
   "Speak the line moved to."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line)))
 
-;;; Statements
+;; Statements
 
-(defadvice c-beginning-of-statement (after emacspeak pre act)
+(defadvice c-beginning-of-statement (after emacspeak pre act comp)
   "Speak the line moved to."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'item)
     (emacspeak-speak-line)))
 
-(defadvice c-end-of-statement (after emacspeak pre act)
+(defadvice c-end-of-statement (after emacspeak pre act comp)
   "Speak the line moved to."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'item)
     (emacspeak-speak-line)))
 
-(defadvice c-mark-function (after emacspeak pre act)
+(defadvice c-mark-function (after emacspeak pre act comp)
   "Provide spoken and auditory feedback."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'mark-object)
@@ -145,13 +146,13 @@
 ;;}}}
 ;;{{{ advice program navigation
 
-(defadvice  c-beginning-of-defun (after emacspeak pre act)
+(defadvice  c-beginning-of-defun (after emacspeak pre act comp)
   "Speak the line."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'paragraph)
     (emacspeak-speak-line)))
 
-(defadvice  c-end-of-defun (after emacspeak pre act)
+(defadvice  c-end-of-defun (after emacspeak pre act comp)
   "Speak the line."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'paragraph)
@@ -160,7 +161,7 @@
 ;;}}}
 ;;{{{  extensions  provided by c++ mode
 
-(defadvice c-scope-operator (after emacspeak pre act)
+(defadvice c-scope-operator (after emacspeak pre act comp)
   "speak what you inserted."
   (when (ems-interactive-p)
     (dtk-speak "colon colon")))
@@ -174,7 +175,7 @@
   (emacspeak-auditory-icon 'item)
   (let  ((opoint (point))
          (semantics (c-guess-basic-syntax)))
-;;; skip across a comment
+    ;; skip across a comment
     (cond
      ((or (assq 'c semantics)
           (assq 'comment-intro semantics))
@@ -204,7 +205,7 @@ this level")
   (emacspeak-auditory-icon 'item)
   (let  ((opoint (point))
          (semantics (c-guess-basic-syntax)))
-;;; skip across a comment
+    ;; skip across a comment
     (cond
      ((or (assq 'c semantics)
           (assq 'comment-intro semantics))
@@ -305,13 +306,12 @@ and their meanings. ")
   "Speak the C semantics of this line. "
   (interactive)
   (cl-declare (special emacspeak-c-syntactic-table))
-  (let  ((semantics (mapcar 'car
-                            (c-guess-basic-syntax)))
+  (let  ((semantics (mapcar 'car (c-guess-basic-syntax)))
          (description ""))
     (setq description
           (mapconcat
            #'(lambda (sem)
-                       (cdr (assq  sem emacspeak-c-syntactic-table)))
+               (cdr (assq  sem emacspeak-c-syntactic-table)))
            semantics
            " "))
     (condition-case nil
@@ -339,8 +339,7 @@ and their meanings. ")
                                  (forward-line 0))
                             (setq start (point))
                             (end-of-line)
-                            (buffer-substring start
-                                              (point))))))))
+                            (buffer-substring start (point))))))))
       (error nil))
     (dtk-speak description)
     description))
@@ -348,13 +347,13 @@ and their meanings. ")
 ;;}}}
 ;;{{{  indenting commands
 
-(defadvice c-indent-defun (after emacspeak pre act)
+(defadvice c-indent-defun (after emacspeak pre act comp)
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'fill-object)
     (message "Indented function")))
 
 (defadvice c-indent-command (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-speak-line)))
 
@@ -369,12 +368,12 @@ and their meanings. ")
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
-     "Provide auditory feedback."
+     "speak."
      (when (ems-interactive-p)
        (emacspeak-auditory-icon 'large-movement)
        (emacspeak-speak-line)))))
 (defadvice c-backslash-region (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'task-done)
     (emacspeak-speak-region (point) (mark))))
@@ -384,7 +383,7 @@ and their meanings. ")
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
-     "Provide auditory feedback."
+     "speak."
      (when (ems-interactive-p)
        (emacspeak-speak-line)
        (emacspeak-auditory-icon 'open-object)))))
@@ -395,7 +394,7 @@ and their meanings. ")
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
-     "Provide auditory feedback."
+     "speak."
      (when (ems-interactive-p)
        (emacspeak-speak-line)
        (emacspeak-auditory-icon 'large-movement)))))
@@ -407,7 +406,7 @@ and their meanings. ")
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
-     "Provide auditory feedback."
+     "speak."
      (when (ems-interactive-p)
        (emacspeak-auditory-icon 'fill-object)
        (emacspeak-speak-line)))))
@@ -422,7 +421,7 @@ and their meanings. ")
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
-     "Provide auditory feedback."
+     "speak."
      (when (ems-interactive-p)
        (emacspeak-auditory-icon 'button)
        (message   "Toggled %s"  ,(symbol-name f))))))
@@ -430,8 +429,7 @@ and their meanings. ")
 ;;}}}
 ;;{{{ Additional keybindings:
 
-(cl-declaim (special c-mode-map
-                  c-mode-base-map))
+(cl-declaim (special c-mode-map c-mode-base-map))
 (add-hook
  'c-mode-common-hook
  #'(lambda ()
@@ -439,20 +437,10 @@ and their meanings. ")
      (define-key c-mode-map "\C-cs" 'emacspeak-c-speak-semantics)
      (define-key c-mode-map "\M-n" 'c-next-statement)
      (define-key c-mode-map "\M-p" 'c-previous-statement)
-     (when (and  (boundp 'c-mode-base-map)
-                 c-mode-base-map)
-       (define-key c-mode-base-map
-         "\M-\C-a" 'c-beginning-of-defun)
-       (define-key c-mode-base-map "\M-\C-e" 'c-end-of-defun)
+     (when (and  (boundp 'c-mode-base-map) c-mode-base-map)
        (define-key c-mode-base-map "\C-cs" 'emacspeak-c-speak-semantics)
        (define-key c-mode-base-map "\M-n" 'c-next-statement)
-       (define-key c-mode-base-map "\M-p"
-         'c-previous-statement))
-     (emacspeak-pronounce-toggle-use-of-dictionaries 'on)
-     (or dtk-split-caps
-         (dtk-toggle-split-caps))
-     (or dtk-allcaps-beep
-         (dtk-toggle-allcaps-beep))))
+       (define-key c-mode-base-map "\M-p" 'c-previous-statement))))
 
 ;;}}}
 ;;{{{ personalities
@@ -466,9 +454,8 @@ and their meanings. ")
 (provide  'emacspeak-c)
 ;;{{{  emacs local variables
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
