@@ -1,46 +1,46 @@
-;;; emacspeak-calendar.el --- Speech enable Emacs Calendar -- maintain a diary and appointments  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $
-;;; Description:  Emacspeak extensions to speech enable the calendar.
-;;; Keywords: Emacspeak, Calendar, Spoken Output
+;;; emacspeak-calendar.el --- Speech enable Emacs Calendar -*- lexical-binding: t; -*-
+;;
+;; $Author: tv.raman.tv $
+;; Description:  Emacspeak extensions to speech enable the calendar.
+;; Keywords: Emacspeak, Calendar, Spoken Output
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2008-06-21 10:50:41 -0700 (Sat, 21 Jun 2008) $ |
-;;;  $Revision: 4532 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman
-;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
 ;;{{{  Introduction:
 ;;; Commentary:
-;;; This module speech enables the Emacs Calendar.
-;;; Speech enabling is not the same as speaking the screen:
-;;; This is an excellent example of the advantages of speech-enabled  interaction.
+;; This module speech enables the Emacs Calendar.
+;; Speech enabling is not the same as speaking the screen:
+;; This is an excellent example of the advantages of speech-enabled  interaction.
 ;;; Code:
 ;;}}}
 ;;{{{ required modules
@@ -55,15 +55,13 @@
 ;;{{{  personalities
 (voice-setup-add-map
  '(
-   (calendar-today voice-lighten)
+   (calendar-today voice-bolden)
    (holiday voice-brighten-extra)
    (diary voice-bolden)
    ))
 
-(defcustom emacspeak-calendar-mark-personality voice-bolden
-  "Personality to use when showing marked calendar entries."
-  :type 'symbol
-  :group 'emacspeak-calendar)
+(defvar emacspeak-calendar-mark-personality voice-bolden
+  "Personality to use when showing marked calendar entries.")
 
 ;;}}}
 ;;{{{  functions:
@@ -79,35 +77,33 @@
 
 (defun emacspeak-calendar-entry-marked-p()
   "Check if diary entry is marked. "
-  (member 'diary
-          (delq nil
-                (mapcar
-                 #'(lambda (overlay)
-                     (overlay-get overlay 'face))
-                 (overlays-at (point))))))
+  (memq 'diary
+        (delq nil
+              (mapcar
+               #'(lambda (overlay)
+                   (overlay-get overlay 'face))
+               (overlays-at (point))))))
 
 (defun emacspeak-calendar-speak-date()
   "Speak the date under point when called in Calendar Mode. "
   (interactive)
   (let ((date (calendar-date-string (calendar-cursor-to-date t))))
-    (tts-with-punctuations 'some
-                           (cond
-                            ((emacspeak-calendar-entry-marked-p)
-                             (dtk-speak-using-voice emacspeak-calendar-mark-personality date))
-                            (t (dtk-speak date))))))
+    (tts-with-punctuations
+     'some
+     (cond
+      ((emacspeak-calendar-entry-marked-p)
+       (dtk-speak-using-voice emacspeak-calendar-mark-personality date))
+      (t (dtk-speak date))))))
 
 ;;}}}
 ;;{{{  Advice:
-(defadvice calendar-exchange-point-and-mark (after emacspeak
-                                                   pre act comp)
+(defadvice calendar-exchange-point-and-mark (after emacspeak pre act comp)
   "Speak date under point"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-calendar-speak-date)))
 
-(defadvice calendar-set-mark (after emacspeak
-                                    pre act
-                                    comp)
+(defadvice calendar-set-mark (after emacspeak pre act comp)
   "Speak date under point"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'mark-object)
@@ -126,7 +122,7 @@
              (let ((emacspeak-speak-messages (not (ems-interactive-p))))
                ad-do-it))))
 
-(defadvice view-diary-entries (after emacspeak pre act)
+(defadvice view-diary-entries (after emacspeak pre act comp)
   "Speak the diary entries."
   (when (ems-interactive-p)
     (ems-with-messages-silenced
@@ -139,7 +135,7 @@
           (emacspeak-speak-buffer))))
       (t (dtk-speak "No diary entries."))))))
 
-(defadvice  mark-visible-calendar-date (after emacspeak pre act)
+(defadvice  mark-visible-calendar-date (after emacspeak pre act comp)
   "Use voice locking to mark date. "
   (let ((date (ad-get-arg 0)))
     (if (calendar-date-is-valid-p date)
@@ -162,7 +158,7 @@
 (setq calendar-mode-line-format
       emacspeak-calendar-mode-line-format)
 
-(defadvice calendar (after emacspeak pre act)
+(defadvice calendar (after emacspeak pre act comp)
   "Announce yourself."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
@@ -174,98 +170,98 @@
     (tts-with-punctuations 'some
                            (emacspeak-speak-mode-line))))
 
-(defadvice calendar-goto-date (after emacspeak pre act)
+(defadvice calendar-goto-date (after emacspeak pre act comp)
   "Speak the date. "
   (when (ems-interactive-p)
     (emacspeak-calendar-speak-date))
   (emacspeak-auditory-icon 'select-object))
 
-(defadvice calendar-goto-today (after emacspeak pre act)
+(defadvice calendar-goto-today (after emacspeak pre act comp)
   "Speak the date. "
   (when (ems-interactive-p)
     (emacspeak-calendar-speak-date))
 
   (emacspeak-auditory-icon 'select-object))
 
-(defadvice calendar-backward-day (after emacspeak pre act)
+(defadvice calendar-backward-day (after emacspeak pre act comp)
   "Speak the date. "
   (when (ems-interactive-p)
     (emacspeak-calendar-speak-date)
     (emacspeak-auditory-icon 'select-object)))
 
-(defadvice calendar-forward-day (after emacspeak pre act)
+(defadvice calendar-forward-day (after emacspeak pre act comp)
   "Speak the date. "
   (when (ems-interactive-p)
     (emacspeak-calendar-speak-date)
     (emacspeak-auditory-icon 'select-object)))
 
-(defadvice calendar-backward-week (after emacspeak pre act)
+(defadvice calendar-backward-week (after emacspeak pre act comp)
   "Speak the date. "
   (when (ems-interactive-p)
     (emacspeak-calendar-speak-date)
     (emacspeak-auditory-icon 'paragraph)))
 
-(defadvice calendar-forward-week (after emacspeak pre act)
+(defadvice calendar-forward-week (after emacspeak pre act comp)
   "Speak the date. "
   (when (ems-interactive-p)
     (emacspeak-calendar-speak-date)
     (emacspeak-auditory-icon 'paragraph)))
 
-(defadvice calendar-backward-month (after emacspeak pre act)
+(defadvice calendar-backward-month (after emacspeak pre act comp)
   "Speak the date. "
   (when (ems-interactive-p)
     (emacspeak-calendar-speak-date)
     (emacspeak-auditory-icon 'section)))
 
-(defadvice calendar-forward-month (after emacspeak pre act)
+(defadvice calendar-forward-month (after emacspeak pre act comp)
   "Speak the date. "
   (when (ems-interactive-p)
     (emacspeak-calendar-speak-date)
     (emacspeak-auditory-icon 'section)))
 
-(defadvice calendar-backward-year (after emacspeak pre act)
+(defadvice calendar-backward-year (after emacspeak pre act comp)
   "Speak the date. "
   (when (ems-interactive-p)
     (emacspeak-calendar-speak-date)
     (emacspeak-auditory-icon 'large-movement)))
 
-(defadvice calendar-forward-year (after emacspeak pre act)
+(defadvice calendar-forward-year (after emacspeak pre act comp)
   "Speak the date. "
   (when (ems-interactive-p)
     (emacspeak-calendar-speak-date)
     (emacspeak-auditory-icon 'large-movement)))
 
-(defadvice calendar-beginning-of-week (after emacspeak pre act)
+(defadvice calendar-beginning-of-week (after emacspeak pre act comp)
   "Speak the date. "
   (when (ems-interactive-p)
     (emacspeak-calendar-speak-date)
     (emacspeak-auditory-icon 'paragraph)))
 
-(defadvice calendar-beginning-of-month (after emacspeak pre act)
+(defadvice calendar-beginning-of-month (after emacspeak pre act comp)
   "Speak the date. "
   (when (ems-interactive-p)
     (emacspeak-calendar-speak-date)
     (emacspeak-auditory-icon 'section)))
 
-(defadvice calendar-beginning-of-year (after emacspeak pre act)
+(defadvice calendar-beginning-of-year (after emacspeak pre act comp)
   "Speak the date. "
   (when (ems-interactive-p)
     (emacspeak-calendar-speak-date)
     (emacspeak-auditory-icon 'large-movement)))
 
-(defadvice calendar-end-of-week (after emacspeak pre act)
+(defadvice calendar-end-of-week (after emacspeak pre act comp)
   "Speak the date. "
   (when (ems-interactive-p)
     (emacspeak-calendar-speak-date)
     (emacspeak-auditory-icon 'paragraph)))
 
-(defadvice calendar-end-of-month (after emacspeak pre act)
+(defadvice calendar-end-of-month (after emacspeak pre act comp)
   "Speak the date. "
   (when (ems-interactive-p)
     (emacspeak-calendar-speak-date)
     (emacspeak-auditory-icon 'section)))
 
-(defadvice calendar-end-of-year (after emacspeak pre act)
+(defadvice calendar-end-of-year (after emacspeak pre act comp)
   "Speak the date. "
   (when (ems-interactive-p)
     (emacspeak-calendar-speak-date)
@@ -274,13 +270,13 @@
          '(exit-calendar calendar-exit calendar-quit)
          do
          (eval
-          `(defadvice ,f (after emacspeak pre act)
+          `(defadvice ,f (after emacspeak pre act comp)
              "Speak modeline. "
              (when (ems-interactive-p)
                (emacspeak-auditory-icon 'close-object)
                (emacspeak-speak-mode-line)))))
 
-(defadvice insert-block-diary-entry (before emacspeak pre act)
+(defadvice insert-block-diary-entry (before emacspeak pre act comp)
   "Speak the line. "
   (when (ems-interactive-p)
     (let*
@@ -309,7 +305,7 @@
   ad-do-it
   (setq emacspeak-calendar-user-input ad-return-value)
   ad-return-value)
-(defadvice insert-anniversary-diary-entry (before emacspeak pre act)
+(defadvice insert-anniversary-diary-entry (before emacspeak pre act comp)
   "Speak the line. "
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
@@ -317,7 +313,7 @@
              (calendar-date-string
               (calendar-cursor-to-date)))))
 
-(defadvice insert-cyclic-diary-entry (after emacspeak pre act)
+(defadvice insert-cyclic-diary-entry (after emacspeak pre act comp)
   "Speak the line. "
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
@@ -325,20 +321,20 @@
 %s days"
              emacspeak-calendar-user-input)))
 
-(defadvice insert-diary-entry (after emacspeak pre act)
+(defadvice insert-diary-entry (after emacspeak pre act comp)
   "Speak the line. "
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-line)))
 
-(defadvice insert-weekly-diary-entry (before emacspeak pre act)
+(defadvice insert-weekly-diary-entry (before emacspeak pre act comp)
   "Speak the line. "
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (message "Weekly diary entry for %s"
              (calendar-day-name (calendar-cursor-to-date t)))))
 
-(defadvice insert-yearly-diary-entry (before emacspeak pre act)
+(defadvice insert-yearly-diary-entry (before emacspeak pre act comp)
   "Speak the line. "
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
@@ -346,7 +342,7 @@
              (calendar-month-name(cl-first (calendar-cursor-to-date t)))
              (cl-second (calendar-cursor-to-date t)))))
 
-(defadvice insert-monthly-diary-entry (before emacspeak pre act)
+(defadvice insert-monthly-diary-entry (before emacspeak pre act comp)
   "Speak the line. "
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
@@ -364,9 +360,35 @@
    ad-do-it
    ad-return-value))
 
+;;}}}
+;;{{{ Global sunrise/sunset wizard:
+
+(defun emacspeak-calendar-sunrise-sunset (address &optional arg)
+  "Display sunrise/sunset for specified address."
+  (interactive
+   (list
+    (read-from-minibuffer "Address: ")
+    current-prefix-arg))
+  (cl-declare (special calendar-standard-time-zone-name
+                       calendar-longitude calendar-latitude))
+  (let* ((geo (gmaps-address-geocode address))
+         (calendar-latitude (g-json-get 'lat geo))
+         (calendar-longitude (g-json-get 'lng geo))
+         (calendar-time-zone
+          (solar-get-number
+           "Enter difference from Coordinated Universal Time (in minutes): "))
+         (calendar-standard-time-zone-name
+          (cond ((zerop calendar-time-zone) "UTC")
+                ((< calendar-time-zone 0)
+                 (format "UTC%dmin" calendar-time-zone))
+                (t (format "UTC+%dmin" calendar-time-zone))))
+         (date (if arg (calendar-read-date) (calendar-current-date)))
+         (date-string (calendar-date-string date t))
+         (time-string (solar-sunrise-sunset-string date)))
+    (message "%s: %s at %s" date-string time-string address)))
+
 ;;}}}
 ;;{{{  keymap
-(cl-eval-when (load))
 
 (defun emacspeak-calendar-setup()
   "Set up appropriate bindings for calendar"
@@ -375,19 +397,17 @@
     (set-buffer calendar-buffer)
     (local-unset-key emacspeak-prefix)
     (define-key calendar-mode-map "v" 'view-diary-entries)
-    (define-key calendar-mode-map "\M-s" 'emacspeak-wizards-sunrise-sunset)
+    (define-key calendar-mode-map "\M-s" 'emacspeak-calendar-sunrise-sunset)
     (define-key calendar-mode-map  "\C-e." 'emacspeak-calendar-speak-date)
     (define-key calendar-mode-map  "\C-ee"
-      'calendar-end-of-week)))
-
-                                        ;(add-hook 'calendar-initial-window-hook 'emacspeak-calendar-setup t)
+                'calendar-end-of-week)))
 
 ;;}}}
 ;;{{{  Appointments:
 
 ;;{{{ take over and speak the appointment
 
-;;; For the present, we just take over and speak the appointment.
+;; For the present, we just take over and speak the appointment.
 
 (cl-declaim (special appt-display-duration))
 (setq appt-display-duration 90)
@@ -401,17 +421,18 @@
 
 (defun emacspeak-appt-delete-display ()
   "Function to delete appointment message"
+  (cl-declare (special appt-buffer-name))
   (and (get-buffer appt-buffer-name)
        (save-current-buffer
          (set-buffer appt-buffer-name)
          (erase-buffer))))
 
 (cl-declaim (special appt-delete-window
-                  appt-disp-window-function))
+                     appt-disp-window-function))
 
 (setq appt-disp-window-function 'emacspeak-appt-speak-appointment)
 (setq appt-delete-window 'emacspeak-appt-delete-display)
-;;;###autoload
+
 (defun emacspeak-appt-repeat-announcement ()
   "Speaks the most recently displayed appointment message if any."
   (interactive)
@@ -428,7 +449,7 @@
 
 ;;}}}
 
-(defadvice appt-add (after emacspeak pre act)
+(defadvice appt-add (after emacspeak pre act comp)
   "Confirm that the alarm got set."
   (when (ems-interactive-p)
     (let ((time (ad-get-arg 0))
@@ -438,35 +459,34 @@
 
 ;;}}}
 ;;{{{ Use GWeb if available for configuring sunrise/sunset coords
-;;;###autoload
+
 (defun emacspeak-calendar-setup-sunrise-sunset ()
   "Set up geo-coordinates using Google Maps reverse geocoding.
-To use, configure variable gweb-my-address via M-x customize-variable."
+To use, configure variable gmaps-my-address via M-x customize-variable."
   (interactive)
-  (cl-declare (special  gweb-my-address gweb-my-location
-                     calendar-latitude calendar-longitude))
+  (cl-declare (special  gmaps-my-address gmaps-my-location
+                        calendar-latitude calendar-longitude))
   (cond
-   ((null gweb-my-location)
-    (message "First customize gweb-my-address."))
+   ((null gmaps-my-location)
+    (message "First customize gmaps-my-address."))
    (t
     (setq
      calendar-latitude
-     (g-json-get 'lat (gmaps-address-geocode gweb-my-address))
+     (g-json-get 'lat (gmaps-address-geocode gmaps-my-address))
      calendar-longitude
-     (g-json-get 'lng (gmaps-address-geocode gweb-my-address)))
-    (message "Setup for %s" gweb-my-address))))
+     (g-json-get 'lng (gmaps-address-geocode gmaps-my-address))))))
 
 (defadvice calendar-sunrise-sunset (around emacspeak pre act comp)
   "Like calendar's sunrise-sunset, but speaks location intelligently."
-  (cl-declare (special gweb-my-address))
+  (cl-declare (special gmaps-my-address))
   (cond
-   ((and (boundp 'gweb-my-address)
-         gweb-my-address
+   ((and (boundp 'gmaps-my-address)
+         gmaps-my-address
          (ems-interactive-p))
     (let ((date (calendar-cursor-to-date t)))
       (message "%s at %s"
                (solar-sunrise-sunset-string date 'nolocation)
-               gweb-my-address)))
+               gmaps-my-address)))
    (t ad-do-it)))
 
 ;;}}}
@@ -477,7 +497,7 @@ To use, configure variable gweb-my-address via M-x customize-variable."
          do
          (eval
           `(defadvice ,f (after emacspeak pre act comp)
-             "Provide auditory feedback."
+             "speak."
              (when (ems-interactive-p)
                (with-current-buffer lunar-phases-buffer
                  (emacspeak-auditory-icon 'open-object)
@@ -488,7 +508,7 @@ To use, configure variable gweb-my-address via M-x customize-variable."
          do
          (eval
           `(defadvice ,f (after emacspeak pre act comp)
-             "Provide auditory feedback."
+             "speak."
              (when (ems-interactive-p)
                (with-current-buffer holiday-buffer
                  (emacspeak-auditory-icon 'open-object)
@@ -498,9 +518,8 @@ To use, configure variable gweb-my-address via M-x customize-variable."
 (provide 'emacspeak-calendar)
 ;;{{{ emacs local variables
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
