@@ -1,52 +1,53 @@
 ;;; emacspeak-compile.el --- Speech enable  navigation of  compile errors, grep matches  -*- lexical-binding: t; -*-
-;;; $Author: tv.raman.tv $ 
-;;; Description:  Emacspeak extensions to  the compile package 
-;;; Keywords: Emacspeak compile
+;; $Author: tv.raman.tv $ 
+;; Description:  Emacspeak extensions to  the compile package 
+;; Keywords: Emacspeak compile
 ;;{{{  LCD Archive entry: 
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
-;;; A speech interface to Emacs |
-;;; $Date: 2007-09-01 15:30:13 -0700 (Sat, 01 Sep 2007) $ |
-;;;  $Revision: 4532 $ | 
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com 
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ | 
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman 
-;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved. 
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman 
+;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
+;; All Rights Reserved. 
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;{{{  Introduction:
 
 ;;; Commentary:
 
-;;; This module makes compiling code from inside Emacs speech friendly.
-;;; It is an example of how a little amount of code can make Emacspeak even better.
+;; This module makes compiling code from inside Emacs speech friendly.
+;; It is an example of how a little amount of code can make Emacspeak even better.
 ;;; Code:
 
 ;;}}}
 ;;{{{ Required modules
+(require 'cl-lib)
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 
@@ -83,10 +84,11 @@
            )
          do
          (eval
-          `(defadvice ,f (after  emacspeak pre act)
+          `(defadvice ,f (after  emacspeak pre act comp)
              "Speak the line containing the error. "
              (when (ems-interactive-p)
                (dtk-stop)
+               (emacspeak-auditory-icon 'large-movement)
                (emacspeak-compilation-speak-error)))))
 
 (cl-loop for f in 
@@ -98,21 +100,21 @@
          do
          (eval
           `(defadvice ,f (after emacspeak pre act comp)
-             "Provide spoken feedback."
+             "Speak."
              (when (ems-interactive-p)
                (emacspeak-speak-line)
                (emacspeak-auditory-icon 'select-object)))))
 ;;}}}
 ;;{{{ advise process filter and sentinels
 
-(defadvice compile (after emacspeak pre act)
+(defadvice compile (after emacspeak pre act comp)
   "provide auditory confirmation"
   (when (ems-interactive-p)
     (message "Launched compilation")
     (emacspeak-auditory-icon 'task-done)))
 
-(defadvice  compilation-sentinel (after emacspeak pre act)
-  "Provide auditory feedback"
+(defadvice  compilation-sentinel (after emacspeak pre act comp)
+  "speak"
   (emacspeak-auditory-icon 'task-done)
   (message "process %s %s"
            (process-name  (ad-get-arg 0))
@@ -123,9 +125,8 @@
 
 ;;{{{  emacs local variables
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end: 
+;; local variables:
+;; folded-file: t
+;; end: 
 
 ;;}}}
