@@ -1,42 +1,42 @@
 ;;; emacspeak-custom.el --- Speech enable interactive Emacs customization  -*- lexical-binding: t; -*- 
-;;; $Id$
-;;; $Author: tv.raman.tv $ 
-;;; Description: Auditory interface to custom
-;;; Keywords: Emacspeak, Speak, Spoken Output, custom
+;;
+;; $Author: tv.raman.tv $ 
+;; Description: Auditory interface to custom
+;; Keywords: Emacspeak, Speak, Spoken Output, custom
 ;;{{{  LCD Archive entry: 
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
-;;; A speech interface to Emacs |
-;;; $Date: 2007-09-01 15:30:13 -0700 (Sat, 01 Sep 2007) $ |
-;;;  $Revision: 4532 $ | 
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com 
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ | 
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2017, T. V. Raman
-;;; All Rights Reserved. 
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (c) 1995 -- 2022, T. V. Raman
+;; All Rights Reserved. 
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  Required modules
 
@@ -46,34 +46,34 @@
 ;;}}}
 ;;{{{  Introduction
 ;;; Commentary:
-;;;Advise custom to speak.
-;;; most of the work is actually done by emacspeak-widget.el
-;;; which speech-enables the widget libraries.
+;; Advise custom to speak.
+;; most of the work is actually done by emacspeak-widget.el
+;; which speech-enables the widget libraries.
 ;;; Code:
 ;;}}}
 
 ;;{{{ advice
 
 (defadvice Custom-reset-current (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'item)
     (dtk-speak "Reset current")))
 
 (defadvice Custom-reset-saved(after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'unmodified-object)
     (dtk-speak "Reset to saved")))
 
 (defadvice Custom-reset-standard (after emacspeak act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'delete-object)
     (dtk-speak "Erase customization")))
 
 (defadvice Custom-set (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'button)
     (dtk-speak "Set for current session")))
@@ -87,55 +87,55 @@
   ad-return-value)
 
 (defadvice Custom-buffer-done (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-line)))
 
 (defadvice customize-save-customized (after emacspeak pre act comp)
-  "Provide auditory feedback. "
+  "speak. "
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'save-object)
     (message "Saved customizations.")))
 
 (defadvice custom-save-all (after emacspeak pre act comp)
-  "Provide auditory feedback. "
+  "speak. "
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'save-object)
     (message "Saved customizations.")))
 
-(defadvice customize-save-customized (around quiet pre act comp)
+(defadvice customize-save-customized (around emacspeak pre act comp)
   "Silence speech."
   (let ((dtk-quiet t)) ad-do-it))
 
 (defadvice custom-set (after emacspeak pre act comp)
-  "Provide auditory feedback. "
+  "speak. "
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'mark-object)
     (message "Set all updates.")))
 
 (defadvice customize (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-custom-goto-group)
     (emacspeak-speak-line)))
 
 (defadvice customize-group (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-custom-goto-group)
     (emacspeak-speak-line)))
 
 (defadvice customize-browse (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice customize-option (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (let ((symbol (ad-get-arg 0)))
       (emacspeak-auditory-icon 'open-object)
@@ -144,14 +144,14 @@
       (emacspeak-speak-line))))
 
 (defadvice customize-apropos (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (forward-line 0)
     (emacspeak-speak-line)))
 
 (defadvice customize-variable (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (let ((symbol (ad-get-arg 0)))
       (emacspeak-auditory-icon 'open-object)
@@ -160,28 +160,29 @@
       (emacspeak-speak-line))))
 
 (defadvice Custom-goto-parent (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line)))
 
 (defadvice Custom-newline (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'button)))
 
 ;;}}}
 ;;{{{ custom hook
 
-(add-hook 'custom-mode-hook
-          (function
-           (lambda nil
-             (emacspeak-pronounce-refresh-pronunciations))))
+(add-hook 'Custom-mode-hook
+          
+          #'(lambda nil
+              (emacspeak-pronounce-refresh-pronunciations)))
 
 ;;}}}
 ;;{{{ define voices
 (voice-setup-add-map
  '(
+   (custom-variable-obsolete voice-monotone-extra)
    (custom-group-subtitle  voice-smoothen)
    (custom-themed voice-brighten)
    (custom-visibility voice-annotate)
@@ -192,7 +193,7 @@
    (custom-button-unraised voice-smoothen)
    (custom-changed voice-smoothen)
    (custom-comment voice-monotone-medium)
-   (custom-comment-tag voice-monotone)
+   (custom-comment-tag voice-monotone-extra)
    (custom-documentation voice-brighten-medium)
    (custom-face-tag voice-lighten)
    (custom-group-tag voice-bolden)
@@ -215,7 +216,6 @@
   "^/-"
   "Pattern identifying start of custom group.")
 
-;;;###autoload
 (defun emacspeak-custom-goto-group ()
   "Jump to custom group when in a customization buffer."
   (interactive)
@@ -231,7 +231,6 @@
   "^Operate on everything in this buffer:"
   "Pattern that identifies toolbar section.")
 
-;;;###autoload
 (defun emacspeak-custom-goto-toolbar ()
   "Jump to custom toolbar when in a customization buffer."
   (interactive)
@@ -257,7 +256,7 @@
 (define-key custom-mode-map "." 'forward-paragraph)
 (define-key custom-mode-map  "\M-t" 'emacspeak-custom-goto-toolbar)
 (define-key custom-mode-map  "\M-g"
-  'emacspeak-custom-goto-group)
+            'emacspeak-custom-goto-group)
 
 ;;}}}
 ;;{{{ augment custom widgets
@@ -266,9 +265,8 @@
 (provide 'emacspeak-custom)
 ;;{{{ end of file 
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end: 
+;; local variables:
+;; folded-file: t
+;; end: 
 
 ;;}}}
