@@ -1,64 +1,68 @@
-;;; emacspeak-dired.el --- Speech enable Dired Mode -- A powerful File Manager  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $
-;;; Description:  Emacspeak extension to speech enable dired
-;;; Keywords: Emacspeak, Dired, Spoken Output
+;;; emacspeak-dired.el --- Speech enable Dired Mode -*- lexical-binding: t; -*-
+;;
+;; $Author: tv.raman.tv $
+;; Description:  Emacspeak extension to speech enable dired
+;; Keywords: Emacspeak, Dired, Spoken Output
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2008-07-19 16:09:43 -0700 (Sat, 19 Jul 2008) $ |
-;;;  $Revision: 4532 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman
-;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;{{{  Introduction:
 
 ;;; Commentary:
-;;; This module speech enables dired.
-;;; It reduces the amount of speech you hear:
-;;; Typically you hear the file names as you move through the dired buffer
-;;; Voicification is used to indicate directories, marked files etc.
+;; This module speech enables dired.
+;; It reduces the amount of speech you hear:
+;; Typically you hear the file names as you move through the dired buffer
+;; Voicification is used to indicate directories, marked files etc.
+
+;;; Code:
 
 ;;}}}
 ;;{{{  required packages
 
-;;; Code:
 (require 'cl-lib)
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
-(require 'desktop)
 (require 'dired)
+
 ;;}}}
 ;;{{{ Define personalities
 
 (voice-setup-add-map
  '(
+   (dired-broken-symlink 'voice-monotone-extra)
+   (dired-set-id  voice-animate)
+   (dired-special voice-lighten)
    (dired-header voice-smoothen)
    (dired-mark voice-lighten)
    (dired-perm-write voice-lighten-extra)
@@ -67,8 +71,7 @@
    (dired-directory voice-bolden-medium)
    (dired-symlink voice-animate-extra)
    (dired-ignored voice-lighten-extra)
-   (dired-flagged voice-animate-extra)
-   ))
+   (dired-flagged voice-animate-extra)))
 
 ;;}}}
 ;;{{{  functions:
@@ -88,7 +91,7 @@
 ;;{{{  advice:
 
 (defadvice dired-sort-toggle-or-edit (around emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (cond
    ((ems-interactive-p)
     (ems-with-messages-silenced ad-do-it)
@@ -102,7 +105,7 @@
   (emacspeak-auditory-icon 'ask-short-question))
 
 (defadvice dired-quit (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
@@ -124,7 +127,7 @@
        (emacspeak-auditory-icon 'open-object)
        (emacspeak-speak-mode-line)))))
 
-(defadvice dired-find-file  (around  emacspeak pre act)
+(defadvice dired-find-file  (around  emacspeak pre act comp)
   "Produce an auditory icon."
   (cond
    ((ems-interactive-p)
@@ -147,7 +150,7 @@
    )
  do
  (eval
-  `(defadvice ,f (after emacspeak pre act)
+  `(defadvice ,f (after emacspeak pre act comp)
      "Speak the filename."
      (when (ems-interactive-p)
        (emacspeak-auditory-icon 'large-movement)
@@ -159,33 +162,33 @@
                    dired-unmark-backward dired-maybe-insert-subdir)
  do
  (eval
-  `(defadvice ,f  (after emacspeak pre act)
+  `(defadvice ,f  (after emacspeak pre act comp)
      "Speak the filename name."
      (when (ems-interactive-p)
        (emacspeak-auditory-icon 'select-object)
        (emacspeak-dired-speak-line)))))
 
-;;; Producing auditory icons:
-;;; These dired commands do some action that causes a state change:
-;;; e.g. marking a file, and then change
-;;; the current selection, ie
-;;; move to the next line:
-;;; We speak the line moved to, and indicate the state change
-;;; with an auditory icon.
+;; Producing auditory icons:
+;; These dired commands do some action that causes a state change:
+;; e.g. marking a file, and then change
+;; the current selection, ie
+;; move to the next line:
+;; We speak the line moved to, and indicate the state change
+;; with an auditory icon.
 
-(defadvice dired-mark (after emacspeak pre act)
+(defadvice dired-mark (after emacspeak pre act comp)
   "Produce an auditory icon."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'mark-object)
     (emacspeak-dired-speak-line)))
 
-(defadvice dired-flag-file-deletion (after emacspeak pre act)
+(defadvice dired-flag-file-deletion (after emacspeak pre act comp)
   "Produce an auditory icon indicating that a file was marked for deletion."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'delete-object)
     (emacspeak-dired-speak-line)))
 
-(defadvice dired-unmark (after emacspeak pre act)
+(defadvice dired-unmark (after emacspeak pre act comp)
   "Give speech feedback. Also provide an auditory icon."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'deselect-object)
@@ -243,12 +246,8 @@ unless `dired-listing-switches' contains -l"
 ;;}}}
 ;;{{{ Additional status speaking commands
 
-(defcustom emacspeak-dired-file-cmd-options "-b"
-  "Options passed to Unix builtin `file' command."
-  :type '(choice
-          (const :tag "Brief" "-b")
-          (const :tag "Detailed" nil))
-  :group 'emacspeak-dired)
+(defvar emacspeak-dired-file-cmd-options "-b"
+  "Options passed to Unix builtin `file' command.")
 
 (defun emacspeak-dired-show-file-type (&optional file deref-symlinks)
   "Displays type of current file by running command file.
@@ -291,7 +290,7 @@ On a directory line, run du -s on the directory to speak its size."
       (when (= size -1)
         (setq size
               (nth  4
-                    (split-string (ems-this-line)))))
+                    (split-string (ems--this-line)))))
       (emacspeak-auditory-icon 'select-object)
       (message "File size %s"
                size))
@@ -353,35 +352,43 @@ On a directory line, run du -s on the directory to speak its size."
 (defun emacspeak-dired-setup-keys ()
   "Add emacspeak keys to dired."
   (cl-declare (special dired-mode-map))
+  (define-key dired-mode-map "F" 'emacspeak-wizards-find-file-as-root)
   (define-key dired-mode-map "E" 'emacspeak-dired-epub-eww)
-  (define-key dired-mode-map (kbd "C-j") 'emacspeak-dired-open-this-file)
-  (define-key dired-mode-map (kbd "C-RET") 'emacspeak-dired-open-this-file)
+  (define-key dired-mode-map (ems-kbd "C-j") 'emacspeak-dired-open-this-file)
+  (define-key dired-mode-map (ems-kbd "C-RET") 'emacspeak-dired-open-this-file)
   (define-key dired-mode-map [C-return] 'emacspeak-dired-open-this-file)
   (define-key dired-mode-map "'" 'emacspeak-dired-show-file-type)
   (define-key  dired-mode-map "/" 'emacspeak-dired-speak-file-permissions)
-  (define-key  dired-mode-map ";" 'emacspeak-dired-speak-header-line)
+  (define-key  dired-mode-map ";" 'emacspeak-dired-play-duration)
+  (define-key  dired-mode-map (ems-kbd "M-;") 'emacspeak-m-player-add-to-dynamic)
   (define-key  dired-mode-map "a" 'emacspeak-dired-speak-file-access-time)
   (define-key dired-mode-map "c" 'emacspeak-dired-speak-file-modification-time)
   (define-key dired-mode-map "z" 'emacspeak-dired-speak-file-size)
   (define-key dired-mode-map "\M-t" 'emacspeak-dired-speak-symlink-target)
   (define-key dired-mode-map "\C-i" 'emacspeak-speak-next-field)
-  (define-key dired-mode-map  "," 'emacspeak-speak-previous-field))
-(add-hook 'dired-mode-hook  'emacspeak-dired-initialize 'append)
-
+  (define-key dired-mode-map  "," 'emacspeak-dired-speak-header-line))
 ;;}}}
 ;;{{{ Advice locate:
+(defun emacspeak-dired-open-this-directory ()
+  "Open directory corresponding to file on current line."
+  (interactive)
+  (cl-assert (dired-get-filename) t "No file here.")
+  (funcall-interactively #'dired (file-name-directory    (dired-get-filename))))
+
 (cl-loop
  for f in
  '(locate locate-with-filter)
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
-     "Provide auditory feedback."
+     "speak."
      (when (ems-interactive-p)
        (emacspeak-speak-line)
        (emacspeak-auditory-icon 'open-object)))))
-(load-library "locate")
+(load "locate" t t)
+
 (cl-declaim (special locate-mode-map))
+(define-key locate-mode-map  "j" 'emacspeak-dired-open-this-directory)
 (define-key locate-mode-map  [C-return] 'emacspeak-dired-open-this-file)
 ;;}}}
 ;;{{{ Context-sensitive openers:
@@ -393,9 +400,25 @@ On a directory line, run du -s on the directory to speak its size."
 (defun emacspeak-dired-play-this-playlist ()
   "Plays playlist on current line."
   (emacspeak-m-player (dired-get-filename) 'playlist))
+(declare-function emacspeak-epub-eww "emacspeak-dired" t)
+
+(defun emacspeak-dired-rpm-query-in-dired ()
+  "Run rpm -qi on current dired entry."
+  (interactive)
+  (cl-declare (special major-mode))
+  (unless (eq major-mode 'dired-mode)
+    (error "This command should be used in dired mode."))
+  (shell-command
+   (format "rpm -qi ` rpm -qf %s`"
+           (dired-get-filename 'no-location)))
+  (other-window 1)
+  (search-forward "Summary" nil t)
+  (emacspeak-speak-line))
 
 (defconst emacspeak-dired-opener-table
   `(("\\.epub$"  emacspeak-dired-epub-eww)
+    ("\\.rpm$" emacspeak-dired-rpm-query-in-dired)
+    ("\\.mid$"  emacspeak-dired-midi-play)
     ("\\.xhtml" emacspeak-dired-eww-open)
     ("\\.html" emacspeak-dired-eww-open)
     ("\\.htm" emacspeak-dired-eww-open)
@@ -407,7 +430,8 @@ On a directory line, run du -s on the directory to speak its size."
   "Association of filename extension patterns to Emacspeak handlers.")
 
 (defun emacspeak-dired-open-this-file  ()
-  "Smart dired opener. Invokes appropriate Emacspeak handler on  current file in DirEd."
+  "Smart dired opener. Invokes appropriate Emacspeak handler on
+current file in DirEd."
   (interactive)
   (let* ((f (dired-get-filename nil t))
          (ext (file-name-extension f))
@@ -415,16 +439,15 @@ On a directory line, run du -s on the directory to speak its size."
     (unless f (error "No file here."))
     (unless ext (error "This entry has no extension."))
     (setq handler
-          (second
-           (find
+          (cl-second
+           (cl-find
             (format ".%s" ext)
             emacspeak-dired-opener-table
             :key #'car                  ; extract pattern from entry 
             :test #'(lambda (e pattern) (string-match  pattern e)))))
     (cond
      ((and handler (fboundp handler))
-      (emacspeak-auditory-icon 'task-done)
-      (funcall handler))
+      (funcall-interactively handler))
      (t (call-interactively #'dired-find-file)))))
 
 (defun emacspeak-dired-eww-open ()
@@ -439,11 +462,20 @@ On a directory line, run du -s on the directory to speak its size."
     (with-current-buffer buffer
       (markdown-preview))))
 
+(declare-function emacspeak-wizards-pdf-open
+                  "emacspeak-wizards" (filename &optional ask-pwd))
+
 (defun emacspeak-dired-pdf-open ()
   "Open PDF file on current dired line."
   (interactive)
   (emacspeak-wizards-pdf-open (dired-get-filename current-prefix-arg)))
 
+(defun emacspeak-dired-midi-play ()
+  "Play midi  file on current dired line."
+  (interactive)
+  (emacspeak-wizards-midi-using-m-score
+   (dired-get-filename current-prefix-arg)))
+
 (defun emacspeak-dired-epub-eww ()
   "Open epub on current line  in EWW"
   (interactive)
@@ -456,13 +488,81 @@ On a directory line, run du -s on the directory to speak its size."
   (emacspeak-table-find-csv-file (dired-get-filename current-prefix-arg)))
 
 ;;}}}
+;;{{{ Locate results as a play-list:
 
+(defun emacspeak-locate-play-results-as-playlist (&optional shuffle)
+  "Treat locate results as a play-list.
+Optional interactive prefix arg shuffles playlist."
+  (interactive "P")
+  (cl-declare (special emacspeak-m-player-options))
+  (cl-assert (eq major-mode 'locate-mode) t "Not in a locate buffer")
+  (save-excursion
+    (goto-char (point-min))
+    (dired-next-line 3)
+    (let* ((m3u (make-temp-file "locate-playlist" nil ".m3u"))
+           (buff (find-file-noselect m3u))
+           (results nil)
+           (file (dired-file-name-at-point)))
+      (while file
+        (push file results)
+        (dired-next-line 1)
+        (setq file  (dired-file-name-at-point)))
+      (setq results (nreverse results))
+      (message "%s tracks matching " (length results))
+      (with-current-buffer buff
+        (cl-loop
+         for f in results do
+         (insert (format "%s\n" (expand-file-name f))))
+        (save-buffer))
+      (let ((emacspeak-m-player-options
+             (if shuffle
+                 (append emacspeak-m-player-options (list "-shuffle"))
+               emacspeak-m-player-options)))
+        (emacspeak-m-player  m3u 'play-list)))))
+
+;;}}}
+;;{{{ Play Duration Using Soxi:
+
+(defun emacspeak-dired-play-duration ()
+  "Speak duration of MP3 files.
+If on a file, speak its duration.
+If on a directory, speak the total duration of all mp3 files under
+  that directory."
+  (interactive)
+  (cl-assert (executable-find "soxi")
+             t "This command needs soxi installed.")
+  (cl-assert (eq major-mode 'dired-mode)
+             t "This command is only available in dired buffers.")
+  (let* ((f   (dired-get-filename)))
+    (cond
+     ((and (not (file-directory-p f))
+           (string-match "\\.mp3$" f))
+      (message "%s %s"
+               (shell-command-to-string (format "soxi -d '%s'" f))
+               (file-name-base f)))
+     ((file-directory-p f)
+      (message "%s in %s"
+               (shell-command-to-string
+                (format
+                 "find %s -name '*.mp3' -print0 | xargs -0 soxi -Td 2>/dev/null"
+                 (shell-quote-argument f)))
+               (file-name-base f)))
+     (t (message "No mp3  on current line.")))))
+
+;;}}}
+;;{{{ Open Downloads:
+
+(defun emacspeak-dired-downloads ()
+  "Open Downloads directory."
+  (interactive)
+  (funcall-interactively 'dired (expand-file-name "~/Downloads") "-alt"))
+
+;;}}}
 (provide 'emacspeak-dired)
 ;;{{{ emacs local variables
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
