@@ -1,43 +1,43 @@
 ;;; emacspeak-dismal.el --- Speech enable Dismal -- An Emacs Spreadsheet program  -*- lexical-binding: t; -*-
-;;; Description: spread sheet extension
-;;; Keywords:emacspeak, audio interface to emacs spread sheets
+;; Description: spread sheet extension
+;; Keywords:emacspeak, audio interface to emacs spread sheets
 ;;{{{  LCD Archive entry: 
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2008-06-21 10:50:41 -0700 (Sat, 21 Jun 2008) $ |
-;;;  $Revision: 4532 $ | 
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ | 
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman 
-;;; Copyright (c) 1995 by T. V. Raman  
-;;; All Rights Reserved. 
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman 
+;; Copyright (c) 1995 by T. V. Raman  
+;; All Rights Reserved. 
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
 ;;{{{  Introduction
 
-;;; emacspeak extensions to the dismal spreadsheet. 
-;;; Dismal can be found at ftp://cs.nyu.edu/pub/local/fox/dismal
+;; emacspeak extensions to the dismal spreadsheet. 
+;; Dismal can be found at ftp://cs.nyu.edu/pub/local/fox/dismal
 ;;; Code:
 
 ;;}}}
@@ -48,32 +48,20 @@
 ;;}}}
 ;;{{{ Forward Decls:
 
-
-(declare-function dismal-get-val nil "dismal")
-(declare-function  dismal-convert-cellexpr-to-string nil "dismal")
-(declare-function 
-    dismal-get-exp nil "dismal")
-(declare-function  dismal-display-current-cell-expr nil "dismal")
-(declare-function  dis-forward-row nil "dismal")
-(declare-function 
-    dis-backward-row nil "dismal")
-(declare-function  dis-forward-column nil "dismal")
-(declare-function  dis-backward-column nil "dismal")
-(declare-function 
-    dis-recalculate-matrix nil "dismal")
-
-;;}}}
-;;{{{ custom
-
-(defgroup emacspeak-dismal nil
-  "Spread-sheet for the Emacspeak Desktop."
-  :group 'emacspeak
-  :prefix "emacspeak-dismal-")
+(declare-function dismal-get-val "ext:dismal" (r c))
+(declare-function  dismal-convert-cellexpr-to-string "dismal" (sexp))
+(declare-function dismal-get-exp "dismal" (r c))
+(declare-function  dismal-display-current-cell-expr "dismal" (r c))
+(declare-function  dis-forward-row "dismal" (rows))
+(declare-function dis-backward-row "dismal" (rows))
+(declare-function  dis-forward-column "dismal" (cols))
+(declare-function  dis-backward-column "dismal" (cols))
+(declare-function dis-recalculate-matrix "dismal" nil)
 
 ;;}}}
 ;;{{{  helper functions:
 
-;;; return cell value as a string
+;; return cell value as a string
 
 (defun emacspeak-dismal-cell-value (row col)
   (let ((value (dismal-get-val row col)))
@@ -85,7 +73,7 @@
   (cl-declare (special dismal-current-row dismal-current-col))
   (emacspeak-dismal-cell-value dismal-current-row dismal-current-col))
 
-;;; return entry in col 0 of current row as a string:
+;; return entry in col 0 of current row as a string:
 
 (defun emacspeak-dismal-current-row-header ()
   (cl-declare (special dismal-current-row))
@@ -182,19 +170,17 @@ The `column header' is the entry in row 0."
 (setq-default emacspeak-dismal-row-summarizer-list nil)
 (setq-default emacspeak-dismal-col-summarizer-list nil)
 (setq-default emacspeak-dismal-sheet-summarizer-list nil)
-(defcustom emacspeak-dismal-value-personality voice-animate
-  "Personality used for speaking cell values in summaries."
-  :group 'emacspeak-dismal
-  :type 'symbol)
+(defvar emacspeak-dismal-value-personality voice-animate
+  "Personality used for speaking cell values in summaries.")
 
 (defun emacspeak-dismal-row-summarize  ()
   "Summarizes a row using the specification in list
 emacspeak-dismal-row-summarizer-list"
   (interactive)
   (cl-declare (special emacspeak-dismal-row-summarizer-list
-                    emacspeak-dismal-value-personality
-                    voice-lock-mode
-                    dismal-current-row))
+                       emacspeak-dismal-value-personality
+                       voice-lock-mode
+                       dismal-current-row))
   (unless  (and  emacspeak-dismal-row-summarizer-list
                  (vectorp emacspeak-dismal-row-summarizer-list))
     (setq emacspeak-dismal-row-summarizer-list
@@ -203,33 +189,32 @@ emacspeak-dismal-row-summarizer-list"
   (let ((summary nil))
     (setq summary 
           (mapconcat
-           (function
-            (lambda (token)
-              (let ((value nil))
-                (cond
-                 ((stringp token) token)
-                 ((numberp token)
-                  (setq value
-                        (format "%s"
-                                (emacspeak-dismal-cell-value
-                                 dismal-current-row token)))
-                  (put-text-property  0   (length value)
-                                      'personality  emacspeak-dismal-value-personality 
+           #'(lambda (token)
+               (let ((value nil))
+                 (cond
+                  ((stringp token) token)
+                  ((numberp token)
+                   (setq value
+                         (format "%s"
+                                 (emacspeak-dismal-cell-value
+                                  dismal-current-row token)))
+                   (put-text-property  0   (length value)
+                                       'personality  emacspeak-dismal-value-personality 
+                                       value)
+                   value)
+                  ((and (listp token)
+                        (numberp (cl-first token))
+                        (numberp (cl-second token)))
+                   (setq value
+                         (format "%s"
+                                 (emacspeak-dismal-cell-value
+                                  (cl-first token)
+                                  (cl-second token))))
+                   (put-text-property 0   (length value)
+                                      'personality emacspeak-dismal-value-personality 
                                       value)
-                  value)
-                 ((and (listp token)
-                       (numberp (cl-first token))
-                       (numberp (cl-second token)))
-                  (setq value
-                        (format "%s"
-                                (emacspeak-dismal-cell-value
-                                 (cl-first token)
-                                 (cl-second token))))
-                  (put-text-property 0   (length value)
-                                     'personality emacspeak-dismal-value-personality 
-                                     value)
-                  value)
-                 (t  (format "%s" token))))))
+                   value)
+                  (t  (format "%s" token)))))
            emacspeak-dismal-row-summarizer-list 
            " "))
     (dtk-speak summary)))
@@ -239,8 +224,8 @@ emacspeak-dismal-row-summarizer-list"
 emacspeak-dismal-col-summarizer-list"
   (interactive)
   (cl-declare (special emacspeak-dismal-col-summarizer-list
-                    emacspeak-dismal-value-personality voice-lock-mode
-                    dismal-current-col))
+                       emacspeak-dismal-value-personality voice-lock-mode
+                       dismal-current-col))
   (unless  (and  emacspeak-dismal-col-summarizer-list
                  (vectorp emacspeak-dismal-col-summarizer-list))
     (setq emacspeak-dismal-col-summarizer-list
@@ -249,33 +234,32 @@ emacspeak-dismal-col-summarizer-list"
   (let ((summary nil))
     (setq summary 
           (mapconcat
-           (function
-            (lambda (token)
-              (let ((value nil))
-                (cond
-                 ((stringp token) token)
-                 ((numberp token)
-                  (setq value
-                        (format "%s"
-                                (emacspeak-dismal-cell-value token
-                                                             dismal-current-col)))
-                  (put-text-property 0 (length value)
-                                     'personality
-                                     emacspeak-dismal-value-personality value)
-                  value)
-                 ((and (listp token)
-                       (numberp (cl-first token))
-                       (numberp (cl-second token)))
-                  (setq value
-                        (format "%s"
-                                (emacspeak-dismal-cell-value
-                                 (cl-first token)
-                                 (cl-second token))))
-                  (put-text-property 0 (length value)
-                                     'personality
-                                     emacspeak-dismal-value-personality value)
-                  value)
-                 (t  (format "%s" token))))))
+           #'(lambda (token)
+               (let ((value nil))
+                 (cond
+                  ((stringp token) token)
+                  ((numberp token)
+                   (setq value
+                         (format "%s"
+                                 (emacspeak-dismal-cell-value token
+                                                              dismal-current-col)))
+                   (put-text-property 0 (length value)
+                                      'personality
+                                      emacspeak-dismal-value-personality value)
+                   value)
+                  ((and (listp token)
+                        (numberp (cl-first token))
+                        (numberp (cl-second token)))
+                   (setq value
+                         (format "%s"
+                                 (emacspeak-dismal-cell-value
+                                  (cl-first token)
+                                  (cl-second token))))
+                   (put-text-property 0 (length value)
+                                      'personality
+                                      emacspeak-dismal-value-personality value)
+                   value)
+                  (t  (format "%s" token)))))
            emacspeak-dismal-col-summarizer-list 
            " "))
     (dtk-speak summary)))
@@ -290,17 +274,16 @@ emacspeak-dismal-sheet-summarizer-list"
       (dis-recalculate-matrix))
     (message 
      (mapconcat
-      (function
-       (lambda (token)
-         (cond
-          ((stringp token) token)
-          ((and (listp token)
-                (numberp (cl-first token))
-                (numberp (cl-second token)))
-           (emacspeak-dismal-cell-value
-            (cl-first token)
-            (cl-second token)))
-          (t  (format "%s" token)))))
+      #'(lambda (token)
+          (cond
+           ((stringp token) token)
+           ((and (listp token)
+                 (numberp (cl-first token))
+                 (numberp (cl-second token)))
+            (emacspeak-dismal-cell-value
+             (cl-first token)
+             (cl-second token)))
+           (t  (format "%s" token))))
       emacspeak-dismal-sheet-summarizer-list 
       " "))))
 
@@ -337,7 +320,7 @@ emacspeak-dismal-sheet-summarizer-list"
 ;;}}}
 ;;{{{  key bindings
 
-;;; record emacspeak stat that we want dismal to save
+;; record emacspeak stat that we want dismal to save
 (defvar emacspeak-dismal-already-customized-dismal nil
   "Records if we have customized dismal.
 Checked by emacspeak specific dis-mode-hooks entry.")
@@ -346,7 +329,7 @@ Checked by emacspeak specific dis-mode-hooks entry.")
           #'(lambda nil
               (cl-declare (special dismal-saved-variables dismal-map))
               (define-key dismal-map (concat emacspeak-prefix "e")
-                'dis-last-column)
+                          'dis-last-column)
               (define-key dismal-map emacspeak-prefix 'emacspeak-prefix-command)
               (unless emacspeak-dismal-already-customized-dismal
                 (setq emacspeak-dismal-already-customized-dismal t)
@@ -365,7 +348,7 @@ Checked by emacspeak specific dis-mode-hooks entry.")
      (local-unset-key emacspeak-prefix)
      (define-key dismal-map emacspeak-prefix 'emacspeak-prefix-command)
      (define-key dismal-map (concat emacspeak-prefix "e")
-       'dis-last-column)
+                 'dis-last-column)
      (define-key dismal-map  "," 'emacspeak-dismal-display-cell-expression)
      (define-key dismal-map  "." 'emacspeak-dismal-display-cell-value)
      (define-key dismal-map "R" 'emacspeak-dismal-display-cell-with-row-header)
@@ -382,13 +365,13 @@ Checked by emacspeak specific dis-mode-hooks entry.")
 
 ;;}}}
 ;;{{{ customize for use with html helper mode
-(defadvice dis-html-dump-file (around fix pre act comp)
+(defadvice dis-html-dump-file (around emacspeak pre act comp)
   "Sets html-helper-build-new-buffer to nil first so we dont
 end up building a template page first."
 
   (let ((html-helper-build-new-buffer nil)) ad-do-it))
 
-(defadvice dis-html-dump-range (around fix pre act comp)
+(defadvice dis-html-dump-range (around emacspeak pre act comp)
   "Sets html-helper-build-new-buffer to nil first so we dont
 end up building a template page first."
 
@@ -398,9 +381,8 @@ end up building a template page first."
 (provide  'emacspeak-dismal)
 ;;{{{  emacs local variables 
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end: 
+;; local variables:
+;; folded-file: t
+;; end: 
 
 ;;}}}
