@@ -1,73 +1,83 @@
 ;;; emacspeak-ecb.el --- speech-enable Emacs Class Browser  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $
-;;; Description:  Emacspeak module for speech-enabling Emacs
-;;; Class Browser
-;;; Keywords: Emacspeak, ecb
+;;
+;; $Author: tv.raman.tv $
+;; Description:  Emacspeak module for speech-enabling Emacs
+;; Class Browser
+;; Keywords: Emacspeak, ecb
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-09-01 15:30:13 -0700 (Sat, 01 Sep 2007) $ |
-;;;  $Revision: 4074 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4074 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2017, T. V. Raman
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;{{{  Introduction:
+
+;;; Commentary:
+;; The ECB is an Emacs Class Browser.
+;; This module speech-enables ECB
+;;; Code:
+
+;;}}}
 ;;{{{ required modules
 
+(cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
-(eval-when-compile
-  (require 'ecb "ecb" 'no-error)
-  (require 'tree-buffer "tree-buffer" 'no-error))
+
 ;;}}}
-;;{{{  Introduction:
-;;; Commentary:
-;;; The ECB is an Emacs Class Browser.
-;;; This module speech-enables ECB
-;;; Code:
+;;{{{ Forward Declarations:
+
+(declare-function tree-node->expandable "tree-buffer" (cl-x))
+(declare-function tree-node->expanded "tree-buffer" (cl-x))
+(declare-function ecb-goto-window-methods "ecb-method-browser" nil)
+(declare-function ecb-goto-window-directories "ecb-file-browser" nil)
+(declare-function ecb-goto-window-history "ecb-file-browser" nil)
+(declare-function ecb-goto-window-sources "ecb-file-browser" nil)
+
 ;;}}}
 ;;{{{  advice interactive commands
 
 (defadvice ecb-activate (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice ecb-cancel-dialog (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice ecb-show-help (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'help)
     (emacspeak-speak-mode-line)))
@@ -87,13 +97,13 @@
  do
  (eval 
   `(defadvice ,f (after emacspeak pre act comp)
-     "Provide auditory feedback."
+     "speak."
      (when (ems-interactive-p)
        (emacspeak-speak-line)
        (emacspeak-auditory-icon 'select-object)))))
 
 (defadvice ecb-select-ecb-frame (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-speak-mode-line)
     (emacspeak-auditory-icon 'select-object)))
@@ -101,14 +111,14 @@
 ;;}}}
 ;;{{{  inform tree browser about emacspeak
 
-;;; define emacspeak versions of these special tree search
-;;; commands
-;;; need these to get ECB working outside X
+;; define emacspeak versions of these special tree search
+;; commands
+;; need these to get ECB working outside X
 
 (defun emacspeak-ecb-tree-backspace ()
   "Back up during incremental search in tree buffers."
   (interactive)
-  (declare (special tree-buffer-incr-searchpattern))
+  (cl-declare (special tree-buffer-incr-searchpattern))
   ;; reduce by one from the end
   (setq tree-buffer-incr-searchpattern
         (substring tree-buffer-incr-searchpattern
@@ -121,7 +131,7 @@
 (defun emacspeak-ecb-tree-clear ()
   "Clear search pattern during incremental search in tree buffers."
   (interactive)
-  (declare (special tree-buffer-incr-searchpattern))  
+  (cl-declare (special tree-buffer-incr-searchpattern))  
   (setq tree-buffer-incr-searchpattern "")
   (dtk-speak "Cleared search pattern."))
 
@@ -135,15 +145,14 @@ available."
                                  tree-buffer-key-map
                                  global-map))
     (define-key tree-buffer-key-map "\d"
-      'emacspeak-ecb-tree-backspace)
+                'emacspeak-ecb-tree-backspace)
     (define-key tree-buffer-key-map '[delete]
-      'emacspeak-ecb-tree-backspace)
+                'emacspeak-ecb-tree-backspace)
     (define-key tree-buffer-key-map '[home]
-      'emacspeak-ecb-tree-clear)
+                'emacspeak-ecb-tree-clear)
     ))
 
-(defadvice tree-buffer-incremental-node-search 
-    (around emacspeak pre act comp)
+(defadvice tree-buffer-incremental-node-search (around emacspeak pre act comp)
   "Track search and provide appropriate auditory feedback."
   
   (cond
@@ -172,7 +181,7 @@ available."
   ad-return-value)
 
 (defadvice tree-buffer-select (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-line)))
@@ -183,7 +192,7 @@ available."
 
 (defadvice tree-node-toggle-expanded (after emacspeak pre
                                             act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (let ((node (ad-get-arg 0))) ;; note that logic is reversed
       (cond
@@ -202,19 +211,19 @@ available."
   (dtk-speak ad-return-value))
 
 (defadvice tree-buffer-arrow-pressed (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'button)
     (emacspeak-speak-line)))
 
 (defadvice tree-buffer-tab-pressed (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'button)
     (emacspeak-speak-line)))
 
 (defadvice tree-buffer-return-pressed (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'button)
     (emacspeak-speak-line)))
@@ -267,9 +276,8 @@ available."
 (provide 'emacspeak-ecb)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: nil
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
