@@ -1,49 +1,49 @@
 ;;; emacspeak-elfeed.el --- Speech-enable ELFEED, A Feed Reader -*- lexical-binding: t; -*-
-;;; $Id: emacspeak-elfeed.el 4797 2007-07-16 23:31:22Z tv.raman.tv $
-;;; $Author: tv.raman.tv $
-;;; Description:  Speech-enable ELFEED A Feed Reader For Emacs
-;;; Keywords: Emacspeak,  Audio Desktop elfeed, Feed Reader
+;; $Id: emacspeak-elfeed.el 4797 2007-07-16 23:31:22Z tv.raman.tv $
+;; $Author: tv.raman.tv $
+;; Description:  Speech-enable ELFEED A Feed Reader For Emacs
+;; Keywords: Emacspeak,  Audio Desktop elfeed, Feed Reader
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
-;;;  $Revision: 4532 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman
-;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNELFEED FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNELFEED FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  introduction
 
 ;;; Commentary:
-;;; ELFEED ==  Feed Reader for Emacs.
-;;; Install from elpa
-;;; M-x package-install  elfeed
+;; ELFEED ==  Feed Reader for Emacs.
+;; Install from elpa
+;; M-x package-install  elfeed
 
 ;;}}}
 ;;{{{  Required modules
@@ -59,7 +59,7 @@
  '(
    (elfeed-search-date-face  voice-smoothen)
    (elfeed-search-title-face voice-bolden)
-   (elfeed-search-unread-title-face voice-bolden-medium)
+   (elfeed-search-unread-title-face voice-bolden-extra)
    (elfeed-search-feed-face voice-animate)
    (elfeed-search-tag-face voice-lighten)))
 
@@ -79,7 +79,7 @@
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
-     "Provide auditory feedback."
+     "speak."
      (when (ems-interactive-p)
        (emacspeak-auditory-icon 'task-done)
        (emacspeak-speak-line)))))
@@ -90,7 +90,7 @@
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
-     "Provide auditory feedback."
+     "speak."
      (when (ems-interactive-p)
        (emacspeak-auditory-icon 'select-object)
        (emacspeak-speak-line)))))
@@ -99,15 +99,19 @@
   "Emacspeak setup."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)))
-
-(defadvice elfeed-kill-buffer (after emacspeak pre act  comp)
-  "Provide auditory feedback."
-  (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'close-object)
-    (emacspeak-speak-mode-line)))
+(cl-loop
+ for f in
+ '(elfeed-kill-buffer  elfeed-search-quit-window)
+ do
+ (eval
+  `(defadvice ,f (after emacspeak pre act  comp)
+     "speak."
+     (when (ems-interactive-p)
+       (emacspeak-auditory-icon 'close-object)
+       (emacspeak-speak-mode-line)))))
 
 (defadvice elfeed-search-yank (after emacspeak pre act  comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'yank-object)))
 
@@ -144,13 +148,13 @@
 (defun emacspeak-elfeed-next-entry ()
   "Move to next entry and speak it."
   (interactive)
-  (next-line)
+  (forward-line 1)
   (emacspeak-elfeed-speak-entry-at-point))
 
 (defun emacspeak-elfeed-previous-entry ()
   "Move to previous entry and speak it."
   (interactive)
-  (previous-line)
+  (forward-line -1)
   (emacspeak-elfeed-speak-entry-at-point))
 
 (defun emacspeak-elfeed-filter-entry-at-point ()
@@ -159,19 +163,8 @@
   (cl-declare (special emacspeak-we-recent-xpath-filter))
   (let* ((entry (emacspeak-elfeed-entry-at-point))
          (link(elfeed-entry-link entry)))
-    (cond
-     (entry (elfeed-untag  entry 'unread)
-            (emacspeak-we-xslt-filter emacspeak-we-recent-xpath-filter link 'speak))
-     (t (message "No link under point.")))))
-
-(defun emacspeak-elfeed-w3-filter-entry-at-point ()
-  "Display current article after filtering using W3.
-Work-around for async fetch bug in EWW."
-  (interactive)
-  (cl-declare (special emacspeak-we-recent-xpath-filter))
-  (let* ((browse-url-browser-function 'browse-url-w3)
-         (entry (emacspeak-elfeed-entry-at-point))
-         (link(elfeed-entry-link entry)))
+    (when (string=  "" emacspeak-we-recent-xpath-filter)
+      (setq emacspeak-we-recent-xpath-filter "//p"))
     (cond
      (entry (elfeed-untag  entry 'unread)
             (emacspeak-we-xslt-filter emacspeak-we-recent-xpath-filter link 'speak))
@@ -187,17 +180,6 @@ Work-around for async fetch bug in EWW."
             (eww link))
      (t (message "No link under point.")))))
 
-(defun emacspeak-elfeed-w3-entry-at-point ()
-  "Display current article in W3."
-  (interactive)
-  (let* ((browse-url-browser-function #'browse-url-w3)
-         (entry (emacspeak-elfeed-entry-at-point))
-         (link(elfeed-entry-link entry)))
-    (cond
-     (entry (elfeed-untag  entry 'unread)
-            (eww link))
-     (t (message "No link under point.")))))
-
 ;;}}}
 ;;{{{ Silence warnings/errors
 (cl-loop
@@ -220,18 +202,16 @@ Work-around for async fetch bug in EWW."
   (define-key elfeed-search-mode-map "n" 'emacspeak-elfeed-next-entry)
   (define-key elfeed-search-mode-map "p" 'emacspeak-elfeed-previous-entry)
   (define-key elfeed-search-mode-map "." 'emacspeak-elfeed-filter-entry-at-point)
+  (define-key elfeed-search-mode-map [right] 'emacspeak-elfeed-filter-entry-at-point)
   (define-key elfeed-search-mode-map "e" 'emacspeak-elfeed-eww-entry-at-point)
-  (define-key elfeed-search-mode-map " "'emacspeak-elfeed-speak-entry-at-point)
-  (define-key elfeed-search-mode-map "W" 'emacspeak-elfeed-w3-entry-at-point)
-  (define-key elfeed-search-mode-map "w" 'emacspeak-elfeed-w3-filter-entry-at-point))
+  (define-key elfeed-search-mode-map " "'emacspeak-elfeed-speak-entry-at-point))
 
 ;;}}}
 (provide 'emacspeak-elfeed)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
