@@ -1,61 +1,63 @@
 ;;; emacspeak-emms.el --- Speech-enable EMMS Multimedia UI  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $
-;;; Description:  Emacspeak extension to speech-enable EMMS
-;;; Keywords: Emacspeak, Multimedia
+;;
+;; $Author: tv.raman.tv $
+;; Description:  Emacspeak extension to speech-enable EMMS
+;; Keywords: Emacspeak, Multimedia
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-08-27 17:54:54 -0700 (Mon, 27 Aug 2007) $ |
-;;;  $Revision: 4150 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4150 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2017, T. V. Raman
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  Introduction
 
 ;;; Commentary:
-;;;Speech-enables EMMS --- the Emacs equivalent of XMMS
-;;; See
-;;; http://savannah.gnu.org/project/emms
-;;; EMMS is under active development,
-;;; to get the current CVS version, use Emacspeak command
-;;; M-x emacspeak-cvs-gnu-get-project-snapshot RET emms RET
-;;;
+;; Speech-enables EMMS --- the Emacs equivalent of XMMS
+;; available from  the Emacs package archive.
+;; http://savannah.gnu.org/project/emms
+;; EMMS is under active development,
+;; to get the current CVS version, use Emacspeak command
+;; M-x emacspeak-cvs-gnu-get-project-snapshot RET emms RET
+;; 
 ;;; Code:
 
 ;;}}}
 ;;{{{ required modules
-
+(require 'cl-lib)
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
-(require 'emms "emms" 'no-error)
+(declare-function emms-playlist-current-selected-track "emacspeak-emms" t)
+(declare-function emms-player-pause "emacspeak-emms" t)
+
 ;;}}}
 ;;{{{ module emms:
 
@@ -74,8 +76,8 @@
              (when (ems-interactive-p)
                (emacspeak-auditory-icon 'select-object)))))
 
-;;; these commands should not be made to talk since that would  interferes
-;;; with real work.
+;; these commands should not be made to talk since that would  interferes
+;; with real work.
 (cl-loop for f in
          '(emms-start emms-stop emms-sort
                       emms-shuffle emms-random)
@@ -92,7 +94,7 @@
          do
          (eval
           `(defadvice ,f (after emacspeak pre act comp)
-             "Provide auditory feedback."
+             "speak."
              (when (ems-interactive-p)
                (emacspeak-auditory-icon 'large-movement)
                (emacspeak-speak-line)))))
@@ -102,13 +104,13 @@
          do
          (eval
           `(defadvice ,f (after emacspeak pre act comp)
-             "Provide auditory feedback."
+             "speak."
              (when (ems-interactive-p)
                (emacspeak-speak-mode-line)
                (emacspeak-auditory-icon 'open-object)))))
 
 (defadvice emms-browser-bury-buffer (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-speak-mode-line)
     (emacspeak-auditory-icon 'close-object)))
@@ -119,17 +121,17 @@
 (defadvice emms-stream-mode (after emacspeak pre act comp)
   "Update keymaps."
   (define-key emms-stream-mode-map "\C-e"
-    'emacspeak-prefix-command))
+              'emacspeak-prefix-command))
 
 (defadvice emms-stream-delete-bookmark (after emacspeak pre act
                                               comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'delete-object)
     (emacspeak-speak-line)))
 
 (defadvice emms-stream-save-bookmarks-file (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'save-object)
     (message "Saved stream bookmarks.")))
@@ -142,7 +144,7 @@
          do
          (eval
           `(defadvice ,f (after emacspeak pre act comp)
-             "Provide auditory feedback."
+             "speak."
              (when (ems-interactive-p)
                (emacspeak-speak-mode-line)))))
 
@@ -151,10 +153,10 @@
          do
          (eval
           `(defadvice ,f (after emacspeak pre act comp)
-             "Provide auditory feedback."
+             "speak."
              (when (ems-interactive-p)
                (emacspeak-speak-line)))))
-(defadvice emms-playlist-mode-bury-buffer (after emacspeak pre act)
+(defadvice emms-playlist-mode-bury-buffer (after emacspeak pre act comp)
   "Announce the buffer that becomes current."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
@@ -163,9 +165,7 @@
 ;;}}}
 ;;{{{ silence chatter from info
 
-(defadvice emms-info-really-initialize-track (around emacspeak
-                                                     pre act
-                                                     comp)
+(defadvice emms-info-really-initialize-track (around emacspeak pre act comp)
   "Silence messages."
   (ems-with-messages-silenced
    ad-do-it))
@@ -173,7 +173,6 @@
 ;;}}}
 ;;{{{ pause/resume if needed
 
-;;;###autoload
 (defun emacspeak-emms-pause-or-resume ()
   "Pause/resume if emms is running. For use  in
 emacspeak-silence-hook."
@@ -188,9 +187,8 @@ emacspeak-silence-hook."
 (provide 'emacspeak-emms)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
