@@ -1,48 +1,48 @@
 ;;; emacspeak-entertain.el --- Speech enable misc games  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $ 
-;;; Description: Auditory interface to diversions
-;;; Keywords: Emacspeak, Speak, Spoken Output, games
-;;{{{  LCD Archive entry: 
+;;
+;; $Author: tv.raman.tv $
+;; Description: Auditory interface to diversions
+;; Keywords: Emacspeak, Speak, Spoken Output, games
+;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
-;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
-;;;  $Revision: 4532 $ | 
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2017, T. V. Raman
-;;; All Rights Reserved. 
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (c) 1995 -- 2022, T. V. Raman
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-;;{{{  Introduction 
+;;{{{  Introduction
 
 ;;; Commentary:
 
-;;; Auditory interface to misc games
+;; Auditory interface to misc games
 
 ;;; Code:
 
@@ -54,11 +54,11 @@
 ;;}}}
 ;;{{{ doctar
 
-(defadvice doctor-txtype (after emacspeak pre act)
+(defadvice doctor-txtype (after emacspeak pre act comp)
   (dtk-speak
    (mapconcat
     #'(lambda (s)
-                (format "%s" s))
+        (format "%s" s))
     (ad-get-arg 0)
     " ")))
 
@@ -66,25 +66,28 @@
 ;;{{{ mpuz
 (voice-setup-add-map
  '(
-   (mpuz-trivial voice-monotone)
+   (mpuz-trivial voice-monotone-extra)
    (mpuz-unsolved voice-bolden)
    (mpuz-solved voice-animate)))
 ;;}}}
-;;{{{ dunnet 
-
-(defadvice dun-parse (around emacspeak pre act comp)
-  "Provide auditory feedback"
-  (cond
-   ((ems-interactive-p)
-    (let ((orig (point)))
-      ad-do-it
-      (emacspeak-auditory-icon 'mark-object)
-      (emacspeak-speak-region orig (point))))
-   (t ad-do-it))
-  ad-return-value)
+;;{{{ dunnet
+(cl-loop
+ for f in
+ '(dun-parse dun-unix-parse) do 
+ (eval
+  `(defadvice ,f (around emacspeak pre act comp)
+     "speak"
+     (cond
+      ((ems-interactive-p)
+       (let ((orig (point)))
+         ad-do-it
+         (emacspeak-auditory-icon 'mark-object)
+         (emacspeak-speak-region orig (point))))
+      (t ad-do-it))
+     ad-return-value)))
 
 ;;}}}
-;;{{{  hangman 
+;;{{{  hangman
 
 (defun emacspeak-hangman-speak-statistics ()
   "Speak statistics."
@@ -102,7 +105,7 @@
             (not emacspeak-pronounce-pronunciation-table))
     (emacspeak-pronounce-toggle-use-of-dictionaries)))
 
-(defadvice hm-self-guess-char (after eemacspeak pre act comp)
+(defadvice hm-self-guess-char (after emacspeak pre act comp)
   "Speak the char."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)))
@@ -111,7 +114,7 @@
   "Speak current guessed string. "
   (interactive)
   (cl-declare (special hm-current-guess-string
-                    hm-current-word))
+                       hm-current-word))
   (let ((string (make-string  (length hm-current-word)
                               ?\))))
     (cl-loop for i from 0 to (1- (length hm-current-word))
@@ -122,7 +125,7 @@
               (length string)
               (downcase string))))
 
-(defadvice hangman (after emacseak pre act comp)
+(defadvice hangman (after emacspeak pre act comp)
   "Speech enable hangman."
   (when (ems-interactive-p)
     (emacspeak-hangman-setup-pronunciations)
@@ -136,11 +139,10 @@
 
 ;;}}}
 (provide 'emacspeak-entertain)
-;;{{{ end of file 
+;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end: 
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
