@@ -1,48 +1,48 @@
 ;;; emacspeak-eperiodic.el --- Speech-enable Periodic Table  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $
-;;; Description:  Emacspeak speech-enabler for Periodic Table
-;;; Keywords: Emacspeak, periodic  Table
+;;
+;; $Author: tv.raman.tv $
+;; Description:  Emacspeak speech-enabler for Periodic Table
+;; Keywords: Emacspeak, periodic  Table
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
-;;;  $Revision: 4074 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4074 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2017, T. V. Raman
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  Introduction:
 ;;; Commentary:
-;;; eperiodic produces an interactive periodic table of elements
-;;; and can be found at 
-;;; http://vegemite.chem.nottingham.ac.uk/~matt/emacs/eperiodic.el
+;; eperiodic produces an interactive periodic table of elements
+;; and can be found at 
+;; http://vegemite.chem.nottingham.ac.uk/~matt/emacs/eperiodic.el
 ;;; Code:
 ;;}}}
 ;;{{{ required modules
@@ -53,9 +53,8 @@
 (require 'emacspeak-preamble)
 ;;}}}
 ;;{{{ Forward decls:
-(declare-function eperiodic-get-element-property  (e prop) "eperiodic.el")
-(declare-function eperiodic-element-at (&optional pos) "eperiodic.el")
-
+(declare-function eperiodic-get-element-property  "ext:eperiodic.el" (e prop))
+(declare-function eperiodic-element-at "ext:eperiodic.el" (&optional pos))
 
 ;;}}}
 ;;{{{ faces and voices 
@@ -69,7 +68,7 @@
    (eperiodic-group-number-face voice-lighten)
    (eperiodic-header-face voice-bolden)
    (eperiodic-liquid-face voice-smoothen)
-   (eperiodic-p-block-face voice-monotone)
+   (eperiodic-p-block-face voice-monotone-extra)
    (eperiodic-period-number-face voice-lighten)
    (eperiodic-s-block-face voice-smoothen-medium)
    (eperiodic-solid-face voice-bolden-extra)
@@ -131,15 +130,13 @@
   (define-key eperiodic-mode-map "n" 'emacspeak-eperiodic-next-line)
   (define-key eperiodic-mode-map "p" 'emacspeak-eperiodic-previous-line)
   (define-key eperiodic-mode-map "l"
-    'emacspeak-eperiodic-play-description)
+              'emacspeak-eperiodic-play-description)
   )
 ;;}}}
 ;;{{{  listen off the web:
-(defcustom emacspeak-eperiodic-media-location 
+(defvar emacspeak-eperiodic-media-location 
   "http://www.webelements.com/webelements/elements/media/snds-description/%s.rm"
-  "Location of streaming media describing elements."
-  :type 'url
-  :group 'emacspeak-eperiodic)
+  "Location of streaming media describing elements.")
 
 (defun emacspeak-eperiodic-play-description ()
   "Play audio description from WebElements."
@@ -147,38 +144,38 @@
   (cl-declare (special emacspeak-eperiodic-media-location))
   (let ((e (eperiodic-element-at)))
     (unless e  (error "No element under point."))
-    (funcall emacspeak-media-player 
-             (format  emacspeak-eperiodic-media-location
-                      (eperiodic-get-element-property e 'symbol))
-             nil)))
+    (emacspeak-m-player
+     (format  emacspeak-eperiodic-media-location
+              (eperiodic-get-element-property e 'symbol))
+     nil)))
 
 ;;}}}
 ;;{{{ advice interactive commands
 
 (defadvice eperiodic-find-element (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when  (ems-interactive-p)
     (emacspeak-eperiodic-speak-current-element)
     (emacspeak-auditory-icon 'large-movement)))
 
 (defadvice eperiodic-previous-element (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (dtk-speak (emacspeak-eperiodic-name-element-at-point))
     (emacspeak-auditory-icon 'large-movement)))
 
 (defadvice eperiodic-next-element (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (dtk-speak (emacspeak-eperiodic-name-element-at-point))
     (emacspeak-auditory-icon 'large-movement)))
 (defadvice eperiodic (after emacspeak pre act comp)
-  "Provide spoken feedback."
+  "Speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 (defadvice eperiodic-move (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)))
 
@@ -193,13 +190,13 @@
         (emacspeak-speak-buffer)))))
 
 (defadvice eperiodic-bury-buffer (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice eperiodic-cycle-view (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (message "View %s"
@@ -209,9 +206,8 @@
 (provide 'emacspeak-eperiodic)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
