@@ -1,50 +1,50 @@
 ;;; emacspeak-erc.el --- speech-enable erc irc client  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $
-;;; Description:  Emacspeak module for speech-enabling erc.el
-;;; Keywords: Emacspeak, erc
+;;
+;; $Author: tv.raman.tv $
+;; Description:  Emacspeak module for speech-enabling erc.el
+;; Keywords: Emacspeak, erc
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
-;;;  $Revision: 4502 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4502 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2017, T. V. Raman
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  Introduction:
 
 ;;; Commentary:
-;;; erc.el is a modern Emacs client for IRC including color
-;;; and font locking support. 
-;;; erc.el - an Emacs IRC client (by Alexander L. Belikoff)
-;;; http://www.cs.cmu.edu/~berez/irc/erc.el
+;; erc.el is a modern Emacs client for IRC including color
+;; and font locking support. 
+;; erc.el - an Emacs IRC client (by Alexander L. Belikoff)
+;; http://www.cs.cmu.edu/~berez/irc/erc.el
 
 ;;; Code:
 
@@ -80,9 +80,9 @@ server."
    (erc-bold-face voice-bolden)
    (erc-inverse-face voice-lighten-extra)
    (erc-underline-face voice-brighten-medium)
-   (erc-prompt-face voice-bolden)
+   (erc-prompt-face voice-animate)
    (erc-notice-face (quote inaudible))
-   (erc-action-face voice-monotone)
+   (erc-action-face voice-monotone-extra)
    (erc-error-face voice-bolden-and-animate)
    (erc-dangerous-host-face voice-brighten-extra)
    (erc-pal-face voice-animate-extra)
@@ -105,7 +105,7 @@ server."
   (setq voice-lock-mode t))
 
 (defadvice erc-select (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
@@ -124,7 +124,7 @@ server."
 (provide 'emacspeak-erc)
 ;;{{{ monitoring chatrooms 
 (defvar emacspeak-erc-room-monitor nil
-  "*Local to each chat room. If turned on,
+  "Local to each chat room. If turned on,
 user is notified about activity in the room.")
 (make-variable-buffer-local 'emacspeak-erc-room-monitor)
 
@@ -187,9 +187,8 @@ Optional interactive prefix  arg defines a pronunciation that
     (error "Not in an ERC buffer."))
   (setq emacspeak-erc-people-to-monitor
         (cl-remove-if
-         (function
-          (lambda (x)
-            (string-equal x name)))
+         #'(lambda (x)
+             (string-equal x name))
          emacspeak-erc-people-to-monitor))
   (emacspeak-auditory-icon 'delete-object)
   (message "monitoring %s"
@@ -206,9 +205,9 @@ Optional interactive prefix  arg defines a pronunciation that
   "Uses environment of buffer to decide what message to
 display. String is the original message."
   (cl-declare (special emacspeak-erc-people-to-monitor
-                    emacspeak-erc-my-nick
-                    emacspeak-erc-speak-all-participants
-                    emacspeak-erc-monitor-my-messages))
+                       emacspeak-erc-my-nick
+                       emacspeak-erc-speak-all-participants
+                       emacspeak-erc-monitor-my-messages))
   (let ((who-from (car (split-string string)))
         (case-fold-search t))
     (cond
@@ -216,7 +215,7 @@ display. String is the original message."
      ((and
        (not (string-match "^\\*\\*\\*" who-from))
        emacspeak-erc-people-to-monitor
-       (find
+       (cl-find
         who-from
         emacspeak-erc-people-to-monitor
         :test #'string-equal))
@@ -239,8 +238,8 @@ set the current local value to the result.")
                                            comp)
   "Speech-enable ERC."
   (cl-declare (special emacspeak-erc-room-monitor
-                    emacspeak-erc-monitor-my-messages
-                    emacspeak-erc-my-nick))
+                       emacspeak-erc-monitor-my-messages
+                       emacspeak-erc-my-nick))
   (let ((buffer (ad-get-arg 1))
         (case-fold-search t))
     (with-current-buffer  buffer
@@ -258,20 +257,19 @@ set the current local value to the result.")
 (defadvice erc-display-line-1  (after emacspeak pre act comp)
   "Speech-enable ERC."
   (cl-declare (special emacspeak-erc-room-monitor
-                    emacspeak-erc-monitor-my-messages
-                    emacspeak-erc-my-nick))
+                       emacspeak-erc-monitor-my-messages
+                       emacspeak-erc-my-nick))
   (let ((buffer (ad-get-arg 1))
         (case-fold-search t))
     (save-current-buffer
       (set-buffer buffer)
       (when (and emacspeak-erc-room-monitor
                  emacspeak-erc-monitor-my-messages)
-        (let ((emacspeak-speak-messages nil)
-              (msg (emacspeak-erc-compute-message (ad-get-arg 0)
+        (let ((msg (emacspeak-erc-compute-message (ad-get-arg 0)
                                                   buffer)))
           (when msg
             (emacspeak-auditory-icon 'progress)
-            (message msg)
+            (dtk-speak-and-echo (format "%s" msg))
             (tts-with-punctuations dtk-punctuation-mode
                                    (dtk-speak  msg))))))))
 
@@ -298,24 +296,17 @@ set the current local value to the result.")
     ad-do-it
     ad-return-value))
 
-(defadvice erc-make-notice (around emacspeak  pre act comp)
-  "Ignore notices from server is emacspeak-erc-ignore-notices it set."
-  ad-do-it
-  (cond
-   ((not emacspeak-erc-ignore-notices) ad-return-value)
-   (t " ")))
-
 ;;}}}
 ;;{{{ define emacspeak keys
 (cl-declaim (special erc-mode-map))
 (define-key erc-mode-map "\C-c "
-  'emacspeak-erc-toggle-speak-all-participants)
+            'emacspeak-erc-toggle-speak-all-participants)
 (define-key erc-mode-map "\C-cm"
-  'emacspeak-erc-toggle-my-monitor)
+            'emacspeak-erc-toggle-my-monitor)
 (define-key erc-mode-map "\C-c\C-m"
-  'emacspeak-erc-toggle-room-monitor)
+            'emacspeak-erc-toggle-room-monitor)
 (define-key erc-mode-map "\C-c\C-a"
-  'emacspeak-erc-add-name-to-monitor)
+            'emacspeak-erc-add-name-to-monitor)
 (define-key erc-mode-map "\C-c\C-d" 'emacspeak-erc-delete-name-from-monitor)
 ;;}}}
 
@@ -340,7 +331,7 @@ set the current local value to the result.")
              (t (cl-second fields))))))
 
 (defvar emacspeak-erc-cricket-4-6-pattern
-  " [0-9]+x\[46]"
+  " [0-9]+x[46]"
   "Matches pattern used to  score number of fours and sixes in IRC #cricket.")
 
 (defun emacspeak-erc-cricket-convert-4-6-pattern (pattern)
@@ -391,9 +382,8 @@ set the current local value to the result.")
 ;;}}}
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
