@@ -1,50 +1,50 @@
 ;;; emacspeak-eshell.el --- Speech-enable EShell - Emacs Shell  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $
-;;; Description:   Speech-enable EShell
-;;; Keywords: Emacspeak, Audio Desktop
+;;
+;; $Author: tv.raman.tv $
+;; Description:   Speech-enable EShell
+;; Keywords: Emacspeak, Audio Desktop
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-09-01 15:30:13 -0700 (Sat, 01 Sep 2007) $ |
-;;;  $Revision: 4532 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2017, T. V. Raman<raman@cs.cornell.edu>
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman<tv.raman.tv@gmail.com>
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  Introduction:
 
 ;;; Commentary:
-;;; EShell is a shell implemented entirely in Emacs Lisp.
-;;; It is part of emacs 21 --and can also be used under
-;;; Emacs 20.
-;;; This module speech-enables EShell
+;; EShell is a shell implemented entirely in Emacs Lisp.
+;; It is part of emacs 21 --and can also be used under
+;; Emacs 20.
+;; This module speech-enables EShell
 ;;; Code:
 
 ;;}}}
@@ -57,7 +57,7 @@
 ;;}}}
 ;;{{{  setup various EShell hooks
 
-;;; Play an auditory icon as you display the prompt
+;; Play an auditory icon as you display the prompt
 (defun emacspeak-eshell-prompt-function ()
   "Play auditory icon for prompt."
   (cl-declare (special eshell-last-command-status))
@@ -68,12 +68,12 @@
 
 (add-hook 'eshell-after-prompt-hook 'emacspeak-eshell-prompt-function)
 
-;;; Speak command output
+;; Speak command output
 
 (defun emacspeak-eshell-speak-output  ()
   "Speak eshell output."
   (cl-declare (special eshell-last-input-end eshell-last-output-end
-                    eshell-last-output-start))
+                       eshell-last-output-start))
   (emacspeak-speak-region eshell-last-input-end eshell-last-output-end))
 
 (add-hook 
@@ -84,7 +84,7 @@
 ;;}}}
 ;;{{{  Advice top-level EShell
 
-(defadvice eshell (after emacspeak pre act)
+(defadvice eshell (after emacspeak pre act comp)
   "Announce switching to shell mode.
 Provide an auditory icon if possible."
   (when (ems-interactive-p)
@@ -123,43 +123,27 @@ Provide an auditory icon if possible."
   :group 'eshell
   :prefix "emacspeak-eshell-")
 
-(defcustom emacspeak-eshell-ls-use-personalities t
+(defvar emacspeak-eshell-ls-use-personalities t
   "Indicates if ls in eshell uses different voice
-personalities."
-  :type 'boolean
-  :group 'emacspeak-eshell)
+personalities.")
 
 ;;}}}
 ;;{{{ voices
 
-(voice-setup-add-map
+(voice-setup-add-map 
  '(
-   (eshell-ls-archive voice-lighten-extra)
-   (eshell-ls-archive-face voice-lighten-extra)
-   (eshell-ls-backup voice-monotone-medium)
-   (eshell-ls-backup-face voice-monotone-medium)
-   (eshell-ls-clutter voice-smoothen-extra)
-   (eshell-ls-clutter-face voice-smoothen-extra)
-   (eshell-ls-directory voice-bolden)
-   (eshell-ls-directory-face voice-bolden)
-   (eshell-ls-executable voice-animate-extra)
-   (eshell-ls-executable-face voice-animate-extra)
-   (eshell-ls-missing voice-brighten)
-   (eshell-ls-missing-face voice-brighten)
-   (eshell-ls-product voice-lighten-medium)
-   (eshell-ls-product-face voice-lighten-medium)
+   (eshell-ls-archive voice-monotone)
+   (eshell-ls-backup voice-monotone-extra)
+   (eshell-ls-clutter voice-smoothen)
+   (eshell-ls-directory voice-bolden-extra)
+   (eshell-ls-executable voice-animate)
+   (eshell-ls-missing voice-lighten)
+   (eshell-ls-product voice-animate)
    (eshell-ls-readonly voice-monotone)
-   (eshell-ls-readonly-face voice-monotone)
-   (eshell-ls-special voice-lighten-extra)
-   (eshell-ls-special-face voice-lighten-extra)
+   (eshell-ls-special voice-brighten)
    (eshell-ls-symlink voice-smoothen)
-   (eshell-ls-symlink-face voice-smoothen)
-   (eshell-ls-unreadable voice-monotone-medium)
-   (eshell-ls-unreadable-face voice-monotone-medium)
-   (eshell-prompt voice-animate)
-   (eshell-prompt-face voice-animate)
-   ))
-
+   (eshell-ls-unreadable voice-animate-extra)
+   (eshell-prompt voice-bolden-and-animate)))
 ;;}}}
 ;;{{{ Advice em-prompt
 
@@ -202,7 +186,7 @@ personalities."
 ;;}}}
 ;;{{{ advice esh-mode
 
-(defadvice eshell-delchar-or-maybe-eof (around emacspeak pre act)
+(defadvice eshell-delchar-or-maybe-eof (around emacspeak pre act comp)
   "Speak character you're deleting."
   (cond
    ((ems-interactive-p)
@@ -215,7 +199,7 @@ personalities."
    (t ad-do-it))
   ad-return-value)
 
-(defadvice eshell-delete-backward-char (around emacspeak pre act)
+(defadvice eshell-delete-backward-char (around emacspeak pre act comp)
   "Speak character you're deleting."
   (cond
    ((ems-interactive-p)
@@ -243,8 +227,8 @@ personalities."
     (emacspeak-auditory-icon 'delete-object)
     (message "Flushed output")))
 
-(defadvice eshell-kill-input (before emacspeak pre act)
-  "Provide spoken feedback."
+(defadvice eshell-kill-input (before emacspeak pre act comp)
+  "Speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'delete-object)
     (emacspeak-speak-line)))
@@ -325,9 +309,8 @@ personalities."
 (provide 'emacspeak-eshell)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
