@@ -1,48 +1,48 @@
 ;;; emacspeak-ess.el --- Speech-enable ESS: Emacs Speaks Statistics  -*- lexical-binding: t; -*- 
-;;; $Id$
-;;; $Author: tv.raman.tv $
-;;; Description:  Speech-enable ESS An Emacs Interface to R and others
-;;; Keywords: Emacspeak,  Audio Desktop Statistics, R
+;;
+;; $Author: tv.raman.tv $
+;; Description:  Speech-enable ESS An Emacs Interface to R and others
+;; Keywords: Emacspeak,  Audio Desktop Statistics, R
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-09-01 15:30:13 -0700 (Sat, 01 Sep 2007) $ |
-;;;  $Revision: 4532 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman
-;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  introduction
 
 ;;; Commentary:
-;;; ESS == Emacs Speaks Statistics
-;;; This module makes ESS speak.
+;; ESS == Emacs Speaks Statistics
+;; This module makes ESS speak.
 
 ;;}}}
 ;;{{{  Required modules
@@ -93,14 +93,14 @@ Cue electric insertion with a tone."
                (emacspeak-speak-line)))))
 
 (defadvice ess-mark-function (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (message "Marked function containing %s lines."
              (count-lines (point) (mark)))))
 
-(defadvice ess-indent-exp  (after emacspeak pre act)
-  "Provide auditory feedback."
+(defadvice ess-indent-exp  (after emacspeak pre act comp)
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'fill-object)
     (message "Indented current s expression ")))
@@ -122,7 +122,7 @@ Cue electric insertion with a tone."
          (eval
           `
           (defadvice ,f (after emacspeak pre act comp)
-            "Provide auditory feedback."
+            "speak."
             (when (ems-interactive-p)
               (emacspeak-auditory-icon 'select-object)))))
 
@@ -140,7 +140,7 @@ Cue electric insertion with a tone."
          do
          (eval
           `(defadvice ,f (after emacspeak pre act comp)
-             "Provide auditory feedback."
+             "speak."
              (when (ems-interactive-p)
                (emacspeak-auditory-icon 'select-object)
                (emacspeak-speak-mode-line)))))
@@ -154,9 +154,8 @@ Cue electric insertion with a tone."
 (provide 'emacspeak-ess)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
