@@ -1,57 +1,54 @@
 ;;; emacspeak-etable.el --- Speech enable table.el  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $ 
-;;; DescriptionEmacspeak extensions for table.el
-;;; Keywords:emacspeak, audio interface to emacs Tables
+;;
+;; $Author: tv.raman.tv $ 
+;; DescriptionEmacspeak extensions for table.el
+;; Keywords:emacspeak, audio interface to emacs Tables
 ;;{{{  LCD Archive entry: 
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
-;;; A speech interface to Emacs |
-;;; $Date: 2008-06-21 14:58:40 -0700 (Sat, 21 Jun 2008) $ |
-;;;  $Revision: 4532 $ | 
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com 
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ | 
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman 
-;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved. 
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman 
+;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
+;; All Rights Reserved. 
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
 
 ;;{{{  Introduction:
 ;;; Commentary:
-;;; table.el provides rich table editing for emacs.
-;;; this module speech-enables table.el
+;; table.el provides rich table editing for emacs.
+;; this module speech-enables table.el
 ;;; Code:
 ;;}}}
 ;;{{{ required modules 
 
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
-(eval-when-compile
-  (condition-case nil
-      (require 'table)
-    (error "table.el is only available in newer Emacsuns")))
 
+(require 'table )
 ;;}}}
 ;;{{{ Update command remap list.
 (defadvice table--make-cell-map(after emacspeak pre act comp)
@@ -72,7 +69,7 @@
 ;;}}}
 ;;{{{ Advice edit commands
 
-(defadvice *table--cell-delete-char (around emacspeak pre act)
+(defadvice *table--cell-delete-char (around emacspeak pre act comp)
   "Speak character you're deleting."
   (cond
    ((ems-interactive-p)
@@ -82,7 +79,7 @@
    (t ad-do-it))
   ad-return-value)
 
-(defadvice *table--cell-delete-backward-char (around emacspeak pre act)
+(defadvice *table--cell-delete-backward-char (around emacspeak pre act comp)
   "Speak character you're deleting."
   (cond
    ((ems-interactive-p)
@@ -107,13 +104,13 @@
       (dtk-stop)
       (emacspeak-speak-this-char last-input-event)))))
 
-(defadvice *table--cell-quoted-insert  (after emacspeak pre act)
+(defadvice *table--cell-quoted-insert  (after emacspeak pre act comp)
   "Speak the character that was inserted."
   (when (ems-interactive-p)
     (table--finish-delayed-tasks)
     (emacspeak-speak-this-char (preceding-char))))
 
-(defadvice *table--cell-newline (before emacspeak pre act)
+(defadvice *table--cell-newline (before emacspeak pre act comp)
   "Speak the previous line if line echo is on.
 See command \\[emacspeak-toggle-line-echo].  Otherwise cue the user to
 the newly created blank line."
@@ -125,7 +122,7 @@ the newly created blank line."
      (t(if dtk-stop-immediately (dtk-stop))
        (dtk-tone 225 120 'force)))))
 
-(defadvice *table--cell-newline-and-indent (around emacspeak pre act)
+(defadvice *table--cell-newline-and-indent (around emacspeak pre act comp)
   "Speak the previous line if line echo is on.
 See command \\[emacspeak-toggle-line-echo].
 Otherwise cue user to the line just created."
@@ -133,20 +130,17 @@ Otherwise cue user to the line just created."
   (cond
    ((ems-interactive-p)
     (cond
-     (emacspeak-line-echo
-      (emacspeak-speak-line)
-      ad-do-it)
-     (t ad-do-it
-        (dtk-speak-using-voice voice-annotate
+     (emacspeak-line-echo (emacspeak-speak-line))
+     (t (dtk-speak-using-voice voice-annotate
                                (format
                                 "indent %s"
                                 (current-column)))
-        (dtk-force))))
-   (t ad-do-it))
+        (dtk-force)))))
+  ad-do-it
   ad-return-value)
 
-(defadvice *table--cell-open-line (after emacspeak pre act)
-  "Provide auditory feedback."
+(defadvice *table--cell-open-line (after emacspeak pre act comp)
+  "speak."
   (when (ems-interactive-p)
     (let ((count (ad-get-arg 0)))
       (emacspeak-auditory-icon 'open-object)
@@ -167,14 +161,14 @@ Otherwise cue user to the line just created."
       (emacspeak-speak-rectangle
        (car cell)
        (cdr cell)))
-     (t (error "Cant identify cell.")))))
+     (t (error "Can't identify cell.")))))
 
 (cl-loop for f in
          '(table-forward-cell table-backward-cell)
          do
          (eval
           `(defadvice ,f (after emacspeak pre act comp)
-             "Provide auditory feedback by speaking current cell
+             "speak by speaking current cell
       contents."
              (when (ems-interactive-p)
                (table--finish-delayed-tasks)
@@ -185,9 +179,8 @@ Otherwise cue user to the line just created."
 (provide  'emacspeak-etable)
 ;;{{{  emacs local variables 
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end: 
+;; local variables:
+;; folded-file: t
+;; end: 
 
 ;;}}}
