@@ -1,55 +1,58 @@
 ;;; emacspeak-eudc.el --- Speech enable  LDAP directory client  -*- lexical-binding: t; -*- 
-;;; $Id$
-;;; $Author: tv.raman.tv $
-;;; Description:   extension to speech enable universal directory client 
-;;; Keywords: Emacspeak, Audio Desktop
+;;
+;; $Author: tv.raman.tv $
+;; Description:   extension to speech enable universal directory client 
+;; Keywords: Emacspeak, Audio Desktop
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
-;;;  $Revision: 4532 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2017, T. V. Raman<raman@cs.cornell.edu>
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman<tv.raman.tv@gmail.com>
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{ required modules
 (cl-declaim  (optimize  (safety 0) (speed 3)))
-(require 'emacspeak-preamble)              
+(require 'emacspeak-preamble)
+(declare-function widget-at "wid-edit" (&optional pos))
+(declare-function widget-type "wid-edit" (widget))
+
 ;;}}}
 ;;{{{  Introduction:
 
 ;;; Commentary:
 
-;;; EUDC --Emacs Universal Directory Client 
-;;; provides a unified interface to directory servers
-;;; e.g. ldap servers
-;;; this module speech enables eudc 
+;; EUDC --Emacs Universal Directory Client 
+;; provides a unified interface to directory servers
+;; e.g. ldap servers
+;; this module speech enables eudc 
 
 ;;; Code:
 
@@ -57,14 +60,14 @@
 ;;{{{ speech enable interactive commands 
 
 (defadvice eudc-move-to-next-record (after emacspeak pre act comp)
-  "Provide auditory feedback. "
+  "speak. "
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-line)))
 
 (defadvice eudc-move-to-previous-record (after emacspeak pre act
                                                comp)
-  "Provide auditory feedback. "
+  "speak. "
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-line)))
@@ -76,7 +79,7 @@
   "Provides emacspeak help for eudc widgets. "
   (cond
    ((eq (widget-type widget) 'editable-field)
-    (concat (ems-this-line) "Edit "))
+    (concat (ems--this-line) "Edit "))
    ((eq (widget-type widget) 'push-button)
     (concat "Push button "
             (widget-value widget)))
@@ -145,17 +148,9 @@ Summarize the form to welcome the user. "
 ;;}}}
 ;;{{{ voiceify values in results 
 
-(defgroup emacspeak-eudc nil
-  "Emacspeak add-on to the Emacs Universal Directory Client."
-  :group 'emacspeak
-  :group 'eudc
-  :prefix "emacspeak-eudc-")
-
-(defcustom emacspeak-eudc-attribute-value-personality
+(defvar emacspeak-eudc-attribute-value-personality
   voice-animate
-  "Personality t use for voiceifying attribute values. "
-  :type 'symbol
-  :group 'emacspeak-eudc)
+  "Personality t use for voiceifying attribute values. ")
 
 (defadvice eudc-print-attribute-value (around emacspeak pre
                                               act comp)
@@ -175,9 +170,8 @@ Summarize the form to welcome the user. "
 (provide 'emacspeak-eudc)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
