@@ -1,42 +1,42 @@
 ;;; emacspeak-filtertext.el --- Utilities to filter text  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $
-;;; Description:   Implement text filters 
-;;; Keywords: Emacspeak, Audio Desktop
+;;
+;; $Author: tv.raman.tv $
+;; Description:   Implement text filters 
+;; Keywords: Emacspeak, Audio Desktop
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
-;;;  $Revision: 4532 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2017, T. V. Raman<raman@cs.cornell.edu>
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman<tv.raman.tv@gmail.com>
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{ required modules
 
@@ -45,27 +45,27 @@
 ;;}}}
 ;;{{{  Introduction:
 ;;; Commentary:
-;;; It is often useful  to view the results of filtering
-;;; large amounts of text.;;; Typically you do this with
-;;; various combinations of grep and friends.
-;;; When doing so it requires explicit effort to not destroy
-;;; the original text being filtered.
-;;; This module provides a textfilter utility that:
-;;; A) Copies over the selected text to a special filtertext
-;;; buffer
-;;; B) Implements a filtertext mode for that buffer that
-;;; allows easy application of filters
-;;; C: Provides commands for reverting to the original
-;;; unfiltered text
-;;; D: Provides commands for saving results from
-;;; intermediate filters.
+;; It is often useful  to view the results of filtering
+;; large amounts of text.;;; Typically you do this with
+;; various combinations of grep and friends.
+;; When doing so it requires explicit effort to not destroy
+;; the original text being filtered.
+;; This module provides a textfilter utility that:
+;; A) Copies over the selected text to a special filtertext
+;; buffer
+;; B) Implements a filtertext mode for that buffer that
+;; allows easy application of filters
+;; C: Provides commands for reverting to the original
+;; unfiltered text
+;; D: Provides commands for saving results from
+;; intermediate filters.
 ;;; Code:
 ;;}}}
 ;;{{{  structures 
 
 (cl-defstruct (emacspeak-filtertext
-            (:constructor
-             emacspeak-filtertext-constructor))
+               (:constructor
+                emacspeak-filtertext-constructor))
   text                                  ;original text
   filters                               ;chain of filters applied 
   )
@@ -85,17 +85,16 @@
 (define-key emacspeak-filtertext-mode-map "=" 'keep-lines)
 (define-key emacspeak-filtertext-mode-map "^" 'flush-lines)
 (define-key emacspeak-filtertext-mode-map "r"
-  'emacspeak-filtertext-revert)
+            'emacspeak-filtertext-revert)
 
 ;;}}}
 ;;{{{ Interactive commands 
 ;;;###autoload
 (defun emacspeak-filtertext(start end)
-  "Copy over text in region to special filtertext buffer in
-preparation for interactively filtering text. "
+  "Copy over text in region to special filtertext buffer to  filter text. "
   (interactive "r")
   (cl-declare (special emacspeak-filtertext-info
-                    case-fold-search))
+                       case-fold-search))
   (let ((this (buffer-substring-no-properties start end))
         (buffer (get-buffer-create
                  (format "filter-%s" (buffer-name)))))
@@ -112,7 +111,6 @@ preparation for interactively filtering text. "
     (switch-to-buffer buffer)
     (emacspeak-speak-mode-line)))
 
-;;;###autoload
 (defun emacspeak-filtertext-revert ()
   "Revert to original text."
   (interactive)
@@ -129,9 +127,8 @@ preparation for interactively filtering text. "
 (provide 'emacspeak-filtertext)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
