@@ -1,39 +1,39 @@
-;;; emacspeak-forms.el --- Speech enable Emacs' forms mode  -- provides  a convenient database interface  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $ 
-;;; DescriptionEmacspeak extensions for forms-mode 
-;;; Keywords:emacspeak, audio interface to emacs forms 
+;;; emacspeak-forms.el --- Speech enable Emacs' forms mode -*- lexical-binding: t; -*-
+;;
+;; $Author: tv.raman.tv $ 
+;; DescriptionEmacspeak extensions for forms-mode 
+;; Keywords:emacspeak, audio interface to emacs forms 
 ;;{{{  LCD Archive entry: 
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
-;;;  $Revision: 4532 $ | 
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ | 
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman 
-;;; Copyright (c) 1996 by T. V. Raman 
-;;; All Rights Reserved. 
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman 
+;; Copyright (c) 1996 by T. V. Raman 
+;; All Rights Reserved. 
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
 
@@ -45,16 +45,8 @@
 ;;}}}
 ;;{{{  Introduction:
 ;;; Commentary:
-;;; Provide additional advice to forms-mode 
+;; Provide additional advice to forms-mode 
 ;;; Code:
-;;}}}
-;;{{{  custom
-(defgroup emacspeak-forms nil
-  "Emacspeak support for forms mode."
-  :group 'emacspeak
-  :group 'forms
-  :prefix "emacspeak-forms-")
-
 ;;}}}
 ;;{{{ Helper functions
 
@@ -75,21 +67,17 @@ speak the first field")
   "Summarize current position in list of records"
   (interactive)
   (cl-declare (special forms--current-record forms--total-records
-                    forms-file))
+                       forms-file))
   (dtk-speak
    (format "Record %s of %s from %s"
            forms--current-record forms--total-records forms-file)))
 
-(defcustom emacspeak-forms-rw-voice 'paul
-  "Personality for read-write fields. "
-  :type 'symbol
-  :group 'emacspeak-forms)
+(defvar emacspeak-forms-rw-voice 'paul
+  "Personality for read-write fields. ")
+
+(defvar emacspeak-forms-ro-voice voice-annotate
+  "Personality for read-only fields. ")
 
-(defcustom emacspeak-forms-ro-voice voice-annotate
-  "Personality for read-only fields. "
-  :type 'symbol
-  :group 'emacspeak-forms)
-;;;###autoload
 (defun emacspeak-forms-speak-field ()
   "Speak current form field name and value.
 Assumes that point is at the front of a field value."
@@ -116,9 +104,19 @@ Assumes that point is at the front of a field value."
 
 ;;}}}
 ;;{{{ Advise interactive  commands
+(cl-loop
+ for f in 
+ '(forms-search-forward forms-search-backward)
+ do
+ (eval
+  `(defadvice ,f (after emacspeak pre act comp)
+     "speak."
+     (when (ems-interactive-p)
+       (emacspeak-auditory-icon 'search-hit)
+       (emacspeak-speak-line)))))
 
 (defadvice forms-next-record (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (goto-char (next-single-property-change 
@@ -129,7 +127,7 @@ Assumes that point is at the front of a field value."
     (emacspeak-forms-summarize-current-record)))
 
 (defadvice forms-prev-record (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (goto-char (next-single-property-change 
@@ -140,37 +138,37 @@ Assumes that point is at the front of a field value."
     (emacspeak-forms-summarize-current-record)))
 
 (defadvice forms-first-record (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-forms-summarize-current-record)))
 
 (defadvice forms-last-record (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-forms-summarize-current-record)))
 
 (defadvice forms-jump-record (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-forms-summarize-current-record)))
 
 (defadvice forms-search (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'search-hit)
     (emacspeak-forms-summarize-current-record)))
 
 (defadvice forms-exit (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice forms-next-field (around emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (cond
    ((ems-interactive-p)
     ad-do-it
@@ -180,27 +178,26 @@ Assumes that point is at the front of a field value."
   ad-return-value)
 
 (defadvice forms-prev-field (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-forms-speak-field)))   
-  
 
 (defadvice forms-kill-record (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'delete-object)
     ))
 
 (defadvice forms-insert-record (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     ))
 
 (defadvice forms-save-buffer (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when  (ems-interactive-p)
     (emacspeak-auditory-icon 'save-object)))
 
@@ -217,12 +214,11 @@ Assumes that point is at the front of a field value."
        pattern))))
 
 (defun emacspeak-forms-rerun-filter ()
-  "Rerun  filter --allows us to nuke more matching records"
+  "Rerun filter --allows us to nuke more matching records"
   (interactive)
   (cl-declare (special forms--file-buffer
-                    forms--total-records forms-read-only))
-  (save-current-buffer
-    (set-buffer forms--file-buffer)
+                       forms--total-records forms-read-only))
+  (with-current-buffer forms--file-buffer
     (let ((inhibit-read-only t)
           (file-modified (buffer-modified-p)))
       (emacspeak-forms-flush-unwanted-records)
@@ -230,10 +226,9 @@ Assumes that point is at the front of a field value."
                                nil))))
   (let (ro)
     (setq forms--total-records
-          (save-excursion
+          (with-current-buffer forms--file-buffer
             (prog1
                 (progn
-                  (set-buffer forms--file-buffer)
                   (bury-buffer (current-buffer))
                   (setq ro buffer-read-only)
                   (count-lines (point-min) (point-max))))))
@@ -256,29 +251,26 @@ Assumes that point is at the front of a field value."
 ;;}}}
 ;;{{{ bind smart filters
 (cl-declaim (special forms-mode-map forms-mode-ro-map
-                  forms-mode-edit-map))
+                     forms-mode-edit-map))
 (add-hook 'forms-mode-hooks
-          (function
-           (lambda nil 
-             (mapcar 
-              (function
-               (lambda (map)
-                 (define-key map "\C-m" 'emacspeak-forms-rerun-filter)
-                 (define-key map "."
-                   'emacspeak-forms-summarize-current-position)
-                 (define-key map "," 'emacspeak-forms-summarize-current-record)))
-              (list forms-mode-ro-map 
-                    forms-mode-map))
-;;; move to first field
-             (forms-next-field 1))))
+          #'(lambda nil 
+              (mapc
+               #'(lambda (map)
+                   (define-key map "\C-m" 'emacspeak-forms-rerun-filter)
+                   (define-key map "."
+                               'emacspeak-forms-summarize-current-position)
+                   (define-key map "," 'emacspeak-forms-summarize-current-record))
+               (list forms-mode-ro-map 
+                     forms-mode-map))
+              ;; move to first field
+              (forms-next-field 1)))
 
 ;;}}}
 (provide  'emacspeak-forms)
 ;;{{{  emacs local variables 
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end: 
+;; local variables:
+;; folded-file: t
+;; end: 
 
 ;;}}}
