@@ -1,42 +1,42 @@
 ;;; emacspeak-gomoku.el --- Speech enable the game of Gomoku  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $ 
-;;; Description: Auditory interface to gomoku
-;;; Keywords: Emacspeak, Speak, Spoken Output, gomoku
+;;
+;; $Author: tv.raman.tv $ 
+;; Description: Auditory interface to gomoku
+;; Keywords: Emacspeak, Speak, Spoken Output, gomoku
 ;;{{{  LCD Archive entry: 
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
-;;; A speech interface to Emacs |
-;;; $Date: 2008-06-21 14:58:40 -0700 (Sat, 21 Jun 2008) $ |
-;;;  $Revision: 4532 $ | 
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com 
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ | 
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2017, T. V. Raman
-;;; All Rights Reserved. 
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (c) 1995 -- 2022, T. V. Raman
+;; All Rights Reserved. 
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  Required modules
 
@@ -46,7 +46,7 @@
 ;;}}}
 ;;{{{  Introduction 
 ;;; Commentary:
-;;; Auditory interface to gomoku
+;; Auditory interface to gomoku
 ;;; Code:
 ;;}}}
 ;;{{{ helper functions
@@ -78,9 +78,9 @@
            (gomoku-point-y)
            (gomoku-point-x)
            (cl-case (char-after (point))
-                 (?X "x")
-                 (?. "-")
-                 (?O "0")))))
+             (?X "x")
+             (?. "-")
+             (?O "0")))))
 
 (defun emacspeak-gomoku-show-current-row ()
   "Aurally display current row"
@@ -92,9 +92,9 @@
           (cl-loop for i from 1 to gomoku-board-width
                    collect 
                    (cl-case (emacspeak-gomoku-cell-value row i)
-                         (0 "-")
-                         (1  "x")
-                         (6 "0"))))
+                     (0 "-")
+                     (1  "x")
+                     (6 "0"))))
     (dtk-speak
      (apply 'concat values))))
 
@@ -108,9 +108,9 @@
           (cl-loop for i from 1 to gomoku-board-height
                    collect 
                    (cl-case (emacspeak-gomoku-cell-value i column)
-                         (0 "-")
-                         (1  "x")
-                         (6 "0"))))
+                     (0 "-")
+                     (1  "x")
+                     (6 "0"))))
     (dtk-speak
      (apply 'concat values))))
 
@@ -118,7 +118,7 @@
   "Aurally display current positively sloped diagonal"
   (interactive)
   (cl-declare (special gomoku-board-height
-                    gomoku-board-width))
+                       gomoku-board-width))
   (let ((row (gomoku-point-y))
         (column (gomoku-point-x))
         (diag-start-x nil)
@@ -139,9 +139,9 @@
                    and j from diag-start-x to gomoku-board-width 
                    collect
                    (cl-case (emacspeak-gomoku-cell-value i j)
-                         (0 "-")
-                         (1  "x")
-                         (6 "0"))))
+                     (0 "-")
+                     (1  "x")
+                     (6 "0"))))
     (dtk-speak
      (apply 'concat values))))
 
@@ -149,7 +149,7 @@
   "Aurally display current negative sloped diagonal "
   (interactive)
   (cl-declare (special gomoku-board-height
-                    gomoku-board-width))
+                       gomoku-board-width))
   (let ((row (gomoku-point-y))
         (column (gomoku-point-x))
         (diag-start-x nil)
@@ -173,9 +173,9 @@
                    and j downfrom   diag-start-x  to 1 
                    collect
                    (cl-case (emacspeak-gomoku-cell-value i j)
-                         (0 "-")
-                         (1  "x")
-                         (6 "0"))))
+                     (0 "-")
+                     (1  "x")
+                     (6 "0"))))
     (dtk-speak
      (apply 'concat values))))
 
@@ -183,8 +183,8 @@
   "Display statistics from previous games"
   (interactive)
   (cl-declare (special gomoku-number-of-human-wins
-                    gomoku-number-of-emacs-wins
-                    gomoku-number-of-draws))
+                       gomoku-number-of-emacs-wins
+                       gomoku-number-of-draws))
   (message (format "Wins %d losses %d%s"
                    gomoku-number-of-human-wins
                    gomoku-number-of-emacs-wins
@@ -235,90 +235,18 @@
 
 ;;{{{  advice all navigation
 
-(defvar emacspeak-gomoku-navigation-commands
-  (list 'gomoku-beginning-of-line
-        'gomoku-end-of-line
-        'gomoku-move-down
-        'gomoku-move-up
-        'gomoku-move-left
-        'gomoku-move-right 
-        'gomoku-move-ne
-        'gomoku-move-nw
-        'gomoku-move-se
-        'gomoku-move-sw)
-  "Commands in gomoku that navigate the board")
-;;; generated by:
-                                        ;(cl-loop for command in
-                                        ;      emacspeak-gomoku-navigation-commands
-                                        ;      do
-                                        ;      (insert
-                                        ;       (format
-                                        ;        "(defadvice %s  (after emacspeak pre act comp)
-                                        ;              \"Provide auditory feedback\"
-                                        ;              (when (ems-interactive-p)
-                                        ;                (emacspeak-auditory-icon 'select-object)
-                                        ;                (emacspeak-gomoku-speak-square)))\n\n"
-                                        ;        command)))
-
-(defadvice gomoku-beginning-of-line  (after emacspeak pre act comp)
-  "Provide auditory feedback"
-  (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-gomoku-speak-square)))
-
-(defadvice gomoku-end-of-line  (after emacspeak pre act comp)
-  "Provide auditory feedback"
-  (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-gomoku-speak-square)))
-
-(defadvice gomoku-move-down  (after emacspeak pre act comp)
-  "Provide auditory feedback"
-  (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-gomoku-speak-square)))
-
-(defadvice gomoku-move-up  (after emacspeak pre act comp)
-  "Provide auditory feedback"
-  (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-gomoku-speak-square)))
-
-(defadvice gomoku-move-left  (after emacspeak pre act comp)
-  "Provide auditory feedback"
-  (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-gomoku-speak-square)))
-
-(defadvice gomoku-move-right  (after emacspeak pre act comp)
-  "Provide auditory feedback"
-  (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-gomoku-speak-square)))
-
-(defadvice gomoku-move-ne  (after emacspeak pre act comp)
-  "Provide auditory feedback"
-  (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-gomoku-speak-square)))
-
-(defadvice gomoku-move-nw  (after emacspeak pre act comp)
-  "Provide auditory feedback"
-  (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-gomoku-speak-square)))
-
-(defadvice gomoku-move-se  (after emacspeak pre act comp)
-  "Provide auditory feedback"
-  (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-gomoku-speak-square)))
-
-(defadvice gomoku-move-sw  (after emacspeak pre act comp)
-  "Provide auditory feedback"
-  (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-gomoku-speak-square)))
+(cl-loop
+ for f in
+ '(gomoku-beginning-of-line gomoku-end-of-line
+                            gomoku-move-down gomoku-move-up gomoku-move-left gomoku-move-right 
+                            gomoku-move-ne gomoku-move-nw gomoku-move-se gomoku-move-sw)
+ do
+ (eval
+  `(defadvice ,f  (after emacspeak pre act comp)
+     "speak"
+     (when (ems-interactive-p)
+       (emacspeak-auditory-icon 'select-object)
+       (emacspeak-gomoku-speak-square)))))
 
 ;;}}}
 
@@ -328,9 +256,9 @@
   (emacspeak-gomoku-speak-square))
 
 (defadvice gomoku-terminate-game (around emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (cl-declare (special emacspeak-last-message
-                    gomoku-number-of-moves))
+                       gomoku-number-of-moves))
   (let((result (ad-get-arg 0)))
     ad-do-it
     (dtk-speak
@@ -358,9 +286,9 @@
            do
            (define-key gomoku-mode-map key 'gomoku-move-right))
   (define-key gomoku-mode-map "\t"
-    'emacspeak-gomoku-speak-emacs-previous-move)
+              'emacspeak-gomoku-speak-emacs-previous-move)
   (define-key gomoku-mode-map "\M-\t"
-    'emacspeak-gomoku-speak-humans-previous-move) 
+              'emacspeak-gomoku-speak-humans-previous-move) 
   (define-key  gomoku-mode-map "f" 'emacspeak-gomoku-goto-x-y)
   ;; my navigational preference
   (define-key gomoku-mode-map "q" 'gomoku-move-nw)
@@ -378,9 +306,9 @@
   (define-key gomoku-mode-map "r" 'emacspeak-gomoku-show-current-row)
   (define-key gomoku-mode-map "c" 'emacspeak-gomoku-show-current-column)
   (define-key gomoku-mode-map "\\"
-    'emacspeak-gomoku-show-current-positive-diagonal)
+              'emacspeak-gomoku-show-current-positive-diagonal)
   (define-key gomoku-mode-map "/"
-    'emacspeak-gomoku-show-current-negative-diagonal)
+              'emacspeak-gomoku-show-current-negative-diagonal)
   (define-key gomoku-mode-map "=" 'emacspeak-gomoku-speak-number-of-moves)
   )
 
@@ -389,9 +317,8 @@
 (provide 'emacspeak-gomoku)
 ;;{{{ end of file 
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end: 
+;; local variables:
+;; folded-file: t
+;; end: 
 
 ;;}}}
