@@ -1,53 +1,53 @@
 ;;; emacspeak-google.el --- Google Search Tools  -*- lexical-binding: t; -*-
-;;; $Id: emacspeak-google.el 4797 2007-07-16 23:31:22Z tv.raman.tv $
-;;; $Author: tv.raman.tv $
-;;; Description:  Speech-enable GOOGLE An Emacs Interface to google
-;;; Keywords: Emacspeak,  Audio Desktop google
+;; $Id: emacspeak-google.el 4797 2007-07-16 23:31:22Z tv.raman.tv $
+;; $Author: tv.raman.tv $
+;; Description:  Speech-enable GOOGLE An Emacs Interface to google
+;; Keywords: Emacspeak,  Audio Desktop google
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
-;;;  $Revision: 4532 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman
-;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNGOOGLE FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNGOOGLE FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  introduction
 
 ;;; Commentary:
-;;; There are a number of search tools that can be implemented on
-;;; the Google search page --- in a JS-powered browser, these
-;;; show up as the Google tool-belt.
-;;; This module implements a minor mode for use in Google result
-;;; pages that enables these tools via single keyboard commands.
-;;; Originally all options were available as tbs=p:v
-;;; Now, some specialized searches, e.g. blog search are tbm=
+;; There are a number of search tools that can be implemented on
+;; the Google search page --- in a JS-powered browser, these
+;; show up as the Google tool-belt.
+;; This module implements a minor mode for use in Google result
+;; pages that enables these tools via single keyboard commands.
+;; Originally all options were available as tbs=p:v
+;; Now, some specialized searches, e.g. blog search are tbm=
 ;;; Code:
 
 ;;}}}
@@ -55,15 +55,14 @@
 
 (require 'cl-lib)
 (cl-declaim  (optimize  (safety 0) (speed 3)))
+(eval-when-compile (require 'derived))
 (require 'emacspeak-preamble)
 (require 'gweb)
-(require 'gmaps)
-(require 'derived)
 
 ;;}}}
 ;;{{{ Data Structures
 
-;;; One tool on a tool-belt
+;; One tool on a tool-belt
 
 (cl-defstruct emacspeak-google-tool
   name ; human readable
@@ -73,6 +72,8 @@
   value ; current setting
   type ;tbs/tbm
   )
+(defvar emacspeak-google-use-https t
+  "Specify whether we use secure connections for Google search.")
 
 (defvar emacspeak-google-query nil
   "Current Google Query.
@@ -132,7 +133,7 @@ This variable is buffer-local.")
       (setq
        emacspeak-google-toolbelt
        (list
-;;; video vid: 1/0
+        ;; video vid: 1/0
         (make-emacspeak-google-tool
          :name "video"
          :param "vid"
@@ -140,7 +141,7 @@ This variable is buffer-local.")
          :default 0
          :type 'tbm
          :value 0)
-;;; Recent
+        ;; Recent
         (make-emacspeak-google-tool
          :name "recent"
          :param "rcnt"
@@ -148,7 +149,7 @@ This variable is buffer-local.")
          :default 0
          :value 0
          :type 'tbs)
-;;; Duration restrict for video
+        ;; Duration restrict for video
         (make-emacspeak-google-tool
          :name "video-duration"
          :param "dur"
@@ -156,7 +157,7 @@ This variable is buffer-local.")
          :default "m"
          :value "m"
          :type 'tbs)
-;;; Recipes
+        ;; Recipes
         (make-emacspeak-google-tool
          :name "recipes"
          :param "rcp"
@@ -164,7 +165,7 @@ This variable is buffer-local.")
          :default 0
          :value 0
          :type 'tbm)
-;;; places/local:
+        ;; places/local:
         (make-emacspeak-google-tool
          :name "places"
          :param "plcs"
@@ -172,7 +173,7 @@ This variable is buffer-local.")
          :default 0
          :value 0
          :type 'tbm)
-;;; patents
+        ;; patents
         (make-emacspeak-google-tool
          :name "patents"
          :param "pts"
@@ -180,7 +181,7 @@ This variable is buffer-local.")
          :default 0
          :value 0
          :type 'tbm)
-;;; discussions/forums
+        ;; discussions/forums
         (make-emacspeak-google-tool
          :name "group-discussions"
          :param "dsc"
@@ -197,7 +198,7 @@ This variable is buffer-local.")
          :value 0
          :type 'tbs)
 
-;;; Blog mode
+        ;; Blog mode
         (make-emacspeak-google-tool
          :name "blog"
          :param "blg"
@@ -205,7 +206,7 @@ This variable is buffer-local.")
          :default 0
          :value 0
          :type 'tbm)
-;;; Books mode
+        ;; Books mode
         (make-emacspeak-google-tool
          :name "books"
          :param "bks"
@@ -213,7 +214,7 @@ This variable is buffer-local.")
          :default 0
          :type 'tbm
          :value 0)
-;;; epub
+        ;; epub
         (make-emacspeak-google-tool
          :name "books-format"
          :param "bft"
@@ -221,7 +222,7 @@ This variable is buffer-local.")
          :default "e"
          :type 'tbs
          :value "e")
-;;; Books viewability
+        ;; Books viewability
         (make-emacspeak-google-tool
          :name "books-viewability"
          :param "bkv"
@@ -229,7 +230,7 @@ This variable is buffer-local.")
          :default "a"
          :value "a"
          :type 'tbs)
-;;; Book Type
+        ;; Book Type
         (make-emacspeak-google-tool
          :name "books-type"
          :param "bkt"
@@ -237,7 +238,7 @@ This variable is buffer-local.")
          :default "b"
          :value "b"
          :type 'tbs)
-;;; Forums Mode
+        ;; Forums Mode
         (make-emacspeak-google-tool
          :name "forums"
          :param "frm"
@@ -245,7 +246,7 @@ This variable is buffer-local.")
          :default 0
          :value 0
          :type 'tbs)
-;;; News Mode
+        ;; News Mode
         (make-emacspeak-google-tool
          :name "news"
          :param "nws"
@@ -253,7 +254,7 @@ This variable is buffer-local.")
          :default 0
          :value 0
          :type 'tbm)
-;;; Reviews
+        ;; Reviews
         (make-emacspeak-google-tool
          :name "reviews"
          :param "rvw"
@@ -261,7 +262,7 @@ This variable is buffer-local.")
          :default 0
          :value 0
          :type 'tbs)
-;;; Web History Visited
+        ;; Web History Visited
         (make-emacspeak-google-tool
          :name "web-history-visited"
          :param "whv"
@@ -269,7 +270,7 @@ This variable is buffer-local.")
          :default 0
          :type 'tbs
          :value 0)
-;;; Web History Not Visited
+        ;; Web History Not Visited
         (make-emacspeak-google-tool
          :name "web-history-not-visited"
          :param "whnv"
@@ -277,7 +278,7 @@ This variable is buffer-local.")
          :range '(0 1)
          :default 0
          :value 0)
-;;; Images
+        ;; Images
         (make-emacspeak-google-tool
          :name "images"
          :param "isch"
@@ -285,7 +286,7 @@ This variable is buffer-local.")
          :default 0
          :value 0
          :type 'tbm)
-;;; Structured Snippets
+        ;; Structured Snippets
         (make-emacspeak-google-tool
          :name "structured-snippets"
          :param "sts"
@@ -293,7 +294,7 @@ This variable is buffer-local.")
          :default 0
          :value 0
          :type 'tbs)
-;;; sort by date
+        ;; sort by date
         (make-emacspeak-google-tool
          :name "sort-by-date"
          :param "std"
@@ -301,7 +302,7 @@ This variable is buffer-local.")
          :default 0
          :value 0
          :type 'tbs)
-;;; Timeline
+        ;; Timeline
         (make-emacspeak-google-tool
          :name "timeline"
          :param "tl"
@@ -309,7 +310,7 @@ This variable is buffer-local.")
          :default 0
          :type 'tbs
          :value 0)
-;;; Timeline Low
+        ;; Timeline Low
         (make-emacspeak-google-tool
          :name "timeline-low"
          :param "tll"
@@ -317,7 +318,7 @@ This variable is buffer-local.")
          :range "YYYY/MM"
          :default ""
          :value "")
-;;; Date Filter
+        ;; Date Filter
         (make-emacspeak-google-tool
          :name "date-filter"
          :param "qdr"
@@ -325,7 +326,7 @@ This variable is buffer-local.")
          :default ""
          :type 'tbs
          :value "")
-;;; Timeline High
+        ;; Timeline High
         (make-emacspeak-google-tool
          :name "timeline-high"
          :param "tlh"
@@ -333,7 +334,7 @@ This variable is buffer-local.")
          :default ""
          :type 'tbs
          :value "")
-;;; more:commercial promotion with prices
+        ;; more:commercial promotion with prices
         (make-emacspeak-google-tool
          :name "commercial"
          :param "cpk"
@@ -341,7 +342,7 @@ This variable is buffer-local.")
          :default 0
          :type 'tbs
          :value 0)
-;;; verbatim/literal search
+        ;; verbatim/literal search
         (make-emacspeak-google-tool
          :name "literal"
          :param "li"
@@ -349,7 +350,7 @@ This variable is buffer-local.")
          :default 0
          :type 'tbs
          :value 0)
-;;; shopping
+        ;; shopping
         (make-emacspeak-google-tool
          :name "Shopping"
          :param "shop"
@@ -364,7 +365,7 @@ This variable is buffer-local.")
          :default 0
          :type 'tbs
          :value 0)
-;;; less:commercial (demotion)
+        ;; less:commercial (demotion)
         (make-emacspeak-google-tool
          :name "non-commercial"
          :param "cdcpk"
@@ -372,7 +373,7 @@ This variable is buffer-local.")
          :default 0
          :type 'tbs
          :value 0)
-;;; soc
+        ;; soc
         (make-emacspeak-google-tool
          :name "social"
          :param "sa"
@@ -384,23 +385,88 @@ This variable is buffer-local.")
 ;;}}}
 ;;{{{  URL Fixup
 
-;;; pattern: http://www.google.com/url?q=http://emacspeak.sourceforge.net/&sa=U&ei=GceWT42_EY_ViALW84nlCQ&ved=0CBIQFjAA&usg=AFQjCNGz91Z7Yz9dPVoKPP6HVGZ0UqFhRA
-;;; prefix: http://www.google.com/url?q=
-;;; Suffix: &sa=...
+;; prefix: https://www.google.com/url?q=
+;; Suffix: &sa=...
 
 (defun emacspeak-google-canonicalize-result-url (url)
   "Strip out the actual result URL from the redirect wrapper."
-  (cl-declare (special emacspeak-websearch-google-use-https))
+  (cl-declare (special emacspeak-google-use-https))
   (url-unhex-string
    (substring url
-              (if emacspeak-websearch-google-use-https 29 28)
+              (if emacspeak-google-use-https 29 28)
               (string-match "&sa=" url))))
 
 (defun emacspeak-google-result-url-prefix ()
   "Return prefix of result urls."
-  (cl-declare (special emacspeak-websearch-google-use-https))
+  (cl-declare (special emacspeak-google-use-https))
   (format "%s://www.google.com/url?q="
-          (if emacspeak-websearch-google-use-https "https" "http")))
+          (if emacspeak-google-use-https "https" "http")))
+
+;;}}}
+;;{{{Cache query, toolbelt
+
+(defun emacspeak-google-cache-query(query)
+  "Setup post process hook to cache google query when rendered."
+  (cl-declare (special emacspeak-google-query))
+  (let ((cache
+         (eval
+          `#'(lambda nil
+               (setq emacspeak-google-query ,query)))))
+    (add-hook 'emacspeak-eww-post-process-hook cache 'at-end)))
+
+(defun emacspeak-google-cache-toolbelt(belt)
+  "Setup post process hook to cache google toolbelt when rendered."
+  (cl-declare (special emacspeak-google-toolbelt))
+  (let ((cache
+         (eval 
+          `#'(lambda nil
+               (setq emacspeak-google-toolbelt' ,belt)))))
+    (add-hook 'emacspeak-eww-post-process-hook cache 'at-end)))
+
+;;}}}
+;;{{{  google tools
+
+(declare-function eww-current-url "eww" nil)
+
+(defun emacspeak-google-who-links-to-this-page ()
+  "Perform a google search to locate documents that link to the
+current page."
+  (interactive)
+  (emacspeak-websearch-google
+   (format "link:%s"
+           (eww-current-url))))
+
+(defun emacspeak-google-extract-from-cache ()
+  "Extract current  page from the Google cache. "
+  (interactive)
+  (browse-url
+   (format "http://webcache.googleusercontent.com/search?q=cache:%s"
+           (shr-url-at-point nil))))
+
+(defun emacspeak-google-on-this-site ()
+  "Perform a google search restricted to the current WWW site."
+  (interactive)
+  (emacspeak-websearch-google
+   (format "site:%s %s"
+           (aref
+            (url-generic-parse-url (eww-current-url)) 3)
+           (read-from-minibuffer "Search this site for: "))))
+
+(defvar emacspeak-google-related-uri
+  "http://www.google.com/search?hl=en&num=25&q=related:")
+
+(defun emacspeak-google-similar-to-this-page (url)
+  "Ask Google to find documents similar to this one."
+  (interactive
+   (list
+    (read-from-minibuffer "URL:"
+                          (eww-current-url))))
+  (cl-declare (special emacspeak-google-related-uri))
+  (emacspeak-we-extract-by-id
+   "res"
+   (format
+    "%s%s"
+    emacspeak-google-related-uri url)))
 
 ;;}}}
 ;;{{{ Interactive Commands
@@ -423,21 +489,21 @@ This variable is buffer-local.")
                  ((belt (emacspeak-google-toolbelt))
                   (tool
                    (cl-find-if #'(lambda (tool) (string-equal (emacspeak-google-tool-name tool)
-                                                           ,(emacspeak-google-tool-name this-tool)))
-                            belt))
+                                                              ,(emacspeak-google-tool-name this-tool)))
+                               belt))
                   (param (emacspeak-google-tool-param tool))
                   (value (emacspeak-google-tool-value tool))
                   (range (emacspeak-google-tool-range tool)))
                (cond
                 ((and (listp range)
                       (= 2 (length range)))
-;;; toggle value
+                 ;; toggle value
                  (setf (emacspeak-google-tool-value tool)
                        (if (equal value (cl-first range))
                            (cl-second range)
                          (cl-first range))))
                 ((listp range)
-;;; Prompt using completion
+                 ;; Prompt using completion
                  (setf  (emacspeak-google-tool-value tool)
                         (completing-read
                          "Set tool to: "
@@ -451,7 +517,7 @@ This variable is buffer-local.")
                      (concat
                       (emacspeak-google-toolbelt-to-tbs belt)
                       (emacspeak-google-toolbelt-to-tbm belt))))
-                 (emacspeak-webutils-cache-google-toolbelt belt)
+                 (emacspeak-google-cache-toolbelt belt)
                  (emacspeak-websearch-google
                   (or emacspeak-google-query
                       (gweb-google-autocomplete))))))))
@@ -485,10 +551,28 @@ This variable is buffer-local.")
 (defun emacspeak-google-show-toolbelt()
   "Reload search page with toolbelt showing."
   (interactive)
-  (cl-declare (special emacspeak-google-query))
+  (cl-declare (special emacspeak-google-query
+                       emacspeak-websearch-google-options))
   (let ((emacspeak-websearch-google-options "&tbo=1"))
     (emacspeak-websearch-google emacspeak-google-query)))
 
+(declare-function emacspeak-eww-next-h1 "emacspeak-eww" (&optional speak))
+(declare-function shr-url-at-point "shr" (image-url))
+
+(defun emacspeak-google-open-link ()
+  "Open Google link under point."
+  (interactive)
+  (cl-declare (special ems--websearch-google-filter))
+  (let ((url (shr-url-at-point nil)))
+    (cl-assert url t "No link under point.")
+    (add-hook
+     'emacspeak-eww-post-process-hook
+     #'(lambda ()
+         (emacspeak-eww-next-h1  'speak)))      
+    (emacspeak-we-extract-by-id-list
+     ems--websearch-google-filter
+     url)))
+
 ;;}}}
 ;;{{{ Sign in, Sign out:
 
@@ -514,21 +598,22 @@ This variable is buffer-local.")
 
 ;;}}}
 ;;{{{  keymap
-;;;###autoload
-(define-prefix-command  'emacspeak-google-command
-  'emacspeak-google-keymap)
 
+(define-prefix-command  'emacspeak-google-command
+                        'emacspeak-google-keymap)
+(cl-declaim (special emacspeak-google-keymap))
 (cl-loop
  for k in
  '(
    ("." emacspeak-google-toolbelt-change)("." emacspeak-google-toolbelt-change)
    ("A" emacspeak-google-sign-in)
    ("a" emacspeak-google-sign-out)
-   ("c" emacspeak-webutils-google-extract-from-cache)
+   ("c" emacspeak-google-extract-from-cache)
    ("g" emacspeak-websearch-google)
+   ("o" emacspeak-google-open-link)
    ("i" emacspeak-google-what-is-my-ip)
-   ("l" emacspeak-webutils-google-who-links-to-this-page)
-   ("s" emacspeak-webutils-google-similar-to-this-page)
+   ("l" emacspeak-google-who-links-to-this-page)
+   ("s" emacspeak-google-similar-to-this-page)
    )
  do
  (emacspeak-keymap-update emacspeak-google-keymap k))
@@ -548,23 +633,23 @@ This variable is buffer-local.")
          do
          (eval
           `(defadvice ,f (after emacspeak pre act comp)
-             "Provide auditory feedback."
+             "speak."
              (when (ems-interactive-p)
                (emacspeak-auditory-icon 'task-done)
                (emacspeak-speak-rest-of-buffer)))))
 
 (defadvice gmaps-set-current-location (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-speak-header-line)))
 
 (defadvice gmaps-set-current-radius (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (message "Radius set to %s. " gmaps-current-radius)))
 
 (defadvice gmaps-place-details (around emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (cond
    ((ems-interactive-p)
     ad-do-it
@@ -588,19 +673,16 @@ This variable is buffer-local.")
   "REST endpoint for network speech synthesis.")
 ;;;###autoload
 (defun emacspeak-google-tts (text &optional lang)
-  "Speak text using Google Network TTS.
-Optional interactive prefix arg `lang' prompts for language identifier."
+  "Google Network TTS.
+Optional interactive prefix arg `lang' specifies  language identifier."
   (interactive
    (list
     (read-from-minibuffer "Text: ")
     current-prefix-arg))
   (cl-declare (special emacspeak-google-tts-default-language
-                    emacspeak-google-tts-rest-uri emacspeak-m-player-program))
-  (when lang
-    (setq lang
-          (read-from-minibuffer
-           "Language: " nil nil t nil
-           emacspeak-google-tts-default-language)))
+                       emacspeak-google-tts-rest-uri emacspeak-m-player-program))
+  (or lang (setq lang "en-us"))
+  (unless (stringp lang) (setq lang (read-string  "Lang:")))
   (let ((url (format emacspeak-google-tts-rest-uri
                      (or lang emacspeak-google-tts-default-language)
                      (url-hexify-string  text))))
@@ -621,17 +703,110 @@ Optional interactive prefix arg `lang' prompts for language identifier."
 (defun emacspeak-google-what-is-my-ip ()
   "Show my public IP"
   (interactive)
-  (emacspeak-we-extract-by-class
-   "_h4c _rGd vk_h"
-   "https://www.google.com/search?lite=90586&q=what+is+my+ip" 'speak))
+  (emacspeak-websearch-google "what+is+my+ip"))
+
+;;}}}
+;;{{{ Google Knowledge Graph:
+
+;; Google Knowledge Graph Search API  |  Knowledge G https://developers.google.com/knowledge-graph/
+
+(defcustom emacspeak-google-kg-key  nil
+  "API Key for Google Knowledge Graph."
+  :type
+  '(choice
+    (const :tag "None" "")
+    (string :tag "Key" :value ""))
+  :group 'emacspeak-google)
+
+(defvar emacspeak-google-kg-rest-end-point
+  "https://kgsearch.googleapis.com/v1/entities:search?%s=%s&key=%s&indent=1&limit=%s"
+  "Rest end-point for KG Search.")
+
+(defun emacspeak-google-kg-id-uri (id)
+  "Return URL for KG Search by id."
+  (cl-declare (special emacspeak-google-kg-rest-end-point))
+  (format
+   emacspeak-google-kg-rest-end-point
+   "ids"
+   (url-hexify-string (substring id 3))
+   emacspeak-google-kg-key
+   1))
+
+(defun emacspeak-google-kg-query-uri (query &optional limit)
+  "Return URL for KG Search."
+  (cl-declare (special emacspeak-google-kg-rest-end-point))
+  (or limit (setq limit 5))
+  (format
+   emacspeak-google-kg-rest-end-point
+   "query"
+   (url-hexify-string query)
+   emacspeak-google-kg-key
+   limit))
+
+(defun emacspeak-google-kg-json-ld (query &optional limit)
+  "Return JSON-LD structure."
+  (or limit (setq limit 5))
+  (g-json-from-url
+   (emacspeak-google-kg-query-uri query limit)))
+
+(defun emacspeak-google-kg-results (query &optional limit)
+  "Return list of results."
+  (or limit (setq limit 5))
+  (cl-map  'list
+           #'(lambda (r) (g-json-get 'result r))
+           (g-json-get 'itemListElement
+                       (emacspeak-google-kg-json-ld query limit))))
+
+(defun emacspeak-google-kg-format-result (result)
+  "Format result as HTML."
+  (let-alist result
+    (format
+     "<p><a href='%s'>%s</a> is a <code>[%s]</code>.
+<strong>%s</strong></p>
+<p>%s</p>
+<p><a href='%s'>Id: %s</a>
+<img src='%s'/></p>\n"
+     (g-json-get 'url .detailedDescription) .name
+     (mapconcat #'identity .@type ", ")
+     .description
+     (or (g-json-get 'articleBody .detailedDescription) "")
+     (emacspeak-google-kg-id-uri .@id)
+     .@id
+     (g-json-get 'contentUrl .image))))
+
+(defun emacspeak-google-knowledge-search (query &optional limit)
+  "Perform a Google Knowledge Graph search.
+Optional interactive prefix arg `limit' prompts for number of
+results, default is 1."
+  (interactive "sQuery:\nP")
+  (setq limit
+        (cond
+         (limit  (read-number "Number of results: "))
+         (t  5)))
+  (let ((results (emacspeak-google-kg-results query limit)))
+    (unless results (error "No results"))
+    (with-temp-buffer
+      (insert (format "<html><head><title>%s</title></head><body>\n" query))
+      (cond
+       ((> limit 1)
+        (insert "<ol>\n")
+        (cl-loop
+         for r in results do
+         (insert "<li>")
+         (insert (emacspeak-google-kg-format-result r))
+         (insert "</li>\n"))
+        (insert "</ol>\n"))
+       (t(insert  (emacspeak-google-kg-format-result (cl-first results)))))
+      (insert "</body></html>\n")
+      (emacspeak-eww-autospeak)
+      (browse-url-of-buffer))))
 
 ;;}}}
 (provide 'emacspeak-google)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
