@@ -1,45 +1,45 @@
 ;;; emacspeak-info.el --- Speech enable Info -- Emacs' online documentation viewer  -*- lexical-binding: t; -*-
-;;; $Author: tv.raman.tv $
-;;; Description:  Speech-enable Emacs Info Reader.
-;;; Keywords:emacspeak, audio interface to emacs
+;; $Author: tv.raman.tv $
+;; Description:  Speech-enable Emacs Info Reader.
+;; Keywords:emacspeak, audio interface to emacs
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
-;;;  $Revision: 4558 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4558 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman
-;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
 ;;{{{ Introduction:
 
 ;;; Commentary:
 
-;;; This module speech-enables the Emacs Info Reader.
+;; This module speech-enables the Emacs Info Reader.
 ;;; Code:
 
 ;;}}}
@@ -55,25 +55,54 @@
 (voice-setup-add-map
  '(
    (Info-quoted voice-lighten)
-   (info-index-match 'voice-bolden-medium)
+   (info-index-match 'voice-animate)
    (info-title-1 voice-bolden-extra)
    (info-title-2 voice-bolden-medium)
    (info-title-3 voice-bolden)
    (info-title-4 voice-lighten)
    (info-header-node voice-smoothen)
    (info-header-xref voice-brighten)
-   (info-menu-header voice-bolden-medium)
-   (info-node voice-monotone)
+   (info-node voice-monotone-extra)
    (info-xref voice-animate-extra)
    (info-menu-star voice-brighten)
    (info-menu-header voice-bolden)
    (info-xref-visited voice-animate-medium)))
 
 ;;}}}
+;;{{{ Module Prefixes 
+
+'(
+  ein:byte
+  ein:debug
+  ein:dev
+  ein:file
+  ein:header
+  ein:ipdb
+  ein:ipynb
+  ein:jupyter
+  ein:jupyterhub
+  ein:log
+  ein:login
+  ein:markdown
+  ein:notebook
+  ein:notebooklist
+  ein:pager
+  ein:process
+  ein:python
+  ein:pytools
+  ein:run
+  ein:shared
+  ein:stop
+  ein:tb
+  ein:traceback
+  ein:version
+  ein:worksheet
+  )
+;;}}}
 ;;{{{ advice
 
 (defcustom  emacspeak-info-select-node-speak-chunk 'node
-  "*Specifies how much of the selected node gets spoken.
+  "Specifies how much of the selected node gets spoken.
 Possible values are:
 screenfull  -- speak the displayed screen
 node -- speak the entire node."
@@ -115,18 +144,18 @@ node -- speak the entire node."
         Info-next Info-prev)
  do
  (eval
-  `(defadvice ,f (after emacspeak pre act)
+  `(defadvice ,f (after emacspeak pre act comp)
      " Speak the selected node based on setting of
 emacspeak-info-select-node-speak-chunk"
      (when (ems-interactive-p) (emacspeak-info-visit-node)))))
 
 (defadvice Info-search (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'search-hit)
     (emacspeak-speak-line)))
 
-(defadvice Info-scroll-up (after emacspeak pre act)
+(defadvice Info-scroll-up (after emacspeak pre act comp)
   "Speak the screenful."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'scroll)
@@ -136,7 +165,7 @@ emacspeak-info-select-node-speak-chunk"
         (forward-line (window-height window))
         (emacspeak-speak-region start (point))))))
 
-(defadvice Info-scroll-down (after emacspeak pre act)
+(defadvice Info-scroll-down (after emacspeak pre act comp)
   "Speak the screenful."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'scroll)
@@ -146,7 +175,7 @@ emacspeak-info-select-node-speak-chunk"
         (forward-line (window-height window))
         (emacspeak-speak-region start (point))))))
 
-(defadvice Info-exit (after emacspeak pre act)
+(defadvice Info-exit (after emacspeak pre act comp)
   "Play an auditory icon to close info,
 and then cue the next selected buffer."
   (when (ems-interactive-p)
@@ -154,13 +183,13 @@ and then cue the next selected buffer."
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
-(defadvice Info-next-reference (after emacspeak pre act)
+(defadvice Info-next-reference (after emacspeak pre act comp)
   "Speak the line. "
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line)))
 
-(defadvice Info-prev-reference (after emacspeak pre act)
+(defadvice Info-prev-reference (after emacspeak pre act comp)
   "Speak the line. "
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'large-movement)
@@ -186,7 +215,7 @@ node-spec."
 
 ;;}}}
 ;;{{{ Info: Section navigation
-;;; Use property info-title-* to move across section titles.
+;; Use property info-title-* to move across section titles.
 (defvar emacspeak-info--title-faces
   '(info-title-1 info-title-2 info-title-3 info-title-4 info-menu-header)
   "Faces that identify section titles.")
@@ -232,7 +261,7 @@ node-spec."
   "Speak info header line."
   (interactive)
   (cl-declare (special Info-use-header-line
-                    Info-header-line))
+                       Info-header-line))
   (cond
    ((and (boundp 'Info-use-header-line)
          (boundp 'Info-header-line)
@@ -255,9 +284,8 @@ node-spec."
 (provide  'emacspeak-info)
 ;;{{{  emacs local variables
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
