@@ -1,49 +1,49 @@
 ;;; emacspeak-jabber.el --- Speech-Enable jabber  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $
-;;; Description: speech-enable jabber
-;;; Keywords: Emacspeak, jabber
+;;
+;; $Author: tv.raman.tv $
+;; Description: speech-enable jabber
+;; Keywords: Emacspeak, jabber
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2008-04-15 06:25:36 -0700 (Tue, 15 Apr 2008) $ |
-;;;  $Revision: 4532 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2017, T. V. Raman
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (c) 1995 -- 2022, T. V. Raman
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{ Introduction:
 
 ;;; Commentary:
-;;; emacs-jabber.el implements a  jabber client for emacs
-;;; emacs-jabber is hosted at sourceforge.
-;;; I use emacs-jabber with my gmail.com account
+;; emacs-jabber.el implements a  jabber client for emacs
+;; emacs-jabber is hosted at sourceforge.
+;; I use emacs-jabber with my gmail.com account
 
 ;;; Code:
 
@@ -52,24 +52,24 @@
 
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
-(require 'jabber "jabber" 'no-error)
+(with-no-warnings (require 'jabber "jabber" 'no-error))
 ;;}}}
 ;;{{{ map voices
 
 (voice-setup-add-map
  '(
-   (jabber-activity-face        voice-animate)
-   (jabber-chat-error           voice-bolden-and-animate)
+   (jabber-activity-face        voice-animate-extra)
+   (jabber-chat-error           voice-monotone)
    (jabber-chat-prompt-foreign  voice-brighten-medium)
    (jabber-chat-prompt-local    voice-smoothen-medium)
    (jabber-chat-prompt-system   voice-brighten-extra)
-   ;;;(jabber-chat-text-foreign    voice-lighten) we use default here 
+   (jabber-chat-text-foreign    voice-lighten) 
    (jabber-chat-text-local      voice-smoothen)
    (jabber-rare-time-face       voice-animate-extra)
    (jabber-roster-user-away     voice-smoothen-extra)
    (jabber-roster-user-chatty   voice-brighten)
    (jabber-roster-user-dnd      voice-lighten-medium)
-   (jabber-roster-user-error    voice-bolden-and-animate)
+   (jabber-roster-user-error    voice-monotone)
    (jabber-roster-user-offline  voice-smoothen-extra)
    (jabber-roster-user-online   voice-bolden)
    (jabber-roster-user-xa       voice-lighten)
@@ -81,7 +81,7 @@
 ;;{{{ Advice interactive commands:
 
 (defadvice jabber-switch-to-roster-buffer (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
@@ -107,7 +107,7 @@
 ;;{{{ jabber activity:
 
 (defadvice jabber-activity-switch-to (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-mode-line)))
@@ -129,31 +129,31 @@
   :group 'emacspeak-jabber)
 (defadvice jabber-send-default-presence (after emacspeak pre act
                                                comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (message "Sent default presence.")))
 
 (defadvice jabber-send-away-presence (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (message "Set to be away.")))
 
 (defadvice jabber-send-xa-presence (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (message "Set extended  away.")))
 
 (defadvice jabber-go-to-next-jid (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line)))
 
 (defadvice jabber-go-to-previous-jid (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line)))
@@ -161,18 +161,19 @@
 (defun emacspeak-jabber-presence-default-message (&rest _ignore)
   "Default presence alert used by Emacspeak.
 Silently drops alerts on the floor --- Google Talk is too chatty otherwise."
-nil)
+  nil)
+(cl-declaim (special jabber-alert-presence-message-function))
 (setq
  jabber-alert-presence-message-function
  #'emacspeak-jabber-presence-default-message)
 
-;;;this is what I use as my jabber alert function:
+;; this is what I use as my jabber alert function:
 (defun emacspeak-jabber-message-default-message (from buffer text)
   "Speak the message."
   (cl-declare (special jabber-message-alert-same-buffer))
   (when (or jabber-message-alert-same-buffer
             (not (memq (selected-window) (get-buffer-window-list buffer))))
-    (emacspeak-auditory-icon 'progress)
+    (emacspeak-auditory-icon 'item)
     (dtk-notify-speak
      (if (jabber-muc-sender-p from)
          (format "Private message from %s in %s"
@@ -225,12 +226,12 @@ nil)
 
 ;;}}}
 ;;{{{ Browse chat buffers:
-(defun emacspeak-jabber-chat-speak-this-message(&optional copy-as-kill )
+(defun emacspeak-jabber-chat-speak-this-message(&optional copy-as-kill)
   "Speak chat message under point.
 With optional interactive prefix arg `copy-as-kill', copy it to
 the kill ring as well."
   (interactive "P")
-  (let ((range (emacspeak-speak-get-text-range 'face)))
+  (let ((range (emacspeak-speak-range)))
     (when copy-as-kill (kill-new range))
     (dtk-speak range)))
 
@@ -238,22 +239,24 @@ the kill ring as well."
   "Move forward to and speak the next message in this chat session."
   (interactive)
   (cl-assert  (eq major-mode 'jabber-chat-mode) nil  "Not in a Jabber chat buffer.")
-    (goto-char (next-single-property-change (point) 'face nil(point-max)))
-    (while (and (not (eobp))
-                (or (null (get-text-property (point) 'face))
-                 (get-text-property (point) 'field)))
-      (goto-char (next-single-property-change (point) 'face  nil  (point-max))))
-    (cond
-     ((eobp)
-        (message "On last message")
-        (emacspeak-auditory-icon 'warn-user))
-      (t(emacspeak-auditory-icon 'select-object)
-       (emacspeak-speak-text-range 'face))))
+  (end-of-line)
+  (goto-char (next-single-property-change (point) 'face nil(point-max)))
+  (while (and (not (eobp))
+              (or (null (get-text-property (point) 'face))
+                  (get-text-property (point) 'field)))
+    (goto-char (next-single-property-change (point) 'face  nil  (point-max))))
+  (cond
+   ((eobp)
+    (message "On last message")
+    (emacspeak-auditory-icon 'warn-user))
+   (t(emacspeak-auditory-icon 'select-object)
+     (emacspeak-speak-range))))
 
 (defun emacspeak-jabber-chat-previous-message ()
   "Move backward to and speak the previous message in this chat session."
   (interactive)
   (cl-assert (eq major-mode 'jabber-chat-mode) nil "Not in a Jabber chat buffer.")
+  (beginning-of-line)
   (goto-char (previous-single-property-change (point) 'face nil  (point-min)))
   (while  (and (not (bobp))
                (or (null (get-text-property (point) 'face))
@@ -264,7 +267,7 @@ the kill ring as well."
     (message "On first message")
     (emacspeak-auditory-icon 'warn-user))
    (t(emacspeak-auditory-icon 'select-object)
-    (emacspeak-speak-text-range 'face))))
+     (emacspeak-speak-range))))
 
 (when (boundp 'jabber-chat-mode-map)
   (cl-loop
@@ -276,13 +279,27 @@ the kill ring as well."
    do
    (emacspeak-keymap-update  jabber-chat-mode-map k)))
 
+;;}}}
+;;{{{ Speak recent message:
+
+(defun emacspeak-jabber-speak-recent-message ()
+  "Speak most recent message if one exists."
+  (interactive)
+  (cl-declare (special jabber-activity-jids))
+  (cond
+   (jabber-activity-jids
+    (save-excursion
+      (jabber-activity-switch-to)
+      (goto-char (point-max))
+      (emacspeak-jabber-chat-previous-message)))
+   (t (message "No recent message."))))
+
 ;;}}}
 (provide 'emacspeak-jabber)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
