@@ -1,49 +1,49 @@
 ;;; emacspeak-js2.el --- Speech-enable JS2  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: raman $
-;;; Description:  Speech-enable JS2 An Emacs Interface to js2
-;;; Keywords: Emacspeak,  Audio Desktop js2
+;;
+;; $Author: raman $
+;; Description:  Speech-enable JS2 An Emacs Interface to js2
+;; Keywords: Emacspeak,  Audio Desktop js2
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2008/04/03 15:05:55 $ |
-;;;  $Revision: 1.1 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 1.1 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman
-;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNJS2 FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNJS2 FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  introduction
 
 ;;; Commentary:
-;;; JS2-mode http://js2-mode.googlecode.com/svn/trunk
-;;; is a new, powerful Emacs mode for working with JavaScript.
-;;; This module speech-enables js2.
+;; JS2-mode http://js2-mode.googlecode.com/svn/trunk
+;; is a new, powerful Emacs mode for working with JavaScript.
+;; This module speech-enables js2.
 
 ;;}}}
 ;;{{{  Required modules
@@ -51,12 +51,15 @@
 (require 'cl-lib)
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
-(require 'js2-mode "js2-mode" 'no-error)
+
 ;;}}}
 ;;{{{  map faces to voices:
 
 (voice-setup-add-map
  '(
+   (js2-function-call  voice-annotate)
+   (js2-object-property  voice-smoothen)
+   (js2-object-property-access voice-lighten)
    (js2-error voice-bolden-extra)
    (js2-external-variable voice-animate) 
    (js2-function-param voice-lighten-extra)
@@ -74,8 +77,16 @@
 
 ;;}}}
 ;;{{{ Advice new interactive commands:
+(defadvice js2-jump-to-definition (after emacspeak pre act comp)
+  "speak."
+  (when (ems-interactive-p)
+    (let ((emacspeak-show-point  t))
+      (emacspeak-auditory-icon 'large-movement)
+      (emacspeak-speak-line))
+    ))
+
 (defadvice js2-mark-defun  (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'mark-object)
     (emacspeak-speak-line)))
@@ -85,10 +96,12 @@
          do
          (eval
           `(defadvice ,f (after emacspeak pre act comp)
-             "Provide auditory feedback."
+             "speak."
              (when (ems-interactive-p)
-               (emacspeak-auditory-icon 'large-movement)
-               (emacspeak-speak-line)))))
+               (let ((emacspeak-show-point t))
+                 (emacspeak-auditory-icon 'large-movement)
+                 (emacspeak-speak-line))))))
+
 (cl-loop for f in
          '(
            js2-beginning-of-line js2-indent-line
@@ -102,7 +115,7 @@
          do
          (eval
           `(defadvice ,f (after emacspeak pre act comp)
-             "Provide auditory feedback."
+             "speak."
              (when (ems-interactive-p)
                (emacspeak-speak-line)))))
 
@@ -112,7 +125,7 @@
          do
          (eval
           `(defadvice ,f (after emacspeak pre act comp)
-             "Provide auditory feedback."
+             "speak."
              (when (ems-interactive-p)
                (emacspeak-auditory-icon 'close-object)
                (message "Hid %s"
@@ -125,7 +138,7 @@
          do
          (eval
           `(defadvice ,f (after emacspeak pre act comp)
-             "Provide auditory feedback."
+             "speak."
              (when (ems-interactive-p)
                (emacspeak-auditory-icon 'open-object)
                (message "Showed %s"
@@ -139,20 +152,20 @@
          do
          (eval
           `(defadvice ,f (after emacspeak pre act comp)
-             "Provide auditory feedback."
+             "speak."
              (when (ems-interactive-p)
                (emacspeak-auditory-icon 'button)
                (message "Toggled %s"
                         ,(substring (symbol-name f)
                                     (length "js2-mode-toggle-")))))))
 (defadvice js2-narrow-to-defun (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'mark-object)
     (message "Narrowed to current function.")))
 
 (defadvice js2-next-error (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line)))
@@ -175,9 +188,8 @@
 (provide 'emacspeak-js2)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
