@@ -1,66 +1,66 @@
 ;;; emacspeak-librivox.el --- LIBRIVOX API client  -*- lexical-binding: t; -*-
-;;; $Id: emacspeak-librivox.el 4797 2007-07-16 23:31:22Z tv.raman.tv $
-;;; $Author: tv.raman.tv $
-;;; Description:  Speech-enable LIBRIVOX --- Free public-domain Audio Books
-;;; Keywords: Emacspeak,  Audio Desktop librivox
+;; $Id: emacspeak-librivox.el 4797 2007-07-16 23:31:22Z tv.raman.tv $
+;; $Author: tv.raman.tv $
+;; Description:  Speech-enable LIBRIVOX --- Free public-domain Audio Books
+;; Keywords: Emacspeak,  Audio Desktop librivox
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
-;;;  $Revision: 4532 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2017, T. V. Raman
-;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or fitness FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or fitness FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  introduction
 
 ;;; Commentary:
-;;; LIBRIVOX == http://www.librivox.org Free Audio Books
-;;; API Info: https://librivox.org/api/info
-;;; It provides a simple Web  API
-;;; This module implements an Emacspeak Librivox client.
-;;;
-;;; @subsection Usage
-;;;
-;;; main entry point is command @code{emacspeak-librivox} bound to @kbd{C-; l}.
-;;; This prompts with the following choices:
-;;; @itemize
-;;; @item @kbd{a} Author --- Search  by Author.
-;;; @item @kbd{t} Title --- Search  by Title.
-;;; @item @kbd{g} Genre --- Search  by Genre --- with minibuffer completion.
-;;; @item @kbd{p} Play --- Play a  book.
-;;;@item @kbd{d} Directory --- Browse local cache.
-;;; @end itemize
-;;;
-;;; Search results are displayed in a Web page that provides controls
-;;;for accessing the book.
+;; LIBRIVOX == @url{http://www.librivox.org} --- Free Audio Books.
+;; API Info: @url{https://librivox.org/api/info}
+;; It provides a simple Web  API
+;; This module implements an Emacspeak Librivox client.
+;; 
+;; @subsection Usage
+;; 
+;; main entry point is command @code{emacspeak-librivox} bound to @kbd{C-; l}.
+;; This prompts with the following choices:
+;; @itemize
+;; @item @kbd{a} Author --- Search  by Author.
+;; @item @kbd{t} Title --- Search  by Title.
+;; @item @kbd{g} Genre --- Search  by Genre --- with minibuffer completion.
+;; @item @kbd{p} Play --- Play a  book.
+;; @item @kbd{d} Directory --- Browse local cache.
+;; @end itemize
+;; 
+;; Search results are displayed in a Web page that provides controls
+;; for accessing the book.
 
 ;;; Code:
 
@@ -71,14 +71,14 @@
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (require 'dom)
-(require 'emacspeak-webutils)
 (require 'g-utils)
+(declare-function emacspeak-xslt-get "emacspeak-xslt" (style))
 
 ;;}}}
 ;;{{{ Variables:
 
 (defvar emacspeak-librivox-buffer-name
-  "*Librivox Interaction*"
+  "Librivox Interaction*"
   "Name of Librivox interaction buffer.")
 
 ;;}}}
@@ -88,18 +88,18 @@
   "https://librivox.org/api/feed/"
   "Base REST end-point for Librivox API  access.")
 
-;;; audiobooks:
-;;; Params from API Documentation:
+;; audiobooks:
+;; Params from API Documentation:
 
-;;; * id - fetches a single record
-;;; * since - takes a UNIX timestamp
-;;; returns all projects cataloged since that time
-;;; * author - all records by that author last name
-;;; * title - all matching titles
-;;; * genre - all projects of the matching genre
-;;; * extended - =1 will return the full set of data about the project
-;;; * limit (default is 50)
-;;;   * offset
+;; * id - fetches a single record
+;; * since - takes a UNIX timestamp
+;; returns all projects cataloged since that time
+;; * author - all records by that author last name
+;; * title - all matching titles
+;; * genre - all projects of the matching genre
+;; * extended - =1 will return the full set of data about the project
+;; * limit (default is 50)
+;;   * offset
 (defvar emacspeak-librivox-results-limit 100
   "Number of results to retrieve at a time.")
 
@@ -112,7 +112,7 @@
            offset emacspeak-librivox-results-limit)
    pattern))
 
-;;; Audio Tracks API:
+;; Audio Tracks API:
 ;;; Params:
 ;; * id - of track itself
 ;; * project_id - all tracks for project
@@ -122,7 +122,7 @@
   (cl-declare (special emacspeak-librivox-api-base))
   (concat emacspeak-librivox-api-base "audiotracks?format=json&" pattern))
 
-;;; Simple Authors API:
+;; Simple Authors API:
 ;;; Params:
 ;; * id - of author
 ;; * last_name - exact match
@@ -174,6 +174,29 @@
     (emacspeak-librivox-display-authors (g-json-get 'authors book))
     (when desc (insert "<p>" desc "</p>\n\n"))))
 
+(defun emacspeak-librivox--render (title books offset)
+  "render results page. "
+  (with-temp-buffer
+    (insert "<title>" title "</title>\n")
+    (insert "<h1>" title "</h1>\n")
+    (insert
+     "<p> Press <code>e e </code> on a <em>listen</em> link to play the
+book.</p>")
+    ;;; convert to list to avoid strange binding  error  when using a vector
+    (setq books (append books nil))
+    (cl-loop
+     for b in  books
+     and i from (1+ offset)
+     do
+     (emacspeak-librivox-display-book b i))
+    (when (= emacspeak-librivox-results-limit (length books))
+      (insert
+       (format
+        "Re-execute this command with an interactive prefix argument and
+specify offset %s to get more results."
+        (+ offset emacspeak-librivox-results-limit))))
+    (browse-url-of-buffer)))
+
 (defun emacspeak-librivox-search (pattern &optional  offset)
   "Search for books.
 Argument `pattern' is of the form:
@@ -186,7 +209,7 @@ Optional arg `offset' (default 0) is used for getting more results."
   (let* ((title
           (format
            "Search: %s Offset: %s"
-           (emacspeak-wizards-unhex-uri pattern) offset))
+           (url-unhex-string pattern) offset))
          (url (emacspeak-librivox-audiobooks-uri pattern offset))
          (result (g-json-get-result
                   (format
@@ -196,34 +219,17 @@ Optional arg `offset' (default 0) is used for getting more results."
     (unless books (message "No results."))
     (emacspeak-auditory-icon 'task-done)
     (when books
-      (emacspeak-webutils-autospeak)
+      (emacspeak-eww-autospeak)
       (add-hook
-       'emacspeak-web-post-process-hook
+       'emacspeak-eww-post-process-hook
        #'(lambda ()
            (cl-declare (special emacspeak-we-url-executor))
            (setq emacspeak-we-url-executor 'emacspeak-librivox-play)))
-      (with-temp-buffer
-        (insert "<title>" title "</title>\n")
-        (insert "<h1>" title "</h1>\n")
-        (insert
-         "<p> Press <code>e e </code> on a <em>listen</em> link to play the
-book.</p>")
-        (cl-loop
-         for b across books
-         and i from (1+ offset)
-         do
-         (emacspeak-librivox-display-book b i))
-        (when (= emacspeak-librivox-results-limit (length books))
-          (insert
-           (format
-            "Re-execute this command with an interactive prefix argument and
-specify offset %s to get more results."
-            (+ offset emacspeak-librivox-results-limit))))
-        (browse-url-of-buffer)))))
+      (emacspeak-librivox--render title books offset))))
 
 (defvar emacspeak-librivox-genre-list
   '(
-    "*Non-fiction" "Action & Adventure" "Action & Adventure Fiction"
+    "Non-fiction" "Action & Adventure" "Action & Adventure Fiction"
     "Ancient" "Animals" "Animals & Nature"
     "Anthologies" "Antiquity" "Art, Design & Architecture"
     "Arts" "Astronomy, Physics & Mechanics" "Ballads"
@@ -272,7 +278,6 @@ specify offset %s to get more results."
     )
   "List of genres.")
 
-;;;###autoload
 (defun emacspeak-librivox-search-by-genre (genre &optional offset)
   "Search by genre.
 Optional prefix arg `offset' prompts for offset."
@@ -285,10 +290,9 @@ Optional prefix arg `offset' prompts for offset."
   (when offset (setq offset (read-number "Offset: ")))
   (emacspeak-librivox-search
    (format "genre=%s"
-           (emacspeak-url-encode genre))
+           (url-encode-url genre))
    offset))
 
-;;;###autoload
 (defun emacspeak-librivox-search-by-author (author &optional offset)
   "Search by author. Both exact and partial matches for
 `author'. Optional interactive prefix arg `offset' prompts for offset
@@ -298,10 +302,9 @@ Optional prefix arg `offset' prompts for offset."
     (setq offset (read-number "Offset: ")))
   (emacspeak-librivox-search
    (format "author=%s"
-           (emacspeak-url-encode author))
+           (url-hexify-string author))
    offset))
 
-;;;###autoload
 (defun emacspeak-librivox-search-by-title (title &optional offset)
   "Search by title. Both exact and partial matches for `title'. Optional
 prefix arg `offset' prompts for offset --- use this for retrieving
@@ -309,7 +312,7 @@ more results."
   (interactive "sTitle: \nP")
   (emacspeak-librivox-search
    (format "title=%s"
-           (emacspeak-url-encode title))
+           (url-hexify-string title))
    offset))
 
 ;;}}}
@@ -321,17 +324,17 @@ more results."
   (interactive
    (list
     (read-char "a: Author, t: Title,  p:Play, g:Genre, d: Browse Local")))
-  (ecase search-type
-         (?d (dired (expand-file-name "librivox" emacspeak-resource-directory)))
-         (?a (call-interactively 'emacspeak-librivox-search-by-author))
-         (?p (call-interactively 'emacspeak-librivox-play))
-         (?t (call-interactively 'emacspeak-librivox-search-by-title))
-         (?g (call-interactively 'emacspeak-librivox-search-by-genre))))
+  (cl-ecase search-type
+    (?d (dired (expand-file-name "librivox" emacspeak-user-directory)))
+    (?a (call-interactively 'emacspeak-librivox-search-by-author))
+    (?p (call-interactively 'emacspeak-librivox-play))
+    (?t (call-interactively 'emacspeak-librivox-search-by-title))
+    (?g (call-interactively 'emacspeak-librivox-search-by-genre))))
 
 ;;}}}
 ;;{{{ Cache Playlists:
 (defcustom emacspeak-librivox-local-cache
-  (expand-file-name "librivox" emacspeak-resource-directory)
+  (expand-file-name "librivox" emacspeak-user-directory)
   "Location where we cache LIBRIVOX playlists."
   :type 'directory
   :group 'emacspeak-librivox)
@@ -345,7 +348,7 @@ more results."
 (defun emacspeak-librivox-get-m3u-name (rss)
   "Parse RSS from temporary location to create a real file name."
   (emacspeak-librivox-ensure-cache)
-  (assert  (file-exists-p rss) nil "RSS file not found.")
+  (cl-assert  (file-exists-p rss) nil "RSS file not found.")
   (with-current-buffer (find-file rss)
     (let* ((title
             (dom-by-tag
@@ -361,14 +364,14 @@ more results."
 
 ;;}}}
 ;;{{{ Play Librivox Streams:
-;;;###autoload
+
 (defun emacspeak-librivox-play (rss-url)
   "Play book stream"
   (interactive
    (list
-    (emacspeak-webutils-read-this-url)))
+    (emacspeak-eww-read-url)))
   (cl-declare (special g-curl-program g-curl-common-options
-                    emacspeak-xslt-program))
+                       emacspeak-xslt-program))
   (let ((file  (make-temp-file "librivox" nil ".rss"))
         (m3u-file nil))
     (shell-command
@@ -385,9 +388,8 @@ more results."
 (provide 'emacspeak-librivox)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
