@@ -1,89 +1,90 @@
 ;;; emacspeak-maths.el --- Audio-Formatted Mathematics  -*- lexical-binding: t; -*-
-;;; $Author: tv.raman.tv, zorkov  $
-;;; Description:  Speak MathML and LaTeX math expressions
-;;; Keywords: Emacspeak,  Audio Desktop maths
+;; $Author: tv.raman.tv, zorkov  $
+;; Description:  Speak MathML and LaTeX math expressions
+;; Keywords: Emacspeak,  Audio Desktop maths
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
-;;;  $Revision: 4532 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2007, 2011, T. V. Raman
-;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNMATHS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2007, 2011, T. V. Raman
+;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNMATHS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  introduction
 
 ;;; Commentary:
-;;; @subsection Setup 
-;;; Do not try what follows until you have read  js/node/README.org
-;;; and successfully set up nvm (Node Version Manager) as described there.
-;;; @subsection Technical Overview 
-;;; Spoken mathematics on the emacspeak audio desktop. Use a NodeJS
-;;; based speech-rule-engine for Mathematics as the backend for
-;;; processing mathematical markup. The result of this processing is
-;;; an annotated S-expression that is rendered via Emacspeak's speech
-;;; facilities. Annotations follow Aural CSS as implemented in
-;;; Emacspeak, This allows us to map these expressions to aural
-;;; properties supported by specific TTS engines. 
-;;; @subsection Basic Usage: 
-;;;
-;;; Start  the server/client: M-x emacspeak-maths-start. Once the server
-;;; and client are started, you can browse any number of math
-;;; expressions using the emacspeak-maths-navigator described below.
-;;; Note: In general, once everything is configured correctly, using
-;;; the maths navigator automatically starts the server and
-;;; client. Invoke the Navigator using s-spc --- this is the <windows>
-;;; key on
-;;; Linux. Now you can use these keys:
-;;; @itemize
-;;; @item  Show Output <o> Switch to output buffer and quit Maths Navigator
-;;; @item Enter: <SPC>
-;;; Enter a LaTeX expression.
-;;; @item Smart-Enter: <enter> Enter the guessed expression with no prompting.
-;;; @item Alt-Text <a> Process alt-text
-;;; under point as LaTeX.
-;;; @item Down <down> Move down a level.
-;;; @item
-;;; Up <up> Move up a level.
-;;; @item Left <left> Move left.
-;;; @item Right
-;;; <right> Move right.
-;;; @item Exit <any other key> Exit
-;;; navigator.
-;;;
-;;;
-;;; @end itemize
-;;;The current expression is spoken after
-;;; each of the above commands. It is also displayed in a special
-;;; buffer *Spoken Math*. That buffer holds all previously generated
-;;; output, And Emacs commands forward-page and backward-page can be
-;;; used to move through each chunk of output.
+;; @subsection Setup 
+;; Do not try what follows until you have read  js/node/README.org
+;; and successfully set up nvm (Node Version Manager) as described there.
+;; @subsection Technical Overview 
+;; Spoken mathematics on the emacspeak audio desktop. Use a NodeJS
+;; based speech-rule-engine for Mathematics as the backend for
+;; processing mathematical markup. The result of this processing is
+;; an annotated S-expression that is rendered via Emacspeak's speech
+;; facilities. Annotations follow Aural CSS as implemented in
+;; Emacspeak, This allows us to map these expressions to aural
+;; properties supported by specific TTS engines. 
+;; 
+;; Start  the server/client: M-x emacspeak-maths-start. Once the server
+;; and client are started, you can browse any number of math
+;; expressions using the emacspeak-maths-navigator defined in module
+;; @xref{emacspeak-maths} as described below.
+;; 
+;; Note: In general, once everything is configured correctly, using
+;; the maths navigator automatically starts the server and
+;; client. Invoke the Navigator using @kbd{s-spc} --- this is the <windows>
+;; key on Linux laptops.
+;; Linux. Now you can use these keys:
+;; @itemize
+;; @item  Show Output <o> Switch to output buffer and quit Maths Navigator
+;; @item Enter: <SPC>
+;; Enter a LaTeX expression.
+;; @item Smart-Enter: <enter> Enter the guessed expression with no prompting.
+;; @item Alt-Text <a> Process alt-text
+;; under point as LaTeX.
+;; @item Down <down> Move down a level.
+;; @item
+;; Up <up> Move up a level.
+;; @item Left <left> Move left.
+;; @item Right
+;; <right> Move right.
+;; @item Exit <any other key> Exit
+;; navigator.
+;; 
+;; 
+;; @end itemize
+;; The current expression is spoken after
+;; each of the above commands. It is also displayed in a special
+;; buffer *Spoken Math*. That buffer holds all previously generated
+;; output, And Emacs commands forward-page and backward-page can be
+;; used to move through each chunk of output.
 
 ;;; Code:
 
@@ -93,31 +94,26 @@
 (require 'emacspeak-preamble)
 (require 'cl-lib)
 (require 'comint)
-(require 'derived)
-(require 'nvm "nvm" 'no-error )
+(eval-when-compile (require 'derived))
+(require 'nvm "nvm" 'no-error)
 
 ;;}}}
 ;;{{{ Customizations And Variables:
 
-(defgroup emacspeak-maths nil
-  "Customize Emacspeak  Maths."
-  :group 'emacspeak)
-
-(defcustom emacspeak-maths-inferior-program
+(defvar emacspeak-maths-inferior-program
   (cond
-   ((executable-find "node") (executable-find "node"))
    ((and (locate-library "nvm")
          (nvm--installed-versions))
     (let ((v (car (sort (mapcar #'car (nvm--installed-versions)) #'string>))))
       (nvm-use v)
-      (executable-find "node"))) 
+      (executable-find "node")))
+   ;; The fallback below  --- /usr/bin/node e.g. on Ubuntu/Debian  is old.
+   ((executable-find "node") (executable-find "node")) 
    (t  nil))
   "Location of `node' executable.  Make sure the environment in which
 Emacs is launched finds the right installation of node.  M-x
 package-install nvm makes it easier to have Emacs find the right node
-install."
-  :type 'file
-  :group 'emacspeak-maths)
+install.")
 
 (cl-defstruct emacspeak-maths
   server-buffer ; comint buffer
@@ -153,12 +149,12 @@ Throw error if no handler defined."
 ;;}}}
 ;;{{{ Handlers:
 
-;;; All handlers are called with the body of the unit being parsed.
-;;; Handlers process input and render to output buffer
-;;; Except for the pause handler that merely records the pause,
-;;; Leaving it to the next text handler to consume that pause.
+;; All handlers are called with the body of the unit being parsed.
+;; Handlers process input and render to output buffer
+;; Except for the pause handler that merely records the pause,
+;; Leaving it to the next text handler to consume that pause.
 
-;;; Helper: Handle plain strings
+;; Helper: Handle plain strings
 
 (defun emacspeak-maths-handle-string (string)
   "Handle plain, unannotated string."
@@ -200,14 +196,14 @@ Otherwise, Examine head of sexp, and applies associated handler to the tail."
 (defun emacspeak-maths-acss (acss-alist)
   "Return ACSS voice corresponding to acss-alist."
   (let-alist acss-alist
-    (acss-personality-from-speech-style
+    (voice-acss-from-speech-style
      (make-acss
       :average-pitch  .average-pitch
       :pitch-range .pitch-range
       :stress .stress
       :richness .richness))))
 
-;;;Helper: Apply pause and consume:
+;; Helper: Apply pause and consume:
 
 (defun emacspeak-maths-apply-pause (start)
   "Apply pause."
@@ -252,7 +248,14 @@ Expected: ((acss) string)."
 
 (defun emacspeak-maths-handle-error (contents)
   "Display error message."
-  (message "%s" contents))
+  (let ((msg (car contents)))
+    (dtk-notify-say
+     (cond
+      ((string= "38" msg) "Top of tree")
+      ((string= "39" msg) "Last Node at this level")
+      ((string= "40" msg) "Bottom of tree")
+      ((string= "37" msg) "First node at this level")
+      (t msg)))))
 
 (defun emacspeak-maths-handle-parse-error (contents)
   "Display parse-error message."
@@ -264,6 +267,7 @@ Expected: ((acss) string)."
 
 ;;}}}
 ;;{{{ Map Handlers:
+
 (cl-loop
  for f in
  '(exp pause text error welcome parse-error)
@@ -289,11 +293,11 @@ left for next run."
   (with-current-buffer (process-buffer proc)
     (let ((moving (= (point) (process-mark proc))))
       (save-excursion
-;;; Insert the text, advancing the process marker.
+        ;; Insert the text, advancing the process marker.
         (goto-char (process-mark proc))
         (insert string)
         (set-marker (process-mark proc) (point)))
-;;; Consume process output
+      ;; Consume process output
       (save-excursion
         (goto-char (point-min))
         (flush-lines "^ *$")
@@ -303,9 +307,9 @@ left for next run."
              (start (point)))
           (condition-case nil
               (while (not (eobp))
-;;; Parse one complete chunk
+                ;; Parse one complete chunk
                 (setq result (emacspeak-maths-read-output))
-;;; Todo: reverse later depending on how we use it.
+                ;; Todo: perhaps accumulate instead of just using recent
                 (setf (emacspeak-maths-result emacspeak-maths) result)
                 (skip-syntax-forward " >")
                 (delete-region start (point))
@@ -324,7 +328,7 @@ left for next run."
   "Start Maths server bridge."
   (interactive)
   (cl-declare (special emacspeak-maths-inferior-program
-                    emacspeak-maths emacspeak-maths-server-program))
+                       emacspeak-maths emacspeak-maths-server-program))
   (cl-assert emacspeak-maths-inferior-program nil "No node executable found.")
   (let ((server
          (make-comint
@@ -360,6 +364,18 @@ left for next run."
   (when (called-interactively-p 'interactive)
     (message "Shutdown Maths server and client.")))
 
+(defun emacspeak-maths-flush-output ()
+  "Flush client buffer if things go out of sync."
+  (interactive)
+  (cl-declare (special emacspeak-maths))
+  (when
+      (process-live-p (emacspeak-maths-client-process emacspeak-maths))
+    (with-current-buffer
+        (process-buffer (emacspeak-maths-client-process emacspeak-maths))
+      (erase-buffer)))
+  (when (called-interactively-p 'interactive)
+    (message "Flushed client buffer.")))
+
 (defun emacspeak-maths-ensure-server ()
   "Start up Maths Server bridge if not already running."
   (cl-declare (special emacspeak-maths))
@@ -378,8 +394,9 @@ left for next run."
 
 ;;}}}
 ;;{{{ Navigators:
+
 (declare-function calc-kill "calc-yank" (flag no-delete))
-;;; Guess expression from Calc:
+;; Guess expression from Calc:
 (defun emacspeak-maths-guess-calc ()
   "Guess expression to speak in calc buffers.
 Set calc-language to tex to use this feature."
@@ -388,7 +405,17 @@ Set calc-language to tex to use this feature."
   (calc-kill 1 'no-delete)
   (substring (car calc-last-kill) 2))
 
-;;; Helper: Guess current math expression from TeX/LaTeX
+;; Guess expression from sage
+
+(declare-function emacspeak-sage-get-output-as-latex "emacspeak-sage" nil)
+
+(defun emacspeak-maths-guess-sage ()
+  "Guess expression to speak in sage-mode buffers."
+  (cl-assert (eq major-mode 'sage-shell:sage-mode) nil "This is not a Sage buffer.")
+  (sit-for 0.1)
+  (emacspeak-sage-get-output-as-latex))
+
+;; Helper: Guess current math expression from TeX/LaTeX
 
 (defun emacspeak-maths-guess-tex ()
   "Extract math content around point."
@@ -400,7 +427,7 @@ Set calc-language to tex to use this feature."
           (begin nil)
           (end nil))
       (cond
-;;; $ and $$
+       ;; $ and $$
        ((or (string= "$" delimiter)
             (string= "$$" delimiter))
         (save-excursion
@@ -410,7 +437,7 @@ Set calc-language to tex to use this feature."
           (skip-syntax-forward "^$")
           (setq end (point))
           (buffer-substring begin end)))
-;;; \( and \[
+       ;; \( and \[
        ((string= "\\(" delimiter)
         (goto-char start)
         (setq begin (+ start  2))
@@ -423,7 +450,7 @@ Set calc-language to tex to use this feature."
         (search-forward "\\]")
         (setq end (- (point) 2))
         (buffer-substring begin end))
-;;; begin equation
+       ;; begin equation
        ((string= "equation" delimiter)
         (goto-char start)
         (forward-char (length "\\begin{equation}"))
@@ -439,56 +466,48 @@ Set calc-language to tex to use this feature."
   "Examine current mode, text around point etc. to guess Math content to read."
   (cl-declare (special emacspeak-maths))
   (unless emacspeak-maths (emacspeak-maths-start))
-  (setf(emacspeak-maths-input emacspeak-maths)
-       (cond
-        ((eq major-mode 'calc-mode)
-         (emacspeak-maths-guess-calc))
-        ((and (memq major-mode '(tex-mode plain-tex-mode latex-mode ams-tex-mode))
-              (featurep 'texmathp))
-         (emacspeak-maths-guess-tex))
-        ((and
-          (eq major-mode 'eww-mode)
-          (not
-           (string-equal
-            (get-text-property (point) 'shr-alt)
-            "No image under point")))
-         (get-text-property (point) 'shr-alt)))))
+  (setf
+   (emacspeak-maths-input emacspeak-maths)
+   (cond
+    ((eq major-mode 'calc-mode)
+     (emacspeak-maths-guess-calc))
+    ((eq major-mode 'sage-shell:sage-mode)
+     (emacspeak-maths-guess-sage))
+    ((and (memq major-mode '(tex-mode plain-tex-mode latex-mode ams-tex-mode))
+          (featurep 'texmathp))
+     (emacspeak-maths-guess-tex))
+    ((and
+      (eq major-mode 'eww-mode)
+      (not
+       (string-equal
+        (get-text-property (point) 'shr-alt)
+        "No image under point")))
+     (get-text-property (point) 'shr-alt))
+    (t
+     (read-from-minibuffer
+      "Maths: " nil nil nil nil
+      (when mark-active (buffer-substring (region-beginning)(region-end))))))))
 
 ;;;###autoload
 (defun emacspeak-maths-enter-guess ()
-  "Send the guessed  LaTeX expression to Maths server.
-Guess is based on context."
+  "Send the guessed  LaTeX expression to Maths server. "
   (interactive)
   (cl-declare (special emacspeak-maths))
+  (emacspeak-maths-ensure-server)        
   (emacspeak-maths-guess-input)         ;guess based on context
-  (emacspeak-maths-ensure-server)
   (process-send-string
    (emacspeak-maths-client-process emacspeak-maths)
-   (format "enter: %s"
-           (or
-            (emacspeak-maths-input emacspeak-maths)
-            (read-from-minibuffer
-             "Maths: "
-             nil nil nil nil
-             (when mark-active
-               (buffer-substring (region-beginning)(region-end))))))))
+   (format "enter: %s" (emacspeak-maths-input emacspeak-maths))))
 
 ;;;###autoload
 (defun emacspeak-maths-enter (latex)
-  "Send a LaTeX expression to Maths server.
-Tries to guess default based on context.
-Uses guessed default if user enters an empty string."
-  (interactive
-   (list
-    (progn
-      (emacspeak-maths-guess-input)     ;guess based on context
-      (read-from-minibuffer "LaTeX: "
-                            nil nil nil nil
-                            (emacspeak-maths-input emacspeak-maths)))))
+  "Send a LaTeX expression to Maths server,
+ guess  based on context. "
+  (interactive (list (emacspeak-maths-guess-input)))
   (cl-declare (special emacspeak-maths))
   (emacspeak-maths-ensure-server)
-  (when (string= "" latex)
-    (setq latex (emacspeak-maths-input emacspeak-maths)))
+  (when (or (null latex) (string= "" latex))
+    (setq latex (read-from-minibuffer "Enter expression:")))
   (setf (emacspeak-maths-input emacspeak-maths) latex)
   (process-send-string
    (emacspeak-maths-client-process emacspeak-maths)
@@ -500,7 +519,7 @@ Uses guessed default if user enters an empty string."
  do
  (eval
   `(defun ,(intern (format "emacspeak-maths-%s" move)) ()
-     ,(format "Move %s in current Math expression." move)
+     ,(format "Move %s in current Math expression. (auto-generated)" move)
      (interactive)
      (cl-declare (special emacspeak-maths))
      (process-send-string
@@ -582,9 +601,8 @@ For use on Wikipedia pages  for example."
 (provide 'emacspeak-maths)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
