@@ -1,59 +1,59 @@
 ;;; emacspeak-ocr.el --- ocr Front-end for emacspeak desktop  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $
-;;; Description:  Emacspeak front-end for OCR
-;;; Keywords: Emacspeak, ocr
+;;
+;; $Author: tv.raman.tv $
+;; Description:  Emacspeak front-end for OCR
+;; Keywords: Emacspeak, ocr
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2008-06-21 10:50:41 -0700 (Sat, 21 Jun 2008) $ |
-;;;  $Revision: 4448 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4448 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2017, T. V. Raman
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  Introduction:
 
 ;;; Commentary:
 
-;;; This module defines Emacspeak front-end to OCR.
-;;; This module assumes that sane is installed and working
-;;; for image acquisition,
-;;; and that there is an OCR engine that can take acquired
-;;; images and produce text.
+;; This module defines Emacspeak front-end to OCR.
+;; This module assumes that sane is installed and working
+;; for image acquisition,
+;; and that there is an OCR engine that can take acquired
+;; images and produce text.
 ;;; Prerequisites:
-;;; Sane installed and working.
-;;; scanimage to generate tiff files from scanner.
-;;; tiffcp to compress the tiff file.
-;;; working ocr executable 
-;;; by default this module assumes that the OCR executable
-;;; is named "ocr"
+;; Sane installed and working.
+;; scanimage to generate tiff files from scanner.
+;; tiffcp to compress the tiff file.
+;; working ocr executable 
+;; by default this module assumes that the OCR executable
+;; is named "ocr"
 
 ;;; Code:
 
@@ -100,7 +100,8 @@ OCR engine for optical character recognition."
   :type 'string
   :group 'emacspeak-ocr)
 
-(defcustom emacspeak-ocr-engine "ocr"
+(defcustom emacspeak-ocr-engine
+  (expand-file-name "tesseract.pl" emacspeak-etc-directory)
   "OCR engine to process acquired image."
   :type 'string
   :group 'emacspeak-ocr)
@@ -113,7 +114,7 @@ OCR engine for optical character recognition."
 
 (defcustom emacspeak-ocr-working-directory
   (expand-file-name "ocr/"
-                    emacspeak-resource-directory)
+                    emacspeak-user-directory)
   "Directory where images and OCR results
 will be placed."
   :group 'emacspeak-ocr
@@ -182,7 +183,7 @@ will be placed."
 (defun emacspeak-ocr-get-image-name (extension)
   "Return name of current image."
   (cl-declare (special emacspeak-ocr-document-name
-                    emacspeak-ocr-last-page-number))
+                       emacspeak-ocr-last-page-number))
   (format "%s-p%s%s"
           emacspeak-ocr-document-name
           (1+ emacspeak-ocr-last-page-number)
@@ -191,7 +192,7 @@ will be placed."
 (defun emacspeak-ocr-get-page-name ()
   "Return name of current page."
   (cl-declare (special emacspeak-ocr-document-name
-                    emacspeak-ocr-current-page-number))
+                       emacspeak-ocr-current-page-number))
   (format "%s-p%s.txt"
           emacspeak-ocr-document-name
           emacspeak-ocr-current-page-number))
@@ -209,7 +210,7 @@ will be placed."
 (defun emacspeak-ocr-get-mode-line-format ()
   "Return string suitable for use as the mode line."
   (cl-declare (special major-mode
-                    emacspeak-ocr-current-page-number))
+                       emacspeak-ocr-current-page-number))
   (format "%s Page-%s/%s %s"
           (buffer-name)
           emacspeak-ocr-current-page-number
@@ -306,19 +307,19 @@ See \\{emacspeak-ocr-mode-map}.
 (define-key emacspeak-ocr-mode-map "p" 'emacspeak-ocr-page)
 (define-key emacspeak-ocr-mode-map "s" 'emacspeak-ocr-save-current-page)
 (define-key emacspeak-ocr-mode-map " "
-  'emacspeak-ocr-read-current-page)
+            'emacspeak-ocr-read-current-page)
 (define-key emacspeak-ocr-mode-map "I"
-  'emacspeak-ocr-set-scan-image-options)
+            'emacspeak-ocr-set-scan-image-options)
 (define-key emacspeak-ocr-mode-map "C" 'emacspeak-ocr-set-compress-image-options)
 (cl-loop for i from 1 to 9
          do
          (define-key emacspeak-ocr-mode-map
-           (format "%s" i)
-           'emacspeak-ocr-page))
+                     (format "%s" i)
+                     'emacspeak-ocr-page))
 
 ;;}}}
 ;;{{{ interactive commands
-;;;###autoload
+
 (defun emacspeak-ocr-customize ()
   "Customize OCR settings."
   (interactive)
@@ -344,11 +345,10 @@ For detailed help, invoke command emacspeak-ocr bound to
 `?' to display mode-specific help for emacspeak-ocr-mode."
   (interactive)
   (cl-declare (special emacspeak-ocr-working-directory
-                    emacspeak-ocr-document-name
-                    buffer-read-only))
+                       emacspeak-ocr-document-name
+                       buffer-read-only))
   (let  ((buffer (emacspeak-ocr-get-buffer)))
-    (save-excursion
-      (set-buffer buffer)
+    (with-current-buffer buffer
       (emacspeak-ocr-mode)
       (when (file-exists-p emacspeak-ocr-working-directory)
         (cd emacspeak-ocr-working-directory))
@@ -364,7 +364,7 @@ This name will be used as the prefix for naming image and
 text files produced in this scan.")
 
 (make-variable-buffer-local 'emacspeak-ocr-document-name)
-;;;###autoload
+
 (defun emacspeak-ocr-name-document (name)
   "Name document being scanned in the current OCR buffer.
 Pick a short but meaningful name."
@@ -372,7 +372,7 @@ Pick a short but meaningful name."
    (list
     (read-from-minibuffer "Document name: ")))
   (cl-declare (special emacspeak-ocr-document-name
-                    mode-line-format))
+                       mode-line-format))
   (setq emacspeak-ocr-document-name name)
   (rename-buffer
    (format "*%s-ocr*" name)
@@ -380,19 +380,19 @@ Pick a short but meaningful name."
   (emacspeak-ocr-update-mode-line)
   (emacspeak-auditory-icon 'select-object)
   (emacspeak-speak-mode-line))
-;;;###autoload
+
 (defun emacspeak-ocr-scan-image ()
   "Acquire page image."
   (interactive)
   (cl-declare (special emacspeak-speak-messages
-                    emacspeak-ocr-last-page-number
-                    emacspeak-ocr-image-extension
-                    emacspeak-ocr-keep-uncompressed-image
-                    emacspeak-ocr-scan-image
-                    emacspeak-ocr-scan-image-options
-                    emacspeak-ocr-compress-image
-                    emacspeak-ocr-compress-image-options
-                    emacspeak-ocr-document-name))
+                       emacspeak-ocr-last-page-number
+                       emacspeak-ocr-image-extension
+                       emacspeak-ocr-keep-uncompressed-image
+                       emacspeak-ocr-scan-image
+                       emacspeak-ocr-scan-image-options
+                       emacspeak-ocr-compress-image
+                       emacspeak-ocr-compress-image-options
+                       emacspeak-ocr-document-name))
   (let ((image-name (emacspeak-ocr-get-image-name
                      emacspeak-ocr-image-extension)))
     (let ((emacspeak-speak-messages nil))
@@ -414,26 +414,25 @@ Pick a short but meaningful name."
         (when emacspeak-ocr-keep-uncompressed-image
           (format "rm -f temp%s"
                   emacspeak-ocr-image-extension))))
-      (when (ems-interactive-p)
+      (when (called-interactively-p 'interactive)
         (setq emacspeak-ocr-last-page-number
               (1+ emacspeak-ocr-last-page-number)))
       (message "Acquired  image to file %s"
                image-name))))
 
-;;;###autoload
 (defun emacspeak-ocr-scan-photo (&optional metadata)
   "Scan in a photograph.
 The scanned image is converted to JPEG."
   (interactive "P")
   (cl-declare (special emacspeak-speak-messages
-                    emacspeak-ocr-jpeg-metadata-writer
-                    emacspeak-ocr-photo-compress-options
-                    emacspeak-ocr-scan-photo-options
-                    emacspeak-ocr-keep-uncompressed-image
-                    emacspeak-ocr-scan-image
-                    emacspeak-ocr-compress-photo
-                    emacspeak-ocr-image-extension
-                    emacspeak-ocr-document-name))
+                       emacspeak-ocr-jpeg-metadata-writer
+                       emacspeak-ocr-photo-compress-options
+                       emacspeak-ocr-scan-photo-options
+                       emacspeak-ocr-keep-uncompressed-image
+                       emacspeak-ocr-scan-image
+                       emacspeak-ocr-compress-photo
+                       emacspeak-ocr-image-extension
+                       emacspeak-ocr-document-name))
   (let (
         (jpg (emacspeak-ocr-get-image-name ".jpg"))
         (pnm (emacspeak-ocr-get-image-name ".pnm")))
@@ -451,7 +450,7 @@ The scanned image is converted to JPEG."
                   pnm)
         (format "rm -f temp.pnm"))))
     (when (and metadata
-               (ems-interactive-p))
+               (called-interactively-p 'interactive))
       (setq metadata
             (read-from-minibuffer "Enter picture description: "))
       (let ((tempfile (format "temp%s.jpg" (gensym))))
@@ -467,7 +466,7 @@ The scanned image is converted to JPEG."
 
 (defvar emacspeak-ocr-process nil
   "Handle to OCR process.")
-;;;###autoload
+
 (defun emacspeak-ocr-write-document ()
   "Writes out recognized text from all pages in current document."
   (interactive)
@@ -479,13 +478,13 @@ The scanned image is converted to JPEG."
        (point-max)
        (emacspeak-ocr-get-text-name))
       (emacspeak-auditory-icon 'save-object))))
-;;;###autoload
+
 (defun emacspeak-ocr-save-current-page ()
   "Writes out recognized text from current page
 to an appropriately named file."
   (interactive)
   (cl-declare (special emacspeak-ocr-current-page-number
-                    emacspeak-ocr-page-positions))
+                       emacspeak-ocr-page-positions))
   (cond
    ((= 0 emacspeak-ocr-current-page-number)
     (message "No pages in current document."))
@@ -503,8 +502,8 @@ to an appropriately named file."
 (defun emacspeak-ocr-process-sentinel  (_process _state)
   "Alert user when OCR is complete."
   (cl-declare (special emacspeak-ocr-page-positions
-                    emacspeak-ocr-last-page-number
-                    emacspeak-ocr-current-page-number))
+                       emacspeak-ocr-last-page-number
+                       emacspeak-ocr-current-page-number))
   (setq emacspeak-ocr-current-page-number
         emacspeak-ocr-last-page-number)
   (emacspeak-auditory-icon 'task-done)
@@ -513,18 +512,18 @@ to an appropriately named file."
   (emacspeak-ocr-save-current-page)
   (emacspeak-ocr-update-mode-line)
   (emacspeak-speak-line))
-;;;###autoload
+
 (defun emacspeak-ocr-recognize-image ()
   "Run OCR engine on current image.
 Prompts for image file if file corresponding to the expected
 `current page' is not found."
   (interactive)
   (cl-declare (special emacspeak-ocr-engine
-                    emacspeak-ocr-engine-options
-                    emacspeak-ocr-process
-                    emacspeak-ocr-last-page-number
-                    emacspeak-ocr-page-positions
-                    emacspeak-ocr-image-extension))
+                       emacspeak-ocr-engine-options
+                       emacspeak-ocr-process
+                       emacspeak-ocr-last-page-number
+                       emacspeak-ocr-page-positions
+                       emacspeak-ocr-image-extension))
   (let ((inhibit-read-only t)
         (image-name
          (if (file-exists-p (emacspeak-ocr-get-image-name emacspeak-ocr-image-extension))
@@ -558,18 +557,19 @@ Prompts for image file if file corresponding to the expected
 
 (defun emacspeak-ocr-flipflop-and-recognize-image ()
   "Run OCR engine on current image after flip-flopping it.
-Useful if you've scanned a page upside down and are using an engine that does not automatically flip the image for you.
-You need the imagemagik family of tools --- we use mogrify to transform the image.
-Prompts for image file if file corresponding to the expected
-`current page' is not found."
+Useful if you've scanned a page upside down and are using an
+engine that does not automatically flip the image for you.  You
+need the imagemagik family of tools --- we use mogrify to
+transform the image.  Prompts for image file if file
+corresponding to the expected `current page' is not found."
   (interactive)
   (cl-declare (special emacspeak-ocr-engine
-                    emacspeak-ocr-image-flipflop
-                    emacspeak-ocr-engine-options
-                    emacspeak-ocr-process
-                    emacspeak-ocr-last-page-number
-                    emacspeak-ocr-page-positions
-                    emacspeak-ocr-image-extension))
+                       emacspeak-ocr-image-flipflop
+                       emacspeak-ocr-engine-options
+                       emacspeak-ocr-process
+                       emacspeak-ocr-last-page-number
+                       emacspeak-ocr-page-positions
+                       emacspeak-ocr-image-extension))
   (let ((inhibit-read-only t)
         (image-name
          (if (file-exists-p (emacspeak-ocr-get-image-name emacspeak-ocr-image-extension))
@@ -600,7 +600,6 @@ Prompts for image file if file corresponding to the expected
                           'emacspeak-ocr-process-sentinel)
     (message "Launched OCR engine.")))
 
-;;;###autoload
 (defun emacspeak-ocr-scan-and-recognize ()
   "Scan in a page and run OCR engine on it.
 Use this command once you've verified that the separate
@@ -610,7 +609,6 @@ correctly by themselves."
   (emacspeak-ocr-scan-image)
   (emacspeak-ocr-recognize-image))
 
-;;;###autoload
 (defun emacspeak-ocr-open-working-directory ()
   "Launch dired on OCR working directory."
   (interactive)
@@ -619,13 +617,13 @@ correctly by themselves."
    (dired-noselect emacspeak-ocr-working-directory))
   (emacspeak-auditory-icon 'open-object)
   (emacspeak-speak-mode-line))
-;;;###autoload
+
 (defun emacspeak-ocr-forward-page (&optional _count-ignored)
   "Like forward page, but tracks page number of current document."
   (interactive "p")
   (cl-declare (special emacspeak-ocr-page-positions
-                    emacspeak-ocr-last-page-number
-                    emacspeak-ocr-current-page-number))
+                       emacspeak-ocr-last-page-number
+                       emacspeak-ocr-current-page-number))
   (cond
    ((= 0 emacspeak-ocr-current-page-number)
     (message "No pages in current document."))
@@ -642,12 +640,12 @@ correctly by themselves."
       (emacspeak-ocr-update-mode-line)
       (emacspeak-speak-line)
       (emacspeak-auditory-icon 'large-movement))))
-;;;###autoload
+
 (defun emacspeak-ocr-backward-page (&optional _count-ignored)
   "Like backward page, but tracks page number of current document."
   (interactive "p")
   (cl-declare (special emacspeak-ocr-page-positions
-                    emacspeak-ocr-current-page-number))
+                       emacspeak-ocr-current-page-number))
   (cond
    ((= 0 emacspeak-ocr-current-page-number)
     (message "No pages in current document."))
@@ -675,7 +673,7 @@ correctly by themselves."
   (emacspeak-auditory-icon 'large-movement)
   (emacspeak-speak-line)
   )
-;;;###autoload
+
 (defun emacspeak-ocr-page ()
   "Move to specified page."
   (interactive)
@@ -695,13 +693,13 @@ correctly by themselves."
       (message "Not that many pages in document."))
      (t 
       (emacspeak-ocr-goto-page page)))))
-;;;###autoload
+
 (defun emacspeak-ocr-read-current-page ()
   "Speaks current page."
   (interactive)
   (cl-declare (special emacspeak-ocr-page-positions
-                    emacspeak-ocr-current-page-number
-                    emacspeak-ocr-last-page-number))
+                       emacspeak-ocr-current-page-number
+                       emacspeak-ocr-last-page-number))
   (cond
    ((= emacspeak-ocr-current-page-number
        emacspeak-ocr-last-page-number)
@@ -715,7 +713,6 @@ correctly by themselves."
        (aref emacspeak-ocr-page-positions
              (1+ emacspeak-ocr-current-page-number))))))
 
-;;;###autoload
 (defun emacspeak-ocr-set-scan-image-options  (setting)
   "Interactively update scan image options.
 Prompts with current setting in the minibuffer.
@@ -728,7 +725,6 @@ Setting persists for current Emacs session."
   (cl-declare (special emacspeak-ocr-scan-image-options))
   (setq emacspeak-ocr-scan-image-options setting))
 
-;;;###autoload
 (defun emacspeak-ocr-set-compress-image-options  (setting)
   "Interactively update  image compression options.
 Prompts with current setting in the minibuffer.
@@ -745,9 +741,8 @@ Setting persists for current Emacs session."
 (provide 'emacspeak-ocr)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
