@@ -1,76 +1,76 @@
 ;;; emacspeak-org.el --- Speech-enable org  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $
-;;; Description:  Emacspeak front-end for ORG
-;;; Keywords: Emacspeak, org
+;;
+;; $Author: tv.raman.tv $
+;; Description:  Emacspeak front-end for ORG
+;; Keywords: Emacspeak, org
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2008-03-22 18:58:40 -0700 (Sat, 22 Mar 2008) $ |
-;;;  $Revision: 4347 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4347 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2017, T. V. Raman
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  Introduction:
 
 ;;; Commentary:
-;;; Speech-enable org ---
-;;;  Org allows you to keep organized notes and todo lists.
-;;; Homepage: http://www.astro.uva.nl/~dominik/Tools/org/
-;;; or http://orgmode.org/
-;;;
+;; Speech-enable org ---
+;;  Org allows you to keep organized notes and todo lists.
+;; Homepage: http://www.astro.uva.nl/~dominik/Tools/org/
+;; or http://orgmode.org/
+;; 
 ;;; Code:
 
 ;;}}}
 ;;{{{ required modules
+
 (require 'cl-lib)
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
-(require 'eww)
-(require 'emacspeak-eww)
-(require 'emacspeak-feeds)
 (require 'org "org" 'no-error)
 (require 'org-table "org-table" 'no-error)
+(defvar org-ans2 nil)
+
 ;;}}}
 ;;{{{ voice locking:
 
 (voice-setup-add-map
  '(
    (org-date voice-animate)
-   (org-done voice-monotone)
+   (org-done voice-monotone-extra)
    (org-formula voice-animate-extra)
    (org-headline-done voice-monotone-medium)
    (org-level-1 voice-bolden-medium)
    (org-level-2 voice-bolden)
    (org-level-3 voice-animate)
-   (org-level-4 voice-monotone)
+   (org-level-4 voice-monotone-extra)
    (org-level-5 voice-smoothen)
    (org-level-6 voice-lighten)
    (org-level-7 voice-lighten-medium)
@@ -86,21 +86,20 @@
    (org-warning voice-bolden-and-animate)
    (org-agenda-calendar-event voice-animate-extra)
    (org-agenda-calendar-sexp voice-animate)
-   (org-agenda-column-dateline voice-monotone)
+   (org-agenda-column-dateline voice-monotone-extra)
    (org-agenda-diary voice-animate)
    (org-agenda-dimmed-todo-face voice-smoothen-medium)
-   (org-agenda-done voice-monotone)
+   (org-agenda-done voice-monotone-extra)
    (org-agenda-filter-category voice-lighten-extra)
    (org-agenda-filter-tags voice-lighten)
-   (org-agenda-restriction-lock voice-monotone)
+   (org-agenda-restriction-lock voice-monotone-extra)
    (org-agenda-structure voice-bolden)
-   (org-archived voice-monotone)
+   (org-archived voice-monotone-extra)
    (org-beamer-tag voice-bolden)
-   (org-block voice-monotone)
-   (org-block-background voice-monotone)
+   (org-block voice-monotone-extra)
    (org-checkbox voice-animate)
-   (org-clock-overlay voice-animate)
-   (org-code voice-monotone)
+   (org-coverlay voice-animate)
+   (org-code voice-monotone-extra)
    (org-column voice-lighten)
    (org-column-title voice-lighten-extra)
    (org-date-selected voice-bolden)
@@ -111,25 +110,24 @@
    (org-drawer voice-smoothen-medium)
    (org-ellipsis voice-smoothen-extra)
    (org-footnote voice-smoothen)
-   (org-habit-alert-face voice-monotone)
-   (org-habit-alert-future-face voice-monotone)
-   (org-habit-clear-face voice-monotone)
-   (org-habit-clear-future-face voice-monotone)
-   (org-habit-overdue-face voice-monotone)
-   (org-habit-overdue-future-face voice-monotone)
-   (org-habit-ready-future-face voice-monotone)
+   (org-habit-alert-face voice-monotone-extra)
+   (org-habit-alert-future-face voice-monotone-extra)
+   (org-habit-clear-face voice-monotone-extra)
+   (org-habit-clear-future-face voice-monotone-extra)
+   (org-habit-overdue-face voice-monotone-extra)
+   (org-habit-overdue-future-face voice-monotone-extra)
+   (org-habit-ready-future-face voice-monotone-extra)
    (org-hide voice-smoothen-extra)
    (org-indent voice-smoothen)
    (org-inlinetask voice-smoothen-extra)
-   (org-latex-and-export-specials voice-monotone)
    (org-meta-line voice-smoothen-medium)
    (org-property-value voice-animate)
    (org-scheduled voice-animate)
-   (org-sexp-date voice-monotone)
+   (org-sexp-date voice-monotone-extra)
    (org-target voice-bolden-medium)
    (org-upcoming-deadline voice-animate)
-   (org-verbatim voice-monotone)
-   (org-habit-ready-face voice-monotone)))
+   (org-verbatim voice-monotone-extra)
+   (org-habit-ready-face voice-monotone-extra)))
 
 ;;}}}
 ;;{{{ Structure Navigation:
@@ -157,48 +155,62 @@
  do
  (eval
   `(defadvice ,f(after emacspeak pre act comp)
-     "Provide spoken feedback."
+     "Speak."
      (when (ems-interactive-p)
        (emacspeak-speak-line)
        (emacspeak-auditory-icon 'paragraph)))))
 
 (defadvice org-cycle-list-bullet (after emacspeak pre act comp)
-  "Provide spoken feedback."
+  "Speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'item)
     (emacspeak-speak-line)))
-;;; orgstruct-mode defines structured navigators that in turn call org-cycle.
-;;; Removing itneractive check in advice for org-cycle 
-;;; to speech enable all such nav commands.
-;;; Note that org itself produces the folded state via org-unlogged-message
-;;; Which gets spoken by Emacspeak
+
+(defcustom emacspeak-org-table-after-movement-function
+  #'emacspeak-org-table-speak-current-element
+  "The function to call after moving in a table"
+  :type
+  '(choice
+    (const :tag "speak cell contents only" emacspeak-org-table-speak-current-element)
+    (const :tag "speak column header" emacspeak-org-table-speak-column-header)
+    (const :tag "speak row header" emacspeak-org-table-speak-row-header)
+    (const :tag "speak cell contents and column header" emacspeak-org-table-speak-column-header-and-element)
+    (const :tag "speak cell contents and row header" emacspeak-org-table-speak-row-header-and-element)
+    (const :tag "speak column contents and both headers" emacspeak-org-table-speak-both-headers-and-element))
+  :group 'emacspeak-org)
+
+;; orgalist-mode defines structured navigators that in turn call org-cycle.
+;; Removing itneractive check in advice for org-cycle
+;; to speech enable all such nav commands.
+;; Note that org itself produces the folded state via org-unlogged-message
+;; Which gets spoken by Emacspeak
 (cl-loop
  for f in
  '(org-cycle org-shifttab)
  do
  (eval
   `(defadvice ,f(after emacspeak pre act comp)
-     "Provide auditory feedback."
+     "speak."
      (cond
       ((org-at-table-p 'any)
-       (emacspeak-org-table-speak-current-element))
+       (funcall emacspeak-org-table-after-movement-function))
       (t
-;;; org produces relevant feedback via org-unlogged-message (folded, children)
        (let ((dtk-stop-immediately nil))
-         (emacspeak-speak-line)))))))
+         (when (ems-interactive-p)
+           (emacspeak-speak-line))))))))
 
 (defadvice org-overview (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (message "Showing top-level overview.")))
 
 (defadvice org-content (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (message "Showing table of contents.")))
 
 (defadvice org-tree-to-indirect-buffer(after emacspeak pre act comp)
-  "Provide spoken feedback."
+  "Speak."
   (when (ems-interactive-p)
     (message "Cloned %s"
              (with-current-buffer org-last-indirect-buffer
@@ -223,7 +235,7 @@
  do
  (eval
   `(defadvice ,f(after emacspeak pre act comp)
-     "Provide spoken feedback."
+     "Speak."
      (when (ems-interactive-p)
        (emacspeak-speak-line)
        (emacspeak-auditory-icon 'open-object)))))
@@ -231,23 +243,24 @@
 ;;}}}
 ;;{{{ cut and paste:
 
-(cl-loop for f in
-         '(
-           org-cut-subtree org-copy-subtree
-           org-paste-subtree org-archive-subtree
-           org-narrow-to-subtree)
-         do
-         (eval
-          `(defadvice ,f(after emacspeak pre act comp)
-             "Provide spoken feedback."
-             (when (ems-interactive-p)
-               (emacspeak-speak-line)
-               (emacspeak-auditory-icon 'yank-object)))))
+(cl-loop
+ for f in
+ '(
+   org-cut-subtree org-copy-subtree
+   org-paste-subtree org-archive-subtree
+   org-narrow-to-subtree)
+ do
+ (eval
+  `(defadvice ,f(after emacspeak pre act comp)
+     "Speak."
+     (when (ems-interactive-p)
+       (emacspeak-speak-line)
+       (emacspeak-auditory-icon 'yank-object)))))
 
 ;;}}}
 ;;{{{ completion:
 
-(defadvice org-complete (around emacspeak pre act)
+(defadvice org-complete (around emacspeak pre act comp)
   "Say what you completed."
   (let ((prior (save-excursion (skip-syntax-backward "^ >") (point)))
         (dtk-stop-immediately t))
@@ -271,7 +284,7 @@
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
-     "Provide spoken feedback."
+     "Speak."
      (when (ems-interactive-p)
        (emacspeak-auditory-icon 'button)
        (emacspeak-speak-line)))))
@@ -288,7 +301,7 @@
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
-     "Provide auditory feedback."
+     "speak."
      (when (ems-interactive-p)
        (emacspeak-auditory-icon 'select-object)
        (emacspeak-speak-line)))))
@@ -298,7 +311,7 @@
          do
          (eval
           `(defadvice ,f (after emacspeak pre act comp)
-             "Provide auditory feedback."
+             "speak."
              (when (ems-interactive-p)
                (emacspeak-auditory-icon 'select-object)
                (dtk-speak org-last-changed-timestamp)))))
@@ -311,7 +324,7 @@
 ;;}}}
 ;;{{{ Agenda:
 
-;;; AGENDA NAVIGATION
+;; AGENDA NAVIGATION
 
 (cl-loop
  for f in
@@ -323,7 +336,7 @@
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
-     "Provide auditory feedback."
+     "speak."
      (when (ems-interactive-p)
        (emacspeak-auditory-icon 'select-object)
        (emacspeak-speak-line)))))
@@ -334,7 +347,7 @@
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
-     "Provide auditory feedback."
+     "speak."
      (when (ems-interactive-p)
        (emacspeak-auditory-icon 'close-object)
        (emacspeak-speak-mode-line)))))
@@ -345,13 +358,13 @@
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
-     "Provide auditory feedback."
+     "speak."
      (when (ems-interactive-p)
        (emacspeak-auditory-icon 'open-object)
        (emacspeak-speak-line)))))
 
 (defadvice org-agenda (after emacspeak pre act comp)
-  "Provide spoken feedback."
+  "Speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-line)))
@@ -363,50 +376,17 @@
 ;;{{{ table minor mode:
 
 (defadvice orgtbl-mode (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (cl-declare (special orgtbl-mode))
   (when (ems-interactive-p)
     (emacspeak-auditory-icon (if orgtbl-mode 'on 'off))
     (message "Turned %s org table mode."
              (if orgtbl-mode 'on 'off))))
 
-;;}}}
-;;{{{ Keymap update:
-
-(defun emacspeak-org-update-keys ()
-  "Update keys in org mode."
-  (cl-declare (special  org-mode-map))
-  (cl-loop for k in
-           '(
-             ("C-e" emacspeak-prefix-command)
-             ("C-j" org-insert-heading)
-             ("M-<down>" org-metadown)
-             ("M-<left>"  org-metaleft)
-             ("M-<right>" org-metaright)
-             ("M-<up>" org-metaup)
-             ("M-RET" org-meta-return)
-             ("M-S-<down>" org-shiftmetadown)
-             ("M-S-<left>" org-shiftmetaleft)
-             ("M-S-<right>" org-shiftmetaright)
-             ("M-S-<up>" org-shiftmetaup)
-             ("M-S-RET" org-insert-todo-heading)
-             ("S-RET" org-table-previous-row)
-             ("M-n" org-next-item)
-             ("M-p" org-previous-item)
-             ("S-<down>" org-shiftdown)
-             ("S-<left>" org-shiftleft)
-             ("S-<right>" org-shiftright)
-             ("S-<up>" org-shiftup)
-             ("S-TAB" org-shifttab))
-           do
-           (emacspeak-keymap-update  org-mode-map k)))
-
-(add-hook 'org-mode-hook #'emacspeak-org-update-keys)
-
 ;;}}}
 ;;{{{ deleting chars:
 
-(defadvice org-delete-backward-char (around emacspeak pre act)
+(defadvice org-delete-backward-char (around emacspeak pre act comp)
   "Speak character you're deleting."
   (cond
    ((ems-interactive-p)
@@ -416,7 +396,7 @@
    (t ad-do-it))
   ad-return-value)
 
-(defadvice org-delete-char (around emacspeak pre act)
+(defadvice org-delete-char (around emacspeak pre act comp)
   "Speak character you're deleting."
   (cond
    ((ems-interactive-p)
@@ -427,28 +407,67 @@
   ad-return-value)
 
 (defadvice org-return (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (cond
      ((org-at-table-p 'any)
-      (emacspeak-org-table-speak-current-element))
+      (funcall emacspeak-org-table-after-movement-function))
      (t
       (emacspeak-speak-line)
       (emacspeak-auditory-icon 'select-object)))))
 
+;;}}}
+;;{{{ Keymap update:
+
+(defun emacspeak-org-update-keys ()
+  "Update keys in org mode."
+  (cl-declare (special  org-mode-map))
+  (cl-loop
+   for k in
+   '(
+     ("C-e" emacspeak-prefix-command)
+     ("C-j" org-insert-heading)
+     ("M-<down>" org-metadown)
+     ("M-<left>"  org-metaleft)
+     ("M-<right>" org-metaright)
+     ("M-<up>" org-metaup)
+     ("M-RET" org-meta-return)
+     ("M-S-<down>" org-shiftmetadown)
+     ("M-S-<left>" org-shiftmetaleft)
+     ("M-S-<right>" org-shiftmetaright)
+     ("M-S-<up>" org-shiftmetaup)
+     ("M-S-RET" org-insert-todo-heading)
+     ("S-RET" org-table-previous-row)
+     ("M-n" org-next-item)
+     ("M-p" org-previous-item)
+     ("S-<down>" org-shiftdown)
+     ("S-<left>" org-shiftleft)
+     ("S-<right>" org-shiftright)
+     ("S-<up>" org-shiftup)
+     ("S-TAB" org-shifttab))
+   do
+   (emacspeak-keymap-update  org-mode-map k)))
+
 ;;}}}
 ;;{{{ mode hook:
 
 (defun emacspeak-org-mode-setup ()
   "Placed on org-mode-hook to do Emacspeak setup."
-  (cl-declare (special org-mode-map))
+  (cl-declare (special org-mode-map
+                       org-link-parameters))
+  (emacspeak-org-update-keys)
+  (define-key org-mode-map (ems-kbd "C-o e") 'tvr-org-enumerate)
+  (define-key org-mode-map (ems-kbd "C-o i") 'tvr-org-itemize)
+  (define-key outline-minor-mode-map (ems-kbd "C-o i") 'tvr-org-itemize)
+  (define-key outline-minor-mode-map (ems-kbd "C-o e") 'tvr-org-enumerate)
   (when (fboundp 'org-end-of-line)
     (define-key org-mode-map emacspeak-prefix  'emacspeak-prefix-command)
-    (emacspeak-setup-programming-mode)))
+    (emacspeak-setup-programming-mode)
+    (when dtk-caps (dtk-toggle-caps))))
 
 (add-hook 'org-mode-hook #'emacspeak-org-mode-setup)
-(add-hook 'orgstruct-mode-hook #'emacspeak-org-mode-setup)
-;;; advice end-of-line here to call org specific action
+
+;; advice end-of-line here to call org specific action
 (defadvice end-of-line (after emacspeak-org pre act comp)
   "Call org specific actions in org mode."
   (when (and (ems-interactive-p)
@@ -457,7 +476,7 @@
     (org-end-of-line)))
 
 (defadvice org-toggle-checkbox (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'button)
     (emacspeak-speak-line)))
@@ -468,60 +487,45 @@
 (cl-loop
  for f in
  '(
-   org-occur
-   org-beginning-of-line org-end-of-line
+   org-occur org-beginning-of-line org-end-of-line
    org-beginning-of-item org-beginning-of-item-list)
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
-     "Provide auditory feedback."
+     "speak."
      (when (ems-interactive-p) (emacspeak-speak-line)
            (emacspeak-auditory-icon 'select-object)))))
 
 ;;}}}
 ;;{{{ global input wizard
 
-;;;###autoload
 (defun emacspeak-org-popup-input ()
   "Pops up an org input area."
   (interactive)
-  (emacspeak-wizards-popup-input-buffer 'org-mode))
+  (emacspeak-org-popup-input-buffer 'org-mode))
 
 ;;}}}
 ;;{{{ org capture
 
-(defcustom emacspeak-org-bookmark-key "h"
-  "Key of template used for capturing  hot list."
-  :type 'string
-  :group 'emacspeak-org)
-
-;;;###autoload
-(defun emacspeak-org-bookmark (&optional goto)
-  "Bookmark from org."
-  (interactive "P")
-  (cl-declare (special emacspeak-org-bookmark-key))
-  (org-capture goto emacspeak-org-bookmark-key))
-
 (defadvice org-capture-goto-last-stored (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line)))
 
 (defadvice org-capture-goto-target (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (emacspeak-auditory-icon 'large-movement)
   (emacspeak-speak-line))
 
 (defadvice org-capture-finalize (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (emacspeak-auditory-icon 'save-object))
 
 (defadvice org-capture-kill (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (emacspeak-auditory-icon 'close-object))
 
-;;;###autoload
 (defun emacspeak-org-table-speak-current-element ()
   "echoes current table element"
   (interactive)
@@ -530,21 +534,18 @@
      ((string-match "^ *$" field) (dtk-speak "space"))
      (t (dtk-speak-and-echo field)))))
 
-;;;###autoload
 (defun emacspeak-org-table-speak-column-header ()
   "echoes column header"
   (interactive)
   (dtk-speak-and-echo
    (propertize (org-table-get 1 nil) 'face 'bold)))
 
-;;;###autoload
 (defun emacspeak-org-table-speak-row-header ()
   "echoes row header"
   (interactive)
   (dtk-speak-and-echo
    (propertize (org-table-get nil 1) 'face 'italic)))
 
-;;;###autoload
 (defun emacspeak-org-table-speak-coordinates ()
   "echoes coordinates"
   (interactive)
@@ -552,7 +553,6 @@
    (concat "row " (number-to-string (org-table-current-line))
            ", column " (number-to-string (org-table-current-column)))))
 
-;;;###autoload
 (defun emacspeak-org-table-speak-both-headers-and-element ()
   "echoes both row and col headers."
   (interactive)
@@ -563,7 +563,6 @@
     (propertize (org-table-get  1 nil) 'face 'bold) " "
     (org-table-get-field))))
 
-;;;###autoload
 (defun emacspeak-org-table-speak-row-header-and-element ()
   "echoes row header and element"
   (interactive)
@@ -573,7 +572,6 @@
     " "
     (org-table-get-field))))
 
-;;;###autoload
 (defun emacspeak-org-table-speak-column-header-and-element ()
   "echoes col header and element"
   (interactive)
@@ -590,13 +588,12 @@
  do
  (eval
   `(defadvice ,f  (after emacspeak pre act comp)
-     "Provide auditory feedback."
-     (emacspeak-org-table-speak-current-element))))
+     "speak."
+     (funcall emacspeak-org-table-after-movement-function))))
 
 ;;}}}
 ;;{{{ Additional table function:
 
- ;;;###autoload
 (unless (fboundp 'org-table-previous-row)
   (defun org-table-previous-row ()
     "Go to the previous row (same column) in the current table.
@@ -619,31 +616,25 @@ Before doing so, re-align the table if necessary."
         (if (looking-at " ") (forward-char 1))))))
 
 ;;}}}
-;;{{{ EWW Integration:
+;;{{{ Capture
 ;;;###autoload
-(defun emacspeak-org-capture-link ()
+(defun emacspeak-org-capture-link (&optional open)
   "Capture hyperlink to current context.
-To use this command, first  do `customize-variable' `org-capture-template'
-and assign  letter `h' to a template that creates the hyperlink on capture."
-  (interactive)
-  (org-store-link nil)
-  (org-capture nil "h"))
-(defun org-eww-store-link ()
-  "Store a link to a EWW buffer."
-  (when (eq major-mode 'eww-mode)
-    (org-store-link-props
-     :type "eww"
-     :link   (emacspeak-eww-current-url)
-     :url (eww-current-url)
-     :description (emacspeak-eww-current-title))))
+To use this command, first do `customize-variable'
+`org-capture-template' and assign letter `h' to a template that
+creates the hyperlink on capture.  Optional interactive prefix
+arg just opens the file"
+  (interactive "P")
+  (require 'org)
+  (require 'ol-eww)
+  (cond
+   (open
+    (funcall-interactively #'find-file (expand-file-name "~/.org/hotlist.org")))
+   (t
+    (org-store-link nil)
+    (org-capture nil "h"))))
 
-(unless (functionp 'org-store-link-functions)
-;;; org-mode 8.x and earlier:
-  (add-hook
-   'org-load-hook
-   #'(lambda nil
-       (cl-declare (special org-store-link-functions))
-       (push #'org-eww-store-link org-store-link-functions))))
+(declare-function emacspeak-eww-current-title "emacspeak-eww" nil)
 
 ;;}}}
 ;;{{{ Speech-enable export prompt:
@@ -651,15 +642,15 @@ and assign  letter `h' to a template that creates the hyperlink on capture."
   "Speak prompt intelligently."
   (let ((prompt (ad-get-arg 0))
         (entries (ad-get-arg 2))
-        (first-key (ad-get-arg 4)) 
+        (first-key (ad-get-arg 4))
         (choices nil))
     (setq choices
           (cond
            ((null first-key) entries)
            (t                           ;third  is cl-caddr
             (cl-caddr (assoc first-key entries)))))
-    (dtk-notify-speak 
-     (mapconcat 
+    (dtk-notify-speak
+     (mapconcat
       #'(lambda (e)
           (format "%c: %s\n" (cl-first e) (cl-second e)))
       choices "\n"))
@@ -670,40 +661,106 @@ and assign  letter `h' to a template that creates the hyperlink on capture."
 
 (defun emacspeak-org-eww-file (file _link)
   "Preview HTML files with EWW from exporter."
+  (add-hook 'emacspeak-eww-post-process-hook  #'emacspeak-speak-buffer)
   (funcall-interactively #'eww-open-file file))
 
 ;;}}}
 ;;{{{ Edit Special Advice:
 
 (cl-loop
- for f in 
+ for f in
  '(org-edit-src-exit org-edit-src-abort)
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
-     "Provide auditory feedback."
+     "speak."
      (when (ems-interactive-p)
        (emacspeak-auditory-icon 'close-object)
        (emacspeak-speak-line)))))
 
 (cl-loop
  for f in
- '(org-edit-src-code org-edit-special) do
+ '(org-edit-src-code org-edit-special org-switchb) do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
-     "Provide auditory feedback."
+     "speak."
      (when (ems-interactive-p)
        (emacspeak-auditory-icon 'open-object)
        (emacspeak-speak-mode-line)))))
 
 ;;}}}
+;;{{{ Fillers:
 
+(defadvice org-fill-paragraph (after emacspeak pre act comp)
+  "speak."
+  (when (ems-interactive-p)
+    (emacspeak-auditory-icon 'fill-object)
+    (message "Filled current paragraph")))
+
+(defadvice org-todo (after emacspeak pre act comp)
+  "speak when changing the state of a TODO item."
+  (when (ems-interactive-p)
+    (emacspeak-auditory-icon 'button)
+    (let ((state (org-get-todo-state)))
+      (if (null state)
+          (message "State unset")
+        (message state)))))
+
+;;}}}
+;;{{{TVR: Conveniences
+
+(defun tvr-org-itemize ()
+  "Start a numbered  list."
+  (interactive)
+  (forward-line 0)
+  (insert "  -  ")
+  (emacspeak-speak-line)
+  (emacspeak-auditory-icon 'item))
+
+(defun tvr-org-enumerate ()
+  "Start a numbered  list."
+  (interactive)
+  (forward-line 0)
+  (insert "  1.  ")
+  (emacspeak-speak-line)
+  (emacspeak-auditory-icon 'item))
+
+;;}}}
+;;{{{ specialized input buffers:
+
+;; Taken from a message on the org mailing list.
+
+(defun emacspeak-org-popup-input-buffer (mode)
+  "Provide an input buffer in a specified mode."
+  (interactive
+   (list
+    (intern
+     (completing-read
+      "Mode: "
+      (mapcar
+       #'(lambda (e)
+           (list (symbol-name e)))
+       (apropos-internal "-mode$" 'commandp))
+      nil t))))
+  (let ((buffer-name (generate-new-buffer-name "*input*")))
+    (pop-to-buffer (make-indirect-buffer (current-buffer) buffer-name))
+    (narrow-to-region (point) (point))
+    (funcall mode)
+    (let ((map (copy-keymap (current-local-map))))
+      (define-key map (ems-kbd "C-c C-c")
+                  #'(lambda ()
+                      (interactive)
+                      (kill-buffer nil)
+                      (delete-window)))
+      (use-local-map map))
+    (shrink-window-if-larger-than-buffer)))
+
+;;}}}
 (provide 'emacspeak-org)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
