@@ -1,49 +1,49 @@
 ;;; emacspeak-package.el --- Speech-enable PACKAGE  -*- lexical-binding: t; -*-
-;;; $Id: emacspeak-package.el 4797 2007-07-16 23:31:22Z tv.raman.tv $
-;;; $Author: tv.raman.tv $
-;;; Description:  Speech-enable PACKAGE An Emacs Interface to package
-;;; Keywords: Emacspeak,  Audio Desktop package
+;; $Id: emacspeak-package.el 4797 2007-07-16 23:31:22Z tv.raman.tv $
+;; $Author: tv.raman.tv $
+;; Description:  Speech-enable PACKAGE An Emacs Interface to package
+;; Keywords: Emacspeak,  Audio Desktop package
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
-;;;  $Revision: 4532 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman
-;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNPACKAGE FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNPACKAGE FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  introduction
 
 ;;; Commentary:
-;;; PACKAGE == package.el
-;;; Manage Emacs packages.
-;;; This module speech-enables package.el with a few convenience commands.
+;; PACKAGE == package.el
+;; Manage Emacs packages.
+;; This module speech-enables package.el with a few convenience commands.
 
 ;;}}}
 ;;{{{  Required modules
@@ -51,7 +51,6 @@
 (require 'cl-lib)
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
-(eval-when-compile (require 'package "package" 'no-error))
 (require 'calendar)
 ;;}}}
 ;;{{{ Map Faces:
@@ -60,18 +59,18 @@
  '(
    (package-help-section-name voice-lighten)
    (package-name voice-bolden)
-   (package-description voice-monotone)
+   (package-description voice-lighten)
    (package-status-built-in voice-monotone-medium)
    (package-status-external voice-animate)
    (package-status-available voice-annotate)
    (package-status-new voice-brighten)
-   (package-status-held voice-monotone)
+   (package-status-held voice-monotone-extra)
    (package-status-disabled voice-smoothen)
    (package-status-installed voice-lighten-extra)
    (package-status-dependency voice-monotone-medium)
    (package-status-unsigned voice-animate-extra)
    (package-status-incompat voice-animate-extra)
-   (package-status-avail-obso voice-monotone)
+   (package-status-avail-obso voice-monotone-extra)
    ))
 ;;}}}
 ;;{{{ Additional Commands
@@ -102,23 +101,25 @@
 (defun emacspeak-package-next-line ()
   "Move to next line and speak it."
   (interactive)
-  (next-line)
+  (forward-line 1)
   (emacspeak-package-summarize-line))
 
 (defun emacspeak-package-previous-line ()
   "Move to next line and speak it."
   (interactive)
-  (previous-line)
+  (forward-line -1)
   (emacspeak-package-summarize-line))
 
 (defun emacspeak-package-mode-hook ()
   "Emacspeak setup hook for package-mode."
+  (define-key package-menu-mode-map (ems-kbd "<left>") 'emacspeak-speak-previous-field)
+  (define-key package-menu-mode-map (ems-kbd "<right>") 'emacspeak-speak-next-field)
   (define-key package-menu-mode-map " " 'emacspeak-package-summarize-line)
   (define-key package-menu-mode-map "n" 'emacspeak-package-next-line)
   (define-key package-menu-mode-map "p" 'emacspeak-package-previous-line)
   (emacspeak-pronounce-add-buffer-local-dictionary-entry
    emacspeak-pronounce-date-yyyymmdd-pattern
-   (cons 're-search-forward 'emacspeak-pronounce-yyyymmdd-date)))
+   (cons #'re-search-forward 'emacspeak-pronounce-yyyymmdd-date)))
 
 (add-hook 'package-menu-mode-hook 'emacspeak-package-mode-hook)
 
@@ -144,18 +145,27 @@
  do
  (eval
   `(defadvice ,f (after emacspeak pre act com)
-     "Provide auditory feedback."
+     "speak."
      (when (ems-interactive-p)
        (emacspeak-speak-line)
        (emacspeak-auditory-icon 'mark-object)))))
 
+;;}}}
+;;{{{ Advice Upgrade:
+
+(defadvice package-menu-mark-upgrades (after emacspeak pre act comp)
+  "Speak list of packages we marked for upgrading."
+  (when (ems-interactive-p)
+    (let ((upgrades (package-menu--find-upgrades)))
+      (when upgrades
+        (dtk-notify-speak (format "%s" (mapcar #'car upgrades)))))))
+
 ;;}}}
 (provide 'emacspeak-package)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
