@@ -1,79 +1,80 @@
 ;;; emacspeak-pianobar.el --- Pandora Radio: Speech-enable PIANOBAR  -*- lexical-binding: t; -*-
-;;; $Id: emacspeak-pianobar.el 4797 2007-07-16 23:31:22Z tv.raman.tv $
-;;; $Author: tv.raman.tv $
-;;; Description:  Speech-enable PIANOBAR An Emacs Interface to pianobar
-;;; Keywords: Emacspeak,  Audio Desktop pianobar
+;; $Id: emacspeak-pianobar.el 4797 2007-07-16 23:31:22Z tv.raman.tv $
+;; $Author: tv.raman.tv $
+;; Description:  Speech-enable PIANOBAR An Emacs Interface to pianobar
+;; Keywords: Emacspeak,  Audio Desktop pianobar
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
-;;;  $Revision: 4532 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman
-;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNPIANOBAR FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNPIANOBAR FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  introduction
 
 ;;; Commentary:
 
-;;; @subsection PIANOBAR ==  Pandora Client for Emacs
+;; @subsection PIANOBAR ==  Pandora Client for Emacs
 
-;;; pianobar git://github.com/PromyLOPh/pianobar.git Ubuntu/Debian:
-;;; sudo apt-get install pianobar 
+;; pianobar git://github.com/PromyLOPh/pianobar.git Ubuntu/Debian:
+;; sudo apt-get install pianobar 
 
-;;; Pianobar Is a stand-alone client for Pandora Radio. pianobar.el
-;;; available on the Emacs Wiki at
-;;; http://www.emacswiki.org/emacs/pianobar.el Provides access to
-;;; Pandora Radio via pianobar from the comfort of Emacs. This module
-;;; speech-enables Pianobar and enhances it for the Complete Audio
-;;; Desktop.
+;; Pianobar Is a stand-alone client for Pandora Radio. pianobar.el
+;; available on the Emacs Wiki at
+;; http://www.emacswiki.org/emacs/pianobar.el Provides access to
+;; Pandora Radio via pianobar from the comfort of Emacs. This module
+;; speech-enables Pianobar and enhances it for the Complete Audio
+;; Desktop.
 
-;;; @subsection Emacspeak Usage:
+;; @subsection Emacspeak Usage:
 
-;;; Emacspeak implements command emacspeak-pianobar, a light-weight
-;;; wrapper on top of pianobar. Emacspeak binds this command to
-;;; @code{C-e '}. In my personal @code{.emacs}, I bind this to
-;;; @code{f5}. Command emacspeak-pianobar is designed to let you
-;;; launch Pandora channels and switch tracks/channels without moving
-;;; away from your primary tasks such as editting code or
-;;; reading/composing email. Toward this end, launching command
-;;; emacspeak-pianobar the first time initializes the
-;;; @code{*pianobar*} buffer and launches command @code{pianobar};
-;;; Focus is placed in the @code{*pianobar*} buffer. Pianobar can be
-;;; controlled with single keystrokes while in this buffer. The most
-;;; useful keys are @code{right} for skipping tracks, @code{up} and
-;;; @code{down} for switching channels etc.; see the keys bound in
-;;; @code{pianobar-key-map} for a complete list. Pressing @code{C-e '}
-;;; in  the @code{*pianobar*} buffer  buries the
-;;; @code{*pianobar*}. From here on, Pianobar can be controlled
-;;; by pressing the Pianobar prefix key (@code{C-e '}) followed by
-;;; keys from @code{pianobar-key-map}.
+;; Emacspeak implements command emacspeak-pianobar, a light-weight
+;; wrapper on top of pianobar. Emacspeak binds this command to
+;; @code{C-e '}. 
+;;  Command emacspeak-pianobar is designed to let you
+;; launch Pandora channels and switch tracks/channels without moving
+;; away from your primary tasks such as editing code or
+;; reading/composing email. Toward this end, launching command
+;; emacspeak-pianobar the first time initializes the
+;; @code{*pianobar*} buffer and launches command @code{pianobar};
+;; but focus  remains   in your current buffer. Pianobar can be
+;; controlled with single keystrokes while in  the pianobar  buffer
+;; --- switch to   using @code{C-e ''}. The most
+;; useful keys are @code{right} for skipping tracks, @code{up} and
+;; @code{down} for switching channels etc.; see the keys bound in
+;; @code{pianobar-key-map} for a complete list. Pressing @code{C-e '}
+;; in  the @code{*pianobar*} buffer  buries the
+;; @code{*pianobar*}. From here on, Pianobar can be controlled
+;; by pressing the Pianobar prefix key (@code{C-e '}) followed by
+;; keys from @code{pianobar-key-map}.
 
 ;;; Code:
 
@@ -83,8 +84,9 @@
 (require 'cl-lib)
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
-(require 'ansi-color)
 
+(require 'ansi-color)
+(require 'emacspeak-comint)
 ;;}}}
 ;;{{{ Pianobar Fixups:
 
@@ -101,8 +103,9 @@
 
 ;;}}}
 ;;{{{ Advice Interactive Commands:
-(declare-function pianobar "Launch pianobar.")
-(declare-function pianobar-send-string  "Send command to pianobar." (cmd))
+
+(declare-function pianobar "ext:pianobar" nil)
+(declare-function pianobar-send-string  "ext:pianobar" (cmd))
 (defun emacspeak-pianobar-volume-down ()
   "Decrease volume"
   (interactive)
@@ -113,16 +116,20 @@
   (interactive)
   (pianobar-send-string ")\n"))
 (defadvice pianobar (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (with-current-buffer pianobar-buffer
-    (define-key pianobar-key-map "t" 'emacspeak-pianobar-electric-mode-toggle)
+    (define-key pianobar-key-map "l"
+                'pianobar-love-current-song)
+    (define-key pianobar-key-map "t"
+                'emacspeak-pianobar-electric-mode-toggle)
+    (define-key pianobar-key-map (ems-kbd "RET") 'emacspeak-pianobar-send-raw)
     (define-key pianobar-key-map [right] 'pianobar-next-song)
     (dotimes (i 10)
       (define-key pianobar-key-map    (format "%s" i)   'emacspeak-pianobar-switch-to-preset))
     (dotimes (i 25)
       (define-key pianobar-key-map
-        (format "%c" (+ i 65))
-        'emacspeak-pianobar-switch-to-preset))
+                  (format "%c" (+ i 65))
+                  'emacspeak-pianobar-switch-to-preset))
     (define-key  pianobar-key-map [up] 'emacspeak-pianobar-previous-preset)
     (define-key  pianobar-key-map [down] 'emacspeak-pianobar-next-preset)
     (define-key  pianobar-key-map "," 'emacspeak-pianobar-previous-preset)
@@ -130,37 +137,40 @@
     (define-key  pianobar-key-map "<" 'emacspeak-pianobar-previous-preset)
     (define-key  pianobar-key-map">" 'emacspeak-pianobar-next-preset)
     (define-key pianobar-key-map "("
-      'emacspeak-pianobar-volume-down)
+                'emacspeak-pianobar-volume-down)
     (define-key pianobar-key-map [prior] 'emacspeak-pianobar-volume-down)
     (define-key pianobar-key-map ")" 'emacspeak-pianobar-volume-up)
     (define-key pianobar-key-map [next] 'emacspeak-pianobar-volume-up)
     (use-local-map pianobar-key-map)
     (emacspeak-speak-mode-line)
+    (bury-buffer)
     (emacspeak-auditory-icon 'open-object)))
 
-;;; Advice all actions to play a pre-auditory icon
+;; Advice all actions to play a pre-auditory icon
+
+(cl-loop
+ for  f in
+ '(pianobar-pause-song pianobar-love-current-song
+                       pianobar-ban-current-song pianobar-bookmark-song
+                       pianobar-create-station pianobar-delete-current-station
+                       pianobar-explain-song
+                       pianobar-add-shared-station pianobar-song-history
+                       pianobar-currently-playing pianobar-add-shared-station
+                       pianobar-move-song-different-station pianobar-next-song
+                       pianobar-rename-current-station
+                       pianobar-change-station
+                       pianobar-tired-of-song
+                       pianobar-upcoming-songs
+                       pianobar-select-quickmix-stations pianobar-next-song)
+ do
+ (eval
+  `(defadvice ,f (before emacspeak pre act comp)
+     "Play auditory icon."
+     (when (ems-interactive-p)
+       (emacspeak-auditory-icon 'item)))))
 
-(cl-loop for  f in
-         '(pianobar-pause-song pianobar-love-current-song
-                               pianobar-ban-current-song pianobar-bookmark-song
-                               pianobar-create-station pianobar-delete-current-station
-                               pianobar-explain-song
-                               pianobar-add-shared-station pianobar-song-history
-                               pianobar-currently-playing pianobar-add-shared-station
-                               pianobar-move-song-different-station pianobar-next-song
-                               pianobar-rename-current-station
-                               pianobar-change-station
-                               pianobar-tired-of-song
-                               pianobar-upcoming-songs
-                               pianobar-select-quickmix-stations pianobar-next-song)
-         do
-         (eval
-          `(defadvice ,f (before emacspeak pre act comp)
-             "Play auditory icon."
-             (when (ems-interactive-p)
-               (emacspeak-auditory-icon 'select-object)))))
 (defadvice pianobar-window-toggle (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (let ((state (get-buffer-window pianobar-buffer)))
       (cond
@@ -172,27 +182,22 @@
         (dtk-speak "Hid Pianobar "))))))
 
 (defadvice pianobar-quit (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)))
 
-;;}}}
-;;; Simplified Pianobar Interaction
-
-;;{{{ Customizations And Variables
-
 ;;}}}
 ;;{{{ emacspeak-pianobar
+
 (defvar emacspeak-pianobar-electric-mode t
   "Records if electric mode is on.")
 
-;;;###autoload
 (defun emacspeak-pianobar-electric-mode-toggle ()
   "Toggle electric mode in pianobar buffer.
 If electric mode is on, keystrokes invoke pianobar commands directly."
   (interactive)
   (cl-declare (special emacspeak-pianobar-electric-mode
-                    pianobar-key-map pianobar-buffer))
+                       pianobar-key-map pianobar-buffer))
   (with-current-buffer pianobar-buffer
     (cond
      (emacspeak-pianobar-electric-mode  ; turn it off
@@ -210,7 +215,7 @@ If electric mode is on, keystrokes invoke pianobar commands directly."
 (defun emacspeak-pianobar  ()
   "Start or control Emacspeak Pianobar player."
   (interactive)
-  (cl-declare (special pianobar-buffer))
+  (cl-declare (special pianobar-buffer emacspeak-comint-autospeak))
   (condition-case nil
       (unless (featurep 'pianobar) (require 'pianobar))
     (error "Pianobar not installed."))
@@ -219,7 +224,10 @@ If electric mode is on, keystrokes invoke pianobar commands directly."
           (processp (get-buffer-process pianobar-buffer))
           (eq 'run (process-status (get-buffer-process  pianobar-buffer))))
     (call-interactively 'emacspeak-pianobar-command))
-   (t (pianobar))))
+   (t
+    (pianobar)
+    (with-current-buffer (get-buffer pianobar-buffer)
+      (when emacspeak-comint-autospeak (emacspeak-toggle-comint-autospeak))))))
 
 (defun emacspeak-pianobar-hide-or-show ()
   "Hide or show pianobar."
@@ -231,7 +239,7 @@ If electric mode is on, keystrokes invoke pianobar commands directly."
     (bury-buffer pianobar-buffer)
     (delete-windows-on pianobar-buffer)
     (emacspeak-auditory-icon 'close-object))
-   (t (switch-to-buffer pianobar-buffer)
+   (t (pop-to-buffer pianobar-buffer)
       (emacspeak-auditory-icon 'open-object))))
 
 (defun emacspeak-pianobar-command (key)
@@ -247,16 +255,13 @@ If electric mode is on, keystrokes invoke pianobar commands directly."
     (call-interactively (lookup-key pianobar-key-map key)))
    (t (pianobar-send-string  key))))
 
-;;;###autoload
-(defcustom emacspeak-pianobar-max-preset 10
-  "Number of presets."
-  :type 'number
-  :group 'emacspeak-pianobar)
+(defvar emacspeak-pianobar-max-preset 28
+  "Number of presets.")
 
 (defvar emacspeak-pianobar-current-preset 0
   "Current preset.")
 
-;;; Station Presets
+;; Station Presets
 (defun emacspeak-pianobar-switch-to-preset ()
   "Switch to one of the  presets."
   (interactive)
@@ -289,16 +294,20 @@ If electric mode is on, keystrokes invoke pianobar commands directly."
   (setq emacspeak-pianobar-current-preset (1- emacspeak-pianobar-current-preset))
   (pianobar-send-string (format "s%s\n" emacspeak-pianobar-current-preset)))
 
+(defun emacspeak-pianobar-send-raw  (string)
+  "Send raw string with newline added to pianobar."
+  (interactive "sString:")
+  (pianobar-send-string (format "%s\n" string)))
+
 ;;}}}
 
 (provide 'emacspeak-pianobar)
-;;; reload pianobar to fix our vol-change commands.
-(load-library "pianobar")
+;; reload pianobar to fix our vol-change commands.
+(load "pianobar")
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
