@@ -1,91 +1,72 @@
-;;; emacspeak-pronounce.el --- Implements Emacspeak pronunciation dictionaries  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $
-;;; Description: Emacspeak pronunciation dictionaries
-;;; Keywords:emacspeak, audio interface to emacs customized pronunciation
+;;; emacspeak-pronounce.el --- Emacspeak pronunciation dictionaries -*- lexical-binding: t; -*-
+;;
+;; $Author: tv.raman.tv $
+;; Description: Emacspeak pronunciation dictionaries
+;; Keywords:emacspeak, audio interface to emacs customized pronunciation
 ;;{{{ LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2008-02-19 16:55:48 -0800 (Tue, 19 Feb 2008) $ |
-;;; $Revision: 4532 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;; $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{ Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman
-;;; Copyright (c) 1995 by T. V. Raman
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING. If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; Copyright (c) 1995 by T. V. Raman
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING. If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
 
-
-;;; Commentary:
 ;;{{{ Introduction
 
-;;;This module implements user customizable pronunciation dictionaries
-;;;for emacspeak. Custom pronunciations can be defined per file, per
-;;;directory and/or per major mode. Emacspeak maintains a persistent
-;;;user dictionary upon request and loads these in new emacspeak
-;;;sessions. This module implements the user interface to the custom
-;;;dictionary as well as providing the internal API used by the rest
-;;;of emacspeak in using the dictionary.
-;;;Algorithm:
+;;; Commentary:
+;; This module implements user customizable pronunciation dictionaries
+;; for emacspeak. Custom pronunciations can be defined per file, per
+;; directory and/or per major mode. Emacspeak maintains a persistent
+;; user dictionary upon request and loads these in new emacspeak
+;; sessions. This module implements the user interface to the custom
+;; dictionary as well as providing the internal API used by the rest
+;; of emacspeak in using the dictionary.
+;; @subsection Algorithm:
 
-;;;The persistent dictionary is a hash table where the hash keys are
-;;;filenames, directory names, or major-mode names. The hash values
-;;;are association lists defining the dictionary. Users of this module
-;;;can retrieve a dictionary made up of all applicable association
-;;;lists for a given file.
+;; The persistent dictionary is a hash table where the hash keys are
+;; filenames, directory names, or major-mode names. The hash values
+;; are association lists defining the dictionary. Users of this module
+;; can retrieve a dictionary made up of all applicable association
+;; lists for a given file.
+;;; Code:
 
 ;;}}}
-;;
-;;; Code:
-;;{{{ required packages
+;;{{{ required Modules:
 
 (require 'cl-lib)
+(require 'emacspeak-sounds)
 (cl-declaim  (optimize  (safety 0) (speed 3)))
-(require 'custom)
-(eval-when-compile (require 'calendar))
-
-(require 'voice-setup)
-(require 'thingatpt)
-(cl-eval-when (compile)
-                                        ;avoid recursive include during compile
-           (provide 'emacspeak-pronounce)
-           (require 'dtk-speak)
-           (require 'emacspeak-sounds))
-
-;;}}}
-;;{{{ customizations
-
-(defgroup emacspeak-pronounce nil
-  "Pronunciation dictionaries."
-  :group 'emacspeak)
-
 ;;}}}
 ;;{{{ Dictionary structure:
 
-(defvar emacspeak-pronounce-dictionaries (make-hash-table)
-  "Hash table holding emacspeak's persistent pronunciation dictionaries.
+(defvar emacspeak-pronounce-dictionaries (make-hash-table :test #'eq)
+  "Hash table  for   pronunciation dictionaries.
 Keys are either filenames, directory names, or major mode names.
 Values are alists containing string.pronunciation pairs.")
 
@@ -96,18 +77,17 @@ Values are alists containing string.pronunciation pairs.")
   (setf (gethash key emacspeak-pronounce-dictionaries) pr-alist))
 
 (defun emacspeak-pronounce-get-dictionary (key)
-  (cl-declare (special emacspeak-pronounce-dictionaries
-                    minibuffer-history))
-  (when (stringp key)
-    (setq key (intern key)))
+  (cl-declare (special emacspeak-pronounce-dictionaries))
+  (when (stringp key) (setq key (intern key)))
   (gethash key emacspeak-pronounce-dictionaries))
 
-;;;###autoload
 (defun emacspeak-pronounce-add-dictionary-entry (key string pronunciation)
-  "Add dictionary entry.
-This adds pronunciation pair
-STRING.PRONUNCIATION to the dictionary.
-Argument KEY specifies a dictionary key e.g. directory, mode etc."
+  " Adds pronunciation pair STRING.PRONUNCIATION to the dictionary.
+Argument KEY specifies a dictionary key e.g. directory, mode etc.
+Pronunciation can be a string or a cons-pair.
+If it is a string, that string is the new pronunciation.
+A cons-pair of the form (matcher . func) results  in 
+the match  being passed to the func which returns  the new pronunciation."
   (cl-declare (special emacspeak-pronounce-dictionaries))
   (let* ((dict (emacspeak-pronounce-get-dictionary key))
          (entry (and dict (assoc string dict))))
@@ -118,19 +98,18 @@ Argument KEY specifies a dictionary key e.g. directory, mode etc."
       (setf dict (cons (cons string pronunciation) dict))
       (emacspeak-pronounce-set-dictionary key dict))
      (t
-      (emacspeak-pronounce-set-dictionary key
-                                          (list (cons string pronunciation)))))))
+      (emacspeak-pronounce-set-dictionary
+       key
+       (list (cons string pronunciation)))))))
 
 (defun emacspeak-pronounce-remove-buffer-local-dictionary-entry (string)
-  "Remove pronunciation entry."
+  "Remove buffer-specificpronunciation."
   (when (and (boundp 'emacspeak-pronounce-pronunciation-table)
              emacspeak-pronounce-pronunciation-table)
-    (remhash string
-             emacspeak-pronounce-pronunciation-table)))
+    (remhash string emacspeak-pronounce-pronunciation-table)))
 
 (defun emacspeak-pronounce-add-buffer-local-dictionary-entry (string pronunciation)
-  "Add specified pronunciation for current buffer.
-Arguments STRING and PRONUNCIATION specify what is being defined."
+  "Add  pronunciation for current buffer. "
   (cl-declare (special emacspeak-pronounce-pronunciation-table))
   (cond
    ((not (boundp 'emacspeak-pronounce-pronunciation-table)) ;first time
@@ -151,10 +130,10 @@ Arguments STRING and PRONUNCIATION specify what is being defined."
 ;;}}}
 ;;{{{ setting up inheritance relations
 
-;;; child inherits parents dictionary
-;;; parent stored as a property on child symbol.
-;;; when dictionary composed for a buffer, inherited dictionaries are
-;;; also looked up.
+;; child inherits parents dictionary
+;; parent stored as a property on child symbol.
+;; when dictionary composed for a buffer, inherited dictionaries are
+;; also looked up.
 (defun emacspeak-pronounce-add-super (parent child)
   "Make CHILD inherit PARENT's pronunciations."
   (let ((orig (get child 'emacspeak-pronounce-supers)))
@@ -173,9 +152,7 @@ Arguments STRING and PRONUNCIATION specify what is being defined."
     orig))
 
 (defun emacspeak-pronounce-compose-pronunciation-table (&optional buffer)
-  "Composes a pronunciation table for BUFFER. The default is current
-buffer. Handles inheritance of pronunciation dictionaries between
-modes."
+  "Compose  pronunciation table for BUFFER. "
   (setq buffer (or buffer (current-buffer)))
   (let* ((table (make-hash-table :test #'equal))
          (filename (buffer-file-name buffer))
@@ -209,75 +186,77 @@ modes."
 ;;}}}
 ;;{{{ defining some inheritance relations:
 
-;;; gnus server mode inherits from gnus group mode
+;; gnus server mode inherits from gnus group mode
 
 (emacspeak-pronounce-add-super 'gnus-group-mode
                                'gnus-server-mode)
 
-;;; c++ mode inherits from C mode
+;; c++ mode inherits from C mode
 (emacspeak-pronounce-add-super 'c-mode 'c++-mode)
-;;; shell inherits from comint:
+;; shell inherits from comint:
 (emacspeak-pronounce-add-super 'comint-mode 'shell-mode)
-;;; latex-mode and latex2e-mode inherit from plain-tex-mode
+;; latex-mode and latex2e-mode inherit from plain-tex-mode
 
 (emacspeak-pronounce-add-super 'plain-tex-mode 'latex-mode)
 (emacspeak-pronounce-add-super 'plain-tex-mode 'latex2e-mode)
-;;; latex modes should inherit from plain text modes too
+;; latex modes should inherit from plain text modes too
 (emacspeak-pronounce-add-super 'text-mode 'latex-mode)
 (emacspeak-pronounce-add-super 'text-mode 'latex2e-mode)
 (emacspeak-pronounce-add-super 'text-mode 'plain-tex-mode)
-;;;xsl inherits from xml
+;; xsl inherits from xml
 (emacspeak-pronounce-add-super 'xml-mode 'xsl-mode)
 
-;;; VM,  w3
-(emacspeak-pronounce-add-super 'text-mode 'w3-mode)
+;; VM,  EWW, org
+(emacspeak-pronounce-add-super 'text-mode 'eww-mode)
 (emacspeak-pronounce-add-super 'text-mode 'vm-presentation-mode)
-
+(emacspeak-pronounce-add-super 'text-mode 'org-mode)
 ;;}}}
 ;;{{{ Composing and applying dictionaries:
 
-;;; Composing a dictionary results in the return of a hash table that
-;;; contains the applicable string.pronunciation pairs for a given
-;;; buffer.
-;;; Applying a pronunciation table results in the strings being
-;;; globally replaced by the defined pronunciations.
-;;; Case is handled similarly to vanila emacs behavior.
+;; Composing a dictionary results in the return of a hash table that
+;; contains the applicable string.pronunciation pairs for a given
+;; buffer.
+;; Applying a pronunciation table results in the strings being
+;; globally replaced by the defined pronunciations.
+;; Case is handled similarly to vanila emacs behavior.
 
 ;;{{{ composing the dictionary
 
 (defun emacspeak-pronounce-get-supers (child)
-  "Return list of supers.
-Argument CHILD specifies the mode whose supers are being requested."
+  "Return list of supers for mode `child'. "
   (get child 'emacspeak-pronounce-supers))
 
 ;;}}}
 
-(defcustom emacspeak-pronounce-pronunciation-personality voice-lighten
-  "*Pronunciation personality.
-This is the personality used when speaking things that have a pronunciation
-applied."
-  :group 'emacspeak-pronounce
-  :type (voice-setup-custom-menu))
+(defvar-local emacspeak-pronounce-personality nil
+  "Personality used for pronunciations")
+
+(defun emacspeak-pronounce-toggle-voice ()
+  "Toggle use of pronunciation personality."
+  (interactive )
+  (cl-declare (special emacspeak-pronounce-personality))
+  (cond
+   (emacspeak-pronounce-personality (setq emacspeak-pronounce-personality nil))
+   (t (setq emacspeak-pronounce-personality 'match)))
+  (emacspeak-auditory-icon
+   (if emacspeak-pronounce-personality 'on 'off))
+  (message "Turned %s pronunciation personality"
+           (if emacspeak-pronounce-personality 'on 'off)))
 
 ;;}}}
 ;;{{{ loading, clearing and saving dictionaries
 
-(cl-declaim (special emacspeak-resource-directory))
+(cl-declaim (special emacspeak-user-directory))
 
 (defcustom emacspeak-pronounce-dictionaries-file
   (expand-file-name ".dictionary"
-                    emacspeak-resource-directory)
-  "File that holds the persistent emacspeak pronunciation dictionaries."
+                    emacspeak-user-directory)
+  "File that holds  emacspeak pronunciations."
   :type '(file :tag "Dictionary File ")
-  :group 'emacspeak-pronounce)
+  :group 'emacspeak)
 
-(defcustom emacspeak-pronounce-load-pronunciations-on-startup t
-  "Says if user dictionaries loaded on emacspeak startup."
-  :type 'boolean
-  :group 'emacspeak-pronounce)
-;;;###autoload
 (defun emacspeak-pronounce-save-dictionaries ()
-  "Writes out the persistent emacspeak pronunciation dictionaries."
+  "Saves  pronunciation dictionaries."
   (interactive)
   (cl-declare (special emacspeak-pronounce-dictionaries))
   (let* ((coding-system-for-write 'utf-8)
@@ -285,7 +264,7 @@ applied."
          (print-length nil)
          (filename (read-file-name
                     "Save pronunciation dictionaries to file: "
-                    emacspeak-resource-directory
+                    emacspeak-user-directory
                     nil nil
                     (file-name-nondirectory emacspeak-pronounce-dictionaries-file)))
          (buffer nil))
@@ -304,29 +283,29 @@ applied."
 
 (defvar emacspeak-pronounce-dictionaries-loaded nil
   "Indicates if dictionaries already loaded.")
-;;;###autoload
 (defun emacspeak-pronounce-load-dictionaries (&optional filename)
   "Load pronunciation dictionaries.
-Optional argument FILENAME specifies the dictionary file."
+Optional argument FILENAME specifies the dictionary file,
+Default is emacspeak-pronounce-dictionaries-file."
   (interactive
-   (list (read-file-name
-          "Load pronunciation dictionaries from file: "
-          emacspeak-resource-directory
-          emacspeak-pronounce-dictionaries-file)))
-  (cl-declare (special emacspeak-pronounce-dictionaries-loaded))
+   (list
+    (read-file-name
+     "Load pronunciation dictionaries from file: "
+     emacspeak-user-directory emacspeak-pronounce-dictionaries-file)))
+  (cl-declare (special emacspeak-pronounce-dictionaries-file
+                       emacspeak-pronounce-dictionaries-loaded))
+  (setq filename (or  filename  emacspeak-pronounce-dictionaries-file))
   (when (file-exists-p filename)
     (condition-case nil
-        (let ((coding-system-for-read  'utf-8)
-              (file-name-handler-alist  nil))
-          (progn
-            (load-file filename)
-            (setq emacspeak-pronounce-dictionaries-loaded t)))
-      (error
-       (message "Error loading pronunciation dictionary, deactivating  pronunciations.")
-       (setq emacspeak-pronounce-dictionaries (make-hash-table)
-             emacspeak-pronounce-dictionaries-loaded t)))))
+        (progn
+          ;; `ems--fastload' is defined in `emacspeak-preamble' which requires
+          ;; us, so we can't require it at top-level.
+          (require 'emacspeak-preamble)
+          (declare-function ems--fastload "emacspeak-preamble" (file))
+          (ems--fastload filename)
+          (setq emacspeak-pronounce-dictionaries-loaded t))
+      (error (message "Error loading pronunciation dictionary")))))
 
-;;;###autoload
 (defun emacspeak-pronounce-clear-dictionaries ()
   "Clear all current pronunciation dictionaries."
   (interactive)
@@ -350,35 +329,19 @@ Optional argument FILENAME specifies the dictionary file."
   "Buffer name where we are currently defining a pronunciation.")
 
 (defvar emacspeak-pronounce-yank-word-point nil
-  "Point where we left off reading from the buffer containing the term being defined.")
+  "Point where we left off reading from the buffer containing the
+  term being defined.")
 
 (make-variable-buffer-local ' emacspeak-pronounce-yank-word-point)
-;;;###autoload
-(defun emacspeak-pronounce-yank-word ()
-  "Yank word at point into minibuffer."
-  (interactive)
-  (cl-declare (special emacspeak-pronounce-yank-word-point
-                    emacspeak-pronounce-current-buffer))
-  (let ((string
-         (save-current-buffer
-           (set-buffer emacspeak-pronounce-current-buffer)
-           (goto-char emacspeak-pronounce-yank-word-point)
-           (buffer-substring-no-properties
-            (point)
-            (save-excursion
-              (forward-word 1)
-              (setq emacspeak-pronounce-yank-word-point (point)))))))
-    (insert string)
-    (dtk-speak string)))
 
 (defun emacspeak-pronounce-read-term (key)
   (cl-declare (special emacspeak-pronounce-yank-word-point
-                    emacspeak-pronounce-current-buffer))
+                       emacspeak-pronounce-current-buffer))
   (let ((default (and (mark)
                       (< (count-lines (region-beginning)
                                       (region-end)) 2)
-                      (buffer-substring (region-beginning)
-                                        (region-end))))
+                      (buffer-substring-no-properties (region-beginning)
+                                                      (region-end))))
         (emacspeak-pronounce-yank-word-point (point)))
     (setq emacspeak-pronounce-current-buffer (current-buffer))
     (read-from-minibuffer
@@ -389,17 +352,17 @@ Optional argument FILENAME specifies the dictionary file."
          (define-key now-map "\C-w"'emacspeak-pronounce-yank-word))
        now-map))))
 
-;;;###autoload
-(defun emacspeak-pronounce-define-local-pronunciation (word pronunciation)
+(defun emacspeak-pronounce-define-local-pronunciation (word pron)
   "Define buffer local pronunciation.
-Argument WORD specifies the word which should be pronounced as specified by PRONUNCIATION."
+Argument `word' specified the word to be pronounced.
+Argument `pron' specifies the new pronunciation. "
   (interactive
    (list
     (emacspeak-pronounce-read-term 'buffer)
     (read-from-minibuffer
      (format "Pronounce as: "))))
   (emacspeak-pronounce-add-buffer-local-dictionary-entry
-   word pronunciation))
+   word pron))
 
 (defun emacspeak-pronounce-get-key ()
   "Collect key from user.
@@ -437,7 +400,6 @@ Returns a pair of the form (key-type . key)."
      (t (error "Cannot define pronunciations with key type %s" key-type)))
     (cons key-type key)))
 
-;;;###autoload
 (defun emacspeak-pronounce-define-template-pronunciation ()
   "Interactively define template entries in the pronunciation dictionaries.
 Default term to define is delimited by region.
@@ -463,7 +425,6 @@ First loads any persistent dictionaries if not already loaded."
     (when (eq (car key-pair) 'buffer)
       (emacspeak-pronounce-add-buffer-local-dictionary-entry word pronunciation))))
 
-;;;###autoload
 (defun emacspeak-pronounce-define-pronunciation ()
   "Interactively define entries in the pronunciation dictionaries.
 Default term to define is delimited by region.
@@ -488,60 +449,36 @@ First loads any persistent dictionaries if not already loaded."
 
 ;;}}}
 ;;{{{ Turning dictionaries on and off on a per buffer basis
-(defvar emacspeak-pronounce-pronunciation-table nil
-  "Variable holding association list of pronunciations for a buffer.
-Becomes automatically buffer local.")
-(make-variable-buffer-local 'emacspeak-pronounce-pronunciation-table)
-(setq-default emacspeak-pronounce-pronunciation-table nil)
 
-;;;###autoload
+(defvar-local  emacspeak-pronounce-pronunciation-table nil
+  "AList for buffer pronunciations")
+
 (defun  emacspeak-pronounce-pronunciation-table ()
-  "Closure that returns the pronunciation table."
+  "Return the pronunciation table."
   emacspeak-pronounce-pronunciation-table)
 
 ;;;###autoload
 (defun emacspeak-pronounce-toggle-use-of-dictionaries (&optional state)
-  "Toggle use of pronunciation dictionaries in current buffer.
-Pronunciations can be defined on a per file, per directory and/or per
-mode basis.
-Pronunciations are activated on a per buffer basis.
-Turning on the use of pronunciation dictionaries results in emacspeak
-composing a pronunciation table based on the currently defined
-pronunciation dictionaries.
-After this, the pronunciations will be applied whenever text in the
-buffer is spoken.
-Optional argument state can be used from Lisp programs to
-explicitly turn pronunciations on or off."
+  "Toggle  pronunciation dictionaries. "
   (interactive "P")
   (cl-declare (special emacspeak-pronounce-pronunciation-table))
+  (unless state (setq state (not emacspeak-pronounce-pronunciation-table)))
   (cond
-   ((or (eq state 'on)
-        (not (boundp 'emacspeak-pronounce-pronunciation-table)))
-    (make-local-variable 'emacspeak-pronounce-pronunciation-table)
-    (setq emacspeak-pronounce-pronunciation-table
-          (emacspeak-pronounce-compose-pronunciation-table))
-    (when (called-interactively-p 'interactive)
-      (emacspeak-auditory-icon 'on)
-      (message "Emacspeak pronunciation dictionaries are now active in this buffer")))
-   ((or (eq state 'off)
-                                        ;already on --turn it off
-        emacspeak-pronounce-pronunciation-table)
-    (setq emacspeak-pronounce-pronunciation-table nil)
-    (when (called-interactively-p 'interactive)
-      (emacspeak-auditory-icon 'off)
-      (message
-       "Emacspeak pronunciation dictionaries no longer active in this buffer")))
-   (t ;turn it on
-    (setq emacspeak-pronounce-pronunciation-table
-          (emacspeak-pronounce-compose-pronunciation-table))
-    (when (called-interactively-p 'interactive)
-      (message
-       "Emacspeak pronunciations have been re-activated in this buffer")
-      (emacspeak-auditory-icon 'on)))))
-;;;###autoload
+   (state
+    (unless emacspeak-pronounce-pronunciation-table
+      (setq emacspeak-pronounce-pronunciation-table
+            (emacspeak-pronounce-compose-pronunciation-table))))
+   ((null state)                        ;already on --turn it off
+    (setq emacspeak-pronounce-pronunciation-table nil)))
+  (when (called-interactively-p 'interactive)
+    (emacspeak-auditory-icon
+     (if emacspeak-pronounce-pronunciation-table 'on 'off))
+    (message
+     "Pronunciations %s."
+     (if emacspeak-pronounce-pronunciation-table " on " " off "))))
+
 (defun emacspeak-pronounce-refresh-pronunciations ()
-  "Refresh pronunciation table for current buffer.
-Activates pronunciation dictionaries if not already active."
+  "Refresh pronunciation table for current buffer. "
   (interactive)
   (cl-declare (special emacspeak-pronounce-pronunciation-table))
   (cond
@@ -551,7 +488,7 @@ Activates pronunciation dictionaries if not already active."
    (emacspeak-pronounce-pronunciation-table ;already on --refresh it
     (setq emacspeak-pronounce-pronunciation-table
           (emacspeak-pronounce-compose-pronunciation-table)))
-   (t ;turn it on
+   (t                                   ;turn it on
     (setq emacspeak-pronounce-pronunciation-table
           (emacspeak-pronounce-compose-pronunciation-table))))
   (when (called-interactively-p 'interactive)
@@ -573,103 +510,85 @@ Activates pronunciation dictionaries if not already active."
     (">:->" . " devillish smile ")
     (">;->" . " lewd smile ")
     (";-)" . " wink "))
-  "Pronunciation dictionary used in all instant messenger and IRC chat
-modes.
-See http://www.charm.net/~kmarsh/smiley.html. "
+  "Smileys"
   :link '(url-link :tag "Smileys Dictionary "
                    "http://oz.uc.edu/~solkode/smileys.html")
   :type '(repeat
           (cons :tag "Dictionary Entry"
                 (string :tag "String")
                 (string :tag "Pronunciation")))
-  :group 'emacspeak-pronounce)
+  :group 'emacspeak)
 
 ;;}}}
 ;;{{{ xml namespace uri's
 
 (defcustom emacspeak-pronounce-common-xml-namespace-uri-pronunciations
   '(
-    ("http://schemas.google.com/g/2005" . " gd ")
     ("http://www.w3.org/2005/Atom" . " atom ")
     ("http://www.w3.org/1999/02/22-rdf-syntax-ns#" . "RDF Syntax")
     ("http://www.w3.org/2002/06/xhtml2" . " xhtml2 ")
-    ("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul"
-     . "XUL")
-    ("http://www.mozilla.org/xbl" . " xbl ")
-    ("http://www.w3.org/2003/XInclude" . "xinclude")
+    ("http://www.w3.org/2003/XInclude" . "XInclude")
     ("http://www.w3.org/1999/XSL/Transform" . " XSLT ")
     ("http://www.w3.org/2002/xforms" . " XForms ")
     ("http://www.w3.org/2001/xml-events" . " XEvents ")
     ("http://www.w3.org/2001/vxml" . " vxml ")
-    ("http://www.w3.org/2001/XMLSchema-instance". " XSchema Instance ")
-    ("http://www.w3.org/2001/XMLSchema". " XSchema ")
+    ("http://www.w3.org/2001/XMLSchema-instance". " XSI ")
+    ("http://www.w3.org/2001/XMLSchema". " XSD ")
     ("http://www.w3.org/1999/xhtml" . " xhtml ")
-    ("http://schemas.xmlsoap.org/wsdl/" . " WSDL ")
-    ("http://www.w3.org/2001/06/soap-envelope" . " SOAP ENV ")
-    ("http://schemas.xmlsoap.org/wsdl/soap/" . " SOAP ")
-    ("http://purl.org/dc/elements/1.1/" . "Dublin Core")
+    ("http://purl.org/dc/elements/1.1/" . "DC")
     ("http://search.yahoo.com/mrss/" . "media")
     )
-  "Pronunciations for well known namespace URIs."
+  "Namespace URIs."
   :type '(repeat
-          (cons :tag "Dictionary Entry"
-                (string :tag "Namespace URI")
+          (cons :tag "Entry"
+                (string :tag "URI")
                 (string :tag "Pronunciation")))
-  :group 'emacspeak-pronounce)
+  :group 'emacspeak)
 
 ;;}}}
 ;;{{{ adding predefined dictionaries to a mode:
+
 (defun emacspeak-pronounce-augment-pronunciations (mode dictionary)
-  "Pushes pronunciations in specified dictionary on to the dictionary
-for the specified mode."
+  "Augment pronunciations."
   (let ((mode-alist (emacspeak-pronounce-get-dictionary mode)))
-    (cl-loop for e in dictionary
-             do
-             (unless (assoc (car e)
-                            mode-alist)
-               (push e mode-alist)))
+    (cl-loop
+     for e in dictionary do
+     (unless (assoc (car e) mode-alist)
+       (push e mode-alist)))
     (emacspeak-pronounce-set-dictionary mode mode-alist)))
 
 ;;}}}
 ;;{{{ dictionary editor
 
 (defun emacspeak-pronounce-edit-generate-pronunciation-editor (key)
-  "Generate a widget-enabled edit buffer for editing the
-pronunciation dictionary for the specified key."
+  "Edit dictionary for given key"
   (cl-declare (special emacspeak-pronounce-dictionaries))
   (unless emacspeak-pronounce-pronunciation-table
     (emacspeak-pronounce-toggle-use-of-dictionaries))
   (let ((value (gethash key emacspeak-pronounce-dictionaries))
         (notify (emacspeak-pronounce-edit-generate-callback key))
-        (buffer-name (format "*Dictionary: %s" key))
-        (buffer nil)
+        (buffer (get-buffer-create (format "*Dict: %s" key)))
         (inhibit-read-only t))
-    (when (get-buffer buffer-name) (kill-buffer buffer-name))
-    (setq buffer (get-buffer-create buffer-name))
     (save-current-buffer
       (set-buffer buffer)
-      (widget-insert "\n")
-      (widget-insert
-       (format "Editing pronunciation dictionary for %s\n\n" key))
-      (widget-create 'repeat
-                     :help-echo "Edit Pronunciations"
-                     :tag "Pronunciations"
-                     :value value
-                     :notify notify
-                     '(cons :tag "Dictionary Entry"
-                            (string :tag "Phrase")
-                            (choice :tag "Pronunciation"
-                                    (string :tag "Pronounce as")
-                                    (cons :tag "Pronouncer"
-                                          (symbol :tag "Matcher")
-                                          (symbol :tag "Pronouncer")))))
-      (widget-insert "\n")
+      (erase-buffer)
+      (widget-insert (format "Dict: %s\n" key))
+      (widget-create
+       'repeat
+       :help-echo "Edit" :tag "Edit"
+       :value value :notify notify
+       '(cons :tag "Entry"
+              (string :tag "Phrase")
+              (choice :tag "Pronounce"
+                      (string :tag "Phrase")
+                      (cons :tag "Pair"
+                            (symbol :tag "Matcher")
+                            (symbol :tag "Pronouncer")))))
       (widget-create 'push-button
-                     :tag "Save Dictionary"
+                     :tag "Save"
                      :notify
                      #'(lambda (&rest _ignore)
-                         (call-interactively 'emacspeak-pronounce-save-dictionaries)))
-      (widget-insert "\n\n")
+                         (call-interactively #'emacspeak-pronounce-save-dictionaries)))
       (use-local-map widget-keymap)
       (widget-setup)
       (goto-char (point-min)))
@@ -686,7 +605,6 @@ pronunciation dictionary for the specified key."
          emacspeak-pronounce-dictionaries)
         value))))
 
-;;;###autoload
 (defun emacspeak-pronounce-edit-pronunciations (key)
   "Prompt for and launch a pronunciation editor on the
 specified pronunciation dictionary key."
@@ -715,54 +633,57 @@ specified pronunciation dictionary key."
 ;;{{{ top level dispatch routine
 
 (defvar emacspeak-pronounce-help
-  "Dictionary: Clear Define Edit Load Refresh Save Toggle"
-  "Help message listing emacspeak commands.")
+  "Dictionary: Clear Define Edit Load Refresh Save Toggle voicify"
+  "Dictionary Help")
 
-;;;###autoload
 (defun emacspeak-pronounce-dispatch ()
-  "Provides the user interface front-end to Emacspeak's pronunciation dictionaries."
+  "Pronounce Frontend"
   (interactive)
   (cl-declare (special emacspeak-pronounce-help))
   (message emacspeak-pronounce-help)
   (let ((event (read-char)))
     (cl-case event
-          (?c (call-interactively 'emacspeak-pronounce-clear-dictionaries))
-          (?d (call-interactively
-               'emacspeak-pronounce-define-pronunciation t))
-          (?D (call-interactively 'emacspeak-pronounce-define-template-pronunciation t))
-          (?e (call-interactively
-               'emacspeak-pronounce-edit-pronunciations t))
-          (?l (call-interactively 'emacspeak-pronounce-load-dictionaries))
-          (?r (call-interactively 'emacspeak-pronounce-refresh-pronunciations))
-          (?s (call-interactively 'emacspeak-pronounce-save-dictionaries))
-          (?t (call-interactively 'emacspeak-pronounce-toggle-use-of-dictionaries))
-          (otherwise (message emacspeak-pronounce-help)))
+      (?c (call-interactively 'emacspeak-pronounce-clear-dictionaries))
+      (?d (call-interactively
+           'emacspeak-pronounce-define-pronunciation t))
+      (?D (call-interactively 'emacspeak-pronounce-define-template-pronunciation t))
+      (?e (call-interactively
+           'emacspeak-pronounce-edit-pronunciations t))
+      (?l (call-interactively 'emacspeak-pronounce-load-dictionaries))
+      (?r (call-interactively 'emacspeak-pronounce-refresh-pronunciations))
+      (?s (call-interactively 'emacspeak-pronounce-save-dictionaries))
+      (?t (call-interactively
+           'emacspeak-pronounce-toggle-use-of-dictionaries))
+      (?v (call-interactively 'emacspeak-pronounce-toggle-voice))
+      (otherwise (message emacspeak-pronounce-help)))
     (emacspeak-auditory-icon 'close-object)))
 
 ;;}}}
 ;;{{{ Helpers: pronouncers
 
-;;{{{ dates
+;;{{{ dates and numbers
+
+(defvar emacspeak-pronounce-number-pattern
+  "[0-9]+\\.?[0-9]+%?"
+  "Pattern that matches  nnnn.nnnn")
 
 (defvar emacspeak-pronounce-date-mm-dd-yyyy-pattern
   "[0-9]\\{2\\}-[0-9]\\{2\\}-[0-9]\\{2\\}\\([0-9]\\{2\\}\\)?"
   "Pattern that matches dates of the form mm-dd-[cc]yy.")
+(declare-function calendar-date-string "calendar" (date &optional abbreviate nodayname))
 
 (defun emacspeak-pronounce-mm-dd-yyyy-date (string)
   "Return pronunciation for mm-dd-yyyy dates."
-  (save-match-data
-    (let ((fields (mapcar #'read (split-string string "-"))))
-      (propertize
-       (calendar-date-string
-        (list (cl-second fields)
-              (cl-first fields)
-              (cond
-               ((< (cl-third fields) 50)
-                (+ 2000 (cl-third fields)))
-               ((< (cl-third fields) 100)
-                (+ 1900 (cl-third fields)))
-               (t (cl-third fields)))))
-       'personality voice-punctuations-some))))
+  (let ((fields (mapcar #'read (split-string string "-"))))
+    (calendar-date-string
+     (list (cl-second fields)
+           (cl-first fields)
+           (cond
+            ((< (cl-third fields) 50)
+             (+ 2000 (cl-third fields)))
+            ((< (cl-third fields) 100)
+             (+ 1900 (cl-third fields)))
+            (t (cl-third fields)))))))
 
 (defvar emacspeak-pronounce-date-yyyymmdd-pattern
   "[0-9]\\{8\\}"
@@ -770,20 +691,18 @@ specified pronunciation dictionary key."
 
 (defun emacspeak-pronounce-yyyymmdd-date (string)
   "Return pronunciation for yyyymmdd dates."
-  (save-match-data
-    (propertize
-     (calendar-date-string
-      (list
-       (read (substring string 4 6))
-       (read (substring string 6))
-       (read (substring string 0 4)))
-      nil 'nodayname)
-     'personality voice-punctuations-some)))
+  (calendar-date-string
+   (list
+    (read (substring string 4 6))
+    (read (substring string 6))
+    (read (substring string 0 4)))
+   nil 'nodayname))
 
 ;;}}}
 ;;{{{ phone numbers
 
-(defvar emacspeak-pronounce-us-phone-number-pattern "1?-?[0-9]\\{3\\}-[0-9]\\{3\\}-[0-9]\\{4\\}"
+(defvar emacspeak-pronounce-us-phone-number-pattern
+  "1?-?[0-9]\\{3\\}-[0-9]\\{3\\}-[0-9]\\{4\\}"
   "Pattern that matches US phone numbers.")
 
 (defun emacspeak-pronounce-us-phone-number (phone)
@@ -803,16 +722,16 @@ specified pronunciation dictionary key."
     (setq suffix-code
           (replace-regexp-in-string
            "[0-9]\\{2\\}" " \\&" suffix-code))
-    (propertize
-     (format "%s %s, %s. "
-             area-code prefix-code suffix-code)
-     'personality voice-punctuations-some)))
+    (format "%s %s, %s. "
+            area-code prefix-code suffix-code)))
+
 (defvar emacspeak-pronounce-sha-checksum-pattern
   "[0-9a-f]\\{40\\}"
   "Regexp pattern that matches 40-digit SHA check-sum.")
 
 (defun emacspeak-pronounce-sha-checksum (sha)
-  "Return pronunciation for 40 digit SHA hash. Useful for working with Git among other things."
+  "Return pronunciation for 40 digit SHA hash. Useful for working
+with Git among other things."
   (when
       (and
        (= 40 (length sha))
@@ -840,13 +759,53 @@ specified pronunciation dictionary key."
 ;;}}}
 
 ;;}}}
+;;{{{Text Mode Pronunciations:
 
+(emacspeak-pronounce-add-dictionary-entry
+ 'text-mode
+ (concat " -" emacspeak-pronounce-number-pattern)
+ (cons
+  #'re-search-forward
+  #'(lambda (number)
+      (concat " minus " (substring number 2)))))
+
+;;}}}
+;;{{{Merge  Dictionaries:
+
+;; Over time, you can end up with dictionary entries in  a child-mode
+;; e.g. eww-mode that better belong in the parent, e.g. text-mode.
+;; Merging dictionaries results in entries from the source
+;; dictionaries moving into the target dictionary. Once merged, these
+;; entries  are removed from the source dictionary.
+;; The same can happen when pronunciations are initially  defined for
+;; a file,, then later merged into the  dictionary for  the
+;; containing directory.
+
+(defun emacspeak-pronounce-merge-dictionaries (from into)
+  "Merge dic `from' into dict `into'"
+  (interactive
+   (let ((keys
+          (cl-loop
+           for k being  the hash-keys of
+           emacspeak-pronounce-dictionaries collect k)))
+     (list
+      (read (completing-read "From:" keys))
+      (read (completing-read "To:" keys)))))
+  (cl-assert (not (eq from into)) t  "Same from and to dicts!")
+  (let ((src (gethash from emacspeak-pronounce-dictionaries))
+        (dst (gethash into emacspeak-pronounce-dictionaries)))
+    (cl-loop
+     for e in src do
+     (cl-pushnew e dst :test #'equal))
+    (puthash into dst emacspeak-pronounce-dictionaries )
+    (puthash from nil emacspeak-pronounce-dictionaries )))
+
+;;}}}
 (provide 'emacspeak-pronounce)
 ;;{{{ emacs local variables
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
