@@ -1,48 +1,48 @@
 ;;; emacspeak-python.el --- Speech enable Python development environment  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $
-;;; Description: Auditory interface to python mode
-;;; Keywords: Emacspeak, Speak, Spoken Output, python
+;;
+;; $Author: tv.raman.tv $
+;; Description: Auditory interface to python mode
+;; Keywords: Emacspeak, Speak, Spoken Output, python
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
-;;;  $Revision: 4532 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2017, T. V. Raman
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (c) 1995 -- 2022, T. V. Raman
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{ Introduction
 
 ;;; Commentary:
 
-;;; This speech-enables python-mode available on sourceforge and ELPA
+;; This speech-enables python-mode available on sourceforge and ELPA
 
 ;;; Code:
 
@@ -51,28 +51,12 @@
 (require 'cl-lib)
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
-(eval-when-compile
-  (require 'python-mode "python-mode" 'no-error))
+
+(with-no-warnings (require 'python-mode "python-mode" 'no-error))
 ;;}}}
 ;;{{{  electric editing
 
-(unless (and (boundp 'post-self-insert-hook)
-             post-self-insert-hook
-             (memq 'emacspeak-post-self-insert-hook post-self-insert-hook))
-  (defadvice py-electric-comment (after emacspeak pre act comp)
-    "Speak what you inserted"
-    (when (ems-interactive-p)
-      (dtk-say " pound "))))
-
-(unless (and (boundp 'post-self-insert-hook)
-             post-self-insert-hook
-             (memq 'emacspeak-post-self-insert-hook post-self-insert-hook))
-  (defadvice py-electric-colon (after emacspeak pre act comp)
-    "Speak what you inserted")
-  (when (ems-interactive-p)
-    (dtk-say " colon ")))
-
-(defadvice py-electric-backspace (around emacspeak pre act)
+(defadvice py-electric-backspace (around emacspeak pre act comp)
   "Speak character you're deleting.
 Provide contextual feedback when closing blocks"
   (cond
@@ -91,7 +75,7 @@ Provide contextual feedback when closing blocks"
    (t ad-do-it))
   ad-return-value)
 
-(defadvice py-electric-delete (around emacspeak pre act)
+(defadvice py-electric-delete (around emacspeak pre act comp)
   "Speak character you're deleting."
   (cond
    ((ems-interactive-p)
@@ -105,23 +89,23 @@ Provide contextual feedback when closing blocks"
 ;;{{{ interactive programming
 
 (defadvice py-shell (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice py-clear-queue (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'task-done)))
 
 (defadvice py-execute-region (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'task-done)))
 
 (defadvice py-execute-buffer (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'task-done)))
 
@@ -152,7 +136,7 @@ Provide contextual feedback when closing blocks"
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
-     "Provide auditory feedback."
+     "speak."
      (when (ems-interactive-p)
        (emacspeak-auditory-icon 'fill-object)))))
 
@@ -343,7 +327,7 @@ Provide contextual feedback when closing blocks"
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
-     "Provide auditory feedback."
+     "speak."
      (when (ems-interactive-p)
        (message "Narrowed  %s lines"
                 (count-lines (point-min) (point-max)))))))
@@ -370,7 +354,7 @@ Provide contextual feedback when closing blocks"
 ;;}}}
 ;;{{{ the process buffer
 
-(defadvice py-process-filter (around emacspeak pre act)
+(defadvice py-process-filter (around emacspeak pre act comp)
   "Make comint in Python speak its output. "
   (cl-declare (special emacspeak-comint-autospeak))
   (let ((prior (point))
@@ -392,34 +376,40 @@ Provide contextual feedback when closing blocks"
  '(
    (py-number-face voice-lighten)
    (py-XXX-tag-face voice-animate)
-   (py-pseudo-keyword-face voice-bolden-medium)
-   (py-variable-name-face  voice-bolden)
+   (py-pseudo-keyword-face voice-animate-medium)
+   (py-variable-name-face  voice-animate)
    (py-decorators-face voice-lighten)
-   (py-builtins-face voice-bolden)
+   (py-builtins-face voice-smoothen)
    (py-class-name-face voice-bolden-extra)
-   (py-exception-name-face voice-smoothen)
+   (py-exception-name-face voice-brighten)
    (py-def-class-face voice-lighten)
    (py-import-from-face voice-animate)
-   (py-object-reference-face voice-monotone-light)
+   (py-object-reference-face voice-bolden-and-animate)
    (py-try-if-face voice-lighten)
    ))
 
 ;;}}}
 ;;{{{ pydoc advice:
 (defadvice pydoc (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-rest-of-buffer)))
 
+(defadvice py-help-at-point (after emacspeak pre act comp)
+  "speak."
+  (when (ems-interactive-p)
+    (emacspeak-auditory-icon 'help)
+    (dtk-stop)
+    (emacspeak-speak-buffer)))
+
 ;;}}}
 
 (provide 'emacspeak-py)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
