@@ -1,43 +1,43 @@
 ;;; emacspeak-reftex.el --- speech enable reftex, Cross-References In La)TeX -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $
-;;; Description:  Emacspeak extension to speech enable
-;;; reftex 
-;;; Keywords: Emacspeak, reftex
+;;
+;; $Author: tv.raman.tv $
+;; Description:  Emacspeak extension to speech enable
+;; reftex 
+;; Keywords: Emacspeak, reftex
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
-;;;  $Revision: 4532 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2017, T. V. Raman<raman@cs.cornell.edu>
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman<tv.raman.tv@gmail.com>
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{ required modules
 
@@ -48,9 +48,9 @@
 
 ;;; Commentary:
 
-;;; This module speech-enables refteex --
-;;; reftex is a minor mode that makes navigation of TeX
-;;; documents  possible via a table of contents buffer.
+;; This module speech-enables refteex --
+;; reftex is a minor mode that makes navigation of TeX
+;; documents  possible via a table of contents buffer.
 
 ;;; Code:
 
@@ -134,7 +134,7 @@
     (emacspeak-speak-line)))
 
 (defadvice reftex-toc-toggle-follow (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon (if reftex-toc-follow-mode
                                  'on
@@ -142,7 +142,7 @@
     (message "Turned %s follow mode. "
              (if reftex-toc-follow-mode 'on 'off))))
 (defadvice reftex-toc-toggle-labels (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon (if reftex-toc-include-labels
                                  'on
@@ -151,7 +151,7 @@
              (if reftex-toc-include-labels 'on 'off))))
 
 (defadvice reftex-toc-toggle-file-boundary (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon (if reftex-toc-include-file-boundaries
                                  'on
@@ -160,7 +160,7 @@
              (if reftex-toc-include-file-boundaries 'on 'off))))
 
 (defadvice reftex-toc-toggle-context (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon (if reftex-toc-include-context
                                  'on
@@ -208,7 +208,7 @@
     (emacspeak-speak-predefined-window 2)))
 
 (defadvice reftex-index-toggle-follow (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon (if reftex-index-follow-mode
                                  'on
@@ -217,7 +217,7 @@
              (if reftex-index-follow-mode 'on 'off))))
 
 (defadvice reftex-index-toggle-labels (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon (if reftex-index-include-labels
                                  'on
@@ -226,7 +226,7 @@
              (if reftex-index-include-labels 'on 'off))))
 
 (defadvice reftex-index-toggle-file-boundary (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon (if reftex-index-include-file-boundaries
                                  'on
@@ -235,7 +235,7 @@
              (if reftex-index-include-file-boundaries 'on 'off))))
 
 (defadvice reftex-index-toggle-context (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon (if reftex-index-include-context
                                  'on
@@ -250,13 +250,13 @@
     (emacspeak-auditory-icon 'open-object)))
 
 (defadvice reftex-index-quit (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice reftex-index-quit-and-kill (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
@@ -281,9 +281,8 @@
 (provide 'emacspeak-reftex)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
