@@ -1,56 +1,57 @@
 ;;; emacspeak-rmail.el --- Speech enable RMail -- Emacs' default mail agent  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $ 
-;;; Description: Emacspeak extension for rmail
-;;; Keywords:emacspeak, audio interface to emacs mail
+;;
+;; $Author: tv.raman.tv $ 
+;; Description: Emacspeak extension for rmail
+;; Keywords:emacspeak, audio interface to emacs mail
 ;;{{{  LCD Archive entry: 
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
-;;;  $Revision: 4532 $ | 
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ | 
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman 
-;;; Copyright (c) 1995 by T. V. Raman  
-;;; All Rights Reserved. 
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman 
+;; Copyright (c) 1995 by T. V. Raman  
+;; All Rights Reserved. 
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
 
 ;;{{{  Introduction
 ;;; Commentary:
-;;; emacspeak extensions to rmail
+;; emacspeak extensions to rmail
 ;;; Code:
 ;;}}}
 ;;{{{ requires
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
-(require 'desktop)
-(require 'rmailsort)
-(require 'emacspeak-desktop)
 
 ;;}}}
 ;;{{{  customizations:
+(declare-function rmail-display-labels "rmail" nil)
+(declare-function rmail-msgend "rmail" (n))
+(declare-function rmail-msgbeg "rmail" (n))
+(declare-function rmail-get-header "rmail" (name &optional msgnum))
 
 (cl-declaim (special rmail-ignored-headers))
 (setq rmail-ignored-headers
@@ -67,10 +68,8 @@
   (let ((subject (rmail-get-header "Subject" message))
         (to (rmail-get-header "To" message))
         (from (rmail-get-header "From" message))
-        (lines (count-lines (rmail-msgbeg message)
-                            (rmail-msgend message)))
-        (labels (let ((rmail-current-message message))
-                  (rmail-display-labels))))
+        (lines (count-lines (rmail-msgbeg message) (rmail-msgend message)))
+        (labels (rmail-display-labels)))
     (dtk-speak
      (format "%s %s   %s %s labelled %s "
              (or from "")
@@ -85,24 +84,24 @@
 ;;{{{  buffer selection
 
 (defadvice rmail-quit(after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice rmail-bury(after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-mode-line)))
 (defadvice rmail (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-rmail-summarize-current-message)))
 
 (defadvice rmail-expunge-and-save (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'save-object)))
 
@@ -110,7 +109,7 @@
 ;;{{{  message navigation
 
 (defadvice rmail-beginning-of-message (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line)))
@@ -119,47 +118,48 @@
 ;;{{{  folder navigation
 
 (defadvice rmail-first-message (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-rmail-summarize-message rmail-current-message)))
 
 (defadvice rmail-first-unseen-message (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-rmail-summarize-message rmail-current-message)))
 
 (defadvice rmail-last-message (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-rmail-summarize-message rmail-current-message)))
 
 (defadvice rmail-next-undeleted-message (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-rmail-summarize-message rmail-current-message)))
 
 (defadvice rmail-next-message (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-rmail-summarize-message rmail-current-message)))
 
 (defadvice rmail-previous-undeleted-message (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-rmail-summarize-message rmail-current-message)))
 (defadvice rmail-previous-message (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-rmail-summarize-message rmail-current-message)))
 (defadvice rmail-next-labeled-message (around emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
+  (cl-declare (special rmail-current-message))
   (cond
    ((ems-interactive-p)
     (let ((original rmail-current-message))
@@ -173,7 +173,7 @@
   ad-return-value)
 
 (defadvice rmail-previous-labeled-message (around emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (cond
    ((ems-interactive-p)
     (let ((original rmail-current-message))
@@ -187,7 +187,7 @@
   ad-return-value)
 
 (defadvice rmail-show-message (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-rmail-summarize-message rmail-current-message)))  
@@ -197,12 +197,12 @@
 
 (defadvice rmail-undelete-previous-message (after emacspeak pre act
                                                   comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-rmail-summarize-current-message)))
-(defadvice rmail-delete-message (after emacspeak pre act)
-  "Provide auditory feedback."
+(defadvice rmail-delete-message (after emacspeak pre act comp)
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'delete-object)
     (message "Message discarded.")))
@@ -236,18 +236,18 @@
 
 ;;}}}
 ;;{{{  key bindings
-
-(cl-declaim (special rmail-mode-map))
-(define-key rmail-mode-map "\C-m" 'emacspeak-rmail-summarize-current-message)
-(define-key rmail-mode-map "L" 'emacspeak-rmail-speak-current-message-labels)
+(when (and (boundp 'rmail-mode-map) (keymapp rmail-mode-map))  
+  (cl-declaim (special rmail-mode-map))
+  (define-key rmail-mode-map "\C-m" 'emacspeak-rmail-summarize-current-message)
+  (define-key rmail-mode-map "L"
+              'emacspeak-rmail-speak-current-message-labels))
 
 ;;}}}
 (provide  'emacspeak-rmail)
 ;;{{{  emacs local variables 
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end: 
+;; local variables:
+;; folded-file: t
+;; end: 
 
 ;;}}}
