@@ -1,55 +1,55 @@
 ;;; emacspeak-speedbar.el --- Speech enable speedbar -- Tool for context-sensitive navigation  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $ 
-;;; Description: Auditory interface to speedbar
-;;; Keywords: Emacspeak, Speedbar
+;;
+;; $Author: tv.raman.tv $ 
+;; Description: Auditory interface to speedbar
+;; Keywords: Emacspeak, Speedbar
 ;;{{{  LCD Archive entry: 
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
-;;; A speech interface to Emacs |
-;;; $Date: 2008-06-21 10:50:41 -0700 (Sat, 21 Jun 2008) $ |
-;;;  $Revision: 4532 $ | 
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com 
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ | 
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2017, T. V. Raman
-;;; All Rights Reserved. 
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (c) 1995 -- 2022, T. V. Raman
+;; All Rights Reserved. 
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  Introduction
 
 ;;; Commentary:
 
-;;; This module advises speedbar.el for use with Emacs.  The
-;;; latest speedbar can be obtained from
-;;; ftp://ftp.ultranet.com/pub/zappo/ This module ensures
-;;; that speedbar works smoothly outside a windowing system
-;;; in addition to speech enabling all interactive
-;;; commands. Emacspeak also adds an Emacspeak environment
-;;; specific entry point to speedbar
-;;; --emacspeak-speedbar-goto-speedbar-- and binds this
+;; This module advises speedbar.el for use with Emacs.  The
+;; latest speedbar can be obtained from
+;; ftp://ftp.ultranet.com/pub/zappo/ This module ensures
+;; that speedbar works smoothly outside a windowing system
+;; in addition to speech enabling all interactive
+;; commands. Emacspeak also adds an Emacspeak environment
+;; specific entry point to speedbar
+;; --emacspeak-speedbar-goto-speedbar-- and binds this
 
 ;;; Code:
 
@@ -59,25 +59,6 @@
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (require 'speedbar "speedbar" 'no-error)
-;;}}}
-;;{{{ custom
-
-(defgroup emacspeak-speedbar nil
-  "Speedbar on the Emacspeak audio desktop."
-  :group 'emacspeak
-  :group 'speedbar
-  :prefix "emacspeak-speedbar")
-
-;;}}}
-;;{{{  work outside a windowing system
-
-                                        ;(defadvice speedbar-frame-mode (around emacspeak pre act comp)
-                                        ;"Wrapper to force speedbar to work outside a windowing system. "
-                                        ;(let ((spoofing-p (not window-system)))
-                                        ;ad-do-it
-                                        ;     (setq voice-lock-mode t))
-                                        ;   ad-return-value)
-
 ;;}}}
 ;;{{{ Helper:
 
@@ -98,7 +79,7 @@
       (setq indent 
             (if (zerop indent) "" indent))
       (dtk-speak 
-       (concat indent (ems-this-line))))))
+       (concat indent (ems--this-line))))))
 
 ;;}}}
 ;;{{{ Advice interactive commands:
@@ -169,14 +150,14 @@ action"
 
 (defadvice speedbar-restricted-next (after emacspeak pre act
                                            comp)
-  "Provide spoken feedback"
+  "Speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speedbar-speak-line)))
 
 (defadvice speedbar-restricted-prev (after emacspeak pre act
                                            comp)
-  "Provide spoken feedback"
+  "Speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speedbar-speak-line)))
@@ -229,24 +210,24 @@ An automatically updating speedbar consumes resources.")
                (emacspeak-speedbar-speak-line)
                (emacspeak-auditory-icon
                 (cl-case action-char
-                      (?+ 'open-object)
-                      (?- 'close-object)
-                      (t 'large-movement))))
+                  (?+ 'open-object)
+                  (?- 'close-object)
+                  (t 'large-movement))))
        (t (message "No target on this line"))))))
 
 ;;}}}
 ;;{{{  hooks
 (cl-declaim (special speedbar-mode-map))
 (cl-eval-when (load)
-           )
+  )
 (defun emacspeak-speedbar-enter-hook ()
   "Actions taken when we enter the Speedbar"
   (cl-declare (special speedbar-mode-map
-                    speedbar-hide-button-brackets-flag))
+                       speedbar-hide-button-brackets-flag))
   (dtk-set-punctuations 'all)
   (setq speedbar-hide-button-brackets-flag t)
   (define-key speedbar-mode-map "f"
-    'emacspeak-speedbar-click)
+              'emacspeak-speedbar-click)
                                         ;(define-key speedbar-mode-map "\M-n"
                                         ;'emacspeak-speedbar-forward)
                                         ;(define-key speedbar-mode-map "\M-p"
@@ -258,42 +239,29 @@ An automatically updating speedbar consumes resources.")
 
 ;;}}}
 ;;{{{  voice locking 
-;;; Map speedbar faces to voices
+;; Map speedbar faces to voices
 ;;
-(defcustom emacspeak-speedbar-button-personality  voice-bolden
-  "personality used for speedbar buttons"
-  :type 'symbol
-  :group 'emacspeak-speedbar)
+(defvar emacspeak-speedbar-button-personality  voice-bolden
+  "personality used for speedbar buttons")
 
-(defcustom emacspeak-speedbar-selected-personality  voice-animate
-  "Personality used to indicate speedbar selection"
-  :type 'symbol
-  :group 'emacspeak-speedbar)
+(defvar emacspeak-speedbar-selected-personality  voice-animate
+  "Personality used to indicate speedbar selection")
 
-(defcustom emacspeak-speedbar-directory-personality voice-bolden-medium
+(defvar emacspeak-speedbar-directory-personality voice-bolden-medium
   "Speedbar personality for directory buttons"
-  :type 'symbol
-  :group 'emacspeak-speedbar)
+  )
 
-(defcustom emacspeak-speedbar-file-personality  'paul
-  "Personality used for file buttons"
-  :type 'symbol
-  :group 'emacspeak-speedbar)
+(defvar emacspeak-speedbar-file-personality  'paul
+  "Personality used for file buttons")
 
-(defcustom emacspeak-speedbar-highlight-personality voice-animate
-  "Personality used for for speedbar highlight."
-  :type 'symbol
-  :group 'emacspeak-speedbar)
+(defvar emacspeak-speedbar-highlight-personality voice-animate
+  "Personality used for for speedbar highlight.")
 
-(defcustom emacspeak-speedbar-tag-personality voice-monotone
-  "Personality used for speedbar tags"
-  :type 'symbol
-  :group 'emacspeak-speedbar)
+(defvar emacspeak-speedbar-tag-personality voice-monotone-extra
+  "Personality used for speedbar tags")
 
-(defcustom emacspeak-speedbar-default-personality 'paul
-  "Default personality used in speedbar buffers"
-  :type 'symbol
-  :group 'emacspeak-speedbar)
+(defvar emacspeak-speedbar-default-personality 'paul
+  "Default personality used in speedbar buffers")
 
 (defadvice speedbar-make-button (after emacspeak pre act comp)
   "Voiceify the button"
@@ -331,9 +299,8 @@ An automatically updating speedbar consumes resources.")
 (provide 'emacspeak-speedbar)
 ;;{{{ end of file 
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end: 
+;; local variables:
+;; folded-file: t
+;; end: 
 
 ;;}}}
