@@ -1,62 +1,144 @@
-;;; emacspeak-table-ui.el --- Emacspeak's current notion of an ideal table UI  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $
-;;; Description: Emacspeak table handling module
-;;; Keywords:emacspeak, audio interface to emacs tables are structured
-;;{{{  LCD Archive entry:
-
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2008-06-26 15:46:49 -0700 (Thu, 26 Jun 2008) $ |
-;;;  $Revision: 4532 $ |
-;;; Location undetermined
-;;;
-
-;;}}}
+;;; emacspeak-table-ui.el --- Table Navigation UI  -*- lexical-binding: t; -*-
+;; $Author: tv.raman.tv $
+;; Description:  Emacspeak Table Navigation UI
+;; Keywords: Emacspeak, Table UI ,  Visual layout gives structure
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2017, T. V. Raman
-;;; Copyright (c) 1995 by T. V. Raman
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; Copyright (c) 1995 by T. V. Raman
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
 
 ;;{{{  Introduction
 
 ;;; Commentary:
-;;; User interface to tables
+;; User interface to tables
 ;;; Code:
 
 ;;}}}
 ;;{{{ requires
-
+(require 'cl-lib)
 (cl-declaim  (optimize  (safety 0) (speed 3)))
+(eval-when-compile
+  (require 'derived))
 (require 'emacspeak-preamble)
 (require 'emacspeak-table)
 
 ;;}}}
 ;;{{{  emacspeak table mode
 
-(defvar emacspeak-table-keymap (make-sparse-keymap)
-  "Keymap for using in table browsing mode")
-;;; emacspeak-table-submap makes these available globally.
+;; emacspeak-table-submap makes these available globally.
+;; Forward declaration
+
+(define-derived-mode  emacspeak-table-mode  special-mode
+  "Table Navigation On The Emacspeak Audio Desktop"
+  "Major mode for browsing tables.
+Table mode is designed to allow speech users to browse tabular
+data with full contextual feedback while retaining all the power
+of the two-dimensional spatial layout of tables.
+
+In table mode, the arrow keys move between cells of the table.
+Emacspeak speaks the cell contents in a user-customizable way.  The
+visual display is kept in sync with the speech you hear; however
+Emacspeak is examining the entire table in order to speak the current
+cell content intelligently.
+
+You can interactively specify that emacspeak should speak either the row or
+column header (or both) while speaking each cell.  You can also specify a row
+or column filter that should be applied when speaking entire rows or columns
+--this lets you view slices of a table.  You can move to a specific row or
+column by searching the cell contents or by searching the row or column
+headers to locate items of interest.
+
+Here is a short description of the special commands provided in this mode.
+
+The next four commands help you move to the edges of the table:
+
+E               emacspeak-table-goto-right
+A               emacspeak-table-goto-left
+B               emacspeak-table-goto-bottom
+T               emacspeak-table-goto-top
+
+The next two commands let you search the table.
+The commands ask you if you want to search rows or columns.
+When searching headers remember that row 0 is the column header,
+and that column 0 is the row header.
+
+h               emacspeak-table-search-headers
+s               emacspeak-table-search
+
+The next command lets you specify how cell contents should be spoken.  Specify
+one of: `b' for both, `c' for column, `r' for row, `f' for row filtering and
+`g' for column filtering. --table cells with then be spoken with both (or
+either)row and column headers, or with the filter applied.
+
+a               emacspeak-table-select-automatic-speaking-method
+
+The next set of commands speak the current table cell:
+
+.               emacspeak-table-speak-coordinates
+b               emacspeak-table-speak-both-headers-and-element
+SPC             emacspeak-table-speak-current-element
+c               emacspeak-table-speak-column-header-and-element
+r               e macspeak-table-speak-row-header-and-element
+
+The next set of commands navigate the table:
+
+right               emacspeak-table-next-column
+left               emacspeak-table-previous-column
+down               emacspeak-table-next-row
+up               emacspeak-table-previous-row
+j               emacspeak-table-goto
+S-tab               emacspeak-table-previous-column
+TAB               emacspeak-table-next-column
+
+Row and Column Filtering
+
+Filtering is designed to let you view slices of a table.
+They are specified as lists of numbers and strings.
+The concept is best explained with an example.
+
+A row filter specifies which of the entries in the current row should be
+spoken.Entries are numbered starting with 0.  Thus, when working with a table
+having 8 columns, a row filter of (1 2 3) will speak only entries 1 2 and 3.
+Use the sample tables in etc/tables   to familiarize yourself with this
+feature. Note that you can intersperse meaningful strings in the list that
+specifies the filter.
+
+Full List Of Keybindings:
+\\{emacspeak-table-mode-map}"
+  (set (make-local-variable 'voice-lock-mode) t)
+  (put-text-property (point-min) (point-max)
+                     'point-entered 'emacspeak-table-point-motion-hook)
+  (set-buffer-modified-p nil)
+  (setq buffer-undo-list t)
+  (setq buffer-read-only t)
+  (emacspeak-auditory-icon 'select-object)
+  (emacspeak-speak-mode-line))
 
 (cl-loop
  for binding in
@@ -107,108 +189,15 @@
    ("x" emacspeak-table-copy-current-element-to-register)
    )
  do
- (emacspeak-keymap-update emacspeak-table-keymap binding)
+ (emacspeak-keymap-update emacspeak-table-mode-map binding)
  (emacspeak-keymap-update emacspeak-table-submap binding))
 
-(defun emacspeak-table-mode ()
-  "Major mode for browsing tables.
-Table mode is designed to allow speech users to browse tabular data
-with full contextual feedback while retaining all the power of the
-two-dimensional spatial layout of tables.
-
-In table mode, the arrow keys move between cells of the table.
-Emacspeak speaks the cell contents in a user-customizable way.  The
-visual display is kept in sync with the speech you hear; however
-Emacspeak is examining the entire table in order to speak the current
-cell content intelligently.
-
-You can interactively specify that emacspeak should speak either the row or
-column header (or both) while speaking each cell.  You can also specify a row
-or column filter that should be applied when speaking entire rows or columns
---this lets you view slices of a table.  You can move to a specific row or
-column by searching the cell contents or by searching the row or column
-headers to locate items of interest.
-
-Here is a short description of the special commands provided in this mode.
-
-The next four commands help you move to the edges of the table:
-
-E               emacspeak-table-goto-right
-A               emacspeak-table-goto-left
-B               emacspeak-table-goto-bottom
-T               emacspeak-table-goto-top
-
-The next two commands let you search the table.
-The commands ask you if you want to search rows or columns.
-When searching headers remember that row 0 is the column header, and that column 0 is the row header.
-
-h               emacspeak-table-search-headers
-s               emacspeak-table-search
-
-The next command lets you specify how cell contents should be spoken.  Specify
-one of: `b' for both, `c' for column, `r' for row, `f' for row filtering and
-`g' for column filtering. --table cells with then be spoken with both (or
-either)row and column headers, or with the filter applied.
-
-a               emacspeak-table-select-automatic-speaking-method
-
-The next set of commands speak the current table cell:
-
-.               emacspeak-table-speak-coordinates
-b               emacspeak-table-speak-both-headers-and-element
-SPC             emacspeak-table-speak-current-element
-c               emacspeak-table-speak-column-header-and-element
-r               e macspeak-table-speak-row-header-and-element
-
-The next set of commands navigate the table:
-
-right               emacspeak-table-next-column
-left               emacspeak-table-previous-column
-down               emacspeak-table-next-row
-up               emacspeak-table-previous-row
-j               emacspeak-table-goto
-S-tab               emacspeak-table-previous-column
-TAB               emacspeak-table-next-column
-
-Row and Column Filtering
-
-Filtering is designed to let you view slices of a table.
-They are specified as lists of numbers and strings.
-The concept is best explained with an example.
-
-A row filter specifies which of the entries in the current row should be
-spoken.Entries are numbered starting with 0.  Thus, when working with a table
-having 8 columns, a row filter of (1 2 3) will speak only entries 1 2 and 3.
-Use the sample tables in etc/tables   to familiarize yourself with this
-feature. Note that you can intersperse meaningful strings in the list that
-specifies the filter.
-
-Full List Of Keybindings:
-\\{emacspeak-table-keymap}"
-  (cl-declare (special emacspeak-table-keymap))
-  (use-local-map emacspeak-table-keymap)
-  (set (make-local-variable 'voice-lock-mode) t)
-  (setq major-mode 'emacspeak-table-mode
-        mode-name "table")
-  (put-text-property
-   (point-min)
-   (point-max)
-   'point-entered
-   'emacspeak-table-point-motion-hook)
-  (not-modified)
-  (setq buffer-undo-list t)
-  (setq buffer-read-only t)
-  (emacspeak-auditory-icon 'select-object)
-  (emacspeak-speak-mode-line))
-
-;;; Inherit from 'special-mode:
-(put 'emacspeak-table-mode  'derived-mode-parent 'special-mode)
 ;;}}}
 ;;{{{  speaking current entry
 
 (defun emacspeak-table-synchronize-display ()
   "Bring visual display in sync with internal representation"
-  (cl-declare (special emacspeak-table positions))
+  (cl-declare (special emacspeak-table ems--positions))
   (let ((row (emacspeak-table-current-row emacspeak-table))
         (column (emacspeak-table-current-column emacspeak-table))
         (width (frame-width)))
@@ -217,7 +206,7 @@ Full List Of Keybindings:
       (gethash
        (intern
         (format "element:%s:%s" row column))
-       positions)
+       ems--positions)
       (point)))
     (scroll-left (- (current-column)
                     (+ (/ width  2)
@@ -227,7 +216,7 @@ Full List Of Keybindings:
   "Speak current table coordinates."
   (interactive)
   (cl-declare (special emacspeak-table))
-  (assert  (boundp 'emacspeak-table) nil "No table here")
+  (cl-assert  (boundp 'emacspeak-table) nil "No table here")
   (message "Row %s Column %s"
            (emacspeak-table-current-row emacspeak-table)
            (emacspeak-table-current-column emacspeak-table)))
@@ -236,7 +225,7 @@ Full List Of Keybindings:
   "Speak current table dimensions."
   (interactive)
   (cl-declare (special emacspeak-table))
-  (assert  (boundp 'emacspeak-table) nil "No table here")
+  (cl-assert  (boundp 'emacspeak-table) nil "No table here")
   (message "%s by %s table"
            (emacspeak-table-num-rows emacspeak-table)
            (emacspeak-table-num-columns emacspeak-table)))
@@ -245,7 +234,7 @@ Full List Of Keybindings:
   "Speak current table element"
   (interactive)
   (cl-declare (special emacspeak-table))
-  (assert  (boundp 'emacspeak-table) nil "No table here")
+  (cl-assert  (boundp 'emacspeak-table) nil "No table here")
   (dtk-speak-and-echo
    (format "%s" (emacspeak-table-current-element emacspeak-table))))
 
@@ -253,7 +242,7 @@ Full List Of Keybindings:
   "Speak  row header and table element"
   (interactive)
   (cl-declare (special emacspeak-table))
-  (assert  (boundp 'emacspeak-table) nil "No table here")
+  (cl-assert  (boundp 'emacspeak-table) nil "No table here")
   (let ((element (emacspeak-table-current-element emacspeak-table))
         (head
          (format
@@ -270,7 +259,7 @@ Full List Of Keybindings:
   "Speak  column header and table element"
   (interactive)
   (cl-declare (special emacspeak-table))
-  (assert  (boundp 'emacspeak-table) nil "No table here")
+  (cl-assert  (boundp 'emacspeak-table) nil "No table here")
   (let ((head
          (format
           "%s"
@@ -287,7 +276,7 @@ Full List Of Keybindings:
   "Speak  both row and column header and table element"
   (interactive)
   (cl-declare (special emacspeak-table))
-  (assert  (boundp 'emacspeak-table) nil "No table here")
+  (cl-assert  (boundp 'emacspeak-table) nil "No table here")
   (let ((element (emacspeak-table-current-element emacspeak-table))
         (col-head
          (format
@@ -312,7 +301,7 @@ Full List Of Keybindings:
 (defun emacspeak-table-get-entry-with-headers  (row column &optional row-head-p col-head-p)
   "Return table element. Optional args specify  if we return any headers."
   (cl-declare (special emacspeak-table))
-  (assert  (boundp 'emacspeak-table) nil "No table here")
+  (cl-assert  (boundp 'emacspeak-table) nil "No table here")
   (let ((col-head nil)
         (row-head nil))
     (when row-head-p
@@ -339,7 +328,7 @@ Full List Of Keybindings:
 (make-variable-buffer-local 'emacspeak-table-speak-row-filter)
 
 (defun emacspeak-table-handle-row-filter-token  (token)
-  "Handle a single token in an Emacspeak table row/column formater."
+  "Handle a single token in an Emacspeak table row/column formatter."
   (let ((value nil))
     (cond
      ((stringp token) (format "%s" token))
@@ -357,11 +346,11 @@ Full List Of Keybindings:
              (cl-first token) (cl-second token)))
       (put-text-property 0 (length value) 'face 'bold value)
       value)
-     ((and (symbolp (cl-first token)) (fboundp  (first token)))
-;;; applying a function:
+     ((and (symbolp (cl-first token)) (fboundp  (cl-first token)))
+      ;; applying a function:
       (setq value
             (funcall
-             (cl-first token) ;;; get args 
+             (cl-first token) ;;; get args
              (cond
               ((and
                 (= 2 (length token)) (numberp (cl-second token)))
@@ -422,11 +411,11 @@ Optional prefix arg prompts for a new filter."
            (numberp (cl-first token))
            (numberp (cl-second token)))
       (emacspeak-table-get-entry-with-headers (cl-first token) (cl-second token)))
-     ((and (symbolp (cl-first token)) (fboundp  (first token)))
-;;; applying a function:
+     ((and (symbolp (cl-first token)) (fboundp  (cl-first token)))
+      ;; applying a function:
       (setq value
             (funcall
-             (cl-first token) ;;; get args 
+             (cl-first token) ;;; get args
              (cond
               ((and
                 (= 2 (length token)) (numberp (cl-second token)))
@@ -440,14 +429,14 @@ Optional prefix arg prompts for a new filter."
                (emacspeak-table-get-entry-with-headers
                 (cl-second token) (cl-third token))))))
       (put-text-property 0 (length value) 'face 'bold  value)
-      value)   
+      value)
      (t  (format "%s" token)))))
 (defun emacspeak-table-speak-column-filtered  (&optional prefix)
   "Speaks a table column after applying a specified column filter.
 Optional prefix arg prompts for a new filter."
   (interactive "P")
   (cl-declare (special emacspeak-table-speak-column-filter
-                    emacspeak-table))
+                       emacspeak-table))
   (unless (and  emacspeak-table-speak-column-filter
                 (listp emacspeak-table-speak-column-filter)
                 (not prefix))
@@ -491,11 +480,12 @@ Optional prefix arg prompts for a new filter."
     (skip-chars-backward "^,\n")))
 
 ;;}}}
-
-(defun emacspeak-table-prepare-table-buffer (table buffer &optional filename)
+;;;###autoload
+(defun emacspeak-table-prepare-table-buffer (table buffer)
   "Prepare tabular data."
-  (cl-declare (special emacspeak-table positions))
+  (cl-declare (special emacspeak-table ems--positions))
   (with-current-buffer buffer
+    (emacspeak-table-mode)
     (let ((i 0)
           (j 0)
           (count 0)
@@ -506,17 +496,16 @@ Optional prefix arg prompts for a new filter."
       (setq buffer-undo-list t)
       (erase-buffer)
       (set (make-local-variable 'emacspeak-table) table)
-      (set (make-local-variable 'positions) (make-hash-table))
-      (when filename (setq buffer-file-name filename))
+      (set (make-local-variable 'ems--positions) (make-hash-table))
       (setq count (1-  (emacspeak-table-num-columns table)))
       (cl-loop
        for row across (emacspeak-table-elements table) do
        (cl-loop
         for _element across row do
         (puthash
-         (intern (format "element:%s:%s" i j))  ; compute key 
-         (point) ; insertion point  is the value 
-         positions)
+         (intern (format "element:%s:%s" i j))  ; compute key
+         (point) ; insertion point  is the value
+         ems--positions)
         (insert
          (format "%s%s"
                  (emacspeak-table-this-element table i j)
@@ -530,8 +519,7 @@ Optional prefix arg prompts for a new filter."
        (setq j 0)
        (put-text-property row-start (point) 'row i)
        (setq row-start (point))
-       (cl-incf i))
-      (emacspeak-table-mode)))
+       (cl-incf i))))
   (switch-to-buffer buffer)
   (emacspeak-table-goto-cell emacspeak-table 0 0)
   (setq truncate-lines t)
@@ -548,7 +536,7 @@ CalTrain schedules.  Execute command `describe-mode' bound to
 \\[describe-mode] in a buffer that is in emacspeak table mode to read
 the documentation on the table browser."
   (interactive "FEnter filename containing table data: ")
-  (cl-declare (special positions))
+  (cl-declare (special ems--positions))
   (let ((buffer (get-buffer-create (format  "*%s*"
                                             (file-name-nondirectory filename))))
         (data nil)
@@ -556,7 +544,7 @@ the documentation on the table browser."
     (setq data (find-file-noselect filename))
     (setq table (emacspeak-table-make-table (read data)))
     (kill-buffer data)
-    (emacspeak-table-prepare-table-buffer table buffer filename)))
+    (emacspeak-table-prepare-table-buffer table buffer)))
 
 (defun ems-csv-get-fields ()
   "Return list of fields on this line."
@@ -606,7 +594,7 @@ The processed  data is  presented using emacspeak table navigation. "
       (set-buffer scratch)
       (setq buffer-undo-list t)
       (erase-buffer)
-      (insert-buffer buffer-name)
+      (insert-buffer-substring buffer-name)
       (goto-char (point-min))
       (flush-lines "^ *$")
       (goto-char (point-min))
@@ -618,29 +606,38 @@ The processed  data is  presented using emacspeak table navigation. "
                (setq fields (ems-csv-get-fields))
                (aset elements i (apply 'vector fields))
                (forward-line 1))
-      (setq table (emacspeak-table-make-table elements))  
+      (setq table (emacspeak-table-make-table elements))
       )
     (kill-buffer scratch)
     (emacspeak-table-prepare-table-buffer table buffer)
     (emacspeak-auditory-icon 'open-object)))
 
-(defun emacspeak-table-view-csv-url  (url)
+(defun emacspeak-table-render-csv-url  (_status result-buffer)
+  "Render the result of asynchronously retrieving CSV data from url."
+  (let ((inhibit-read-only t)
+        (data-buffer (current-buffer))
+        (coding-system-for-read 'utf-8)
+        (coding-system-for-write 'utf-8))
+    (with-current-buffer data-buffer
+      (goto-char (point-min))
+      (search-forward "\n\n")
+      (delete-region (point-min) (point))
+      (decode-coding-region (point-min) (point-max) 'utf-8)
+      (emacspeak-table-view-csv-buffer)
+      (rename-buffer result-buffer 'unique)
+      (emacspeak-speak-mode-line)
+      (emacspeak-auditory-icon 'open-object))))
+
+;;;###autoload
+(defun emacspeak-table-view-csv-url  (url &optional buffer-name)
   "Process a csv (comma separated values) data at  `URL'.
 The processed  data is  presented using emacspeak table navigation. "
-  (interactive "sURL:")
+  (interactive "sURL:\nP")
+  (unless (or buffer-name (stringp buffer-name))
+    (setq buffer-name "CSV Data Table"))
   (cl-declare (special g-curl-program g-curl-common-options))
-  (let ((data (get-buffer-create " *csv-data*")))
-    (with-current-buffer data
-      (erase-buffer)
-      (setq buffer-undo-list t)
-      (insert
-       (shell-command-to-string
-       (format "%s %s '%s'"
-               g-curl-program"--silent" url)))
-      (goto-char (point-min))
-      (emacspeak-table-view-csv-buffer))))
-    
-  
+  (url-retrieve url #'emacspeak-table-render-csv-url  (list buffer-name)))
+
 ;;}}}
 ;;{{{ Processing a region of tabular data
 ;;;###autoload
@@ -655,7 +652,7 @@ CalTrain schedules.  Execute command `describe-mode' bound to
 \\[describe-mode] in a buffer that is in emacspeak table mode to read
 the documentation on the table browser."
   (interactive "r")
-  (cl-declare (special emacspeak-table positions))
+  (cl-declare (special emacspeak-table ems--positions))
   (let ((buffer-undo-list t)
         (workspace (get-buffer-create " table workspace  "))
         (buffer (get-buffer-create
@@ -679,15 +676,15 @@ the documentation on the table browser."
       (flush-lines "^ *$")
       (setq table (emacspeak-table-make-table
                    (ems-tabulate-parse-region
-                    (point-min)
-                    (point-max)))))
+                    (point-min) (point-max)))))
     (kill-buffer workspace)
     (save-current-buffer
       (set-buffer buffer)
+      (emacspeak-table-mode)
       (let ((inhibit-read-only t))
         (erase-buffer)
         (set (make-local-variable 'emacspeak-table) table)
-        (set (make-local-variable 'positions) (make-hash-table))
+        (set (make-local-variable 'ems--positions) (make-hash-table))
         (setq count (1-  (emacspeak-table-num-columns table)))
         (cl-loop for row across (emacspeak-table-elements table)
                  do
@@ -696,7 +693,7 @@ the documentation on the table browser."
                           (setf
                            (gethash
                             (intern (format "element:%s:%s" i j))
-                            positions)
+                            ems--positions)
                            (point))
                           (insert
                            (format "%s%s"
@@ -712,7 +709,6 @@ the documentation on the table browser."
                  (put-text-property row-start (point) 'row i)
                  (setq row-start (point))
                  (cl-incf i))
-        (emacspeak-table-mode)
         (goto-char (point-min))))
     (switch-to-buffer buffer)
     (rename-buffer
@@ -738,15 +734,15 @@ browsing table elements"
   (let ((key (read-char)))
     (setq emacspeak-table-speak-element
           (cl-case  key
-                 (?b 'emacspeak-table-speak-both-headers-and-element)
-                 (?c 'emacspeak-table-speak-column-header-and-element)
-                 (?r 'emacspeak-table-speak-row-header-and-element)
-                 (?d 'emacspeak-table-speak-current-element)
-                 (?f 'emacspeak-table-speak-row-filtered)
-                 (?g 'emacspeak-table-speak-column-filtered)
-                 (?. 'emacspeak-table-speak-coordinates)
-                 (otherwise (message "Invalid method specified")
-                            emacspeak-table-speak-element)))
+            (?b 'emacspeak-table-speak-both-headers-and-element)
+            (?c 'emacspeak-table-speak-column-header-and-element)
+            (?r 'emacspeak-table-speak-row-header-and-element)
+            (?d 'emacspeak-table-speak-current-element)
+            (?f 'emacspeak-table-speak-row-filtered)
+            (?g 'emacspeak-table-speak-column-filtered)
+            (?. 'emacspeak-table-speak-coordinates)
+            (otherwise (message "Invalid method specified")
+                       emacspeak-table-speak-element)))
     (emacspeak-auditory-icon 'button)))
 
 ;;}}}
@@ -758,45 +754,41 @@ browsing table elements"
 
 (make-variable-buffer-local 'emacspeak-table-speak-element)
 
-;;;###autoload
 (defun emacspeak-table-next-row (&optional count)
   "Move to the next row if possible"
   (interactive "p")
   (cl-declare (special emacspeak-table))
-  (assert  (boundp 'emacspeak-table) nil "No table here")
+  (cl-assert  (boundp 'emacspeak-table) nil "No table here")
   (setq count (or count 1))
   (emacspeak-table-move-down emacspeak-table count)
   (emacspeak-table-synchronize-display)
   (funcall emacspeak-table-speak-element))
 
-;;;###autoload
 (defun emacspeak-table-previous-row (&optional count)
   "Move to the previous row if possible"
   (interactive "p")
   (cl-declare (special emacspeak-table))
-  (assert  (boundp 'emacspeak-table) nil "No table here")
+  (cl-assert  (boundp 'emacspeak-table) nil "No table here")
   (setq count (or count 1))
   (emacspeak-table-move-up emacspeak-table count)
   (emacspeak-table-synchronize-display)
   (funcall emacspeak-table-speak-element))
 
-;;;###autoload
 (defun emacspeak-table-next-column (&optional count)
   "Move to the next column if possible"
   (interactive "p")
   (cl-declare (special emacspeak-table))
-  (assert  (boundp 'emacspeak-table) nil "No table here")
+  (cl-assert  (boundp 'emacspeak-table) nil "No table here")
   (setq count (or count 1))
   (emacspeak-table-move-right emacspeak-table count)
   (emacspeak-table-synchronize-display)
   (funcall emacspeak-table-speak-element))
 
-;;;###autoload
 (defun emacspeak-table-previous-column (&optional count)
   "Move to the previous column  if possible"
   (interactive "p")
   (cl-declare (special emacspeak-table))
-  (assert  (boundp 'emacspeak-table) nil "No table here")
+  (cl-assert  (boundp 'emacspeak-table) nil "No table here")
   (setq count (or count 1))
   (emacspeak-table-move-left emacspeak-table count)
   (emacspeak-table-synchronize-display)
@@ -806,7 +798,7 @@ browsing table elements"
   "Prompt for a table cell coordinates and jump to it."
   (interactive "nRow:\nNColumn:")
   (cl-declare (special emacspeak-table))
-  (assert  (boundp 'emacspeak-table) nil "No table here")
+  (cl-assert  (boundp 'emacspeak-table) nil "No table here")
   (emacspeak-table-goto-cell emacspeak-table row column)
   (emacspeak-table-synchronize-display)
   (funcall emacspeak-table-speak-element)
@@ -816,7 +808,7 @@ browsing table elements"
   "Goes to the top of the current column."
   (interactive)
   (cl-declare (special emacspeak-table))
-  (assert  (boundp 'emacspeak-table) nil "No table here")
+  (cl-assert  (boundp 'emacspeak-table) nil "No table here")
   (emacspeak-table-goto-cell
    emacspeak-table
    0 (emacspeak-table-current-column emacspeak-table))
@@ -828,10 +820,10 @@ browsing table elements"
   "Goes to the bottom of the current column."
   (interactive)
   (cl-declare (special emacspeak-table))
-  (assert  (boundp 'emacspeak-table) nil "No table here")
+  (cl-assert  (boundp 'emacspeak-table) nil "No table here")
   (emacspeak-table-goto-cell
    emacspeak-table
-   
+
    (1- (emacspeak-table-num-rows emacspeak-table))
    (emacspeak-table-current-column
     emacspeak-table))
@@ -843,7 +835,7 @@ browsing table elements"
   "Goes to the left of the current row."
   (interactive)
   (cl-declare (special emacspeak-table))
-  (assert  (boundp 'emacspeak-table) nil "No table here")
+  (cl-assert  (boundp 'emacspeak-table) nil "No table here")
   (emacspeak-table-goto-cell
    emacspeak-table
    (emacspeak-table-current-row emacspeak-table) 0)
@@ -855,7 +847,7 @@ browsing table elements"
   "Goes to the right of the current row."
   (interactive)
   (cl-declare (special emacspeak-table))
-  (assert  (boundp 'emacspeak-table) nil "No table here")
+  (cl-assert  (boundp 'emacspeak-table) nil "No table here")
   (emacspeak-table-goto-cell
    emacspeak-table
    (emacspeak-table-current-row emacspeak-table)
@@ -874,7 +866,7 @@ the matching cell current. When called from a program, `what' can
   be either `row' or `column'."
   (interactive "P")
   (cl-declare (special emacspeak-table))
-  (assert  (boundp 'emacspeak-table) nil "No table here")
+  (cl-assert  (boundp 'emacspeak-table) nil "No table here")
   (message "Search   in: r row c column")
   (let* ((row (emacspeak-table-current-row emacspeak-table))
          (column (emacspeak-table-current-column emacspeak-table))
@@ -882,9 +874,9 @@ the matching cell current. When called from a program, `what' can
          (slice
           (or what
               (cl-case (read-char)
-                    (?r 'row)
-                    (?c 'column)
-                    (otherwise (error "Can only search in either row or column")))))
+                (?r 'row)
+                (?c 'column)
+                (otherwise (error "Can only search in either row or column")))))
          (pattern
           (read-string
            (format "Search in current  %s for: " slice))))
@@ -926,20 +918,26 @@ row or column to search and pattern to look for.  If there is a
 match, makes the matching row or column current."
   (interactive)
   (cl-declare (special emacspeak-table))
-  (assert  (boundp 'emacspeak-table) nil "No table here")
+  (cl-assert  (boundp 'emacspeak-table) nil "No table here")
   (message
    "Search headers : r row c column")
   (let* ((row (emacspeak-table-current-row emacspeak-table))
          (column (emacspeak-table-current-column emacspeak-table))
          (found nil)
          (slice
-          (cl-case (read-char)
-                (?r 'row)
-                (?c 'column)
-                (otherwise (error "Can only search in either row or column"))))
+          (cl-case (read-char "Search headers : r row c column")
+            (?r 'row)
+            (?c 'column)
+            (otherwise (error "Can only search in either row or column"))))
          (pattern
-          (read-string
-           (format "Search %s headers for: " slice))))
+          (completing-read
+           (format "Search %s headers for: " slice)
+           (cond
+            ((eq slice 'row)
+             (append (emacspeak-table-row-header emacspeak-table) nil))
+            ((eq slice 'column)
+             (append (emacspeak-table-column-header emacspeak-table) nil)))
+           nil 'must-match)))
     (cond
      ((eq slice 'row)
       (setq found
@@ -969,27 +967,25 @@ match, makes the matching row or column current."
   "Copy current table element to kill ring."
   (interactive)
   (cl-declare (special emacspeak-table))
-  (assert  (boundp 'emacspeak-table) nil "No table here")
+  (cl-assert  (boundp 'emacspeak-table) nil "No table here")
   (kill-new  (emacspeak-table-current-element emacspeak-table))
-  (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'delete-object)
+  (when (called-interactively-p 'interactive) 
+    (emacspeak-auditory-icon 'yank-object)
     (message "Copied element to kill ring")))
 (defun emacspeak-table-copy-current-element-to-register (register)
   "Copy current table element to specified register."
   (interactive (list (register-read-with-preview "Copy to register: ")))
   (cl-declare (special emacspeak-table))
-  (assert  (boundp 'emacspeak-table) nil "No table here")
+  (cl-assert  (boundp 'emacspeak-table) nil "No table here")
   (set-register register (emacspeak-table-current-element
                           emacspeak-table))
-  (when (ems-interactive-p)
+  (when (called-interactively-p 'interactive)
     (emacspeak-auditory-icon 'select-object)
     (message "Copied element to register %c" register)))
-
-(emacspeak-fix-interactive-command-if-necessary 'emacspeak-table-copy-current-element-to-register)
-
-;;; Implementing table editing and table clipboard.
+;;}}}
 ;;{{{ variables
 
+;; Implementing table editing and table clipboard.
 (defvar emacspeak-table-clipboard nil
   "Variable to hold table copied to the clipboard.")
 
@@ -997,8 +993,8 @@ match, makes the matching row or column current."
 ;;{{{  define table markup structure and accessors
 
 (cl-defstruct (emacspeak-table-markup
-            (:constructor
-             emacspeak-table-make-markup))
+               (:constructor
+                emacspeak-table-make-markup))
   table-start
   table-end
   row-start
@@ -1044,18 +1040,6 @@ table markup.")
                                    :col-start ""
                                    :col-end ""
                                    :col-separator " & "))
-
-
-(emacspeak-table-markup-set-table
- 'org-mode
- (emacspeak-table-make-markup
-  :table-start "|-|\n"
-  :table-end "|-|\n"
-  :row-start "|"
-  :row-end "|\n"
-  :col-start ""
-  :col-end ""
-  :col-separator " | "))
 (emacspeak-table-markup-set-table 'latex-mode
                                   (emacspeak-table-markup-get-table
                                    'latex2e-mode))
@@ -1085,8 +1069,8 @@ table markup.")
                                    :table-end ""
                                    :row-start ""
                                    :row-end "\n"
-                                   :col-start ""
-                                   :col-end ""
+                                   :col-start "\""
+                                   :col-end "\""
                                    :col-separator ", "))
 
 (emacspeak-table-markup-set-table 'text-mode
@@ -1103,14 +1087,14 @@ table markup.")
 
 ;;}}}
 ;;{{{ copy and paste tables
-;;;###autoload
+
 (defun emacspeak-table-copy-to-clipboard ()
   "Copy table in current buffer to the table clipboard.
 Current buffer must be in emacspeak-table mode."
   (interactive)
   (cl-declare (special emacspeak-table-clipboard emacspeak-table))
-  (assert (eq   major-mode 'emacspeak-table-mode)  nil "Not in table mode.")
-  (assert  (boundp 'emacspeak-table) nil "No table here")
+  (cl-assert (eq   major-mode 'emacspeak-table-mode)  nil "Not in table mode.")
+  (cl-assert  (boundp 'emacspeak-table) nil "No table here")
   (setq emacspeak-table-clipboard emacspeak-table)
   (message "Copied current table to emacspeak table clipboard."))
 
@@ -1158,8 +1142,6 @@ markup to use."
                     (insert (format "%s" col-separator)))))              (insert (format "%s" row-end)))
       (insert (format "%s" table-end))))))
 
-;;}}}
-
 ;;}}}
 ;;{{{  table sorting:
 
@@ -1167,8 +1149,8 @@ markup to use."
   "Sort table on current column. "
   (interactive)
   (cl-declare (special major-mode emacspeak-table
-                    emacspeak-table-speak-row-filter))
-  (assert (eq major-mode  'emacspeak-table-mode) nil "Not in table mode.")
+                       emacspeak-table-speak-row-filter))
+  (cl-assert (eq major-mode  'emacspeak-table-mode) nil "Not in table mode.")
   (let* ((column  (emacspeak-table-current-column emacspeak-table))
          (row-head   nil)
          (row-filter emacspeak-table-speak-row-filter)
@@ -1241,12 +1223,12 @@ future  use."
   (interactive
    (list
     (read-file-name "Load filter settings  from file: "
-                    emacspeak-resource-directory
+                    emacspeak-user-directory
                     ".table-ui-filter")))
   (condition-case nil
       (progn
         (load
-         (expand-file-name  file emacspeak-resource-directory)))
+         (expand-file-name  file emacspeak-user-directory)))
     (error (message "Error loading resources from %s "
                     file))))
 
@@ -1255,12 +1237,12 @@ future  use."
   (interactive
    (list
     (read-file-name "Save table-ui-filter settings  to file: "
-                    emacspeak-resource-directory
+                    emacspeak-user-directory
                     ".table-ui-filter")))
-  (cl-declare (special emacspeak-resource-directory))
+  (cl-declare (special emacspeak-user-directory))
   (let ((buffer (find-file-noselect
                  (expand-file-name file
-                                   emacspeak-resource-directory))))
+                                   emacspeak-user-directory))))
     (save-current-buffer
       (set-buffer buffer)
       (erase-buffer)
@@ -1282,9 +1264,8 @@ future  use."
 (provide  'emacspeak-table-ui)
 ;;{{{  emacs local variables
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
