@@ -1,47 +1,47 @@
 ;;; emacspeak-tabulate.el --- Interpret tabulated information as a table  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $ 
-;;; Description:  Utility to help emacspeak identify tabulated information
-;;; Keywords: Emacspeak, Tabulated Data,  Visual layout gives structure
+;;
+;; $Author: tv.raman.tv $ 
+;; Description:  Utility to help emacspeak identify tabulated information
+;; Keywords: Emacspeak, Tabulated Data,  Visual layout gives structure
 ;;{{{  LCD Archive entry: 
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
-;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
-;;;  $Revision: 4532 $ | 
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com 
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ | 
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman 
-;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved. 
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman 
+;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
+;; All Rights Reserved. 
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
 
 
 ;;{{{  Introduction:
 ;;; Commentary:
-;;; This module is a simple table recognizer.
-;;; Can recognize the columns in tabulated output, e.g. ps, ls output
+;; This module is a simple table recognizer.
+;; Can recognize the columns in tabulated output, e.g. ps, ls output
 ;;; Code:
 ;;}}}
 ;;{{{ requires
@@ -51,7 +51,7 @@
 ;;}}}
 ;;{{{  helper functions:
 
-;;; An interval is a cons of start and end 
+;; An interval is a cons of start and end 
 (defun ems-make-interval (start end) (cons start end))
 (defun ems-interval-start (interval) (car interval))
 (defun ems-interval-end (interval) (cdr interval))
@@ -140,77 +140,12 @@ Fields are assumed to be delimited by whitespace. "
                 new-guesses nil))
         guesses))))
 
-(defun ems-tabulate-process-column (tl tr br _bl mark-headers start)
-  (let ((header (buffer-substring  tl tr))
-        (personality-table (emacspeak-possible-voices)))
-    (emacspeak-voiceify-rectangle
-     tl br 
-     (intern (completing-read
-              (format "Personality for column %s from  %s through %s"
-                      header (- tl start) (- tr start))
-              personality-table  nil t)))
-    (and mark-headers
-         (emacspeak-put-text-property-on-rectangle
-          tl br
-          'field-name header))))
-
-;;;  White space contains a list of intervals giving position of inter
-;;;  columnal space. All calculations are done in terms of buffer
-;;;  position.
-;;; Invariants: (= (- tl tr) (- bl br))
-;;; tl = start for first column
-;;; br = end for last column
-;;;###autoload
-(defun emacspeak-tabulate-region (start end  &optional mark-fields)
-  "Voicifies the white-space of a table if one found.  Optional interactive prefix
-arg mark-fields specifies if the header row information is used to mark fields
-in the white-space."
-  (interactive "r\nP")
-  (let ((white-space   (ems-tabulate-field-separators-in-region start end))
-        (dtk-stop-immediately nil)
-        (width nil)
-        (tl nil)
-        (tr nil)
-        (br nil)
-        (bl nil))
-    (with-silent-modifications
-      (progn
-        (message   "Detected %s rows and  %s columns."
-                   (count-lines start end)
-                   (+ 1 (length white-space)))
-        (sit-for 1.5)
-        (save-excursion
-          (goto-char end)
-          (beginning-of-line)
-          (setq bl  (point))
-          (setq tl  start)
-                                        ;(goto-char tl)
-          (setq width   (ems-interval-start (car white-space)))
-          (setq tr (+ tl width)
-                br (+ bl width))
-          (ems-tabulate-process-column tl tr br bl mark-fields start)
-          (while white-space
-                                        ;move to beginning of next column
-            (goto-char (+ start (ems-interval-end (car white-space))))
-            (setq tl (point))
-                                        ; width of space between columns 
-            (setq width (- tl tr))
-            (setq bl (+ br width))
-            (setq white-space (cdr white-space))
-                                        ;Now detect right edges of this column 
-            (cond
-             (white-space
-                                        ;white-space holds column positions, not buffer positions
-              (setq width (- (ems-interval-start (car white-space))
-                             (- tl start)))
-              (setq tr (+ tl width)
-                    br (+ bl width)))
-             (t (goto-char start)
-                (end-of-line)
-                (setq tr (point)
-                      br end)))
-            (ems-tabulate-process-column tl tr br bl
-                                         mark-fields start)))))))
+;;  White space contains a list of intervals giving position of inter
+;;  columnal space. All calculations are done in terms of buffer
+;;  position.
+;; Invariants: (= (- tl tr) (- bl br))
+;; tl = start for first column
+;; br = end for last column
 
 ;;}}}
 ;;{{{ Parse a region of tabular data
@@ -267,9 +202,8 @@ in the white-space."
 
 ;;{{{  emacs local variables 
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end: 
+;; local variables:
+;; folded-file: t
+;; end: 
 
 ;;}}}
