@@ -1,45 +1,45 @@
 ;;; emacspeak-tcl.el --- Speech enable TCL development environment  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $ 
-;;; DescriptionEmacspeak extensions for tcl-mode
-;;; Keywords:emacspeak, audio interface to emacs tcl
+;;
+;; $Author: tv.raman.tv $ 
+;; DescriptionEmacspeak extensions for tcl-mode
+;; Keywords:emacspeak, audio interface to emacs tcl
 ;;{{{  LCD Archive entry: 
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
-;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
-;;;  $Revision: 4532 $ | 
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com 
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ | 
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman 
-;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved. 
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman 
+;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
+;; All Rights Reserved. 
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
 
 ;;{{{  Introduction:
 ;;; Commentary:
-;;; Provide additional advice to tcl-mode 
+;; Provide additional advice to tcl-mode 
 ;;; Code:
 ;;}}}
 ;;{{{ requires
@@ -49,7 +49,7 @@
 ;;}}}
 ;;{{{ voice locking:
 
-;;;  Snarfed from tcl.el /usr/local/lib/emacs/site-lisp/tcl.el
+;;  Snarfed from tcl.el /usr/local/lib/emacs/site-lisp/tcl.el
 
 (defvar tcl-proc-list
   '("proc" "method" "itcl_class" "public" "protected")
@@ -171,28 +171,28 @@ is a Tcl expression, and the last argument is Tcl commands.")
 ;;{{{  Program structure:
 
 (defadvice tcl-mark-defun (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'mark-object)
     (message "Marked procedure")))
 
 (defadvice tcl-beginning-of-defun (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'paragraph)
     (emacspeak-speak-line)))
 
 (defadvice tcl-end-of-defun (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'paragraph)))
 
-(defadvice indent-tcl-exp (after emacspeak pre act)
+(defadvice indent-tcl-exp (after emacspeak pre act comp)
   "Produce an auditory icon"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'fill-object)))
 
-(defadvice tcl-indent-line (after emacspeak pre act)
+(defadvice tcl-indent-line (after emacspeak pre act comp)
   "Speak the line"
   (when (ems-interactive-p)
     (emacspeak-speak-line)))
@@ -201,9 +201,8 @@ is a Tcl expression, and the last argument is Tcl commands.")
 (provide  'emacspeak-tcl)
 ;;{{{  emacs local variables 
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end: 
+;; local variables:
+;; folded-file: t
+;; end: 
 
 ;;}}}
