@@ -1,46 +1,46 @@
 ;;; emacspeak-tetris.el --- Speech enable game of Tetris  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $ 
-;;; Description: Auditory interface to tetris
-;;; Keywords: Emacspeak, Speak, Spoken Output, tetris
+;;
+;; $Author: tv.raman.tv $ 
+;; Description: Auditory interface to tetris
+;; Keywords: Emacspeak, Speak, Spoken Output, tetris
 ;;{{{  LCD Archive entry: 
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
-;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
-;;;  $Revision: 4532 $ | 
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com 
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ | 
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2017, T. V. Raman
-;;; All Rights Reserved. 
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (c) 1995 -- 2022, T. V. Raman
+;; All Rights Reserved. 
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA..
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{ Introduction:
 ;;; Commentary:
-;;; Speech-enables tetris.
+;; Speech-enables tetris.
 ;;; Code:
 
 ;;}}}
@@ -52,7 +52,7 @@
 ;;}}}
 ;;{{{  Introduction 
 
-;;; Auditory interface to tetris
+;; Auditory interface to tetris
 
 ;;}}}
 ;;{{{  Setup speech display table 
@@ -63,11 +63,13 @@
 (defun emacspeak-tetris-define-pronunciations ()
   "Define speech display for tetris"
   (cl-declare (special emacspeak-tetris-pronunciations-defined
-                    emacspeak-pronounce-pronunciation-table emacspeak-pronounce-dictionaries-loaded))
+                       emacspeak-pronounce-pronunciation-table emacspeak-pronounce-dictionaries-loaded))
   (require 'emacspeak-pronounce)
   (unless emacspeak-tetris-pronunciations-defined
     (setq emacspeak-tetris-pronunciations-defined t)
-    (mapcar
+    ;;; add tiles as repeating patterns 
+    (cl-pushnew (format "%c" 0) dtk-cleanup-repeats )
+    (mapc
      #'(lambda (entry)
          (emacspeak-pronounce-add-dictionary-entry 'tetris-mode
                                                    (car entry) (cdr entry)))
@@ -108,8 +110,8 @@
 
 ;;}}}
 ;;{{{  helpers
-;;;we need this because in the new version a line is not a row (on the
-;;;bottom)
+;; we need this because in the new version a line is not a row (on the
+;; bottom)
 
 (defun emacspeak-tetris-get-current-row ()
   (cl-declare (special tetris-border))
@@ -130,12 +132,12 @@
 (defun emacspeak-tetris-speak-row-number ()
   "Speak where on the tetris board we are"
   (interactive)
-  (emacspeak-speak-line-number))
+  (what-line))
 (defun emacspeak-tetris-speak-x-coordinate ()
   "Speak current position"
   (interactive)
   (cl-declare  (special tetris-pos-x
-                     tetris-shape))
+                        tetris-shape))
   (message "%s at %s"
            (emacspeak-tetris-shape-name (1+ tetris-shape))
            tetris-pos-x))
@@ -144,7 +146,7 @@
   "Speak current position"
   (interactive)
   (cl-declare  (special tetris-pos-x tetris-pos-y
-                     tetris-shape))
+                        tetris-shape))
   (message "%s at %s %s"
            (emacspeak-tetris-shape-name (1+ tetris-shape))
            tetris-pos-x tetris-pos-y))
@@ -153,16 +155,17 @@
   "Speak current shape"
   (interactive)
   (cl-declare (special tetris-shape tetris-rot
-                    tetris-next-shape
-                    tetris-n-rows emacspeak-tetris-filled-a-row))
+                       tetris-next-shape
+                       tetris-n-rows emacspeak-tetris-filled-a-row))
   (dtk-speak
-   (format "%s %s at rotation  %s next is %s"
-           (if emacspeak-tetris-filled-a-row 
-               tetris-n-rows
-             " ")
-           (emacspeak-tetris-shape-name (1+ tetris-shape))
-           tetris-rot
-           (emacspeak-tetris-shape-name (1+ tetris-next-shape))))
+   (format
+    (format "%s %s at rotation  %s next is %s"
+            (if emacspeak-tetris-filled-a-row 
+                tetris-n-rows
+              " ")
+            (emacspeak-tetris-shape-name (1+ tetris-shape))
+            tetris-rot
+            (emacspeak-tetris-shape-name (1+ tetris-next-shape)))))
   (if emacspeak-tetris-filled-a-row
       (setq  emacspeak-tetris-filled-a-row nil)))
 
@@ -178,7 +181,7 @@
   "Speak shape orientation and coordinates"
   (interactive)
   (cl-declare (special  tetris-pos-x tetris-pos-y
-                     tetris-shape tetris-rot))
+                        tetris-shape tetris-rot))
   (message "%s at %s %s  at rotation %s"
            (emacspeak-tetris-shape-name (1+ tetris-shape))
            tetris-pos-x
@@ -189,8 +192,8 @@
   "Speak the score"
   (interactive)
   (cl-declare (special tetris-n-shapes tetris-n-rows
-                    tetris-score
-                    tetris-width))
+                       tetris-score
+                       tetris-width))
   (dtk-speak
    (format "%s complete rows after %s tiles to score %s  for an average of %s"
            tetris-n-rows
@@ -205,17 +208,17 @@
 ;;{{{  Advice
 
 (defvar emacspeak-tetris-tick-period 15
-  "*Set this to a convenient value so you get time to look at what is
+  "Set this to a convenient value so you get time to look at what is
 going on. Reduce it as you get better.")
 
 (defun emacspeak-tetris-tick-period ()
   (cl-declare (special emacspeak-tetris-tick-period))
   emacspeak-tetris-tick-period)
 
-(defalias 'tetris-get-tick-period 'emacspeak-tetris-tick-period)
+(cl--defalias 'tetris-get-tick-period 'emacspeak-tetris-tick-period)
 
 (defvar emacspeak-tetris-width tetris-width
-  "*Set this to different values for fun")
+  "Set this to different values for fun")
 
 (defadvice tetris (around emacspeak pre act comp)
   "Tetris is speech-enabled by Emacspeak.
@@ -289,7 +292,7 @@ provided by Tetris are adequate since the user can visually
 line up the current tile with the available openings at the
 bottom.  In the case of a speech interface, having absolute
 positioning commands, e.g. move the tile to the left edge,
-are almost indispensible.
+are almost indispensable.
 
 Emacspeak therefore implements and binds the following additional commands:
 
@@ -330,7 +333,7 @@ interaction.  Despite the clock being slowed down, playing
 Tetris with speech feedback alone requires a lot of
 concentration and the game is a good mental challenge. "
   (cl-declare (special tetris-tick-period
-                    emacspeak-tetris-blank-row))
+                       emacspeak-tetris-blank-row))
   (when (ems-interactive-p)
     (setq tetris-tick-period emacspeak-tetris-tick-period)
     (setq tetris-width emacspeak-tetris-width)
@@ -339,67 +342,73 @@ concentration and the game is a good mental challenge. "
     (dtk-set-punctuations 'all)
     (emacspeak-tetris-define-pronunciations)
     (emacspeak-tetris-define-keys)
+    (emacspeak-auditory-icon 'open-object)
     (emacspeak-tetris-speak-current-shape)
     (goto-char (point-min))
-    (forward-line tetris-height)
-    (message "Welcome to tetris!")))
+    (forward-line tetris-height)))
 
 (defadvice tetris-start-game (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (cl-declare (special emacspeak-tetris-blank-row))
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'open-object)
     (setq tetris-width emacspeak-tetris-width)
     (setq emacspeak-tetris-blank-row (emacspeak-tetris-blank-row))
-    (goto-line tetris-height)))
+    (goto-char (point-max))
+    (beginning-of-line)))
 
 (defadvice tetris-end-game (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (message "Ending current game")))
 
 (defadvice tetris-draw-next-shape (after emacspeak pre act comp)
-  "Provide spoken feedback"
+  "Speak"
   (emacspeak-tetris-speak-current-shape))
 
 (defadvice tetris-rotate-next (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-tetris-speak-current-shape)))
 
 (defadvice tetris-rotate-prev (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-tetris-speak-current-shape)))
 
 (defadvice tetris-move-left-edge (after emacspeak pre act comp)
   "Speak coordinates"
   (when (ems-interactive-p)
+    (emacspeak-auditory-icon 'large-movement)
     (emacspeak-tetris-speak-column)))
 
 (defadvice tetris-move-right-edge (after emacspeak pre act comp)
   "Speak coordinates"
   (when (ems-interactive-p)
+    (emacspeak-auditory-icon 'large-movement)
     (emacspeak-tetris-speak-column)))
 
 (defadvice tetris-move-to-x-pos (after emacspeak pre act comp)
   "Speak coordinates"
   (when (ems-interactive-p)
+    (emacspeak-auditory-icon 'select-object)
     (emacspeak-tetris-speak-column)))
 
 (defadvice tetris-move-left (after emacspeak pre act comp)
   "Speak coordinates"
   (when (ems-interactive-p)
+    (emacspeak-auditory-icon 'select-object)
     (emacspeak-tetris-speak-column)))
 
 (defadvice tetris-move-right (after emacspeak pre act comp)
   "Speak coordinates"
   (when (ems-interactive-p)
+    (emacspeak-auditory-icon 'select-object)
     (emacspeak-tetris-speak-column)))
 
 (defadvice tetris-move-bottom (after emacspeak pre act comp)
-  "Provide auditory feedback as the tile falls"
+  "speak as the tile falls"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)))
 (defvar emacspeak-tetris-filled-a-row nil
@@ -414,7 +423,7 @@ concentration and the game is a good mental challenge. "
 (defadvice tetris-draw-score (around emacspeak pre act comp)
   "dont draw the score"
   (when nil ad-do-it) ; to silence byte-compiler 
-)
+  )
 ;;}}}
 ;;{{{  speak line 
 
@@ -431,8 +440,8 @@ concentration and the game is a good mental challenge. "
   (cl-loop for i from 0 to 9
            do
            (define-key tetris-mode-map
-             (format "%s" i)
-             'tetris-move-to-x-pos))
+                       (format "%s" i)
+                       'tetris-move-to-x-pos))
   (define-key tetris-mode-map "a" 'tetris-move-left-edge)
   (define-key tetris-mode-map "e" 'tetris-move-right-edge)
   (define-key tetris-mode-map "l" 'tetris-move-right)
@@ -441,7 +450,7 @@ concentration and the game is a good mental challenge. "
   (define-key tetris-mode-map "k" 'tetris-rotate-prev)
   (define-key tetris-mode-map "\C-m" 'emacspeak-tetris-speak-score)
   (define-key tetris-mode-map "."
-    'emacspeak-tetris-speak-current-shape-and-coordinates)
+              'emacspeak-tetris-speak-current-shape-and-coordinates)
   (define-key tetris-mode-map "," 'emacspeak-tetris-speak-next-shape)
   (define-key tetris-mode-map "m" 'emacspeak-tetris-speak-row)
   (define-key tetris-mode-map "b" 'emacspeak-tetris-goto-bottom-row)
@@ -456,8 +465,9 @@ concentration and the game is a good mental challenge. "
   "Move to and speak bottom row"
   (interactive)
   (cl-declare (special tetris-height))
-  (goto-line
-   (1+ tetris-height))
+  (ems-with-messages-silenced
+   (goto-char (point-max))
+   (forward-line -2))
   (emacspeak-tetris-speak-row))
 
 (defvar emacspeak-tetris-blank-row
@@ -468,8 +478,8 @@ concentration and the game is a good mental challenge. "
   "Move to and speak the top row"
   (interactive)
   (cl-declare (special tetris-height
-                    emacspeak-tetris-blank-row))
-  (goto-line tetris-height)
+                       emacspeak-tetris-blank-row))
+  (goto-char (point-max))
   (search-backward emacspeak-tetris-blank-row  nil t)
   (forward-line 1)
   (emacspeak-tetris-speak-row))
@@ -513,16 +523,16 @@ concentration and the game is a good mental challenge. "
     (setq diff (- x tetris-pos-x))
     (tetris-erase-shape)
     (cond
-     ((plusp diff)
+     ((cl-plusp diff)
       (while(and (< tetris-pos-x max)
                  (> diff 0)
                  (not hit))
         (setq tetris-pos-x (1+ tetris-pos-x))
         (setq hit (tetris-test-shape))
-        (decf diff)))
-     ((minusp diff)
+        (cl-decf diff)))
+     ((cl-minusp diff)
       (while(and (> tetris-pos-x 0)
-                 (minusp diff)
+                 (cl-minusp diff)
                  (not hit))
         (setq tetris-pos-x (1- tetris-pos-x))
         (setq hit (tetris-test-shape))
@@ -535,7 +545,7 @@ concentration and the game is a good mental challenge. "
 (defun emacspeak-tetris-get-column-contents (x)
   "Return column contents as a string"
   (cl-declare (special tetris-height tetris-top-left-y
-                    tetris-top-left-x))
+                       tetris-top-left-x))
   (let ((result nil))
     (setq x (+ tetris-top-left-x x))
     (setq result
@@ -549,7 +559,8 @@ concentration and the game is a good mental challenge. "
   (interactive "p")
   (cl-declare (special tetris-pos-x))
   (or  x (setq x tetris-pos-x))
-  (dtk-speak (emacspeak-tetris-get-column-contents x)))
+  (when  (sit-for 0.5 'no-disp)
+    (dtk-speak (emacspeak-tetris-get-column-contents x))))
 
 ;;}}}
 ;;{{{ Mode hook:
@@ -563,9 +574,8 @@ concentration and the game is a good mental challenge. "
 (provide 'emacspeak-tetris)
 ;;{{{ end of file 
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end: 
+;; local variables:
+;; folded-file: t
+;; end: 
 
 ;;}}}
