@@ -1,45 +1,45 @@
 ;;; emacspeak-view.el --- Speech enable View mode -- Efficient browsing of read-only content  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $ 
-;;; DescriptionEmacspeak extensions for view
-;;; Keywords:emacspeak, audio interface to emacs, view-mode
+;;
+;; $Author: tv.raman.tv $ 
+;; DescriptionEmacspeak extensions for view
+;; Keywords:emacspeak, audio interface to emacs, view-mode
 ;;{{{  LCD Archive entry: 
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2008-06-21 14:58:40 -0700 (Sat, 21 Jun 2008) $ |
-;;;  $Revision: 4532 $ | 
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ | 
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman 
-;;; Copyright (c) 1996 by T. V. Raman 
-;;; All Rights Reserved. 
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman 
+;; Copyright (c) 1996 by T. V. Raman 
+;; All Rights Reserved. 
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
 
 ;;{{{  Introduction:
 ;;; Commentary:
-;;; Provide additional advice to view-mode
+;; Provide additional advice to view-mode
 ;;; Code:
 ;;}}}
 ;;{{{ requires
@@ -49,14 +49,14 @@
 ;;}}}
 ;;{{{  Setup view mode to work with emacspeak
 
-;;; restore emacspeak keybindings:
+;; restore emacspeak keybindings:
 (cl-declaim (special emacspeak-prefix))
 (add-hook
  'view-mode-hook
  #'(lambda ()
      (local-unset-key emacspeak-prefix)
      (emacspeak-view-setup-keys)))
-;;; Generate automatic advise:
+;; Generate automatic advise:
 
 ;;}}}
 ;;{{{ additional interactive commands
@@ -87,6 +87,7 @@
                  (key-description
                   (where-is-internal 'View-exit view-mode-map 'firstonly)))
       (message "Exited view mode"))))
+
 (cl-loop
  for f in
  '(
@@ -95,82 +96,98 @@
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
-     "Provide auditory feedback."
+     "speak."
      (when (ems-interactive-p)
        (emacspeak-auditory-icon 'close-object)
        (emacspeak-speak-mode-line)))))
 
+(cl-loop
+ for f in
+ '(
+   view-buffer view-buffer-other-frame view-buffer-other-window
+   view-emacs-FAQ
+   view-emacs-debugging ^ view-emacs-problems
+   view-emacs-todo view-external-packages
+   view-file-other-frame view-file-other-window
+   view-hello-file view-lossage ) do
+ (eval
+  `(defadvice ,f (after emacspeak pre act comp)
+     "Speech-enabled by Emacspeak."
+     (when (ems-interactive-p)
+       (emacspeak-auditory-icon 'open-object)
+       (emacspeak-speak-mode-line)))))
+
 (defadvice View-exit (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice View-leave (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-speak-mode-line)))
 
 (defadvice View-search-regexp-forward (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (let ((emacspeak-show-point t))
       (emacspeak-speak-line))
     (emacspeak-auditory-icon 'search-hit)))
 
 (defadvice View-search-regexp-backward (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (let ((emacspeak-show-point t))
       (emacspeak-speak-line))
     (emacspeak-auditory-icon 'search-hit)))
 
 (defadvice View-search-last-regexp-forward (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (let ((emacspeak-show-point t))
       (emacspeak-speak-line))
     (emacspeak-auditory-icon 'search-hit)))
 
 (defadvice View-search-last-regexp-backward (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (let ((emacspeak-show-point t))
       (emacspeak-speak-line))
     (emacspeak-auditory-icon 'search-hit)))
 
 (defadvice view-exit (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice View-scroll-one-more-line (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'scroll)
     (emacspeak-speak-line)))
 
 (defadvice View-scroll-line-forward (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'scroll)
     (emacspeak-speak-line)))
 
 (defadvice View-scroll-line-backward (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'scroll)
     (emacspeak-speak-line)))
 (defadvice View-scroll-page-forward-set-page-size (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (let ((start (point)))
       (emacspeak-auditory-icon 'scroll)
       (dtk-speak (emacspeak-get-window-contents)))))
 
 (defadvice View-scroll-page-backward-set-page-size (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (let ((start (point)))
       (emacspeak-auditory-icon 'scroll)
@@ -206,7 +223,7 @@
   ad-return-value)
 
 (defadvice View-scroll-lines-forward-set-scroll-size (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (let ((start (point)))
       (emacspeak-auditory-icon 'scroll)
@@ -215,7 +232,7 @@
         (emacspeak-speak-region start (point))))))
 
 (defadvice View-scroll-lines-forward (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'scroll)
     (dtk-speak (emacspeak-get-window-contents))))
@@ -236,14 +253,14 @@
   ad-return-value)
 
 (defadvice View-back-to-mark (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'large-movement)
     (let ((emacspeak-show-point t))
       (emacspeak-speak-line))))
 
 (defadvice View-goto-line (after emacspeak pre act comp)
-  "Provide spoken feedback"
+  "Speak"
   (when (ems-interactive-p)
     (let ((line-number
            (format "line %s"
@@ -252,33 +269,33 @@
                          'personality voice-annotate line-number)
       (emacspeak-auditory-icon 'large-movement)
       (dtk-speak
-       (concat line-number (ems-this-line))))))
+       (concat line-number (ems--this-line))))))
 (defadvice View-scroll-to-buffer-end (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'large-movement)))
 
 (defadvice View-goto-percent (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'scroll)
     (dtk-speak (emacspeak-get-window-contents))))
 
 (defadvice View-revert-buffer-scroll-page-forward (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'scroll)
     (dtk-speak (emacspeak-get-window-contents))))
 
 (defadvice View-scroll-page-forward (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'scroll)
     (dtk-speak (emacspeak-get-window-contents))))
 
 (defadvice View-scroll-page-backward (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'scroll)
     (dtk-speak (emacspeak-get-window-contents))))
@@ -290,8 +307,7 @@
 keybindings for view mode")
 
 (defvar emacspeak-view-edit-commands
-  (list 'emacspeak-self-insert-command
-        'completion-separator-self-insert-autofilling
+  (list ''completion-separator-self-insert-autofilling
         'completion-separator-self-insert-command
         'delete-char
         'completion-kill-region
@@ -301,8 +317,8 @@ keybindings for view mode")
 (defun emacspeak-view-optimize-view-keys()
   "optimize keybindings for emacspeak in view mode"
   (cl-declare (special emacspeak-view-edit-commands
-                    emacspeak-view-keys-optimized
-                    view-mode-map emacspeak-keymap))
+                       emacspeak-view-keys-optimized
+                       view-mode-map emacspeak-keymap))
   (unless emacspeak-view-keys-optimized
     (setq emacspeak-view-keys-optimized t)
     (cl-loop for edit-command in emacspeak-view-edit-commands
@@ -327,24 +343,21 @@ keybindings for view mode")
   (cl-loop for i from 0 to 9
            do
            (define-key view-mode-map
-             (format "%s" i)
-             'emacspeak-speak-predefined-window))
-;;;convenience keys
-  (define-key view-mode-map "\C-j"
-    'emacspeak-hide-speak-block-sans-prefix)
+                       (format "%s" i)
+                       'emacspeak-speak-predefined-window))
+  ;; convenience keys
+  (define-key view-mode-map "\C-j" 'emacspeak-hide-speak-block-sans-prefix)
   (define-key view-mode-map "\M- " 'emacspeak-outline-speak-this-heading)
-  (define-key view-mode-map "\M-n"
-    'outline-next-visible-heading)
+  (define-key view-mode-map "\M-n" 'outline-next-visible-heading)
   (define-key view-mode-map "\M-p" 'outline-previous-visible-heading)
   (define-key view-mode-map " " 'scroll-up)
   (define-key view-mode-map "\d" 'scroll-down)
-  (define-key view-mode-map "R" 'dtk-resume)
+  (define-key view-mode-map "[" 'backward-page)
+  (define-key view-mode-map "]" 'forward-page)
   (define-key view-mode-map "S" 'dtk-stop)
   (define-key view-mode-map "t" 'emacspeak-view-line-to-top)
-  (define-key view-mode-map ","
-    'emacspeak-speak-current-window)
-  (define-key view-mode-map "\M-d"
-    'emacspeak-pronounce-dispatch)
+  (define-key view-mode-map "," 'emacspeak-speak-current-window)
+  (define-key view-mode-map "\M-d" 'emacspeak-pronounce-dispatch)
   (define-key view-mode-map "c" 'emacspeak-speak-char)
   (define-key view-mode-map "w" 'emacspeak-speak-word)
   (emacspeak-view-optimize-view-keys))
@@ -353,9 +366,8 @@ keybindings for view mode")
 (provide  'emacspeak-view)
 ;;{{{  emacs local variables 
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end: 
+;; local variables:
+;; folded-file: t
+;; end: 
 
 ;;}}}
