@@ -1,73 +1,74 @@
 ;;; emacspeak-vm.el --- Speech enable VMMail    -*- lexical-binding: t; -*-
-;;;(and the one I use)
-;;; $Id$
-;;; $Author: tv.raman.tv $
-;;; Description:  Emacspeak extension to speech enhance vm
-;;; Keywords: Emacspeak, VM, Email, Spoken Output, Voice annotations
+;; (and the one I use)
+;;
+;; $Author: tv.raman.tv $
+;; Description:  Emacspeak extension to speech enhance vm
+;; Keywords: Emacspeak, VM, Email, Spoken Output, Voice annotations
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2008-07-31 10:49:44 -0700 (Thu, 31 Jul 2008) $ |
-;;;  $Revision: 4557 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4557 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2017, T. V. Raman
-;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
 
 ;;{{{  Introduction:
 
 ;;; Commentary:
-;;; This module extends the mail reader vm.
-;;; Uses voice locking for message headers and cited messages
+;; This module extends the mail reader vm.
+;; Uses voice locking for message headers and cited messages
 ;;; Code:
 ;;}}}
 ;;{{{ requires
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (require  'vm "vm" 'no-error)
+
 ;;}}}
 ;;{{{ Forward Decls:
 
-(declare-function vm-from-of (msg) "vm-message")
-(declare-function  vm-subject-of (msg) "vm-message")
-(declare-function  vm-to-of (msg) "vm-message")
-(declare-function  vm-su-full-name (msg) "vm-summary")
-(declare-function  vm-su-from (msg) "vm-summary")
-(declare-function vm-su-subject (msg) "vm-summary")
-(declare-function  vm-su-to-names (msg) "vm-summary")
-(declare-function  vm-su-to (msg) "vm-summary")
-(declare-function  vm-su-line-count (msg) "vm-summary")
-(declare-function vm-decode-mime-encoded-words-in-string (s) "vm-mime")
-(declare-function  vm-labels-of (msg) "vm-message")
-(declare-function  vm-goto-message (msg) "vm-message")
-(declare-function vm-delete-message (msg) "vm-message")
-(declare-function  u-vm-color-fontify-buffer nil "u-vm-color")
-(declare-function  u-vm-color-summary-mode (&optional arg) "u-vm-color")
+(defsubst ems--vm-from-of (message) (aref (aref message 3) 8))
+(defsubst ems--vm-subject-of (message) (aref (aref message 3) 11))
+(defsubst ems--vm-to-of (message) (aref (aref message 3) 13))
+(declare-function  vm-su-full-name "vm-summary" (msg))
+(declare-function  vm-su-from "vm-summary" (msg))
+(declare-function vm-su-subject "vm-summary" (msg))
+(declare-function  vm-su-to-names "vm-summary" (msg))
+(declare-function  vm-su-to "vm-summary" (msg))
+(declare-function  vm-su-line-count "vm-summary" (msg))
+(declare-function vm-decode-mime-encoded-words-in-string "vm-mime" (s))
+(defsubst vm-labels-of (message) (aref (aref message 4) 3))
+(declare-function  vm-goto-message "vm-message" (msg))
+(declare-function vm-delete-message "vm-message" (msg))
+(declare-function  u-vm-color-fontify-buffer "u-vm-color" nil)
+(declare-function  u-vm-color-summary-mode "u-vm-color" (&optional arg))
 
 ;;}}}
 ;;{{{ voice locking:
@@ -88,10 +89,10 @@ Note that some badly formed mime messages  cause trouble."
 
 (defun emacspeak-vm-mode-setup ()
   "Setup function placed on vm-mode-hook by Emacspeak."
-  (cl-declare (special  dtk-punctuation-mode dtk-allcaps-beep))
+  (cl-declare (special  dtk-punctuation-mode dtk-caps))
   (setq dtk-punctuation-mode 'all)
-  (when dtk-allcaps-beep
-    (dtk-toggle-allcaps-beep)))
+  (when dtk-caps
+    (dtk-toggle-caps)))
 
 ;;}}}
 ;;{{{ inline helpers
@@ -101,7 +102,7 @@ Note that some badly formed mime messages  cause trouble."
 ;;}}}
 ;;{{{ Advice completions
 
-(defadvice vm-minibuffer-complete-word (around emacspeak pre act)
+(defadvice vm-minibuffer-complete-word (around emacspeak pre act comp)
   "Say what you completed."
   (let ((prior (save-excursion (skip-syntax-backward "^ >") (point)))
         (dtk-stop-immediately t))
@@ -116,7 +117,7 @@ Note that some badly formed mime messages  cause trouble."
       (emacspeak-speak-completions-if-available))
     ad-return-value))
 
-(defadvice vm-minibuffer-complete-word-and-exit (around emacspeak pre act)
+(defadvice vm-minibuffer-complete-word-and-exit (around emacspeak pre act comp)
   "Say what you completed."
   (let ((prior (save-excursion (skip-syntax-backward "^ >") (point)))
         (dtk-stop-immediately t))
@@ -147,27 +148,25 @@ Note that some badly formed mime messages  cause trouble."
    (vm-message-pointer
     (dtk-stop)
     (let*  ((message (car vm-message-pointer))
-            (from (vm-from-of message))
-            (subject (vm-subject-of  message))
-            (to (vm-to-of message))
+            (from (ems--vm-from-of message))
+            (subject (ems--vm-subject-of  message))
+            (to (ems--vm-to-of message))
             (url  (browse-url-url-at-point))
             (header nil))
       (while (not header)
         (setq header
-              (case (read-char "f From s Subject t To u URL")
+              (cl-case (read-char "f From s Subject t To u URL")
                 (?s subject)
                 (?f from)
                 (?u url)
                 (?t to))))
       (when header (kill-new header))
-      (message "%s" header)))
+      (dtk-speak-and-echo  (format  "%s" header))))
    (t (error "No current message."))))
 
-(defcustom emacspeak-vm-headers-strip-octals t
+(defvar emacspeak-vm-headers-strip-octals t
   "Specify whether non-ascii chars should be stripped when
-  speaking email headers."
-  :type 'boolean
-  :group 'emacspeak-vm)
+  speaking email headers.")
 
 (defun emacspeak-vm-speak-message ()
   "Move point to the message body."
@@ -182,7 +181,7 @@ Note that some badly formed mime messages  cause trouble."
 (defun emacspeak-vm-summarize-message ()
   "Summarize the current vm message. "
   (cl-declare (special vm-message-pointer smtpmail-local-domain
-                    vm-presentation-buffer  emacspeak-vm-headers-strip-octals))
+                       vm-presentation-buffer  emacspeak-vm-headers-strip-octals))
   (when vm-message-pointer
     (let*  ((message (car vm-message-pointer))
             (number (emacspeak-vm-number-of  message))
@@ -234,9 +233,9 @@ Note that some badly formed mime messages  cause trouble."
   "VM mode line information. "
   (interactive)
   (cl-declare (special vm-ml-message-attributes-alist
-                    vm-ml-message-read vm-ml-message-unread
-                    vm-virtual-folder-definition vm-ml-message-new
-                    vm-ml-message-number vm-ml-highest-message-number))
+                       vm-ml-message-read vm-ml-message-unread
+                       vm-virtual-folder-definition vm-ml-message-new
+                       vm-ml-message-number vm-ml-highest-message-number))
   (cond
    (vm-virtual-folder-definition
     (dtk-speak
@@ -277,7 +276,7 @@ that has been forwarded multiple times."
   (re-search-forward "^ *Subject:" nil t)
   (emacspeak-speak-line))
 
-(defadvice vm-scroll-forward (after emacspeak pre act)
+(defadvice vm-scroll-forward (after emacspeak pre act comp)
   "Produce auditory feedback.
 Then speak the screenful. "
   (when (ems-interactive-p)
@@ -288,7 +287,7 @@ Then speak the screenful. "
         (forward-line (window-height window))
         (emacspeak-speak-region start (point))))))
 
-(defadvice vm-scroll-backward (after emacspeak pre act)
+(defadvice vm-scroll-backward (after emacspeak pre act comp)
   "Produce auditory feedback.
 Then speak the screenful. "
   (when (ems-interactive-p)
@@ -306,19 +305,19 @@ Then speak the screenful. "
 ;;}}}
 ;;{{{  deleting and killing
 
-(defadvice vm-delete-message (after emacspeak pre act)
-  "Provide auditory feedback."
+(defadvice vm-delete-message (after emacspeak pre act comp)
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'delete-object)
     (message "Message discarded.")))
 
-(defadvice vm-undelete-message (after emacspeak pre act)
-  "Provide auditory feedback."
+(defadvice vm-undelete-message (after emacspeak pre act comp)
+  "speak."
   (when (ems-interactive-p)
     (message "Message recovered.")))
 
-(defadvice vm-kill-subject (after emacspeak pre act)
-  "Provide auditory feedback. "
+(defadvice vm-kill-subject (after emacspeak pre act comp)
+  "speak. "
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'delete-object)
     (call-interactively 'vm-next-message)))
@@ -326,33 +325,35 @@ Then speak the screenful. "
 ;;}}}
 ;;{{{  Sending mail:
 
-(defadvice vm-forward-message (around emacspeak pre act)
+(defadvice vm-forward-message (around emacspeak pre act comp)
   "Provide aural feedback."
-  (if (ems-interactive-p)
-      (let ((dtk-stop-immediately nil))
-        (message "Forwarding message")
-        ad-do-it
-        (emacspeak-speak-line))
-    ad-do-it)
+  (cond
+   ((ems-interactive-p)
+    (emacspeak-auditory-icon 'open-object)
+    (message "Forwarding message")
+    ad-do-it
+    (emacspeak-speak-line))
+   (t
+    ad-do-it))
   ad-return-value)
 
-(defadvice vm-reply (after emacspeak pre act)
+(defadvice vm-reply (after emacspeak pre act comp)
   "Provide aural feedback."
   (when (ems-interactive-p)
     (emacspeak-speak-mode-line)))
 
-(defadvice vm-followup (after emacspeak pre act)
+(defadvice vm-followup (after emacspeak pre act comp)
   "Provide aural feedback."
   (when (ems-interactive-p)
     (message "Folluwing up")
     (emacspeak-speak-mode-line)))
 
-(defadvice vm-reply-include-text (after emacspeak pre act)
+(defadvice vm-reply-include-text (after emacspeak pre act comp)
   "Provide aural feedback."
   (when (ems-interactive-p)
     (emacspeak-speak-mode-line)))
 
-(defadvice vm-followup-include-text (after emacspeak pre act)
+(defadvice vm-followup-include-text (after emacspeak pre act comp)
   "Provide aural feedback."
   (when (ems-interactive-p)
     (message "Following up")
@@ -368,17 +369,22 @@ Then speak the screenful. "
   (when  (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)))
 
-(defadvice vm-mail (after emacspeak pre act)
-  "Provide aural feedback."
-  (when (ems-interactive-p)
-    (let ((dtk-stop-immediately nil))
-      (message "Composing a message")
-      (emacspeak-speak-line))))
+(cl-loop
+ for f in
+ '(vm-mail vm-mail-from-folder)
+ do
+ (eval
+  `(defadvice ,f (after emacspeak pre act comp)
+     "Speak."
+     (when (ems-interactive-p)
+       (let ((dtk-stop-immediately nil))
+         (message "Composing a message")
+         (emacspeak-speak-line))))))
 
 ;;}}}
 ;;{{{ quitting
 
-(defadvice vm-quit (after emacspeak pre act)
+(defadvice vm-quit (after emacspeak pre act comp)
   "Provide an auditory icon if requested"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
@@ -402,11 +408,11 @@ Then speak the screenful. "
 ;;{{{  Keybindings:
 (when (boundp 'vm-mode-map)
   (cl-declaim  (special
-             vm-mode-map
-             global-map emacspeak-prefix emacspeak-keymap))
+                vm-mode-map
+                global-map emacspeak-prefix emacspeak-keymap))
+  (define-key vm-mode-map "C" 'vm-chromium)
   (define-key vm-mode-map "\M-\C-m" 'widget-button-press)
   (define-key vm-mode-map "y" 'emacspeak-vm-yank-header)
-  (define-key vm-mode-map "\M-\t" 'emacspeak-vm-next-button)
   (define-key vm-mode-map  "j" 'emacspeak-hide-or-expose-all-blocks)
   (define-key vm-mode-map  "\M-g" 'vm-goto-message)
   (define-key vm-mode-map "J" 'vm-discard-cached-data)
@@ -417,13 +423,13 @@ Then speak the screenful. "
   (define-key vm-mode-map "," 'emacspeak-vm-speak-message)
   (define-key vm-mode-map "\M-l" 'emacspeak-vm-speak-labels)
   (define-key vm-mode-map
-    (concat emacspeak-prefix "m")
-    'emacspeak-vm-mode-line)
+              (concat emacspeak-prefix "m")
+              'emacspeak-vm-mode-line)
   )
 ;;}}}
 ;;{{{ advise searching:
 (defadvice vm-isearch-forward (around emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (cl-declare (special vm-message-pointer))
   (cond
    ((ems-interactive-p)
@@ -438,7 +444,7 @@ Then speak the screenful. "
   ad-return-value)
 
 (defadvice vm-isearch-backward (around emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (cl-declare (special vm-message-pointer))
   (cond
    ((ems-interactive-p)
@@ -464,7 +470,7 @@ Then speak the screenful. "
    ad-do-it))
 
 (defadvice vm-mime-run-display-function-at-point (around emacspeak pre act comp)
-  "Provide auditory feedback.
+  "speak.
 Leave point at front of decoded attachment."
   (cond
    ((ems-interactive-p)
@@ -509,6 +515,10 @@ Leave point at front of decoded attachment."
  do
  (add-hook hook 'emacspeak-pronounce-refresh-pronunciations 'append))
 
+(defvar emacspeak-speak-embedded-url-pattern
+  "<https?:[^ \t]*>"
+  "Pattern to recognize embedded URLs.")
+
 (cl-loop
  for mode in
  '(vm-presentation-mode mail-mode)
@@ -533,53 +543,23 @@ Leave point at front of decoded attachment."
 
 ;;}}}
 ;;{{{ advice button motion
-(defadvice vm-next-button (after emacspeak pre act comp)
-  "Provide auditory feedback"
-  (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'large-movement)
-    (emacspeak-speak-text-range  'w3-hyperlink-info)))
 
 ;;}}}
 ;;{{{  misc
 
-(defadvice vm-count-messages-in-file (around emacspeak-fix pre act comp)
+(defadvice vm (around emacspeak pre act comp)
+  "Silence chatter."
+  (let ((emacspeak-speak-messages nil))
+    ad-do-it
+    (emacspeak-vm-mode-line)))
+
+(defadvice vm-count-messages-in-file (around emacspeak pre act comp)
   (ad-set-arg 1 'quiet)
   ad-do-it)
 
 ;;}}}
 ;;{{{  button motion in vm
 
-(defun emacspeak-vm-next-button (n)
-  "Move point to N buttons forward.
-If N is negative, move backward instead."
-  (interactive "p")
-  (let ((function (if (< n 0) 'previous-single-property-change
-                    'next-single-property-change))
-        (inhibit-point-motion-hooks t)
-        (inhibit-modification-hooks t)
-        (backward (< n 0))
-        (limit (if (< n 0) (point-min) (point-max))))
-    (setq n (abs n))
-    (while (and (not (= limit (point)))
-                (> n 0))
-      ;; Skip past the current button.
-      (when (get-text-property (point) 'w3-hyperlink-info)
-        (goto-char (funcall function (point) 'w3-hyperlink-info nil limit)))
-      ;; Go to the next (or previous) button.
-      (goto-char (funcall function (point) 'w3-hyperlink-info nil limit))
-      ;; Put point at the start of the button.
-      (when (and backward (not (get-text-property (point) 'w3-hyperlink-info)))
-        (goto-char (funcall function (point) 'w3-hyperlink-info nil limit)))
-      ;; Skip past intangible buttons.
-      (when
-          (or (get-text-property (point) 'intangible)
-              (get-text-property (point) 'cursorintangible))
-        (cl-incf n))
-      (decf n))
-    (unless (zerop n)
-      (message  "No more buttons"))
-    n))
-
 ;;}}}
 ;;{{{ saving mime attachment under point
 
@@ -597,9 +577,9 @@ If N is negative, move backward instead."
      (u-vm-color-header-face voice-bolden-medium)
      (u-vm-color-recipient-face voice-annotate)
      (u-vm-color-signature-face voice-smoothen)
-     (u-vm-color-spamassassin-face voice-monotone)
+     (u-vm-color-spamassassin-face voice-monotone-extra)
      (u-vm-color-subject-face voice-lighten)
-     (u-vm-color-time-face voice-monotone)
+     (u-vm-color-time-face voice-monotone-extra)
      (u-vm-color-user-face voice-animate)
 
      )
@@ -611,15 +591,34 @@ If N is negative, move backward instead."
   )
 
 ;;}}}
-
 ;;{{{ configure and customize vm
 
-;;; This is how I customize VM
+;; This is how I customize VM
+;; First, Configure VM into using shr instead of w3m:
+
+(defun vm-mime-display-internal-shr-text/html (start end _layout)
+  "Use shr to inline HTML mails in the VM presentation buffer."
+  (shr-render-region start (1- end))
+  (put-text-property start end 'text-rendered-by-shr t))
+
+;; has to be done indirectly
+;; Fake emacs-w3m, though we actually use shr
+(defalias 'vm-mime-display-internal-emacs-w3m-text/html  'vm-mime-display-internal-shr-text/html)
+
+(defun vm-chromium ()
+  "Run Chromium on current link."
+  (interactive)
+  (let ((url (browse-url-url-at-point)))
+    (unless url (error "No link here."))
+    (dtk-stop)
+    (browse-url-chrome url)
+    (message "Opening url with Chrome")))
 
 (defcustom emacspeak-vm-use-raman-settings t
   "Should VM  use the customizations used by the author of Emacspeak."
   :type 'boolean
   :group 'emacspeak-vm)
+
 (defvar emacspeak-vm-demote-html-attachments
   '(
     favorite-internal  "text/plain" "text/enriched"
@@ -633,71 +632,59 @@ If N is negative, move backward instead."
   "Setting that prefers  alternatives  html/xhtml over text/plain.")
 
 (defun emacspeak-vm-use-raman-settings ()
-  "Customization settings for VM used by the author of
-Emacspeak."
+  "Customization settings for VM used by the author of Emacspeak."
   (cl-declare (special emacspeak-vm-demote-html-attachments
-                    emacspeak-vm-promote-html-attachments
-                    vm-mime-charset-converter-alist
-                    vm-mime-default-face-charsets
-                    vm-frame-per-folder
-                    vm-frame-per-composition
-                    vm-frame-per-edit
-                    vm-frame-per-help
-                    vm-frame-per-summary
-                    vm-index-file-suffix
-                    vm-primary-inbox
-                    vm-folder-directory
-                    vm-forwarding-subject-format
-                    vm-startup-with-summary
-                    vm-inhibit-startup-message
-                    vm-visible-headers
-                    vm-delete-after-saving
-                    vm-url-browser
-                    vm-confirm-new-folders
-                    vm-mime-alternative-select-method
-                    vm-move-after-deleting))
-  (setq vm-mime-alternative-select-method
-        emacspeak-vm-demote-html-attachments)
+                       emacspeak-vm-promote-html-attachments
+                       vm-mime-charset-converter-alist vm-mime-default-face-charsets
+                       vm-frame-per-folder vm-frame-per-composition
+                       vm-frame-per-edit vm-frame-per-help
+                       vm-frame-per-summary vm-index-file-suffix
+                       vm-crash-box vm-primary-inbox vm-folder-directory
+                       vm-forwarding-subject-format vm-startup-with-summary
+                       vm-inhibit-startup-message vm-visible-headers
+                       vm-delete-after-saving vm-url-browser
+                       vm-confirm-new-folders vm-mime-alternative-select-method
+                       vm-mime-text/html-handler vm-move-after-deleting))
+  (setq vm-mime-text/html-handler'emacs-w3m  )
+  (setq vm-mime-alternative-select-method emacspeak-vm-demote-html-attachments)
   (setq vm-mime-charset-converter-alist
         '(
-          ("utf-8" "iso-8859-1" "iconv -f utf-8 -t iso-8859-1")
-          )
-        )
+          ("utf-8" "iso-8859-1" "iconv -f utf-8 -t iso-8859-1")))
   (setq vm-mime-default-face-charsets t)
   (setq vm-frame-per-folder nil
         vm-frame-per-composition nil
         vm-frame-per-edit nil
         vm-frame-per-help nil
         vm-frame-per-summary nil)
-
   (setq vm-index-file-suffix ".idx"
         vm-primary-inbox "~/mbox"
         vm-folder-directory "~/Mail/"
+        vm-crash-box "mbox.crash"
         vm-forwarding-subject-format "[%s]"
         vm-startup-with-summary nil
         vm-inhibit-startup-message t
         vm-visible-headers '("From:" "To:" "Subject:" "Date:" "Cc:")
         vm-delete-after-saving t
-        vm-url-browser 'browse-url
+        vm-url-browser 'eww-browse-url
         vm-confirm-new-folders t
         vm-move-after-deleting nil)
   t)
 
 (defun emacspeak-vm-toggle-html-mime-demotion ()
-  "Toggle state of HTML Mime Demotion."
+  "Toggle state of HTML Mime promotion/Demotion."
   (interactive)
   (cl-declare (special emacspeak-vm-demote-html-attachments
-                    emacspeak-vm-promote-html-attachments
-                    vm-mime-alternative-select-method))
+                       emacspeak-vm-promote-html-attachments
+                       vm-mime-alternative-select-method))
   (cond
    ((eq vm-mime-alternative-select-method emacspeak-vm-demote-html-attachments)
     (setq vm-mime-alternative-select-method
           emacspeak-vm-promote-html-attachments)
-    (message "Prefering HTML Mime alternative."))
+    (message "Preferring HTML Mime alternative."))
    ((eq vm-mime-alternative-select-method emacspeak-vm-promote-html-attachments)
     (setq vm-mime-alternative-select-method
           emacspeak-vm-demote-html-attachments)
-    (message "Prefering Text/Plain Mime alternative."))
+    (message "Preferring Text/Plain Mime alternative."))
    (t (message "Resetting state to HTML Mime demotion.")
       (setq vm-mime-alternative-select-method
             emacspeak-vm-demote-html-attachments))))
@@ -718,12 +705,6 @@ text using pdftotext."
   :type 'string
   :group 'emacspeak-vm)
 
-(defcustom emacspeak-vm-doc2text
-  (expand-file-name "doc2text" emacspeak-etc-directory)
-  "Executable that converts MSWord documents on standard input to plain
-text using wvText."
-  :type 'string
-  :group 'emacspeak-vm)
 (defcustom emacspeak-vm-cal2text
   (expand-file-name "cal2text" emacspeak-etc-directory)
   "Executable that converts calendar invitations    on
@@ -731,20 +712,6 @@ text using wvText."
   :type 'string
   :group 'emacspeak-vm)
 
-(defcustom emacspeak-vm-xls2html
-  (expand-file-name "xls2html" emacspeak-etc-directory)
-  "Executable that converts MSXL documents on standard input to HTML
- using xlhtml."
-  :type 'string
-  :group 'emacspeak-vm)
-
-(defcustom emacspeak-vm-ppt2html
-  (expand-file-name "ppt2html" emacspeak-etc-directory)
-  "Executable that converts MSPPT documents on standard input to HTML
- using xlhtml."
-  :type 'string
-  :group 'emacspeak-vm)
-
 (defun emacspeak-vm-add-mime-converter (converter)
   "Helper to add a converter specification."
   (cl-declare (special vm-mime-type-converter-alist))
@@ -759,32 +726,22 @@ text using wvText."
 (defun emacspeak-vm-customize-mime-settings ()
   "Customize VM mime settings."
   (cl-declare (special vm-preview-lines
-                    vm-infer-mime-types
-                    vm-mime-decode-for-preview
-                    vm-auto-decode-mime-messages
-                    vm-auto-displayed-mime-content-type-exceptions
-                    vm-mime-attachment-save-directory
-                    vm-mime-base64-encoder-program
-                    vm-mime-base64-decoder-program
-                    vm-mime-attachment-auto-type-alist
-                    vm-mime-type-converter-alist
-                    emacspeak-vm-pdf2text
-                    emacspeak-vm-ppt2html
-                    emacspeak-vm-xls2html
-                    emacspeak-vm-doc2text
-                    emacspeak-vm-cal2text))
+                       vm-infer-mime-types
+                       vm-mime-decode-for-preview
+                       vm-auto-decode-mime-messages
+                       vm-auto-displayed-mime-content-type-exceptions
+                       vm-mime-attachment-save-directory
+                       vm-mime-base64-encoder-program
+                       vm-mime-base64-decoder-program
+                       vm-mime-attachment-auto-type-alist
+                       vm-mime-type-converter-alist
+                       emacspeak-vm-pdf2text
+                       emacspeak-vm-cal2text))
   (emacspeak-vm-add-mime-converter
    (list "text/calendar" "text/plain" emacspeak-vm-cal2text))
   (emacspeak-vm-add-mime-converter
    (list "application/pdf" "text/plain"
          emacspeak-vm-pdf2text))
-  (emacspeak-vm-add-mime-converter
-   (list "application/vnd.ms-excel" "text/html"
-         emacspeak-vm-xls2html))
-  (emacspeak-vm-add-mime-converter
-   (list "application/vnd.ms-powerpoint" "text/html" emacspeak-vm-ppt2html))
-  (emacspeak-vm-add-mime-converter
-   (list "application/msword" "text/plain" emacspeak-vm-doc2text))
   (setq vm-preview-lines nil
         vm-infer-mime-types t
         vm-mime-decode-for-preview nil
@@ -803,9 +760,8 @@ text using wvText."
 (provide 'emacspeak-vm)
 ;;{{{  local variables
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
