@@ -1,55 +1,53 @@
 ;;; emacspeak-we.el --- Transform Web Pages Using XSLT  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $
-;;; Description:  Edit/Transform Web Pages using XSLT
-;;; Keywords: Emacspeak,  Audio Desktop Web, XSLT
+;;
+;; $Author: tv.raman.tv $
+;; Description:  Edit/Transform Web Pages using XSLT
+;; Keywords: Emacspeak,  Audio Desktop Web, XSLT
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2008-08-04 09:12:03 -0700 (Mon, 04 Aug 2008) $ |
-;;;  $Revision: 4532 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman
-;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  introduction
 
 ;;; Commentary:
-;;; we is for webedit
-;;; Invoke XSLT to edit/transform Web pages before they get
-;;; rendered.
-;;; we makes emacspeak's webedit layer independent of a given
-;;; Emacs web browser like W3 or W3M
-;;; This module will use the abstraction provided by browse-url
-;;; to handle Web pages.
-;;; Module emacspeak-webutils provides the needed additional
-;;; abstractions not already covered by browse-url
+;; we is for webedit
+;; Invoke XSLT to edit/transform Web pages before they get
+;; rendered.
+;; we makes emacspeak's webedit layer independent of a given
+;; Emacs web browser  EWW
+;; This module will use the abstraction provided by browse-url
+;; to handle Web pages.
 
 ;;; Code:
 
@@ -60,12 +58,26 @@
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
 (require 'emacspeak-xslt)
-(require 'emacspeak-webutils)
+
+;;}}}
+;;{{{Helper:
+
+(defun emacspeak-we-rename-buffer (key)
+  "Setup emacspeak-eww-post-process-hook  to rename result buffer"
+  (add-hook
+   'emacspeak-eww-post-process-hook
+   (eval
+    `#'(lambda nil
+         (rename-buffer
+          (format "%s %s"
+                  (buffer-name) ,key)
+          'unique)))))
 
 ;;}}}
 ;;{{{ URL Rewrite:
+;; forward decl to help compiler 
+(defvar emacspeak-eww-url-at-point)
 
-;;;###autoload
 (defun emacspeak-we-url-rewrite-and-follow (&optional prompt)
   "Apply a url rewrite rule as specified in the current buffer
 before following link under point.  If no rewrite rule is
@@ -78,8 +90,8 @@ article for example.  Optional interactive prefix arg prompts for
 a rewrite rule even if one is already defined."
   (interactive "P")
   (cl-declare (special emacspeak-we-url-rewrite-rule))
-  (emacspeak-webutils-browser-check)
-  (let ((url (funcall emacspeak-webutils-url-at-point))
+  (emacspeak-eww-browser-check)
+  (let ((url (funcall emacspeak-eww-url-at-point))
         (redirect nil))
     (unless url (error "Not on a link."))
     (when (or prompt (null emacspeak-we-url-rewrite-rule))
@@ -95,7 +107,7 @@ a rewrite rule even if one is already defined."
 
 ;;}}}
 ;;{{{ url expand and execute
-
+;;;###autoload
 (defvar emacspeak-we-url-executor nil
   "URL expand/execute function  to use in current buffer.")
 
@@ -105,12 +117,12 @@ a rewrite rule even if one is already defined."
   "Applies buffer-specific URL expander/executor function."
   (interactive "P")
   (cl-declare (special emacspeak-we-url-executor))
-  (emacspeak-webutils-browser-check)
-  (let ((url (funcall emacspeak-webutils-url-at-point)))
+  (emacspeak-eww-browser-check)
+  (let ((url (funcall emacspeak-eww-url-at-point)))
     (unless url (error "Not on a link."))
+    (emacspeak-auditory-icon 'button)
     (cond
-     ((and (boundp 'emacspeak-we-url-executor)
-           (fboundp emacspeak-we-url-executor))
+     ((functionp emacspeak-we-url-executor)
       (if prefix
           (funcall emacspeak-we-url-executor url prefix)
         (funcall emacspeak-we-url-executor url)))
@@ -121,15 +133,14 @@ a rewrite rule even if one is already defined."
               "Executor function: "
               obarray 'fboundp t
               "emacspeak-" nil)))
-      (if (and (boundp 'emacspeak-we-url-executor)
-               (fboundp emacspeak-we-url-executor))
+      (if (functionp emacspeak-we-url-executor)
           (funcall emacspeak-we-url-executor url)
         (error "Invalid executor %s"
                emacspeak-we-url-executor))))))
 
 ;;}}}
 ;;{{{ applying XSL transforms before displaying
-
+;;;###autoload
 (define-prefix-command 'emacspeak-we-xsl-map)
 
 (defvar emacspeak-we-xsl-filter
@@ -142,48 +153,38 @@ a rewrite rule even if one is already defined."
 (defgroup emacspeak-we nil
   "Emacspeak WebEdit"
   :group 'emacspeak)
-
 ;;;###autoload
-(defcustom emacspeak-we-xsl-p nil
-  "T means we apply XSL before displaying HTML."
-  :type 'boolean
-  :group 'emacspeak-we)
-
-(defcustom emacspeak-we-xsl-transform
-  (emacspeak-xslt-get "sort-tables.xsl")
+(defvar emacspeak-we-xsl-p nil
+  "T means we apply XSL before displaying HTML.")
+;;;###autoload
+(defvar emacspeak-we-xsl-transform
+  nil
   "Specifies transform to use before displaying a page.
-Default is to apply sort-tables."
-  :type  '(choice
-           (file :tag "XSL")
-           (const :tag "none" nil))
-  :group 'emacspeak-we)
+Default is to apply sort-tables.")
 
 ;;;###autoload
 (defvar emacspeak-we-xsl-params nil
   "XSL params if any to pass to emacspeak-xslt-region.")
 
-;;; Note that emacspeak-we-xsl-transform, emacspeak-we-xsl-params
-;;; and emacspeak-we-xsl-p
-;;; need to be set at top-level since the page-rendering code is
-;;; called asynchronously.
+;; Note that emacspeak-we-xsl-transform, emacspeak-we-xsl-params
+;; and emacspeak-we-xsl-p
+;; need to be set at top-level since the page-rendering code is
+;; called asynchronously.
 
-;;;###autoload
-(defcustom emacspeak-we-cleanup-bogus-quotes t
-  "Clean up bogus Unicode chars for magic quotes."
-  :type 'boolean
-  :group 'emacspeak-we)
+(defvar emacspeak-we-cleanup-bogus-quotes t
+  "Clean up bogus Unicode chars for magic quotes.")
+
+(declare-function eww-current-url "eww" nil)
 
-;;;###autoload
 (defun emacspeak-we-xslt-apply (xsl)
   "Apply specified transformation to current Web page."
   (interactive (list (emacspeak-xslt-read)))
-  (emacspeak-webutils-browser-check)
-  (add-to-list
-   'emacspeak-web-pre-process-hook
-   (emacspeak-webutils-make-xsl-transformer  xsl))
-  (browse-url (funcall emacspeak-webutils-current-url)))
+  (emacspeak-eww-browser-check)
+  (add-hook
+   'emacspeak-eww-pre-process-hook
+   (emacspeak-xslt-make-xsl-transformer  xsl))
+  (browse-url (eww-current-url)))
 
-;;;###autoload
 (defun emacspeak-we-xslt-select (xsl)
   "Select XSL transformation applied to Web pages before they are displayed ."
   (interactive (list (emacspeak-xslt-read)))
@@ -195,7 +196,6 @@ Default is to apply sort-tables."
              (file-name-sans-extension
               (file-name-nondirectory xsl)))))
 
-;;;###autoload
 (defun emacspeak-we-xsl-toggle ()
   "Toggle  application of XSL transformations."
   (interactive)
@@ -207,12 +207,11 @@ Default is to apply sort-tables."
     (message "Turned %s XSL"
              (if emacspeak-we-xsl-p 'on 'off))))
 
-;;;###autoload
 (defun emacspeak-we-count-matches (url locator)
   "Count matches for locator  in Web page."
   (interactive
    (list
-    (emacspeak-webutils-read-url)
+    (emacspeak-eww-read-url)
     (read-from-minibuffer "XPath locator: ")))
   (read
    (emacspeak-xslt-url
@@ -221,23 +220,19 @@ Default is to apply sort-tables."
     (emacspeak-xslt-params-from-xpath locator url)
     'no-comment)))
 
-;;;###autoload
 (defun emacspeak-we-count-nested-tables (url)
   "Count nested tables in Web page."
-  (interactive (list (emacspeak-webutils-read-url)))
+  (interactive (list (emacspeak-eww-read-url)))
   (emacspeak-we-count-matches url "'//table//table'"))
 
-;;;###autoload
 (defun emacspeak-we-count-tables (url)
   "Count  tables in Web page."
-  (interactive (list (emacspeak-webutils-read-url)))
+  (interactive (list (emacspeak-eww-read-url)))
   (emacspeak-we-count-matches url "//table"))
 
-;;;###autoload
 (defvar emacspeak-we-xsl-keep-result nil
   "Toggle via command \\[emacspeak-we-toggle-xsl-keep-result].")
 
-;;;###autoload
 (defun emacspeak-we-toggle-xsl-keep-result ()
   "Toggle xsl keep result flag."
   (interactive)
@@ -253,128 +248,73 @@ Default is to apply sort-tables."
   "Set to T  if you want the buffer name to contain the applied filter."
   :type  'boolean
   :group 'emacspeak-we)
-
+(declare-function emacspeak-eww-reading-settings "emacspeak-eww")
 ;;;###autoload
-(defun emacspeak-we-xslt-filter (path    url  &optional speak)
+(defun emacspeak-we-xslt-filter (path    url  &optional _speak)
   "Extract elements matching specified XPath path locator
 from Web page -- default is the current page being viewed."
   (interactive
    (list
     (read-from-minibuffer "XPath: ")
-    (emacspeak-webutils-read-url)
+    (emacspeak-eww-read-url)
     current-prefix-arg))
   (cl-declare (special emacspeak-we-xsl-filter
-                    emacspeak-we-filters-rename-buffer))
+                       emacspeak-we-filters-rename-buffer))
   (let ((params (emacspeak-xslt-params-from-xpath  path url)))
-               (when emacspeak-we-filters-rename-buffer(emacspeak-webutils-rename-buffer (format "Filtered %s" path)))
-               (when speak (emacspeak-webutils-autospeak))
-               (add-to-list
-                'emacspeak-web-pre-process-hook
-                (emacspeak-webutils-make-xsl-transformer emacspeak-we-xsl-filter params))
-               (when (eq browse-url-browser-function 'eww-browse-url)
-               (add-hook
-             'emacspeak-web-post-process-hook
-             #'emacspeak-eww-reading-settings))
-               (browse-url url)))
+    (when emacspeak-we-filters-rename-buffer(emacspeak-we-rename-buffer (format "Filtered %s" path)))
+    (add-hook
+     'emacspeak-eww-pre-process-hook
+     (emacspeak-xslt-make-xsl-transformer emacspeak-we-xsl-filter params))
+    (add-hook
+     'emacspeak-eww-post-process-hook
+     #'emacspeak-eww-reading-settings 'at-end)
+    (browse-url url)))
+
+(defun emacspeak-we-xslt-pipeline-filter (specs    url  &optional _speak)
+  "Apply a pipeline of filters specified in `specs', a list.
+Each filter is a list of the form
+ `(xsl-stylesheet-name xpath)'."
+  (cl-declare (special emacspeak-we-filters-rename-buffer))
+  (when emacspeak-we-filters-rename-buffer
+    (emacspeak-we-rename-buffer (format "Pipeline filtered ")))
+  (add-hook
+   'emacspeak-eww-pre-process-hook
+   (emacspeak-xslt-make-xsl-transformer-pipeline specs url))
+  (add-hook
+   'emacspeak-eww-post-process-hook
+   #'emacspeak-eww-reading-settings 'at-end)
+  (browse-url url))
 
-;;;###autoload
 (defun emacspeak-we-xslt-junk (path    url &optional speak)
   "Junk elements matching specified locator."
   (interactive
    (list
     (read-from-minibuffer "XPath: ")
-    (emacspeak-webutils-read-url)
+    (emacspeak-eww-read-url)
     (called-interactively-p 'interactive)))
   (cl-declare (special emacspeak-we-xsl-junk))
   (let ((params (emacspeak-xslt-params-from-xpath  path url)))
-               (emacspeak-webutils-rename-buffer (format "Filtered %s" path))
-               (when speak (emacspeak-webutils-autospeak))
-               (add-to-list
-                'emacspeak-web-pre-process-hook
-                (emacspeak-webutils-make-xsl-transformer emacspeak-we-xsl-junk params))
-               (browse-url url)))
+    (emacspeak-we-rename-buffer (format "Filtered %s" path))
+    (when speak (emacspeak-eww-autospeak))
+    (add-hook
+     'emacspeak-eww-pre-process-hook
+     (emacspeak-xslt-make-xsl-transformer emacspeak-we-xsl-junk params))
+    (browse-url url)))
 
-(defcustom emacspeak-we-media-stream-suffixes
-  (list
-   ".ram"
-   ".rm"
-   ".ra"
-   ".pls"
-   ".asf"
-   ".asx"
-   ".mp3"
-   ".m3u"
-   ".m4v"
-   ".wma"
-   ".wmv"
-   ".avi"
-   ".mpg")
-  "Suffixes that identify   URLs   to media streams."
-  :type  '(repeat
-           (string :tag "Extension Suffix"))
-  :group 'emacspeak-we)
-
-;;;###autoload
-(defun emacspeak-we-extract-media-streams (url &optional speak)
-  "Extract links to media streams.
-operate on current web page when in a browser buffer; otherwise
- prompt for url.  Optional arg `speak' specifies if the result
- should be spoken automatically."
-  (interactive
-   (list
-    (emacspeak-webutils-read-url)
-    (called-interactively-p 'interactive)))
-  (cl-declare (special emacspeak-we-media-stream-suffixes))
-  (let ((filter "//a[%s]")
-        (predicate
-         (mapconcat
-          #'(lambda (suffix)
-              (format "contains(@href,\"%s\")"
-                      suffix))
-          emacspeak-we-media-stream-suffixes
-          " or ")))
-    (emacspeak-we-xslt-filter
-     (format filter predicate)
-     url speak)))
-
-;;;###autoload
-(defun emacspeak-we-extract-print-streams (url &optional speak)
-  "Extract links to printable  streams.
-operate on current web page when in a browser buffer; otherwise
- prompt for url.  Optional arg `speak' specifies if the result
- should be spoken automatically."
-  (interactive
-   (list
-    (emacspeak-webutils-read-url)
-    (called-interactively-p 'interactive)))
-  (let ((filter "//a[contains(@href,\"print\")]"))
-    (emacspeak-we-xslt-filter filter url speak)))
-
-;;;###autoload
 (defun emacspeak-we-follow-and-extract-main (&optional speak)
   "Follow URL, then extract role=main."
   (interactive
    (list
-    (called-interactively-p 'interactive)))
+    (or (called-interactively-p 'interactive) current-prefix-arg)))
   (emacspeak-we-extract-by-role "main"
-                                (funcall emacspeak-webutils-url-at-point) speak))
+                                (funcall emacspeak-eww-url-at-point) speak))
 
-;;;###autoload
-(defun emacspeak-we-extract-media-streams-under-point ()
-  "In browser buffers, extract media streams from url under point."
-  (interactive)
-  (emacspeak-webutils-browser-check)
-  (emacspeak-we-extract-media-streams
-   (funcall emacspeak-webutils-url-at-point)
-   'speak))
-
-;;;###autoload
 (defun emacspeak-we-extract-matching-urls (pattern url &optional speak)
   "Extracts links whose URL matches pattern."
   (interactive
    (list
     (read-from-minibuffer "Pattern: ")
-    (emacspeak-webutils-read-url)
+    (emacspeak-eww-read-url)
     (called-interactively-p 'interactive)))
   (let ((filter
          (format
@@ -391,8 +331,8 @@ spoken automatically."
   (interactive
    (list
     (read-from-minibuffer "Table Index: ")
-    (emacspeak-webutils-read-url)
-    (called-interactively-p 'interactive)))
+    (emacspeak-eww-read-url)
+    (or (called-interactively-p 'interactive) current-prefix-arg)))
   (emacspeak-we-xslt-filter
    (format "(//table//table)[%s]" index)
    url speak))
@@ -438,8 +378,8 @@ Empty value finishes the list."
   (interactive
    (list
     (emacspeak-we-get-table-list)
-    (emacspeak-webutils-read-url)
-    (called-interactively-p 'interactive)))
+    (emacspeak-eww-read-url)
+    (or (called-interactively-p 'interactive) current-prefix-arg)))
   (let ((filter
          (mapconcat
           #'(lambda  (i)
@@ -450,14 +390,14 @@ Empty value finishes the list."
 
 ;;;###autoload
 (defun emacspeak-we-extract-table-by-position (pos   url
-                                                          &optional speak)
+                                                     &optional speak)
   "Extract table at specified pos.
 Default is to extract from current page."
   (interactive
    (list
     (read-from-minibuffer "Extract Table: ")
-    (emacspeak-webutils-read-url)
-    current-prefix-arg))
+    (emacspeak-eww-read-url)
+    (or (called-interactively-p 'interactive) current-prefix-arg)))
   (emacspeak-we-xslt-filter
    (format "/descendant::table[%s]"
            pos)
@@ -472,8 +412,8 @@ Tables are specified by their position in the list
   (interactive
    (list
     (emacspeak-we-get-table-list)
-    (emacspeak-webutils-read-url)
-    current-prefix-arg))
+    (emacspeak-eww-read-url)
+    (or (called-interactively-p 'interactive) current-prefix-arg)))
   (let ((filter
          (mapconcat
           #'(lambda  (i)
@@ -493,8 +433,8 @@ Tables are specified by their position in the list
   (interactive
    (list
     (read-from-minibuffer "Tables Matching: ")
-    (emacspeak-webutils-read-url)
-    current-prefix-arg))
+    (emacspeak-eww-read-url)
+    (or (called-interactively-p 'interactive) current-prefix-arg)))
   (emacspeak-we-xslt-filter
    (format "(/descendant::table[contains(., \"%s\")])[last()]"
            match)
@@ -511,8 +451,8 @@ Tables are specified by containing  match pattern
   (interactive
    (list
     (emacspeak-we-get-table-match-list)
-    (emacspeak-webutils-read-url)
-    current-prefix-arg))
+    (emacspeak-eww-read-url)
+    (or (called-interactively-p 'interactive) current-prefix-arg)))
   (let ((filter
          (mapconcat
           #'(lambda  (i)
@@ -529,13 +469,13 @@ Tables are specified by containing  match pattern
   "Caches class attribute values for current buffer.")
 
 (make-variable-buffer-local 'emacspeak-we-buffer-class-cache)
+(declare-function emacspeak-xslt-run "emacspeak-xslt" (xsl &optional start end))
 
 (defun emacspeak-we-build-class-cache ()
   "Build class cache and forward it to rendered page."
   (let ((values nil)
         (content (clone-buffer)))
-    (save-excursion
-      (set-buffer content)
+    (with-current-buffer content
       (setq buffer-undo-list t)
       (emacspeak-xslt-run
        (emacspeak-xslt-get "class-values.xsl")
@@ -545,7 +485,7 @@ Tables are specified by containing  match pattern
       (delete-region (point-min) (point))
       (setq values (split-string (buffer-string))))
     (add-hook
-     'emacspeak-web-post-process-hook
+     'emacspeak-eww-post-process-hook
      (eval
       `#'(lambda nil
            (cl-declare (special  emacspeak-we-buffer-class-cache))
@@ -562,15 +502,14 @@ Tables are specified by containing  match pattern
   "Build id cache and forward it to rendered page."
   (let ((values nil)
         (content (clone-buffer)))
-    (save-excursion
-      (set-buffer content)
+    (with-current-buffer content
       (setq buffer-undo-list t)
       (emacspeak-xslt-run
        (emacspeak-xslt-get "id-values.xsl")
        (point-min) (point-max))
       (setq values (split-string (buffer-string))))
     (add-hook
-     'emacspeak-web-post-process-hook
+     'emacspeak-eww-post-process-hook
      (eval
       `#'(lambda nil
            (cl-declare (special  emacspeak-we-buffer-id-cache))
@@ -587,15 +526,14 @@ Tables are specified by containing  match pattern
   "Build role cache and forward it to rendered page."
   (let ((values nil)
         (content (clone-buffer)))
-    (save-excursion
-      (set-buffer content)
+    (with-current-buffer content
       (setq buffer-undo-list t)
       (emacspeak-xslt-run
        (emacspeak-xslt-get "role-values.xsl")
        (point-min) (point-max))
       (setq values (split-string (buffer-string))))
     (add-hook
-     'emacspeak-web-post-process-hook
+     'emacspeak-eww-post-process-hook
      (eval
       `#'(lambda nil
            (cl-declare (special  emacspeak-we-buffer-role-cache))
@@ -612,14 +550,22 @@ buffer. Interactive use provides list of class values as completion."
    (list
     (completing-read "Class: "
                      emacspeak-we-buffer-class-cache)
-    (emacspeak-webutils-read-url)
-    current-prefix-arg))
+    (emacspeak-eww-read-url)
+    (or (called-interactively-p 'interactive) current-prefix-arg)))
   (let ((filter (format "//*[contains(@class,\"%s\")]" class)))
     (emacspeak-we-xslt-filter filter
                               url
                               (or (called-interactively-p 'interactive)
                                   speak))))
 
+(defun emacspeak-we-extract-speakable (url &optional speak)
+  "Extract elements having class`speakable' from HTML. "
+  (interactive
+   (list
+    (emacspeak-eww-read-url)
+    (or (called-interactively-p 'interactive) current-prefix-arg)))
+  (emacspeak-we-extract-by-class "speakable" url speak))
+
 (defun emacspeak-we-extract-by-role (role    url &optional speak)
   "Extract elements having specified role attribute from HTML. Extracts
 specified elements from current WWW page and displays it in a separate
@@ -628,8 +574,8 @@ buffer. Interactive use provides list of role values as completion."
    (list
     (completing-read "Role: "
                      emacspeak-we-buffer-role-cache)
-    (emacspeak-webutils-read-url)
-    current-prefix-arg))
+    (emacspeak-eww-read-url)
+    (or (called-interactively-p 'interactive) current-prefix-arg)))
   (let ((filter (format "//*[contains(@role,\"%s\")]" role)))
     (emacspeak-we-xslt-filter filter
                               url
@@ -645,7 +591,7 @@ buffer. Interactive use provides list of class values as completion."
    (list
     (completing-read "Class: "
                      emacspeak-we-buffer-class-cache)
-    (emacspeak-webutils-read-this-url)
+    (emacspeak-eww-read-url)
     current-prefix-arg))
   (let ((filter (format "//*[contains(@class,\"%s\")]" class)))
     (emacspeak-we-xslt-junk filter
@@ -700,8 +646,8 @@ values as completion. "
    (list
     (let ((completion-ignore-case t))
       (emacspeak-we-css-get-class-list))
-    (emacspeak-webutils-read-url)
-    current-prefix-arg))
+    (emacspeak-eww-read-url)
+    (or (called-interactively-p 'interactive) current-prefix-arg)))
   (let ((filter
          (mapconcat
           #'(lambda  (c)
@@ -723,7 +669,7 @@ values as completion. "
    (list
     (let ((completion-ignore-case t))
       (emacspeak-we-css-get-class-list))
-    (emacspeak-webutils-read-this-url)
+    (emacspeak-eww-read-url)
     current-prefix-arg))
   (let ((filter
          (mapconcat
@@ -747,8 +693,8 @@ Interactive use provides list of id values as completion."
     (let ((completion-ignore-case t))
       (completing-read "Id: "
                        emacspeak-we-buffer-id-cache))
-    (emacspeak-webutils-read-url)
-    current-prefix-arg))
+    (emacspeak-eww-read-url)
+    (or (called-interactively-p 'interactive) current-prefix-arg)))
   (emacspeak-we-xslt-filter
    (format "//*[@id=\"%s\"]"
            id)
@@ -763,49 +709,8 @@ separate buffer. Interactive use provides list of id values as completion. "
   (interactive
    (list
     (emacspeak-we-get-id-list)
-    (emacspeak-webutils-read-url)
-    current-prefix-arg))
-  (let ((filter
-                 (mapconcat
-                  #'(lambda  (c)
-                      (format "(@id=\"%s\")" c))
-                  ids
-                  " or ")))
-               (emacspeak-we-xslt-filter
-                (format "//*[%s]" filter)
-                url
-                (or (called-interactively-p 'interactive)
-                    speak))))
-
-;;;###autoload
-(defun emacspeak-we-extract-id-text (id   url &optional speak)
-  "Extract text nodes from elements having specified id attribute from HTML. Extracts
-specified elements from current WWW page and displays it in a separate
-buffer.
-Interactive use provides list of id values as completion."
-  (interactive
-   (list
-    (let ((completion-ignore-case t))
-      (completing-read "Id: "
-                       emacspeak-we-buffer-id-cache))
-    (emacspeak-webutils-read-url)
-    current-prefix-arg))
-  (emacspeak-we-xslt-filter
-   (format "//*[@id=\"%s\"]//text()"
-           id)
-   url
-   speak))
-
-;;;###autoload
-(defun emacspeak-we-extract-id-list-text(ids   url &optional speak)
-  "Extract text nodes from elements having id specified in list `ids' from HTML.
-Extracts specified elements from current WWW page and displays it in a
-separate buffer. Interactive use provides list of id values as completion. "
-  (interactive
-   (list
-    (emacspeak-we-get-id-list)
-    (emacspeak-webutils-read-url)
-    current-prefix-arg))
+    (emacspeak-eww-read-url)
+    (or (called-interactively-p 'interactive) current-prefix-arg)))
   (let ((filter
          (mapconcat
           #'(lambda  (c)
@@ -813,13 +718,12 @@ separate buffer. Interactive use provides list of id values as completion. "
           ids
           " or ")))
     (emacspeak-we-xslt-filter
-     (format "//*[%s]//text()" filter)
+     (format "//*[%s]" filter)
      url
      (or (called-interactively-p 'interactive)
          speak))))
 
 ;;;###autoload
-
 (defvar emacspeak-we-url-rewrite-rule nil
   "URL rewrite rule to use in current buffer.")
 
@@ -839,9 +743,13 @@ used as well."
    (list
     (cond
      ((and (not current-prefix-arg)emacspeak-we-class-filter) emacspeak-we-class-filter)
-     (t (setq emacspeak-we-class-filter
-              (read-from-minibuffer "Class: "))))
-    (emacspeak-webutils-read-this-url)
+     (t
+      (setq emacspeak-we-class-filter
+            (read-from-minibuffer
+             "Class: "
+             nil nil nil nil
+             "article"))))
+    (emacspeak-eww-read-url)
     current-prefix-arg))
   (cl-declare (special emacspeak-we-class-filter emacspeak-we-url-rewrite-rule))
   (let ((redirect nil))
@@ -877,9 +785,9 @@ used as well."
             (read-from-minibuffer "Id: "))))
     current-prefix-arg))
   (cl-declare (special emacspeak-we-id-filter
-                    emacspeak-we-url-rewrite-rule))
-  (emacspeak-webutils-browser-check)
-  (let ((url (funcall emacspeak-webutils-url-at-point))
+                       emacspeak-we-url-rewrite-rule))
+  (emacspeak-eww-browser-check)
+  (let ((url (funcall emacspeak-eww-url-at-point))
         (redirect nil))
     (unless url
       (error "Not on a link."))
@@ -903,7 +811,7 @@ specifies the page to extract contents  from."
   (interactive
    (list
     (read-from-minibuffer "Style: ")
-    (emacspeak-webutils-read-url)
+    (emacspeak-eww-read-url)
     current-prefix-arg))
   (emacspeak-we-xslt-filter
    (format "//*[contains(@style,  \"%s\")]" style)
@@ -913,12 +821,9 @@ specifies the page to extract contents  from."
 ;;}}}
 ;;{{{ xpath  filter
 ;;;###autoload
-(defcustom emacspeak-we-recent-xpath-filter
-  "//p|//ol|//ul|//dl|//h1|//h2|//h3|//h4|//h5|//h6|//blockquote|//div"
-  "Caches most recently used xpath filter.
-Can be customized to set up initial default."
-  :type 'string
-  :group 'emacspeak-we)
+(defvar emacspeak-we-recent-xpath-filter
+  "//p"
+  "Caches most recently used xpath filter.")
 
 (defvar emacspeak-we-xpath-filter-history 
   (list
@@ -936,11 +841,9 @@ urls.")
 (make-variable-buffer-local 'emacspeak-we-xpath-filter)
 
 ;;;###autoload
-(defcustom emacspeak-we-paragraphs-xpath-filter
+(defvar emacspeak-we-paragraphs-xpath-filter
   "//p"
-  "Filter paragraphs."
-  :type 'string
-  :group 'emacspeak-we)
+  "Filter paragraphs.")
 
 ;;;###autoload
 (defun emacspeak-we-xpath-filter-and-follow (&optional prompt)
@@ -950,10 +853,10 @@ interactive prefix arg. If there is a known rewrite url rule, that is
 used as well."
   (interactive "P")
   (cl-declare (special emacspeak-we-xpath-filter
-                    emacspeak-we-recent-xpath-filter emacspeak-we-xpath-filter-history
-                    emacspeak-we-url-rewrite-rule))
-  (emacspeak-webutils-browser-check)
-  (let ((url (funcall emacspeak-webutils-url-at-point))
+                       emacspeak-we-recent-xpath-filter emacspeak-we-xpath-filter-history
+                       emacspeak-we-url-rewrite-rule))
+  (emacspeak-eww-browser-check)
+  (let ((url (funcall emacspeak-eww-url-at-point))
         (redirect nil))
     (unless url (error "Not on a link."))
     (when emacspeak-we-url-rewrite-rule
@@ -962,7 +865,8 @@ used as well."
              (cl-first emacspeak-we-url-rewrite-rule)
              (cl-second emacspeak-we-url-rewrite-rule)
              url)))
-    (when (or prompt (null emacspeak-we-xpath-filter))
+    (when (or prompt (null emacspeak-we-xpath-filter)
+              (= 0 (length emacspeak-we-xpath-filter)))
       (setq emacspeak-we-xpath-filter
             (read-from-minibuffer
              "Specify XPath: "
@@ -986,12 +890,10 @@ used as well."
 urls.")
 
 (make-variable-buffer-local 'emacspeak-we-class-filter)
-(defcustom emacspeak-we-recent-class-filter
+(defvar emacspeak-we-recent-class-filter
   nil
-  "Caches most recently used class filter.
-Can be customized to set up initial default."
-  :type 'string
-  :group 'emacspeak-we)
+  "Caches most recently used class filter.")
+
 ;;;###autoload
 (defun emacspeak-we-class-filter-and-follow-link (&optional prompt)
   "Follow url and point, and filter the result by specified class.
@@ -1000,10 +902,10 @@ interactive prefix arg. If there is a known rewrite url rule, that is
 used as well."
   (interactive "P")
   (cl-declare (special emacspeak-we-class-filter
-                    emacspeak-we-recent-class-filter emacspeak-we-class-filter-history
-                    emacspeak-we-url-rewrite-rule))
-  (emacspeak-webutils-browser-check)
-  (let ((url (funcall emacspeak-webutils-url-at-point))
+                       emacspeak-we-recent-class-filter emacspeak-we-class-filter-history
+                       emacspeak-we-url-rewrite-rule))
+  (emacspeak-eww-browser-check)
+  (let ((url (funcall emacspeak-eww-url-at-point))
         (redirect nil))
     (unless url (error "Not on a link."))
     (when emacspeak-we-url-rewrite-rule
@@ -1044,11 +946,11 @@ interactive prefix arg. If there is a known rewrite url rule, that is
 used as well."
   (interactive "P")
   (cl-declare (special emacspeak-we-xpath-junk
-                    emacspeak-we-xsl-junk
-                    emacspeak-we-recent-xpath-junk
-                    emacspeak-we-url-rewrite-rule))
-  (emacspeak-webutils-browser-check)
-  (let ((url (funcall emacspeak-webutils-url-at-point))
+                       emacspeak-we-xsl-junk
+                       emacspeak-we-recent-xpath-junk
+                       emacspeak-we-url-rewrite-rule))
+  (emacspeak-eww-browser-check)
+  (let ((url (funcall emacspeak-eww-url-at-point))
         (redirect nil))
     (unless url
       (error "Not on a link."))
@@ -1072,36 +974,6 @@ used as well."
 
 ;;}}}
 ;;{{{ Property filter
-(declare-function emacspeak-w3-html-stack "emacspeak-w3" nil)
-;;;###autoload
-(defun emacspeak-we-extract-by-property (url &optional speak)
-  "Interactively prompt for an HTML property, e.g. id or class,
-and provide a completion list of applicable  property values. Filter document by property that is specified."
-  (interactive
-   (list
-    (emacspeak-webutils-read-url)
-    current-prefix-arg))
-  (let* ((completion-ignore-case t)
-         (choices
-          (mapcar 'symbol-name (cl-intersection
-                                '(id class style role)
-                                (emacspeak-webutils-property-names-from-html-stack (emacspeak-w3-html-stack)))))
-         (property
-          (read
-           (completing-read "Property: "
-                            choices)))
-         (values (emacspeak-webutils-get-property-from-html-stack
-                  (emacspeak-w3-html-stack)
-                  property))
-         (v (completing-read "Having value: " values))
-         (filter
-          (if (eq property 'class)
-              (format "//*[contains(@%s, \"%s\")]"
-                      property v)
-            (format "//*[@%s=\"%s\"]"
-                    property v))))
-    (emacspeak-we-xslt-filter filter url
-                              (or (called-interactively-p 'interactive) speak))))
 
 ;;}}}
 ;;{{{  xsl keymap
@@ -1123,6 +995,7 @@ and provide a completion list of applicable  property values. Filter document by
            ("S" emacspeak-we-style-filter)
            ("T" emacspeak-we-extract-tables-by-position-list)
            ("X" emacspeak-we-extract-nested-table-list)
+           ("]" emacspeak-we-url-rewrite-and-follow)
            ("a" emacspeak-we-xslt-apply)
            ("b" emacspeak-we-follow-and-filter-by-id)
            ("c" emacspeak-we-extract-by-class)
@@ -1140,9 +1013,10 @@ and provide a completion list of applicable  property values. Filter document by
            ("t" emacspeak-we-extract-table-by-position)
            ("u" emacspeak-we-extract-matching-urls)
            ("v" emacspeak-we-class-filter-and-follow-link)
-           ;("w" emacspeak-we-extract-by-property)
+                                        ;("w" emacspeak-we-extract-by-property)
            ("x" emacspeak-we-extract-nested-table)
            ("y" emacspeak-we-class-filter-and-follow)
+           ("z" emacspeak-we-extract-speakable)
            )
          do
          (emacspeak-keymap-update emacspeak-we-xsl-map binding))
@@ -1168,9 +1042,8 @@ and provide a completion list of applicable  property values. Filter document by
 (provide 'emacspeak-we)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
