@@ -1,39 +1,39 @@
 ;;; emacspeak-widget.el --- Speech enable Emacs' native GUI widget library  -*- lexical-binding: t; -*-
-;;; $Id$
-;;; $Author: tv.raman.tv $ 
-;;; Description: Emacspeak extensions to widgets
-;;; Keywords:emacspeak, audio interface to emacs customized widgets
+;;
+;; $Author: tv.raman.tv $ 
+;; Description: Emacspeak extensions to widgets
+;; Keywords:emacspeak, audio interface to emacs customized widgets
 ;;{{{  LCD Archive entry: 
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2008-03-23 20:20:09 -0700 (Sun, 23 Mar 2008) $ |
-;;;  $Revision: 4532 $ | 
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ | 
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman 
-;;; Copyright (c) 1995 by T. V. Raman  
-;;; All Rights Reserved. 
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman 
+;; Copyright (c) 1995 by T. V. Raman  
+;; All Rights Reserved. 
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
 
@@ -41,8 +41,8 @@
 
 ;;; Commentary:
 
-;;; This module implements the necessary extensions to provide talking
-;;; widgets.
+;; This module implements the necessary extensions to provide talking
+;; widgets.
 
 ;;}}}
 ;;{{{ required modules 
@@ -51,31 +51,21 @@
 
 (require 'cl-lib)
 (cl-declaim  (optimize  (safety 0) (speed 3)))
-(require 'custom)
+(require 'emacspeak-preamble)
 (require 'voice-setup)
-(require 'dtk-speak)
-(require 'widget)
 (require 'wid-edit)
-(require 'emacspeak-speak)
-(require 'emacspeak-sounds)
-(require 'emacspeak-webutils)
+
 ;;}}}
 ;;{{{  Customize global behavior
 
-(defgroup emacspeak-widget nil
-  "Widgets on the Emacspeak Desktop."
-  :group 'emacspeak
-  :group 'widget
-  :prefix "emacspeak-widget")
-
 (voice-setup-add-map
  '(
    (widget-field voice-smoothen)
    (widget-single-line-field voice-smoothen)
    (widget-button voice-bolden)
    (widget-button-pressed voice-bolden-extra)
-   (widget-documentation voice-smoothen-extra)
-   (widget-inactive voice-lighten)
+   (widget-documentation voice-monotone-extra)
+   (widget-inactive voice-smoothen)
    ))
 
 (cl-declaim (special widget-menu-minibuffer-flag))
@@ -135,7 +125,7 @@ Returns a string with appropriate personality."
                            parent-help))
      (w (message (format " %s " type)))
      (t (message " Not on a widget. ")))))
-;;;###autoload        
+
 (defun emacspeak-widget-summarize-parent ()
   "Summarize parent of widget at point."
   (interactive)
@@ -145,8 +135,8 @@ Returns a string with appropriate personality."
      (p (emacspeak-widget-summarize p))
      (t (message "Widget at point has no parent")))))
 
-;;; Find summarizer for a specific widget type and dispatch.
-;;;###autoload
+;; Find summarizer for a specific widget type and dispatch.
+
 (defun emacspeak-widget-summarize(widget)
   "Summarize specified widget."
   (ems-with-messages-silenced
@@ -434,7 +424,7 @@ Returns a string with appropriate personality."
 (defun emacspeak-widget-help-checkbox (widget)
   "Summarize a checkbox"
   (let* ((value (widget-value widget))
-                                        ;sibling has the lable
+                                        ;sibling has the label
          (sibling (widget-get-sibling widget))
          (label (if sibling
                     (emacspeak-widget-label sibling)
@@ -513,13 +503,13 @@ Returns a string with appropriate personality."
 ;;}}}
 ;;{{{  Widget motion
 
-;;; avoid redundant message speech output
+;; avoid redundant message speech output
 (defadvice widget-echo-help (around emacspeak pre act comp)
   (ems-with-messages-silenced
    ad-do-it
    ad-return-value))
 (defadvice widget-beginning-of-line (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (cond
    ((ems-interactive-p)
     (let ((widget (widget-at (point))))
@@ -533,7 +523,7 @@ Returns a string with appropriate personality."
   ad-return-value)
 
 (defadvice widget-end-of-line (around emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (cond
    ((ems-interactive-p)
     (let ((widget (widget-at (point))))
@@ -547,19 +537,19 @@ Returns a string with appropriate personality."
   ad-return-value)
 
 (defadvice widget-forward (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'item)
     (emacspeak-widget-summarize (widget-at  (point)))))
 
 (defadvice widget-backward (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'item)
     (emacspeak-widget-summarize (widget-at (point)))))
 
 (defadvice widget-kill-line (after emacspeak pre act comp)
-  "Provide auditory feedback"
+  "speak"
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'delete-object)
     (emacspeak-speak-current-kill 0)
@@ -567,31 +557,25 @@ Returns a string with appropriate personality."
 
 ;;}}}
 ;;{{{  activating widgets:
-;;; forward declaration:
-(defvar emacspeak-we-url-executor)
+;; forward declaration:
+
 (defadvice widget-button-press (around emacspeak pre act comp)
-  "Provide auditory feedback"
-  (cl-declare (special emacspeak-webutils-url-at-point
-                    emacspeak-we-url-executor))
+  "speak"
   (let ((inhibit-read-only t)
         (widget (widget-at (ad-get-arg 0))))
     (cond
-     (widget                           ; First record some state:
+     (widget                            ; First record some state:
       (let ((pos (ad-get-arg 0))
             (old-position (point)))
         (cond
-         ((and
-           (or (eq major-mode 'eww-mode)(eq major-mode 'w3-mode) )
-           emacspeak-webutils-url-at-point
-           (funcall emacspeak-webutils-url-at-point)
-           emacspeak-we-url-executor
-           (boundp 'emacspeak-we-url-executor)
-           (fboundp emacspeak-we-url-executor))
+         ((and (eq major-mode 'eww-mode)
+               (bound-and-true-p emacspeak-we-url-executor)
+               (functionp emacspeak-we-url-executor))
           (emacspeak-auditory-icon 'button)
           (call-interactively 'emacspeak-we-url-expand-and-execute))
          (t ad-do-it
             (cond
-             ((= old-position (point)) ;did not move
+             ((= old-position (point))  ;did not move
               (emacspeak-auditory-icon 'button)
               (emacspeak-widget-summarize (widget-at pos)))
              (t  (emacspeak-auditory-icon 'large-movement)
@@ -636,7 +620,7 @@ widget before summarizing."
           (setq level 1)))
        ((= key ?d)
         (if (> level  0)
-            (decf level)
+            (cl-decf level)
           (message "Leaf widget")))
        (t (read-key-sequence "Press any key to continue")))
       (emacspeak-widget-summarize-widget-under-point level))))
@@ -663,7 +647,7 @@ widget before summarizing."
 (defadvice widget-setup (after emacspeak pre act comp)
   "Update widget keymaps."
   (cl-declare (special emacspeak-prefix
-                    widget-field-keymap widget-text-keymap))
+                       widget-field-keymap widget-text-keymap))
   (cl-loop
    for map in
    '(widget-field-keymap widget-text-keymap)
@@ -693,8 +677,8 @@ widget before summarizing."
     (emacspeak-widget-summarize w)))
 
 (cl-declaim (special widget-keymap
-                  widget-field-keymap
-                  widget-text-keymap))
+                     widget-field-keymap
+                     widget-text-keymap))
 
 ;;}}}
 
@@ -707,10 +691,10 @@ widget before summarizing."
 (define-widget 'personality 'item
   "Individual voice in a voice selector.")
 
-;;; We rely on dectalk-voice-table as our default voice table.
-;;; Names defined in this --- and other voice tables --- are
-;;; generic --and  not device specific.
-;;;
+;; We rely on dectalk-voice-table as our default voice table.
+;; Names defined in this --- and other voice tables --- are
+;; generic --and  not device specific.
+;; 
 
 (defun emacspeak-widget-create-voice-selector ()
   "Create a suitable voice selector widget."
@@ -728,9 +712,8 @@ widget before summarizing."
 (provide  'emacspeak-widget)
 ;;{{{  emacs local variables 
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end: 
+;; local variables:
+;; folded-file: t
+;; end: 
 
 ;;}}}
