@@ -1,50 +1,50 @@
 ;;; emacspeak-xkcd.el --- Speech-enable XKCD  -*- lexical-binding: t; -*-
-;;; $Id: emacspeak-xkcd.el 4797 2007-07-16 23:31:22Z tv.raman.tv $
-;;; $Author: tv.raman.tv $
-;;; Description:  Speech-enable XKCD An Emacs Interface to xkcd
-;;; Keywords: Emacspeak,  Audio Desktop xkcd
+;; $Id: emacspeak-xkcd.el 4797 2007-07-16 23:31:22Z tv.raman.tv $
+;; $Author: tv.raman.tv $
+;; Description:  Speech-enable XKCD An Emacs Interface to xkcd
+;; Keywords: Emacspeak,  Audio Desktop xkcd
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
-;;;  $Revision: 4532 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman
-;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNXKCD FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNXKCD FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  introduction
 
 ;;; Commentary:
-;;; XKCD ==  XKCD In Emacs
-;;; View XKCD comics in Emacs.
-;;; Speech enables package xkcd
-;;; Augments it by displaying the alt text and the transcript.
+;; XKCD ==  XKCD In Emacs
+;; View XKCD comics in Emacs.
+;; Speech enables package xkcd
+;; Augments it by displaying the alt text and the transcript.
 
 ;;}}}
 ;;{{{  Required modules
@@ -66,15 +66,15 @@
 ;;}}}
 
 (defadvice xkcd-kill-buffer (after emacspeak pre act comp)
-  "Provide auditory feedback."
+  "speak."
   (when (ems-interactive-p)
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defvar xkcd-transcript nil
   "Cache current transcript.")
-;;; Cache transcript.
-;;; Content downloaded by the time this is called.
+;; Cache transcript.
+;; Content downloaded by the time this is called.
 (defun emacspeak-xkcd-get-current-transcript ()
   "Cache current transcript."
   (cl-declare (special xkcd-cur))
@@ -117,9 +117,8 @@
 (provide 'emacspeak-xkcd)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
