@@ -1,56 +1,56 @@
 ;;; ladspa.el --- Ladspa Tools For Emacs  -*- lexical-binding: t; -*-
-;;; $Author: tv.raman.tv $
-;;; Description:  Expose Ladspa Plugins to Emacs/Emacspeak
-;;; Keywords: Emacspeak,  Audio Desktop Ladspa
+;; $Author: tv.raman.tv $
+;; Description:  Expose Ladspa Plugins to Emacs/Emacspeak
+;; Keywords: Emacspeak,  Audio Desktop Ladspa
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
-;;;  $Revision: 4532 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman
-;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNSOX FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNSOX FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  introduction
 
 ;;; Commentary:
 
-;;; This module  uses tools from the Ladspa SDK  to expose
-;;; Ladspa plugins in a consistent way to elisp.
-;;; The goal is to make it easy to inspect Ladspa Plugins,
-;;; And invoke them easily from  Ladspa host applications such as MPlayer.
-;;; See
-;;; @url{http://emacspeak.blogspot.com/2015/12/a-ladspa-work-bench-for-emacspeak.html}
-;;; Some Ladspa Packages that provide plugins:
-;;; sudo apt-get install zam-plugins wah-plugins vco-plugins tap-plugins 
-;;; swh-plugins rev-plugins mcp-plugins liquidsoap-plugin-ladspa 
-;;; ladspa-foo-plugins invada-studio-plugins-ladspa fil-plugins 
+;; This module  uses tools from the Ladspa SDK  to expose
+;; Ladspa plugins in a consistent way to elisp.
+;; The goal is to make it easy to inspect Ladspa Plugins,
+;; And invoke them easily from  Ladspa host applications such as MPlayer.
+;; See
+;; @url{http://emacspeak.blogspot.com/2015/12/a-ladspa-work-bench-for-emacspeak.html}
+;; Some Ladspa Packages that provide plugins:
+;; sudo apt-get install zam-plugins wah-plugins vco-plugins tap-plugins 
+;; swh-plugins rev-plugins mcp-plugins liquidsoap-plugin-ladspa 
+;; ladspa-foo-plugins invada-studio-plugins-ladspa fil-plugins 
 
 ;;; Code:
 
@@ -59,8 +59,9 @@
 
 (require 'cl-lib)
 (cl-declaim  (optimize  (safety 0) (speed 3)))
-(require 'subr-x)
-(require 'derived)
+(eval-when-compile
+  (require 'subr-x)
+  (require 'derived))
 ;;}}}
 ;;{{{ Structures:
 
@@ -74,10 +75,10 @@
 
 ;;}}}
 ;;{{{ Ladspa Setup:
-
+;;;###autoload
 (defconst ladspa-home
   (or (getenv "LADSPA_PATH") "/usr/lib/ladspa")
-  "Instalation location for Ladspa plugins.")
+  "Installation location for Ladspa plugins.")
 
 (defconst ladspa-analyse
   (executable-find "analyseplugin")
@@ -99,7 +100,7 @@
     (setq ladspa-plugins nil)
     (cl-loop
      for d in (split-string ladspa-home ":" t) do
-     (setq ladspa-libs (nconc ladspa-libs (directory-files d  nil "\\.so$"))))
+     (setq ladspa-libs (nconc ladspa-libs (directory-files d  nil "\\.so\\'"))))
     ladspa-libs)))
 
 ;;}}}
@@ -117,8 +118,8 @@
           (when (>= (length fields) 3)
             (split-string (cl-third fields) " " 'omit)))
          (default
-           (when (>= (length fields) 4)
-             (split-string (cl-fourth fields) " " 'omit)))
+          (when (>= (length fields) 4)
+            (split-string (cl-fourth fields) " " 'omit)))
          (result (make-ladspa-control)))
     (when (string-match "^Ports:" desc)
       (setq desc (string-trim (substring desc  7))))
@@ -137,7 +138,7 @@
          (lines (split-string
                  (shell-command-to-string
                   (format
-                   "%s   %s %s | grep  control "
+                   "%s   %s %s 2>/dev/null | grep  control "
                    ladspa-analyse library label))
                  "\n" 'omit-null))
          (result (make-ladspa-plugin :library library :label label :desc desc)))
@@ -154,7 +155,7 @@ list of parsed ladspa-plugin structures, one per label."
         (labels
          (split-string
           (shell-command-to-string
-           (format "%s -l %s" ladspa-analyse library))
+           (format "%s -l %s 2>/dev/null" ladspa-analyse library))
           "\n" 'omit-null)))
     (cl-loop for label in labels  do
              (push (ladspa-analyse-label library label) result))
@@ -248,7 +249,7 @@ list of parsed ladspa-plugin structures, one per label."
 
 ;;;###autoload
 (defun ladspa (&optional refresh)
-  "Launch Ladspa workbench."
+  "Ladspa workbench."
   (interactive "P")
   (cl-declare (special ladspa-libs ladspa-plugins))
   (let ((buffer (get-buffer-create "*Ladspa*")))
@@ -397,7 +398,7 @@ list of parsed ladspa-plugin structures, one per label."
     (error "No Ladspa Plugin here."))
   (let ((plugin (get-text-property (point) 'ladspa)))
     (shell-command
-     (format "%s %s %s"
+     (format "%s %s %s 2>/dev/null"
              ladspa-analyse
              (ladspa-plugin-library plugin) (ladspa-plugin-label plugin)))))
 
@@ -405,9 +406,8 @@ list of parsed ladspa-plugin structures, one per label."
 (provide 'ladspa)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
