@@ -1,94 +1,107 @@
 ;;; soundscape.el -- Soundscapes for The Emacspeak Desktop  -*- lexical-binding: t; -*-
-;;; Description:  Soundscapes Using Boodler
-;;; Keywords: Emacspeak,  Audio Desktop Soundscapes
+;; Description:  Soundscapes Using Boodler
+;; Keywords: Emacspeak,  Audio Desktop Soundscapes
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
-;;;  $Revision: 4532 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman
-;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNSOX FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNSOX FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  introduction
 
 ;;; Commentary:
-;;; Soundscapes @url{https://en.wikipedia.org/wiki/Soundscape}
-;;; define an acoustic environment.
-;;; Boodler  at @url{http://boodler.org} is a
-;;; Python-based SoundScape generator.
-;;; To use this module, first install boodler.
-;;; Then install the soundscape packages (*.boop) files available
-;;; at @url{http://boodler.org/lib}.
-;;; Make sure boodler works and produces audio in your environment.
-;;; finally install the Boodler packages  from
-;;; emacspeak/scapes from the Emacspeak GitHub repository by running
-;;; @code{cd emacspeak/scapes; make }
-;;;
-;;; When  boodler is set up and all packages installed, copy
-;;; file emacspeak/scapes/soundscapes  to ~/.boodler/Collection.
-;;; The above file lists all installed SoundScapes.
-;;; Directory emacspeak/scapes also contains
-;;; additional Boodler Agents and SoundScapes  that
-;;; I have created for use with Emacspeak.
-;;;
-;;;  Module soundscape.el  defines Emacs conveniences for running
-;;; Soundscapes. Main Entry Points:
-;;;
-;;;@itemize
-;;; @item M-x soundscape-toggle -- Enables or
-;;; disables automatic SoundScapes.
-;;; @item M-x soundscape --
-;;; runs a named SoundScape
-;;; @item M-x soundscape-stop -- Stops a specified running Soundscape.
-;;; @item M-x soundscape-kill -- Kills all running Soundscapes.
-;;;@end itemize
-;;;
-;;; When automatic Soundscapes are enabled, SoundScapes are
-;;;  started and stopped based on the current major
-;;; mode. Active Soundscape  are displayed as part of the minor-mode-alist.
-;;; Command emacspeak-speak-minor-mode-line can be used to have this spoken.
-;;;
-;;; Thus, SoundScapes can be thought of as reflecting the
-;;; @emph{mood} of the current @emph{mode}.
-;;; This package defines a single @var{soundscape-default-theme}
-;;; that is loaded using @code{(soundscape-load soundscape-default-theme)}.
-;;; Emacs modes that provide similar functionality e.g.,
-;;; communication == email, IM, ... map to  the same @emph{mood}.
+;; Soundscapes @url{https://en.wikipedia.org/wiki/Soundscape}
+;; define an acoustic environment.
+;; Boodler  at @url{http://boodler.org} is a
+;; Python-based SoundScape generator.
+;; To use this module, first install boodler.
+;; Then install the soundscape packages (*.boop) files available
+;; at @url{http://boodler.org/lib}.
+;; Make sure boodler works and produces audio in your environment.
+;; finally install the Boodler packages  from
+;; emacspeak/scapes from the Emacspeak GitHub repository by running
+;; @code{cd emacspeak/scapes; make }
+;; 
+;; When  boodler is set up and all packages installed, copy
+;; file emacspeak/scapes/soundscapes  to ~/.boodler/Collection.
+;; The above file lists all installed SoundScapes.
+;; Directory emacspeak/scapes also contains
+;; additional Boodler Agents and SoundScapes  that
+;; I have created for use with Emacspeak.
+;; 
+;;  Module soundscape.el  defines Emacs conveniences for running
+;; Soundscapes. Main Entry Points:
+;; 
+;; @itemize
+;; @item M-x soundscape-toggle -- Enables or
+;; disables automatic SoundScapes.
+;; @item M-x soundscape --
+;; runs a named SoundScape
+;; @item M-x soundscape-stop -- Stops a specified running Soundscape.
+;; @item M-x soundscape-kill -- Kills all running Soundscapes.
+;; @end itemize
+;; 
+;; When automatic Soundscapes are enabled, SoundScapes are
+;;  started and stopped based on the current major
+;; mode. Active Soundscape  are displayed as part of the minor-mode-alist.
+;; Command emacspeak-speak-minor-mode-line can be used to have this spoken.
+;; 
+;; Thus, SoundScapes can be thought of as reflecting the
+;; @emph{mood} of the current @emph{mode}.
+;; This package defines a single @var{soundscape-default-theme}
+;; that is loaded using @code{(soundscape-load soundscape-default-theme)}.
+;; Emacs modes that provide similar functionality e.g.,
+;; communication == email, IM, ... map to  the same @emph{mood}.
 ;;; Code:
 
+;; Automatic switching of soundscapes happens by sending a message to a UNIX domain socket in /tmp.
+;; This socket is created by Boodler on startup 
+;; ls /tmp/soundscape* to find the named pipe.
+;; To make sure the listener works correctly in your environment, 
+;;  try this in a shell:
+;; nc -U <name-of-socket>
+;; soundscape 1
+;; Above will switch to the first scape.
+;; soundscape 1 2 3 
+;; Will turn   on first three scapes.
+;; soundscape 0
+;;  Turns on null soundscape to give silence.
+
 ;;}}}
 ;;{{{  Required modules
 
 (require 'cl-lib)
 (cl-declaim  (optimize  (safety 0) (speed 3)))
-(require 'subr-x)
+(eval-when-compile (require 'subr-x))
 
 ;;}}}
 ;;{{{ Configuration:
@@ -117,23 +130,26 @@
 
 (defvar soundscape--scapes nil
   "Cache of currently running scapes.")
-;;;###autoload
-(defcustom soundscape-device nil
+
+(defcustom soundscape-device "default"
   "Alsa sound device to use for soundscapes."
   :type  '(choice  :tag "Device"
-                   (const :tag "None" nil)
+                   (const :tag "None" "default")
                    (string :tag "Alsa Device Name"))
   :group 'soundscape)
 
-;;;###autoload
+(defvar soundscape-volume 0.3
+  "Volume used for soundscape -- between 0 and 1")
+
 (defcustom soundscape-manager-options
-  '("-o" "alsa"
-    "-m" "0.3")
+  `(
+                                        ;"-o" "alsa"
+    "-m" ,(format "%s" soundscape-volume))
   "User customizable options list passed to boodler.
-Defaults specify alsa as the output and set master volume to 0.5"
+Defaults specify alsa as the output and set master volume"
   :group 'soundscape
   :type '(repeat
-          (string :tag "Option: ")))
+          (string :tag "Option")))
 
 ;;}}}
 ;;{{{ Catalog:
@@ -159,7 +175,7 @@ Defaults specify alsa as the output and set master volume to 0.5"
 (defun soundscape-catalog (&optional refresh)
   "Return catalog of installed Soundscapes, initialize if necessary."
   (cl-declare (special soundscape--catalog soundscape-list))
-  (when (null (file-exists-p soundscape-list)) (error "Catalog missing."))
+  (when (null (file-exists-p soundscape-list)) (error "Soundscape Catalog missing."))
   (cond
    ((and soundscape--catalog (null refresh)) soundscape--catalog)
    (t
@@ -199,7 +215,7 @@ Default is to return NullAgent if name not found."
   "Play soundscape."
   (interactive (list (soundscape-read)))
   (cl-declare (special soundscape-processes
-                    soundscape-device soundscape-manager-options))
+                       soundscape-device soundscape-manager-options))
   (let ((process-connection-type  nil)
         (proc (gethash scape soundscape-processes)))
     (unless (process-live-p proc)
@@ -239,7 +255,9 @@ Default is to return NullAgent if name not found."
 (defun soundscape-current ()
   "Return names of currently running scapes."
   (cl-declare (special soundscape--scapes))
-  (mapconcat #'soundscape-lookup-scape soundscape--scapes " "))
+  (concat
+   (mapconcat #'soundscape-lookup-scape soundscape--scapes " ")
+   " "))
 
 ;;}}}
 ;;{{{ Modes->SoundScapes:
@@ -251,7 +269,8 @@ Default is to return NullAgent if name not found."
   "Return associated soundscape for this mode if any."
   (let ((result nil))
     (while mode
-      (cl-pushnew (gethash mode soundscape-mode-table) result)
+      (cl-pushnew (gethash mode soundscape-mode-table) result
+                  :test #'string-equal)
       (setq mode (get mode 'derived-mode-parent)))
     (delq nil result)))
 
@@ -263,9 +282,6 @@ Default is to return NullAgent if name not found."
 ;;}}}
 ;;{{{ Default mapping:
 
-(defconst soundscape-web-modes
-  '(w3-mode eww-mode)
-  "List of mode-names that get the Web  mood.")
 (defconst soundscape-vc-modes
   '(magit-mode vc-mode)
   "Version control modes.")
@@ -283,7 +299,6 @@ Default is to return NullAgent if name not found."
     Custom-mode messages-buffer-mode)
   "List of mode names that get the Help mood.")
 
-;;;###autoload
 (defun soundscape-load-theme (theme)
   "Sets up automatic Soundscape mappings based on theme.
 See  \\{soundscape-default-theme} for details."
@@ -300,16 +315,17 @@ See  \\{soundscape-default-theme} for details."
   `(
     ("()" nil)
     ("BirdCalls" nil)
-    ("BirdSongs" nil)
-    ("BirdChorus" (shell-mode term-mode))
+    ("BirdSongs" (threes-mode))
+    ("BirdChorus" (shell-mode term-mode eshell-mode))
     ("BlopEchoes"  (elfeed-search-mode))
     ("Bonfire" (calendar-mode diary-mode))
-    ("BuddhaLoop" nil)
+    ("BuddhaLoop" (comint-mode))
+    ("BuddhaLoop" (chess-display-mode))
     ("RandomLoop" nil)
     ("LoopStew" (lisp-interaction-mode))
     ("Cavern" (prog-mode))
     ("ChangingLoops" (special-mode))
-    ("ChangingLoopsPitches" (comint-mode))
+    ("ChangingLoopsPitches" nil)
     ("Drip" ,soundscape-communication-modes)
     ("GardenBackground" nil)
     ("LoopStew" (emacspeak-m-player-mode))
@@ -320,15 +336,17 @@ See  \\{soundscape-default-theme} for details."
     ("MockingBirds" nil)
     ("MockingCuckoos" nil)
     ("Nightscape" (emacspeak-screen-saver-mode))
-    ("NoStormYet"  (fundamental-mode))
+    ("BirdCalls"  (fundamental-mode))
     ("RainForever" ,soundscape-help-modes)
     ("RainSounds" ,soundscape-vc-modes)
-    ("Still" (text-mode view-mode))
-    ("SurfWaves"  ,soundscape-web-modes)
+    ("BirdCalls" (text-mode view-mode))
+    ("BuddhaLoop" (org-mode))
+    ("SurfWaves"  (eww-mode))
+    
     ("TonkSpace" (tabulated-list-mode))
     ("WaterFlow"  (dired-mode))
     )
-  "*Specifies default map.
+  "Specifies default map.
 Map is a list of lists, where the first element of each sublist
 is a Soundscape name, and the second element is a list of
 Soundscape names. Soundscape at position 0 (the first entry in
@@ -352,14 +370,14 @@ Optional interactive prefix arg `prompt-mode' prompts for the mode."
           (soundscape-lookup-name
            (completing-read "Scape:" (mapcar 'car soundscape-default-theme)))))
     (soundscape-map-mode mode scape)
-        (soundscape-sync major-mode)
+    (soundscape-sync major-mode)
     (message "Now using %s for %s" scape mode)))
 
 ;;}}}
 ;;{{{ Soundscape Remote Control
 
 (defvar soundscape--remote
-  (make-temp-name "/tmp/soundscape")
+  (make-temp-name (expand-file-name  "soundscape" temporary-file-directory))
   "Name of Unix Domain socket used to control Soundscape.")
 
 (defun soundscape-sentinel (proc _state)
@@ -393,7 +411,7 @@ Optional interactive prefix arg `prompt-mode' prompts for the mode."
 
 ;;;###autoload
 (defun soundscape-init ()
-  "Initialize Soundscape module."
+  "Initialize Soundscape."
   (soundscape-catalog)
   (soundscape-listener)
   (unless (member '(soundscape--auto (:eval (soundscape-current)))
@@ -404,11 +422,11 @@ Optional interactive prefix arg `prompt-mode' prompts for the mode."
 (defun soundscape-listener  (&optional restart)
   "Start  a Soundscape listener.
 Listener is loaded with all Soundscapes defined in `soundscape-default-theme' .
-Optional interactive prefix arg restarts the listener if already running."
+Optional interactive prefix arg restarts the listener."
   (interactive "P")
   (cl-declare (special soundscape-listener-process soundscape--remote
-                    soundscape-manager-options soundscape-device
-                    soundscape-remote-control soundscape-default-theme))
+                       soundscape-manager-options soundscape-device
+                       soundscape-remote-control soundscape-default-theme))
   (let ((process-connection-type nil))
     (cond
      ((or restart (not (process-live-p soundscape-listener-process)))
@@ -433,7 +451,7 @@ Optional interactive prefix arg restarts the listener if already running."
   "Shutdown listener."
   (interactive)
   (cl-declare (special soundscape-listener-process soundscape-remote-control
-                    soundscape--scapes))
+                       soundscape--scapes))
   (setq soundscape--scapes nil)
   (when (process-live-p soundscape-listener-process)
     (delete-process soundscape-listener-process))
@@ -443,7 +461,7 @@ Optional interactive prefix arg restarts the listener if already running."
     (delete-file soundscape--remote)))
 
 (defun soundscape-remote (names)
-  "Activate scapes named names."
+  "Activate scapes named `names' --- a list of strings."
   (interactive
    (list
     (let ((completion-ignore-case t)
@@ -453,7 +471,7 @@ Optional interactive prefix arg restarts the listener if already running."
         (setq name
               (completing-read "Soundscape Name:"
                                (mapcar #'car soundscape-default-theme)))
-        (when (> (length name) 0) (push name  result)))
+        (when (> (length name) 0) (push name result)))
       result)))
   (cl-declare (special soundscape-remote-nc))
   (unless (process-live-p soundscape-listener-process) (soundscape-listener))
@@ -461,9 +479,10 @@ Optional interactive prefix arg restarts the listener if already running."
     (when (and (process-live-p soundscape-listener-process)
                (file-exists-p soundscape--remote))
       (setq soundscape-remote-control
-            (make-network-process  :name "nc-connect"
-                                   :family 'local
-                                   :remote soundscape--remote))))
+            (make-network-process
+             :name "nc-connect"
+             :family 'local
+             :remote soundscape--remote))))
   (when (process-live-p soundscape-remote-control)
     (process-send-string
      soundscape-remote-control
@@ -473,7 +492,6 @@ Optional interactive prefix arg restarts the listener if already running."
 ;;}}}
 ;;{{{ Automatic soundscapes:
 
-;;;###autoload
 (defvar soundscape--auto nil
   "Record if automatic soundscapes are on.
 Do not set this by hand, use command \\[soundscape-toggle].")
@@ -501,23 +519,27 @@ Optional interactive prefix arg `force' skips optimization checks."
        (string-prefix-p " *Minibuf-" (buffer-name))
        (string-match "temp" (buffer-name)))
     (setq soundscape--last-mode major-mode)
-    (soundscape-sync major-mode)))
+    (soundscape-sync major-mode 'force)))
 
-;;; Advice on select-window, force-mode-line-update etc fire too often.
-;;; Ditto with buffer-list-update-hook
-;;; Running on an idle timer can
-;;;  soundscape-delay (default is 0.1)
-;;;   triggers fewer spurious changes than running on advice.
+(defun soundscape-tickle ()
+  "Function to unconditionally update Soundscape automatically."
+  (cl-declare (special  soundscape--last-mode))
+  (setq soundscape--last-mode major-mode)
+  (soundscape-sync major-mode 'force))
+
+;; Advice on select-window, force-mode-line-update etc fire too often.
+;; Ditto with buffer-list-update-hook
+;; Running on an idle timer 
+;;  soundscape-delay (default is 0.1)
+;;   triggers fewer spurious changes than running on advice.
 
 ;;}}}
 ;;{{{ SoundScape Toggle:
-(defun
-    soundscape-quiet ()
+(defun soundscape-quiet ()
   "Activate NullAgent."
   (when (process-live-p soundscape-remote-control)
     (process-send-string soundscape-remote-control "soundscape 0\n")))
 
-;;;###autoload
 (defcustom soundscape-idle-delay 0.1
   "Number of seconds of idle time
 before soundscapes are synchronized with current mode."
@@ -527,11 +549,10 @@ before soundscapes are synchronized with current mode."
 ;;;###autoload
 (defun soundscape-toggle ()
   "Toggle automatic SoundScapes.
-When turned on, Soundscapes are automatically run based on current major mode.
 Run command \\[soundscape-theme] to see the default mode->mood mapping."
   (interactive)
   (cl-declare (special soundscape--auto soundscape--scapes
-                    soundscape-idle-delay soundscape--last-mode))
+                       soundscape-idle-delay soundscape--last-mode))
   (cond
    (soundscape--auto
     (cancel-timer soundscape--auto)
@@ -557,28 +578,36 @@ Run command \\[soundscape-theme] to see the default mode->mood mapping."
     "tts_a45_em45" "tts_a135_em45" "tts_a225_em45" "tts_am45_em45")
   "Available virtual ALSA devices for filtering soundscapes.")
 
-(defun soundscape-restart (&optional device)
+(defun soundscape-restart (&optional prompt)
   "Restart Soundscape  environment.
-With prefix arg `device', prompt for a alsa/ladspa device.
-This is then saved to soundscape-device for future use."
+With prefix arg `prompt', prompt for a alsa/ladspa device and volume.
+The  is then saved to soundscape-device for future use."
   (interactive "P")
   (cl-declare (special soundscape--last-mode  soundscape--scapes
-                    soundscape--filters soundscape--auto
-                    soundscape-manager-options soundscape-device))
+                       soundscape--filters soundscape--auto
+                       soundscape-volume soundscape-manager-options
+                       soundscape-device))
   (setq soundscape--scapes nil soundscape--last-mode nil)
-  (when  device
+  (when  prompt
+    (setq soundscape-volume
+          (read-number  "Soundscape Volume:" soundscape-volume))
+    (cl-assert (< 0 soundscape-volume) t "Volume must be positive."
+               soundscape-volume)
+    (cl-assert (< soundscape-volume 1) t "Volume must be positive."
+               soundscape-volume)
     (setq soundscape-device
           (if (called-interactively-p 'interactive)
               (completing-read
-               "Filter: "
+               "Soundscape Filter: "
                soundscape--filters)
-            device)))
-    (when soundscape--auto
-      (soundscape-toggle)
-      (soundscape-listener-shutdown))
+            "default"))
+    (setq soundscape-manager-options
+          `("-o" "alsa"
+            "-m" ,(format "%s" soundscape-volume))))
+  (when soundscape--auto
     (soundscape-toggle)
-    (sit-for 0.1)
-    (soundscape-sync major-mode 'force))
+    (soundscape-listener-shutdown))
+  (soundscape-toggle))
 
 ;;}}}
 ;;{{{ Display Theme:
@@ -615,9 +644,8 @@ This is then saved to soundscape-device for future use."
 (provide 'soundscape)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
