@@ -1,151 +1,140 @@
 ;;; sox-gen.el --- Binaural Beats And More Using SoX -*- lexical-binding: t; -*-
-;;; $Author: tv.raman.tv $
-;;; Description:  collection of SoX  sound generators including Binaural Beats
-;;; Keywords: Emacspeak,  Audio Desktop sox
+;; $Author: tv.raman.tv $
+;; Description:  collection of SoX  sound generators including Binaural Beats
+;; Keywords: Emacspeak,  Audio Desktop sox
 ;;{{{  LCD Archive entry:
 
-;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
-;;; A speech interface to Emacs |
-;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
-;;;  $Revision: 4532 $ |
-;;; Location undetermined
-;;;
+;; LCD Archive Entry:
+;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
+;; A speech interface to Emacs |
+;; 
+;;  $Revision: 4532 $ |
+;; Location undetermined
+;; 
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2017, T. V. Raman
-;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
-;;; All Rights Reserved.
-;;;
-;;; This file is not part of GNU Emacs, but the same permissions apply.
-;;;
-;;; GNU Emacs is free software; you can redistribute it and/or modify
-;;; it under the terms of the GNU General Public License as published by
-;;; the Free Software Foundation; either version 2, or (at your option)
-;;; any later version.
-;;;
-;;; GNU Emacs is distributed in the hope that it will be useful,
-;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;;; MERCHANTABILITY or FITNSOX FOR A PARTICULAR PURPOSE.  See the
-;;; GNU General Public License for more details.
-;;;
-;;; You should have received a copy of the GNU General Public License
-;;; along with GNU Emacs; see the file COPYING.  If not, write to
-;;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+;; Copyright (C) 1995 -- 2022, T. V. Raman
+;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
+;; All Rights Reserved.
+;; 
+;; This file is not part of GNU Emacs, but the same permissions apply.
+;; 
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
+;; 
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNSOX FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;; 
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs; see the file COPYING.  If not, write to
+;; the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 
 ;;}}}
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  introduction
 
 ;;; Commentary:
 
-;;; Provides binaural audio along with pre-defined themes.
-;;; This module can be used independent of Emacspeak.
+;; Provides binaural audio along with pre-defined themes.
+;; This module can be used independent of Emacspeak.
 
-;;; @subsection Binaural Beats  Using SoX
-;;;
-;;; A binaural beat is an auditory illusion perceived when two different
-;;; pure-tone sine waves, both with frequencies lower than 1500 Hz, with
-;;; less than a 40 Hz difference between them, are presented to a listener
-;;; dichotically (one through each ear). For example, if a 530 Hz pure tone
-;;; is presented to a subject's right ear, while a 520 Hz pure tone is
-;;; presented to the subject's left ear, the listener will perceive the
-;;; auditory illusion of a third tone, in addition to the two pure-tones
-;;; presented to each ear. The third sound is called a binaural beat, and in
-;;; this example would have a perceived pitch correlating to a frequency of
-;;; 10 Hz, that being the difference between the 530 Hz and 520 Hz pure
-;;; tones presented to each ear. For more details, see
-;;; @url{https://en.wikipedia.org/wiki/Binaural_beats}.
-;;;
-;;; This module implements a set of user-facing commands for generating
-;;; binaural beats. The commands are organized from high-level commands that
-;;; play predefined binaural beats to lower-level commands that can be
-;;; used to create new effect sequences.
-;;;
-;;; All binaural beat sequences are played with a relatively low gain
-;;; --- they are designed to be heard in the background and when
-;;; effective blend fully into the background. You can increase the
-;;; overall volume of all binaural beat sequences by customizing
-;;; @defvar {User Option} sox-binaural-gain-offset to a positive value
-;;; @end defvar
-;;; --- default is 0.
-;;;
-;;; @subsubsection High-Level Commands For Pre-Defined Binaural Beats
-;;;
-;;; These commands can be called directly to play one of the predefined
-;;; binaural beats.
-;;;
-;;; @itemize
-;;; @item @command{sox-rev-up}: A set of binaural beats designed for  use
-;;; at the start of the day. Transitions from @emph{Dream} -> @emph{Think}
-;;; ->@emph{Act} -> @emph{Focus}.
-;;; @item @command{sox-wind-down}: A  set of binaural beats for winding down
-;;; at the end of the day. This can be thought of as the reverse of
-;;; @command{sox-rev-up} and the sequence transitions from @emph{Act} ->
-;;; @emph{Think} -> @emph{Dream} ->@emph{Sleep}.
-;;; @item @command{sox-turn-down}: Designed for falling asleep.
-;;; This sequence starts with a short period of @emph{Dream} before moving
-;;; to @emph{Sleep}.
-;;; @item @command{sox-relax}:  A variant of the previous sequence,
-;;; @code{sox-relax} spends equal time in @emph{Dream} and @emph{Sleep}.
-;;; @item @command{sox-binaural}: Provide a completion-based front-end to
-;;; playing any one of the predefined binaural effects (@emph{Delta},
-;;; @emph{Theta}, @emph{Alpha}, @emph{Beta}, or @emph{Gamma}. The previously
-;;; defined sequences are built up using these effects.
-;;; @item @command{sox-beats-binaural}: Plays a collection of binaural
-;;; beats, prompting for carrier and beat frequencies for each tone. The
-;;; predefined sequences listed earlier were created after first generating
-;;; experimental beat-sequences using this command.
-;;; @item @command{sox-slide-binaural}: Prompts for two binaural effects
-;;; (see above) and generates a binaural beat that @emph{slides} from the
-;;; first effect to the second over a specified duration.
-;;; @item @command{sox-chakras}: Pick  amongst one of a predefined set of
-;;; sequences designed for @emph{Chakra} meditation.
-;;; @item @command{sox-tone-binaural}: Generate a simple binaural beat
-;;; with a single carrier frequency.
-;;; @item @command{sox-tone-slide-binaural}: Generate a  tone that slides
-;;; from one binaural beat to another.
-;;; @end itemize
-;;;
+;; @subsection Binaural Beats  Using SoX
+;; 
+;; A binaural beat is an auditory illusion perceived when two different
+;; pure-tone sine waves, both with frequencies lower than 1500 Hz, with
+;; less than a 40 Hz difference between them, are presented to a listener
+;; dichotically (one through each ear). For example, if a 530 Hz pure tone
+;; is presented to a subject's right ear, while a 520 Hz pure tone is
+;; presented to the subject's left ear, the listener will perceive the
+;; auditory illusion of a third tone, in addition to the two pure-tones
+;; presented to each ear. The third sound is called a binaural beat, and in
+;; this example would have a perceived pitch correlating to a frequency of
+;; 10 Hz, that being the difference between the 530 Hz and 520 Hz pure
+;; tones presented to each ear. For more details, see
+;; @url{https://en.wikipedia.org/wiki/Binaural_beats}.
+;; 
+;; This module implements a set of user-facing commands for generating
+;; binaural beats. The commands are organized from high-level commands that
+;; play predefined binaural beats to lower-level commands that can be
+;; used to create new effect sequences.
+;; 
+;; All binaural beat sequences are played with a relatively low gain
+;; --- they are designed to be heard in the background and when
+;; effective blend fully into the background. You can increase the
+;; overall volume of all binaural beat sequences by customizing
+;; @defvar {User Option} sox-binaural-gain-offset to a positive value
+;; @end defvar
+;; --- default is 0.
+;; 
+;; @subsubsection High-Level Commands For Pre-Defined Binaural Beats
+;; 
+;; These commands can be called directly to play one of the predefined
+;; binaural beats.
+;; 
+;; @itemize
+;; @item @command{sox-rev-up}: A set of binaural beats designed for  use
+;; at the start of the day. Transitions from @emph{Dream} -> @emph{Think}
+;; ->@emph{Act} -> @emph{Focus}.
+;; @item @command{sox-wind-down}: A  set of binaural beats for winding down
+;; at the end of the day. This can be thought of as the reverse of
+;; @command{sox-rev-up} and the sequence transitions from @emph{Act} ->
+;; @emph{Think} -> @emph{Dream} ->@emph{Sleep}.
+;; @item @command{sox-turn-down}: Designed for falling asleep.
+;; This sequence starts with a short period of @emph{Dream} before moving
+;; to @emph{Sleep}.
+;; @item @command{sox-relax}:  A variant of the previous sequence,
+;; @code{sox-relax} spends equal time in @emph{Dream} and @emph{Sleep}.
+;; @item @command{sox-binaural}: Provide a completion-based front-end to
+;; playing any one of the predefined binaural effects (@emph{Delta},
+;; @emph{Theta}, @emph{Alpha}, @emph{Beta}, or @emph{Gamma}. The previously
+;; defined sequences are built up using these effects.
+;; @item @command{sox-beats-binaural}: Plays a collection of binaural
+;; beats, prompting for carrier and beat frequencies for each tone. The
+;; predefined sequences listed earlier were created after first generating
+;; experimental beat-sequences using this command.
+;; @item @command{sox-slide-binaural}: Prompts for two binaural effects
+;; (see above) and generates a binaural beat that @emph{slides} from the
+;; first effect to the second over a specified duration.
+;; @item @command{sox-chakras}: Pick  amongst one of a predefined set of
+;; sequences designed for @emph{Chakra} meditation.
+;; @item @command{sox-tone-binaural}: Generate a simple binaural beat
+;; with a single carrier frequency.
+;; @item @command{sox-tone-slide-binaural}: Generate a  tone that slides
+;; from one binaural beat to another.
+;; @end itemize
+;; 
 ;;; Code:
 
 ;;}}}
 ;;{{{  Required modules
 
 (require 'cl-lib)
+(require 'dtk-speak)
 (cl-declaim  (optimize  (safety 0) (speed 3)))
-(require 'sox)
 
 ;;}}}
 ;;{{{ sox-gen-p:
-;;;###autoload
-(defcustom sox-gen-p (executable-find "sox")
-  "Should sox-gen commands attempt to invoke SoX."
-  :type 'boolean
-  :group 'sox-gen)
+
+(defvar sox-gen-p
+  (eval-when-compile (executable-find "sox"))
+  "Is sox available?")
 
 ;;}}}
 ;;{{{ SoX Command Generator:
-(defvar sox-gen-processes nil
-  "Handle to list of running sox processes.")
+(defvar sox-gen-play (executable-find "play")
+  "Location of play from SoX.")
 
 (defun sox-gen-cmd (cmd)
   "Play specified command."
-  (cl-declare (special sox-play sox-gen-p sox-gen-processes))
+  (cl-declare (special sox-gen-play sox-gen-p))
   (when sox-gen-p
-    (push 
-     (apply #'start-process "SoX" nil sox-play  (split-string cmd))
-     sox-gen-processes)))
-
-(defun sox-gen-kill-process ()
-  "Delete SoX process at the front of the sox-gen-processes list."
-  (interactive)
-  (cl-declare (special sox-gen-processes))
-  (let ((proc (pop sox-gen-processes)))
-    (when proc (delete-process proc)
-          (message "Deleted sox generator."))))
+    (apply #'start-process "SoX" nil sox-gen-play  (split-string cmd))))
 
 ;;}}}
 ;;{{{ Binaural Audio:
@@ -159,7 +148,6 @@ tones using SoX, e.g., for binaural beats."
   "-q -n synth %s sin %s sin %s gain %s channels 2 "
   "Command-line that produces a binaural beat.")
 
-;;;###autoload
 (defun sox-tone-binaural (length freq beat gain)
   "Play binaural audio with carrier frequency `freq', beat `beat', and
 gain `gain'."
@@ -176,7 +164,6 @@ gain `gain'."
     freq (+ freq beat)
     (+ gain sox-binaural-gain-offset))))
 
-;;;###autoload
 (defun sox-tone-slide-binaural (length freq beat-start beat-end  gain)
   "Play binaural audio with carrier frequency `freq', beat
 `beat-start' -> `beat-end', and gain `gain'."
@@ -200,7 +187,7 @@ gain `gain'."
   "Command-line that produces multiple  binaural beats.")
 
 (defun sox-read-binaural-beats ()
-  "Read and return a list of binaural beat-spec tupples."
+  "Read and return a list of binaural beat-spec tuples."
   (let ((specs nil)
         (this-freq 0)
         (this-beat nil))
@@ -212,10 +199,9 @@ gain `gain'."
         (push (list this-freq this-beat) specs)))
     (nreverse specs)))
 
-;;;###autoload
 (defun sox-beats-binaural (length beat-spec-list  gain)
   "Play binaural audio with beat-spec specifying the various tones.
-Param `beat-spec-list' is a list of `(carrier beat) tupples."
+Param `beat-spec-list' is a list of `(carrier beat) tuples."
   (interactive
    (list
     (timer-duration(read-from-minibuffer "Duration: "))
@@ -271,14 +257,14 @@ Param `beat-spec-list' is a list of `(carrier beat) tupples."
       (error "Effect not defined.")))
 ;;{{{  Define Effects:
 
-;;; delta, theta, alpha, beta, gamma
-;;; sleep, dream, think, act, focus
+;; delta, theta, alpha, beta, gamma
+;; sleep, dream, think, act, focus
 
 (sox-define-binaural-effect
  "sleep" ; delta
  (make-sox--binaural
   :beats '((75 0.5) (150 1.0) (225 2.0) (300 4.0))
-  :gain -10))
+  :gain -20))
 
 (sox-define-binaural-effect
  "dream" ; theta
@@ -301,15 +287,15 @@ Param `beat-spec-list' is a list of `(carrier beat) tupples."
 (sox-define-binaural-effect
  "focus" ; gamma
  (make-sox--binaural
-  :beats '((75 40) (150 40) (225 40) (300 40.0))
-  :gain -10))
+  :beats '((75 40.0) (150 40.0) (225 40.0) (300 40.0))
+  :gain -20))
+
 ;; }}}
 
-(defun sox--format-seconds (seconds)
+(defun sox--format-seconds (secs)
   "Audio-format seconds."
-  (format-seconds "%H %M and%z %S" seconds))
+  (format-seconds "%H %M and%z %S" secs))
 
-;;;###autoload
 (defun sox-binaural (name duration)
   "Play specified binaural effect."
   (interactive
@@ -318,11 +304,9 @@ Param `beat-spec-list' is a list of `(carrier beat) tupples."
                      nil 'must-match)
     (timer-duration (read-from-minibuffer "Duration: "))))
   (sox--binaural-play duration (sox-binaural-get-effect name))
-  (when emacspeak-use-auditory-icons(emacspeak-play-auditory-icon 'time))
   (dtk-notify-say
    (format "%s: %s" name (sox--format-seconds duration))))
 
-;;;###autoload
 (defun sox-slide-binaural (name-1 name-2 duration)
   "Play specified binaural slide from `name-1' to `name-2'."
   (interactive
@@ -338,7 +322,6 @@ Param `beat-spec-list' is a list of `(carrier beat) tupples."
     (run-with-timer
      dur nil
      #'(lambda (n1 n2  d)
-         (when emacspeak-use-auditory-icons(emacspeak-play-auditory-icon 'time))
          (dtk-notify-say
           (format "%s  to %s %s" n1 n2 (sox--format-seconds d)))
          (sox--binaural-play  d slide))
@@ -369,7 +352,7 @@ Param `beat-spec-list' is a list of `(carrier beat) tupples."
       (let ((a-i (elt a-beats i))
             (b-i (elt b-beats i)))
         (list
-         (/ (+ (cl-first a-i) (first b-i)) 2) ; carrier frequency
+         (/ (+ (cl-first a-i) (cl-first b-i)) 2) ; carrier frequency
          (list (cl-second a-i) (cl-second b-i))))))))
 
 ;;}}}
@@ -393,7 +376,7 @@ Param `beat-spec-list' is a list of `(carrier beat) tupples."
   '(("dream" 4) ("sleep" 4))
   "List of  beats to use for relaxing.")
 
-;;; Theme Helper:
+;; Theme Helper:
 (defcustom sox-binaural-slider-scale 5.0
   "Scale factor used to compute slide duration when moving from one
 binaural beat to another."
@@ -417,7 +400,7 @@ binaural beat to another."
     sox--theme-duration-scale (theme duration)
   "Given a theme and a desired overall duration, compute duration scale."
   (cl-declare (special sox-binaural-slider-scale))
-  (let ((steps (mapcar #'second theme)))
+  (let ((steps (mapcar #'cl-second theme)))
     (/
      (timer-duration duration)
      (+ (apply #'+ steps)
@@ -445,7 +428,7 @@ binaural beat to another."
             (sox-binaural this then))
         b end)
        (setq start (+ start end))
-;;; slider
+       ;; slider
        (when (and next (not (zerop slider-len)))
          (run-with-timer                ; start  at slider-start
           slider-start nil              ; no repeat
@@ -459,34 +442,26 @@ binaural beat to another."
           b next slider-len)
          (setq start (+ start slider-len)))))))
 
-;;;###autoload
 (defun sox-rev-up (length)
-  "Play rev-up set of  binaural beats.
-Param `length' specifies total duration."
+  "Play rev-up set of  binaural beats for `length' seconds. "
   (interactive "sDuration: ")
   (cl-declare (special sox-rev-up-beats))
   (sox--theme-play sox-rev-up-beats length))
 
-;;;###autoload
 (defun sox-turn-down (length)
-  "Play turn-down set of  binaural beats.
-Param `length' specifies total duration."
+  "Play turn-down set of  binaural beats for `length' seconds. "
   (interactive "sDuration: ")
   (cl-declare (special sox-turn-down-beats))
   (sox--theme-play sox-turn-down-beats length))
 
-;;;###autoload
 (defun sox-wind-down (length)
-  "Play wind-down set of  binaural beats.
-Param `length' specifies total duration."
+  "Play wind-down set of  binaural beats for `length' seconds."
   (interactive "sDuration: ")
   (cl-declare (special sox-wind-down-beats))
   (sox--theme-play sox-wind-down-beats length))
 
-;;;###autoload
 (defun sox-relax (length)
-  "Play relax set of  binaural beats.
-Param `length' specifies total duration."
+  "Play relax set of  binaural beats for `length' seconds."
   (interactive "sDuration: ")
   (cl-declare (special sox-relax-beats))
   (sox--theme-play sox-relax-beats length))
@@ -494,8 +469,8 @@ Param `length' specifies total duration."
 ;;}}}
 ;;{{{ Chakra Themes:
 
-;;; Default Theme For Chakras:
-;;; From: https://www.youtube.com/watch?v=ARoih8HTPGw
+;; Default Theme For Chakras:
+;; From: https://www.youtube.com/watch?v=ARoih8HTPGw
 
 (defconst sox--chakra-settings-0
   '(
@@ -515,20 +490,20 @@ Param `length' specifies total duration."
   (cl-first s)
   (make-sox--binaural
    :beats `(,(cdr s))
-   :gain -10)))
+   :gain -20)))
 
-;;; Chakras: Set 1:Carrier frequencies taken from  the Web.
-;;; https://sourceforge.net/p/sbagen/mailman/message/3047882/
+;; Chakras: Set 1:Carrier frequencies taken from  the Web.
+;; https://sourceforge.net/p/sbagen/mailman/message/3047882/
 
 (defconst sox--chakra-settings-1
   '(
-    ("root-0" 256 7.83)
-    ("navel-0" 288 7.83)
-    ("solar-plexus-0" 320 7.83)
-    ("heart-0" 341.3 7.83)
-    ("throat-0" 384 7.83)
-    ("3rd-eye-0" 426.7 7.83)
-    ("crown-0" 480 7.83)
+    ("root" 256 7.83)
+    ("navel" 288 7.83)
+    ("solar-plexus" 320 7.83)
+    ("heart" 341.3 7.83)
+    ("throat" 384 7.83)
+    ("3rd-eye" 426.7 7.83)
+    ("crown" 480 7.83)
     )
   "Frequency settings.")
 
@@ -538,9 +513,8 @@ Param `length' specifies total duration."
   (cl-first s)
   (make-sox--binaural
    :beats `(,(cdr s))
-   :gain -10)))
+   :gain -20)))
 
-;;;###autoload
 (defun sox-chakras (theme duration)
   "Play each chakra for specified duration.
 Parameter `theme' specifies variant."
@@ -549,7 +523,8 @@ Parameter `theme' specifies variant."
     (intern
      (completing-read  "Chakra Theme Variant: "
                        '("sox--chakra-settings-0" "sox--chakra-settings-1")
-                       nil 'must-match))
+                       nil 'must-match
+                       "sox--chakra-settings-"))
     (timer-duration (read-from-minibuffer "Chakra Duration: "))))
   (let ((names  (mapcar #'car (symbol-value theme)))
         (start 0))
@@ -615,7 +590,6 @@ Freq can be specified as a frequency, note (%nn) or frequency range."
                   1.3 1 .76 .54 .27 remix - fade h 0 2.7 2.5 norm -1 channels 2"
   "Command-line that produces a simple chime.")
 
-;;;###autoload
 (defun sox-chime (&optional tempo speed)
   "Play chime --- optional args tempo and speed default to 1."
   (cl-declare (special sox-chime-cmd))
@@ -630,20 +604,21 @@ Freq can be specified as a frequency, note (%nn) or frequency range."
 
 (defconst sox-multiwindow-cmd
   "-q -n synth -j 3 \
-sin %-5 sin %-2 \
+%s %%-5 %s %%-2 \
 fade h 0.2 0.7 0.5 \
 delay 0.1 0.5 \
 echo .9 .5 40 0.5 60 0.3 5 0.2 \
-channels 2 tempo 1.3   gain -4"
-  "Chime used to indicate multiple windows.")
+channels 2 tempo 1.3   gain -10"
+  "Chime used to indicate multiple windows.
+%s is an op --- either sin or pluck.")
 
-;;;###autoload
-(defun sox-multiwindow (&optional swap  speed)
+(defun sox-multiwindow (&optional swap  speed op)
   "Produce a short note used to cue multiwindow."
   (cl-declare (special sox-multiwindow-cmd))
+  (or op (setq op "sin"))
   (sox-gen-cmd
    (concat
-    sox-multiwindow-cmd
+    (format  sox-multiwindow-cmd op op )
     (when swap " swap ")
     (when speed (format " speed %s" speed)))))
 
@@ -657,7 +632,6 @@ delay 0.1 0.5 \
 tempo 2 channels 2"
   "A quick scroll sound.")
 
-;;;###autoload
 (defun sox-do-scroll-up (&optional  speed)
   "Produce a short do-scroll-up."
   (cl-declare (special sox-do-scroll-up-cmd))
@@ -673,7 +647,6 @@ delay 0.5 0.1 \
 tempo 2 channels 2   "
   "A quick scroll sound.")
 
-;;;###autoload
 (defun sox-do-scroll-down (&optional speed)
   "Produce a short do-scroll-down."
   (cl-declare (special sox-do-scroll-down-cmd))
@@ -693,7 +666,6 @@ delay  1.3 1 .76 .54 .27 \
   norm -1 channels 2"
   "Command-line that produces a sequence of  tones.")
 
-;;;###autoload
 (defun sox-tones (&optional tempo speed)
   "Play sequence of tones --- optional args tempo and speed default to 1."
   (cl-declare (special sox-tones-cmd))
@@ -724,9 +696,8 @@ remix - fade 0 4 .1 norm -1 channels 2"
 (provide 'sox-gen)
 ;;{{{ end of file
 
-;;; local variables:
-;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end:
+;; local variables:
+;; folded-file: t
+;; end:
 
 ;;}}}
