@@ -1,6 +1,6 @@
 #$Id$
-# {{{ LCD Entry: 
-#x
+#{{{ LCD Entry: 
+#
 # LCD Archive Entry:
 # emacspeak| T. V. Raman |raman@cs.cornell.edu
 # A speech interface to Emacs |
@@ -9,11 +9,11 @@
 # Location undetermined
 #
 
-# }}}
-# {{{ Copyright:
+#}}}
+#{{{ Copyright:
 
 #x
-#Copyright (C) 1995 -- 2007, T. V. Raman 
+#Copyright (C) 1995 -- 2022, T. V. Raman 
 #All Rights Reserved
 # Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 # All Rights Reserved. 
@@ -32,20 +32,18 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with GNU Emacs; see the file COPYING.  If not, write to
-# the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+# the Free Software Foundation, 51 Franklin Street, Fifth Floor, Boston,MA 02110-1301, USA.
 #
 
-# }}}
-# {{{ sync state 
-proc tts_sync_state {punct capitalize allcaps splitcaps rate} {
+#}}}
+#{{{ sync state 
+proc tts_sync_state {punct  splitcaps rate } {
     tts_set_punctuations  $punct
-    tts_capitalize  $capitalize
-    tts_allcaps_beep  $allcaps
     tts_split_caps   $splitcaps
     tts_set_speech_rate  $rate
 } 
-# }}}
-# {{{ queue:
+#}}}
+#{{{ queue:
 
 #currently we use an inlined version of this test in speech_task
 
@@ -187,18 +185,18 @@ proc queue_restore {} {
     set tts(q_tail) $tail
 }
 
-# }}}
-# {{{sounds: 
+#}}}
+#{{{sounds: 
 
 #play a sound over the server
 proc p {sound} {
     global tts
-    catch "exec $tts(play) -q $tts(play_dev) $sound &" errcode
+    catch "exec $tts(play) $tts(play_dev) $sound &" errcode
     speech_task
 }
 
-# }}}
-# {{{beep  
+#}}}
+#{{{beep  
 
 #you need to have beep installed 
 
@@ -209,17 +207,17 @@ proc beep_initialize {} {
         set tts(beep) 1
     }
 }
-
+# length is in milliseconds with a 10ms fade-in and fade-out.
 proc beep {{freq 523} {length 100}} {
     set l  [expr $length / 1000.0]
-    set f  [expr $freq + 2]
         # equal 10ms fade at start and end:
-        exec play -q -n synth $l sin $freq sin $f fade  0.01    0 channels 2 > /dev/null &
+        exec play -q -n  synth $l sin $freq  sin $freq \
+        fade  h 0.01 0  delay 0 0.01 channels 2 > /dev/null &
 }
 
 
-# }}}
-# {{{self test 
+#}}}
+#{{{self test 
 
 proc tts_selftest {} {
      loop i 1 10 {
@@ -229,8 +227,8 @@ proc tts_selftest {} {
 }
 
 
-# }}}
-# {{{guessing os   and port 
+#}}}
+#{{{guessing os   and port 
 
 proc which_os {} {
 global env
@@ -287,8 +285,8 @@ proc which_port {{os Linux}} {
     return $port
 }
 
-# }}}
-# {{{tts setserial 
+#}}}
+#{{{tts setserial 
 
 proc tts_setserial {} {
     global tts
@@ -326,8 +324,8 @@ proc tts_setserial {} {
     fcntl $tts(write) nobuf 1
 }
 
-# }}}
-# {{{tts initialize  
+#}}}
+#{{{tts initialize  
 
 proc tts_initialize {} {
     global tts backup  queue env
@@ -350,7 +348,7 @@ proc tts_initialize {} {
     if {[info exists env(EMACSPEAK_PLAY_PROGRAM)] } {
         set tts(play)  $env(EMACSPEAK_PLAY_PROGRAM)
     } else {
-        set tts(play) "/usr/bin/aplay"
+        set tts(play) "/usr/bin/aplay -q"
     }
 # aplay device options:
     if {[info exists env(ALSA_DEFAULT)] } {
@@ -370,13 +368,13 @@ proc tts_initialize {} {
     set tts(not_stopped) 1
 }
 
-# }}}
-# {{{ Emacs local variables  
+#}}}
+#{{{ Emacs local variables  
 
 ### Local variables:
-### major-mode: tcl-mode 
+### mode: tcl
 ### voice-lock-mode: t
 ### folded-file: t
 ### End:
 
-# }}}
+#}}}
